/* Automatically @generated by tree-sitter v0.25.10 */

#include "tree_sitter/parser.h"

#if defined(__GNUC__) || defined(__clang__)
#pragma GCC diagnostic ignored "-Wmissing-field-initializers"
#endif

#define LANGUAGE_VERSION 14
#define STATE_COUNT 832
#define LARGE_STATE_COUNT 2
#define SYMBOL_COUNT 96
#define ALIAS_COUNT 0
#define TOKEN_COUNT 43
#define EXTERNAL_TOKEN_COUNT 7
#define FIELD_COUNT 0
#define MAX_ALIAS_SEQUENCE_LENGTH 7
#define MAX_RESERVED_WORD_SET_SIZE 0
#define PRODUCTION_ID_COUNT 1
#define SUPERTYPE_COUNT 0

enum ts_symbol_identifiers {
  sym__escape_identity = 1,
  anon_sym_BSLASHt = 2,
  anon_sym_BSLASHr = 3,
  anon_sym_BSLASHn = 4,
  anon_sym_SEMI = 5,
  anon_sym_BSLASH_SEMI = 6,
  aux_sym_variable_token1 = 7,
  anon_sym_DOLLAR = 8,
  anon_sym_LBRACE = 9,
  anon_sym_RBRACE = 10,
  anon_sym_ENV = 11,
  anon_sym_CACHE = 12,
  aux_sym__untrimmed_argument_token1 = 13,
  anon_sym_LPAREN = 14,
  anon_sym_RPAREN = 15,
  anon_sym_DQUOTE = 16,
  aux_sym__quoted_text_token1 = 17,
  aux_sym__unquoted_text_token1 = 18,
  aux_sym_if_command_token1 = 19,
  aux_sym_endwhile_command_token1 = 20,
  sym_if = 21,
  sym_elseif = 22,
  sym_else = 23,
  sym_endif = 24,
  sym_foreach = 25,
  sym_endforeach = 26,
  sym_while = 27,
  sym_endwhile = 28,
  sym_function = 29,
  sym_endfunction = 30,
  sym_macro = 31,
  sym_endmacro = 32,
  sym_block = 33,
  sym_endblock = 34,
  sym_identifier = 35,
  sym_bracket_argument_open = 36,
  sym_bracket_argument_content = 37,
  sym_bracket_argument_close = 38,
  sym_bracket_comment_open = 39,
  sym_bracket_comment_content = 40,
  sym_bracket_comment_close = 41,
  sym_line_comment = 42,
  sym_source_file = 43,
  sym_escape_sequence = 44,
  sym__escape_encoded = 45,
  sym__escape_semicolon = 46,
  sym_variable = 47,
  sym_variable_ref = 48,
  sym_normal_var = 49,
  sym_env_var = 50,
  sym_cache_var = 51,
  sym_bracket_argument = 52,
  sym_bracket_comment = 53,
  sym_argument = 54,
  sym__untrimmed_argument = 55,
  sym__paren_argument = 56,
  sym_quoted_argument = 57,
  sym_quoted_element = 58,
  sym__quoted_text = 59,
  sym_unquoted_argument = 60,
  sym__unquoted_text = 61,
  sym_body = 62,
  sym_argument_list = 63,
  sym_if_command = 64,
  sym_elseif_command = 65,
  sym_else_command = 66,
  sym_endif_command = 67,
  sym_if_condition = 68,
  sym_foreach_command = 69,
  sym_endforeach_command = 70,
  sym_foreach_loop = 71,
  sym_while_command = 72,
  sym_endwhile_command = 73,
  sym_while_loop = 74,
  sym_function_command = 75,
  sym_endfunction_command = 76,
  sym_function_def = 77,
  sym_macro_command = 78,
  sym_endmacro_command = 79,
  sym_macro_def = 80,
  sym_block_command = 81,
  sym_endblock_command = 82,
  sym_block_def = 83,
  sym_normal_command = 84,
  sym__command_invocation = 85,
  sym__untrimmed_command_invocation = 86,
  aux_sym_source_file_repeat1 = 87,
  aux_sym_variable_repeat1 = 88,
  aux_sym__paren_argument_repeat1 = 89,
  aux_sym_quoted_element_repeat1 = 90,
  aux_sym__quoted_text_repeat1 = 91,
  aux_sym_unquoted_argument_repeat1 = 92,
  aux_sym__unquoted_text_repeat1 = 93,
  aux_sym_if_command_repeat1 = 94,
  aux_sym_if_condition_repeat1 = 95,
};

static const char * const ts_symbol_names[] = {
  [ts_builtin_sym_end] = "end",
  [sym__escape_identity] = "_escape_identity",
  [anon_sym_BSLASHt] = "\\t",
  [anon_sym_BSLASHr] = "\\r",
  [anon_sym_BSLASHn] = "\\n",
  [anon_sym_SEMI] = ";",
  [anon_sym_BSLASH_SEMI] = "\\;",
  [aux_sym_variable_token1] = "variable_token1",
  [anon_sym_DOLLAR] = "$",
  [anon_sym_LBRACE] = "{",
  [anon_sym_RBRACE] = "}",
  [anon_sym_ENV] = "ENV",
  [anon_sym_CACHE] = "CACHE",
  [aux_sym__untrimmed_argument_token1] = "_untrimmed_argument_token1",
  [anon_sym_LPAREN] = "(",
  [anon_sym_RPAREN] = ")",
  [anon_sym_DQUOTE] = "\"",
  [aux_sym__quoted_text_token1] = "_quoted_text_token1",
  [aux_sym__unquoted_text_token1] = "_unquoted_text_token1",
  [aux_sym_if_command_token1] = "if_command_token1",
  [aux_sym_endwhile_command_token1] = "endwhile_command_token1",
  [sym_if] = "if",
  [sym_elseif] = "elseif",
  [sym_else] = "else",
  [sym_endif] = "endif",
  [sym_foreach] = "foreach",
  [sym_endforeach] = "endforeach",
  [sym_while] = "while",
  [sym_endwhile] = "endwhile",
  [sym_function] = "function",
  [sym_endfunction] = "endfunction",
  [sym_macro] = "macro",
  [sym_endmacro] = "endmacro",
  [sym_block] = "block",
  [sym_endblock] = "endblock",
  [sym_identifier] = "identifier",
  [sym_bracket_argument_open] = "bracket_argument_open",
  [sym_bracket_argument_content] = "bracket_argument_content",
  [sym_bracket_argument_close] = "bracket_argument_close",
  [sym_bracket_comment_open] = "bracket_comment_open",
  [sym_bracket_comment_content] = "bracket_comment_content",
  [sym_bracket_comment_close] = "bracket_comment_close",
  [sym_line_comment] = "line_comment",
  [sym_source_file] = "source_file",
  [sym_escape_sequence] = "escape_sequence",
  [sym__escape_encoded] = "_escape_encoded",
  [sym__escape_semicolon] = "_escape_semicolon",
  [sym_variable] = "variable",
  [sym_variable_ref] = "variable_ref",
  [sym_normal_var] = "normal_var",
  [sym_env_var] = "env_var",
  [sym_cache_var] = "cache_var",
  [sym_bracket_argument] = "bracket_argument",
  [sym_bracket_comment] = "bracket_comment",
  [sym_argument] = "argument",
  [sym__untrimmed_argument] = "_untrimmed_argument",
  [sym__paren_argument] = "_paren_argument",
  [sym_quoted_argument] = "quoted_argument",
  [sym_quoted_element] = "quoted_element",
  [sym__quoted_text] = "_quoted_text",
  [sym_unquoted_argument] = "unquoted_argument",
  [sym__unquoted_text] = "_unquoted_text",
  [sym_body] = "body",
  [sym_argument_list] = "argument_list",
  [sym_if_command] = "if_command",
  [sym_elseif_command] = "elseif_command",
  [sym_else_command] = "else_command",
  [sym_endif_command] = "endif_command",
  [sym_if_condition] = "if_condition",
  [sym_foreach_command] = "foreach_command",
  [sym_endforeach_command] = "endforeach_command",
  [sym_foreach_loop] = "foreach_loop",
  [sym_while_command] = "while_command",
  [sym_endwhile_command] = "endwhile_command",
  [sym_while_loop] = "while_loop",
  [sym_function_command] = "function_command",
  [sym_endfunction_command] = "endfunction_command",
  [sym_function_def] = "function_def",
  [sym_macro_command] = "macro_command",
  [sym_endmacro_command] = "endmacro_command",
  [sym_macro_def] = "macro_def",
  [sym_block_command] = "block_command",
  [sym_endblock_command] = "endblock_command",
  [sym_block_def] = "block_def",
  [sym_normal_command] = "normal_command",
  [sym__command_invocation] = "_command_invocation",
  [sym__untrimmed_command_invocation] = "_untrimmed_command_invocation",
  [aux_sym_source_file_repeat1] = "source_file_repeat1",
  [aux_sym_variable_repeat1] = "variable_repeat1",
  [aux_sym__paren_argument_repeat1] = "_paren_argument_repeat1",
  [aux_sym_quoted_element_repeat1] = "quoted_element_repeat1",
  [aux_sym__quoted_text_repeat1] = "_quoted_text_repeat1",
  [aux_sym_unquoted_argument_repeat1] = "unquoted_argument_repeat1",
  [aux_sym__unquoted_text_repeat1] = "_unquoted_text_repeat1",
  [aux_sym_if_command_repeat1] = "if_command_repeat1",
  [aux_sym_if_condition_repeat1] = "if_condition_repeat1",
};

static const TSSymbol ts_symbol_map[] = {
  [ts_builtin_sym_end] = ts_builtin_sym_end,
  [sym__escape_identity] = sym__escape_identity,
  [anon_sym_BSLASHt] = anon_sym_BSLASHt,
  [anon_sym_BSLASHr] = anon_sym_BSLASHr,
  [anon_sym_BSLASHn] = anon_sym_BSLASHn,
  [anon_sym_SEMI] = anon_sym_SEMI,
  [anon_sym_BSLASH_SEMI] = anon_sym_BSLASH_SEMI,
  [aux_sym_variable_token1] = aux_sym_variable_token1,
  [anon_sym_DOLLAR] = anon_sym_DOLLAR,
  [anon_sym_LBRACE] = anon_sym_LBRACE,
  [anon_sym_RBRACE] = anon_sym_RBRACE,
  [anon_sym_ENV] = anon_sym_ENV,
  [anon_sym_CACHE] = anon_sym_CACHE,
  [aux_sym__untrimmed_argument_token1] = aux_sym__untrimmed_argument_token1,
  [anon_sym_LPAREN] = anon_sym_LPAREN,
  [anon_sym_RPAREN] = anon_sym_RPAREN,
  [anon_sym_DQUOTE] = anon_sym_DQUOTE,
  [aux_sym__quoted_text_token1] = aux_sym__quoted_text_token1,
  [aux_sym__unquoted_text_token1] = aux_sym__unquoted_text_token1,
  [aux_sym_if_command_token1] = aux_sym_if_command_token1,
  [aux_sym_endwhile_command_token1] = aux_sym_endwhile_command_token1,
  [sym_if] = sym_if,
  [sym_elseif] = sym_elseif,
  [sym_else] = sym_else,
  [sym_endif] = sym_endif,
  [sym_foreach] = sym_foreach,
  [sym_endforeach] = sym_endforeach,
  [sym_while] = sym_while,
  [sym_endwhile] = sym_endwhile,
  [sym_function] = sym_function,
  [sym_endfunction] = sym_endfunction,
  [sym_macro] = sym_macro,
  [sym_endmacro] = sym_endmacro,
  [sym_block] = sym_block,
  [sym_endblock] = sym_endblock,
  [sym_identifier] = sym_identifier,
  [sym_bracket_argument_open] = sym_bracket_argument_open,
  [sym_bracket_argument_content] = sym_bracket_argument_content,
  [sym_bracket_argument_close] = sym_bracket_argument_close,
  [sym_bracket_comment_open] = sym_bracket_comment_open,
  [sym_bracket_comment_content] = sym_bracket_comment_content,
  [sym_bracket_comment_close] = sym_bracket_comment_close,
  [sym_line_comment] = sym_line_comment,
  [sym_source_file] = sym_source_file,
  [sym_escape_sequence] = sym_escape_sequence,
  [sym__escape_encoded] = sym__escape_encoded,
  [sym__escape_semicolon] = sym__escape_semicolon,
  [sym_variable] = sym_variable,
  [sym_variable_ref] = sym_variable_ref,
  [sym_normal_var] = sym_normal_var,
  [sym_env_var] = sym_env_var,
  [sym_cache_var] = sym_cache_var,
  [sym_bracket_argument] = sym_bracket_argument,
  [sym_bracket_comment] = sym_bracket_comment,
  [sym_argument] = sym_argument,
  [sym__untrimmed_argument] = sym__untrimmed_argument,
  [sym__paren_argument] = sym__paren_argument,
  [sym_quoted_argument] = sym_quoted_argument,
  [sym_quoted_element] = sym_quoted_element,
  [sym__quoted_text] = sym__quoted_text,
  [sym_unquoted_argument] = sym_unquoted_argument,
  [sym__unquoted_text] = sym__unquoted_text,
  [sym_body] = sym_body,
  [sym_argument_list] = sym_argument_list,
  [sym_if_command] = sym_if_command,
  [sym_elseif_command] = sym_elseif_command,
  [sym_else_command] = sym_else_command,
  [sym_endif_command] = sym_endif_command,
  [sym_if_condition] = sym_if_condition,
  [sym_foreach_command] = sym_foreach_command,
  [sym_endforeach_command] = sym_endforeach_command,
  [sym_foreach_loop] = sym_foreach_loop,
  [sym_while_command] = sym_while_command,
  [sym_endwhile_command] = sym_endwhile_command,
  [sym_while_loop] = sym_while_loop,
  [sym_function_command] = sym_function_command,
  [sym_endfunction_command] = sym_endfunction_command,
  [sym_function_def] = sym_function_def,
  [sym_macro_command] = sym_macro_command,
  [sym_endmacro_command] = sym_endmacro_command,
  [sym_macro_def] = sym_macro_def,
  [sym_block_command] = sym_block_command,
  [sym_endblock_command] = sym_endblock_command,
  [sym_block_def] = sym_block_def,
  [sym_normal_command] = sym_normal_command,
  [sym__command_invocation] = sym__command_invocation,
  [sym__untrimmed_command_invocation] = sym__untrimmed_command_invocation,
  [aux_sym_source_file_repeat1] = aux_sym_source_file_repeat1,
  [aux_sym_variable_repeat1] = aux_sym_variable_repeat1,
  [aux_sym__paren_argument_repeat1] = aux_sym__paren_argument_repeat1,
  [aux_sym_quoted_element_repeat1] = aux_sym_quoted_element_repeat1,
  [aux_sym__quoted_text_repeat1] = aux_sym__quoted_text_repeat1,
  [aux_sym_unquoted_argument_repeat1] = aux_sym_unquoted_argument_repeat1,
  [aux_sym__unquoted_text_repeat1] = aux_sym__unquoted_text_repeat1,
  [aux_sym_if_command_repeat1] = aux_sym_if_command_repeat1,
  [aux_sym_if_condition_repeat1] = aux_sym_if_condition_repeat1,
};

static const TSSymbolMetadata ts_symbol_metadata[] = {
  [ts_builtin_sym_end] = {
    .visible = false,
    .named = true,
  },
  [sym__escape_identity] = {
    .visible = false,
    .named = true,
  },
  [anon_sym_BSLASHt] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BSLASHr] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BSLASHn] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SEMI] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BSLASH_SEMI] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_variable_token1] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_DOLLAR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ENV] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_CACHE] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__untrimmed_argument_token1] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_LPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DQUOTE] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__quoted_text_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__unquoted_text_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_if_command_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_endwhile_command_token1] = {
    .visible = false,
    .named = false,
  },
  [sym_if] = {
    .visible = true,
    .named = true,
  },
  [sym_elseif] = {
    .visible = true,
    .named = true,
  },
  [sym_else] = {
    .visible = true,
    .named = true,
  },
  [sym_endif] = {
    .visible = true,
    .named = true,
  },
  [sym_foreach] = {
    .visible = true,
    .named = true,
  },
  [sym_endforeach] = {
    .visible = true,
    .named = true,
  },
  [sym_while] = {
    .visible = true,
    .named = true,
  },
  [sym_endwhile] = {
    .visible = true,
    .named = true,
  },
  [sym_function] = {
    .visible = true,
    .named = true,
  },
  [sym_endfunction] = {
    .visible = true,
    .named = true,
  },
  [sym_macro] = {
    .visible = true,
    .named = true,
  },
  [sym_endmacro] = {
    .visible = true,
    .named = true,
  },
  [sym_block] = {
    .visible = true,
    .named = true,
  },
  [sym_endblock] = {
    .visible = true,
    .named = true,
  },
  [sym_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym_bracket_argument_open] = {
    .visible = true,
    .named = true,
  },
  [sym_bracket_argument_content] = {
    .visible = true,
    .named = true,
  },
  [sym_bracket_argument_close] = {
    .visible = true,
    .named = true,
  },
  [sym_bracket_comment_open] = {
    .visible = true,
    .named = true,
  },
  [sym_bracket_comment_content] = {
    .visible = true,
    .named = true,
  },
  [sym_bracket_comment_close] = {
    .visible = true,
    .named = true,
  },
  [sym_line_comment] = {
    .visible = true,
    .named = true,
  },
  [sym_source_file] = {
    .visible = true,
    .named = true,
  },
  [sym_escape_sequence] = {
    .visible = true,
    .named = true,
  },
  [sym__escape_encoded] = {
    .visible = false,
    .named = true,
  },
  [sym__escape_semicolon] = {
    .visible = false,
    .named = true,
  },
  [sym_variable] = {
    .visible = true,
    .named = true,
  },
  [sym_variable_ref] = {
    .visible = true,
    .named = true,
  },
  [sym_normal_var] = {
    .visible = true,
    .named = true,
  },
  [sym_env_var] = {
    .visible = true,
    .named = true,
  },
  [sym_cache_var] = {
    .visible = true,
    .named = true,
  },
  [sym_bracket_argument] = {
    .visible = true,
    .named = true,
  },
  [sym_bracket_comment] = {
    .visible = true,
    .named = true,
  },
  [sym_argument] = {
    .visible = true,
    .named = true,
  },
  [sym__untrimmed_argument] = {
    .visible = false,
    .named = true,
  },
  [sym__paren_argument] = {
    .visible = false,
    .named = true,
  },
  [sym_quoted_argument] = {
    .visible = true,
    .named = true,
  },
  [sym_quoted_element] = {
    .visible = true,
    .named = true,
  },
  [sym__quoted_text] = {
    .visible = false,
    .named = true,
  },
  [sym_unquoted_argument] = {
    .visible = true,
    .named = true,
  },
  [sym__unquoted_text] = {
    .visible = false,
    .named = true,
  },
  [sym_body] = {
    .visible = true,
    .named = true,
  },
  [sym_argument_list] = {
    .visible = true,
    .named = true,
  },
  [sym_if_command] = {
    .visible = true,
    .named = true,
  },
  [sym_elseif_command] = {
    .visible = true,
    .named = true,
  },
  [sym_else_command] = {
    .visible = true,
    .named = true,
  },
  [sym_endif_command] = {
    .visible = true,
    .named = true,
  },
  [sym_if_condition] = {
    .visible = true,
    .named = true,
  },
  [sym_foreach_command] = {
    .visible = true,
    .named = true,
  },
  [sym_endforeach_command] = {
    .visible = true,
    .named = true,
  },
  [sym_foreach_loop] = {
    .visible = true,
    .named = true,
  },
  [sym_while_command] = {
    .visible = true,
    .named = true,
  },
  [sym_endwhile_command] = {
    .visible = true,
    .named = true,
  },
  [sym_while_loop] = {
    .visible = true,
    .named = true,
  },
  [sym_function_command] = {
    .visible = true,
    .named = true,
  },
  [sym_endfunction_command] = {
    .visible = true,
    .named = true,
  },
  [sym_function_def] = {
    .visible = true,
    .named = true,
  },
  [sym_macro_command] = {
    .visible = true,
    .named = true,
  },
  [sym_endmacro_command] = {
    .visible = true,
    .named = true,
  },
  [sym_macro_def] = {
    .visible = true,
    .named = true,
  },
  [sym_block_command] = {
    .visible = true,
    .named = true,
  },
  [sym_endblock_command] = {
    .visible = true,
    .named = true,
  },
  [sym_block_def] = {
    .visible = true,
    .named = true,
  },
  [sym_normal_command] = {
    .visible = true,
    .named = true,
  },
  [sym__command_invocation] = {
    .visible = false,
    .named = true,
  },
  [sym__untrimmed_command_invocation] = {
    .visible = false,
    .named = true,
  },
  [aux_sym_source_file_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_variable_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__paren_argument_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_quoted_element_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__quoted_text_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_unquoted_argument_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__unquoted_text_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_if_command_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_if_condition_repeat1] = {
    .visible = false,
    .named = false,
  },
};

static const TSSymbol ts_alias_sequences[PRODUCTION_ID_COUNT][MAX_ALIAS_SEQUENCE_LENGTH] = {
  [0] = {0},
};

static const uint16_t ts_non_terminal_alias_map[] = {
  0,
};

static const TSStateId ts_primary_state_ids[STATE_COUNT] = {
  [0] = 0,
  [1] = 1,
  [2] = 2,
  [3] = 3,
  [4] = 2,
  [5] = 3,
  [6] = 3,
  [7] = 2,
  [8] = 3,
  [9] = 2,
  [10] = 3,
  [11] = 2,
  [12] = 3,
  [13] = 2,
  [14] = 3,
  [15] = 2,
  [16] = 16,
  [17] = 17,
  [18] = 18,
  [19] = 19,
  [20] = 20,
  [21] = 21,
  [22] = 22,
  [23] = 23,
  [24] = 16,
  [25] = 25,
  [26] = 26,
  [27] = 27,
  [28] = 28,
  [29] = 17,
  [30] = 30,
  [31] = 31,
  [32] = 19,
  [33] = 21,
  [34] = 25,
  [35] = 26,
  [36] = 27,
  [37] = 28,
  [38] = 17,
  [39] = 30,
  [40] = 31,
  [41] = 19,
  [42] = 21,
  [43] = 16,
  [44] = 25,
  [45] = 26,
  [46] = 27,
  [47] = 28,
  [48] = 30,
  [49] = 30,
  [50] = 31,
  [51] = 19,
  [52] = 21,
  [53] = 16,
  [54] = 25,
  [55] = 26,
  [56] = 27,
  [57] = 28,
  [58] = 17,
  [59] = 30,
  [60] = 31,
  [61] = 19,
  [62] = 21,
  [63] = 16,
  [64] = 25,
  [65] = 26,
  [66] = 27,
  [67] = 28,
  [68] = 17,
  [69] = 30,
  [70] = 70,
  [71] = 31,
  [72] = 31,
  [73] = 19,
  [74] = 21,
  [75] = 16,
  [76] = 25,
  [77] = 26,
  [78] = 27,
  [79] = 28,
  [80] = 17,
  [81] = 30,
  [82] = 31,
  [83] = 19,
  [84] = 21,
  [85] = 16,
  [86] = 25,
  [87] = 26,
  [88] = 27,
  [89] = 28,
  [90] = 17,
  [91] = 91,
  [92] = 92,
  [93] = 93,
  [94] = 94,
  [95] = 95,
  [96] = 96,
  [97] = 97,
  [98] = 98,
  [99] = 99,
  [100] = 100,
  [101] = 101,
  [102] = 102,
  [103] = 103,
  [104] = 104,
  [105] = 105,
  [106] = 106,
  [107] = 107,
  [108] = 108,
  [109] = 108,
  [110] = 107,
  [111] = 108,
  [112] = 107,
  [113] = 108,
  [114] = 107,
  [115] = 108,
  [116] = 107,
  [117] = 108,
  [118] = 108,
  [119] = 119,
  [120] = 120,
  [121] = 121,
  [122] = 122,
  [123] = 123,
  [124] = 107,
  [125] = 125,
  [126] = 125,
  [127] = 119,
  [128] = 120,
  [129] = 122,
  [130] = 122,
  [131] = 125,
  [132] = 119,
  [133] = 120,
  [134] = 121,
  [135] = 122,
  [136] = 125,
  [137] = 119,
  [138] = 120,
  [139] = 121,
  [140] = 122,
  [141] = 125,
  [142] = 119,
  [143] = 120,
  [144] = 121,
  [145] = 122,
  [146] = 125,
  [147] = 119,
  [148] = 120,
  [149] = 121,
  [150] = 122,
  [151] = 125,
  [152] = 119,
  [153] = 120,
  [154] = 121,
  [155] = 121,
  [156] = 156,
  [157] = 157,
  [158] = 158,
  [159] = 156,
  [160] = 158,
  [161] = 158,
  [162] = 156,
  [163] = 158,
  [164] = 156,
  [165] = 158,
  [166] = 166,
  [167] = 156,
  [168] = 158,
  [169] = 158,
  [170] = 156,
  [171] = 156,
  [172] = 172,
  [173] = 173,
  [174] = 172,
  [175] = 172,
  [176] = 173,
  [177] = 172,
  [178] = 173,
  [179] = 172,
  [180] = 173,
  [181] = 172,
  [182] = 173,
  [183] = 173,
  [184] = 172,
  [185] = 173,
  [186] = 186,
  [187] = 186,
  [188] = 186,
  [189] = 157,
  [190] = 166,
  [191] = 191,
  [192] = 166,
  [193] = 193,
  [194] = 157,
  [195] = 195,
  [196] = 196,
  [197] = 196,
  [198] = 198,
  [199] = 199,
  [200] = 200,
  [201] = 198,
  [202] = 199,
  [203] = 196,
  [204] = 196,
  [205] = 198,
  [206] = 199,
  [207] = 207,
  [208] = 198,
  [209] = 196,
  [210] = 198,
  [211] = 199,
  [212] = 199,
  [213] = 213,
  [214] = 214,
  [215] = 215,
  [216] = 216,
  [217] = 217,
  [218] = 218,
  [219] = 219,
  [220] = 220,
  [221] = 221,
  [222] = 222,
  [223] = 223,
  [224] = 224,
  [225] = 225,
  [226] = 226,
  [227] = 227,
  [228] = 228,
  [229] = 229,
  [230] = 230,
  [231] = 231,
  [232] = 232,
  [233] = 233,
  [234] = 234,
  [235] = 235,
  [236] = 219,
  [237] = 237,
  [238] = 238,
  [239] = 239,
  [240] = 240,
  [241] = 241,
  [242] = 242,
  [243] = 243,
  [244] = 244,
  [245] = 245,
  [246] = 246,
  [247] = 247,
  [248] = 248,
  [249] = 249,
  [250] = 250,
  [251] = 251,
  [252] = 252,
  [253] = 253,
  [254] = 254,
  [255] = 255,
  [256] = 256,
  [257] = 257,
  [258] = 258,
  [259] = 259,
  [260] = 260,
  [261] = 261,
  [262] = 262,
  [263] = 263,
  [264] = 195,
  [265] = 195,
  [266] = 227,
  [267] = 238,
  [268] = 258,
  [269] = 249,
  [270] = 230,
  [271] = 237,
  [272] = 244,
  [273] = 231,
  [274] = 243,
  [275] = 252,
  [276] = 227,
  [277] = 229,
  [278] = 233,
  [279] = 234,
  [280] = 226,
  [281] = 240,
  [282] = 241,
  [283] = 262,
  [284] = 242,
  [285] = 239,
  [286] = 219,
  [287] = 250,
  [288] = 251,
  [289] = 253,
  [290] = 254,
  [291] = 255,
  [292] = 256,
  [293] = 257,
  [294] = 259,
  [295] = 260,
  [296] = 261,
  [297] = 238,
  [298] = 258,
  [299] = 249,
  [300] = 230,
  [301] = 237,
  [302] = 244,
  [303] = 231,
  [304] = 243,
  [305] = 252,
  [306] = 227,
  [307] = 229,
  [308] = 233,
  [309] = 234,
  [310] = 226,
  [311] = 240,
  [312] = 241,
  [313] = 262,
  [314] = 242,
  [315] = 239,
  [316] = 219,
  [317] = 250,
  [318] = 251,
  [319] = 253,
  [320] = 254,
  [321] = 255,
  [322] = 256,
  [323] = 257,
  [324] = 259,
  [325] = 260,
  [326] = 261,
  [327] = 238,
  [328] = 258,
  [329] = 249,
  [330] = 230,
  [331] = 237,
  [332] = 244,
  [333] = 231,
  [334] = 243,
  [335] = 252,
  [336] = 227,
  [337] = 229,
  [338] = 233,
  [339] = 234,
  [340] = 226,
  [341] = 240,
  [342] = 241,
  [343] = 262,
  [344] = 242,
  [345] = 239,
  [346] = 260,
  [347] = 219,
  [348] = 250,
  [349] = 251,
  [350] = 253,
  [351] = 254,
  [352] = 255,
  [353] = 256,
  [354] = 257,
  [355] = 259,
  [356] = 260,
  [357] = 261,
  [358] = 238,
  [359] = 258,
  [360] = 249,
  [361] = 230,
  [362] = 261,
  [363] = 244,
  [364] = 231,
  [365] = 243,
  [366] = 252,
  [367] = 227,
  [368] = 229,
  [369] = 233,
  [370] = 234,
  [371] = 226,
  [372] = 240,
  [373] = 241,
  [374] = 262,
  [375] = 242,
  [376] = 239,
  [377] = 219,
  [378] = 250,
  [379] = 251,
  [380] = 253,
  [381] = 254,
  [382] = 255,
  [383] = 256,
  [384] = 257,
  [385] = 259,
  [386] = 260,
  [387] = 261,
  [388] = 238,
  [389] = 258,
  [390] = 249,
  [391] = 230,
  [392] = 237,
  [393] = 244,
  [394] = 231,
  [395] = 243,
  [396] = 252,
  [397] = 229,
  [398] = 233,
  [399] = 234,
  [400] = 226,
  [401] = 240,
  [402] = 241,
  [403] = 262,
  [404] = 242,
  [405] = 259,
  [406] = 261,
  [407] = 238,
  [408] = 258,
  [409] = 249,
  [410] = 230,
  [411] = 237,
  [412] = 250,
  [413] = 244,
  [414] = 231,
  [415] = 243,
  [416] = 252,
  [417] = 227,
  [418] = 229,
  [419] = 233,
  [420] = 239,
  [421] = 234,
  [422] = 226,
  [423] = 240,
  [424] = 241,
  [425] = 262,
  [426] = 242,
  [427] = 251,
  [428] = 253,
  [429] = 254,
  [430] = 255,
  [431] = 256,
  [432] = 257,
  [433] = 219,
  [434] = 239,
  [435] = 219,
  [436] = 259,
  [437] = 250,
  [438] = 260,
  [439] = 251,
  [440] = 253,
  [441] = 254,
  [442] = 255,
  [443] = 256,
  [444] = 257,
  [445] = 237,
  [446] = 446,
  [447] = 447,
  [448] = 448,
  [449] = 449,
  [450] = 450,
  [451] = 451,
  [452] = 213,
  [453] = 453,
  [454] = 454,
  [455] = 455,
  [456] = 456,
  [457] = 457,
  [458] = 458,
  [459] = 213,
  [460] = 214,
  [461] = 221,
  [462] = 217,
  [463] = 215,
  [464] = 214,
  [465] = 221,
  [466] = 214,
  [467] = 221,
  [468] = 217,
  [469] = 215,
  [470] = 215,
  [471] = 216,
  [472] = 217,
  [473] = 215,
  [474] = 216,
  [475] = 216,
  [476] = 216,
  [477] = 214,
  [478] = 221,
  [479] = 217,
  [480] = 480,
  [481] = 481,
  [482] = 482,
  [483] = 483,
  [484] = 484,
  [485] = 485,
  [486] = 486,
  [487] = 487,
  [488] = 488,
  [489] = 489,
  [490] = 490,
  [491] = 491,
  [492] = 492,
  [493] = 493,
  [494] = 494,
  [495] = 495,
  [496] = 496,
  [497] = 497,
  [498] = 480,
  [499] = 499,
  [500] = 500,
  [501] = 483,
  [502] = 486,
  [503] = 490,
  [504] = 491,
  [505] = 493,
  [506] = 496,
  [507] = 480,
  [508] = 487,
  [509] = 488,
  [510] = 492,
  [511] = 497,
  [512] = 512,
  [513] = 513,
  [514] = 495,
  [515] = 500,
  [516] = 483,
  [517] = 486,
  [518] = 490,
  [519] = 491,
  [520] = 493,
  [521] = 496,
  [522] = 487,
  [523] = 488,
  [524] = 492,
  [525] = 497,
  [526] = 512,
  [527] = 495,
  [528] = 528,
  [529] = 512,
  [530] = 500,
  [531] = 486,
  [532] = 490,
  [533] = 491,
  [534] = 493,
  [535] = 496,
  [536] = 480,
  [537] = 487,
  [538] = 488,
  [539] = 492,
  [540] = 497,
  [541] = 512,
  [542] = 495,
  [543] = 495,
  [544] = 500,
  [545] = 545,
  [546] = 546,
  [547] = 500,
  [548] = 483,
  [549] = 486,
  [550] = 490,
  [551] = 491,
  [552] = 493,
  [553] = 496,
  [554] = 480,
  [555] = 487,
  [556] = 488,
  [557] = 492,
  [558] = 497,
  [559] = 512,
  [560] = 560,
  [561] = 495,
  [562] = 562,
  [563] = 500,
  [564] = 483,
  [565] = 486,
  [566] = 490,
  [567] = 491,
  [568] = 493,
  [569] = 496,
  [570] = 480,
  [571] = 487,
  [572] = 488,
  [573] = 492,
  [574] = 497,
  [575] = 512,
  [576] = 495,
  [577] = 577,
  [578] = 578,
  [579] = 500,
  [580] = 483,
  [581] = 486,
  [582] = 490,
  [583] = 491,
  [584] = 493,
  [585] = 496,
  [586] = 480,
  [587] = 487,
  [588] = 488,
  [589] = 492,
  [590] = 497,
  [591] = 512,
  [592] = 592,
  [593] = 593,
  [594] = 594,
  [595] = 483,
  [596] = 596,
  [597] = 597,
  [598] = 598,
  [599] = 599,
  [600] = 597,
  [601] = 598,
  [602] = 602,
  [603] = 603,
  [604] = 599,
  [605] = 599,
  [606] = 602,
  [607] = 602,
  [608] = 603,
  [609] = 599,
  [610] = 610,
  [611] = 610,
  [612] = 602,
  [613] = 596,
  [614] = 603,
  [615] = 596,
  [616] = 597,
  [617] = 603,
  [618] = 596,
  [619] = 603,
  [620] = 596,
  [621] = 597,
  [622] = 598,
  [623] = 599,
  [624] = 598,
  [625] = 602,
  [626] = 602,
  [627] = 610,
  [628] = 603,
  [629] = 597,
  [630] = 599,
  [631] = 602,
  [632] = 610,
  [633] = 598,
  [634] = 610,
  [635] = 610,
  [636] = 610,
  [637] = 598,
  [638] = 596,
  [639] = 598,
  [640] = 603,
  [641] = 596,
  [642] = 597,
  [643] = 599,
  [644] = 597,
  [645] = 645,
  [646] = 646,
  [647] = 647,
  [648] = 648,
  [649] = 218,
  [650] = 650,
  [651] = 651,
  [652] = 652,
  [653] = 653,
  [654] = 654,
  [655] = 655,
  [656] = 656,
  [657] = 646,
  [658] = 652,
  [659] = 654,
  [660] = 660,
  [661] = 661,
  [662] = 662,
  [663] = 663,
  [664] = 664,
  [665] = 665,
  [666] = 666,
  [667] = 660,
  [668] = 661,
  [669] = 662,
  [670] = 670,
  [671] = 651,
  [672] = 670,
  [673] = 673,
  [674] = 674,
  [675] = 647,
  [676] = 648,
  [677] = 663,
  [678] = 678,
  [679] = 651,
  [680] = 223,
  [681] = 653,
  [682] = 653,
  [683] = 683,
  [684] = 655,
  [685] = 656,
  [686] = 686,
  [687] = 687,
  [688] = 688,
  [689] = 689,
  [690] = 664,
  [691] = 646,
  [692] = 692,
  [693] = 645,
  [694] = 222,
  [695] = 225,
  [696] = 652,
  [697] = 654,
  [698] = 660,
  [699] = 673,
  [700] = 661,
  [701] = 662,
  [702] = 655,
  [703] = 663,
  [704] = 650,
  [705] = 665,
  [706] = 706,
  [707] = 664,
  [708] = 708,
  [709] = 663,
  [710] = 650,
  [711] = 650,
  [712] = 665,
  [713] = 686,
  [714] = 688,
  [715] = 689,
  [716] = 664,
  [717] = 656,
  [718] = 683,
  [719] = 665,
  [720] = 663,
  [721] = 687,
  [722] = 674,
  [723] = 670,
  [724] = 683,
  [725] = 656,
  [726] = 665,
  [727] = 674,
  [728] = 647,
  [729] = 648,
  [730] = 646,
  [731] = 673,
  [732] = 674,
  [733] = 651,
  [734] = 688,
  [735] = 653,
  [736] = 647,
  [737] = 655,
  [738] = 738,
  [739] = 688,
  [740] = 689,
  [741] = 664,
  [742] = 648,
  [743] = 686,
  [744] = 744,
  [745] = 222,
  [746] = 646,
  [747] = 652,
  [748] = 654,
  [749] = 660,
  [750] = 661,
  [751] = 662,
  [752] = 650,
  [753] = 663,
  [754] = 652,
  [755] = 755,
  [756] = 756,
  [757] = 757,
  [758] = 674,
  [759] = 647,
  [760] = 648,
  [761] = 761,
  [762] = 650,
  [763] = 763,
  [764] = 688,
  [765] = 689,
  [766] = 664,
  [767] = 654,
  [768] = 651,
  [769] = 769,
  [770] = 656,
  [771] = 665,
  [772] = 772,
  [773] = 660,
  [774] = 651,
  [775] = 775,
  [776] = 653,
  [777] = 777,
  [778] = 661,
  [779] = 647,
  [780] = 648,
  [781] = 689,
  [782] = 655,
  [783] = 651,
  [784] = 653,
  [785] = 653,
  [786] = 688,
  [787] = 689,
  [788] = 664,
  [789] = 686,
  [790] = 655,
  [791] = 687,
  [792] = 646,
  [793] = 652,
  [794] = 218,
  [795] = 654,
  [796] = 660,
  [797] = 661,
  [798] = 662,
  [799] = 646,
  [800] = 663,
  [801] = 662,
  [802] = 652,
  [803] = 654,
  [804] = 660,
  [805] = 661,
  [806] = 662,
  [807] = 647,
  [808] = 688,
  [809] = 689,
  [810] = 664,
  [811] = 692,
  [812] = 645,
  [813] = 656,
  [814] = 650,
  [815] = 692,
  [816] = 663,
  [817] = 225,
  [818] = 656,
  [819] = 692,
  [820] = 645,
  [821] = 665,
  [822] = 648,
  [823] = 692,
  [824] = 645,
  [825] = 655,
  [826] = 826,
  [827] = 223,
  [828] = 828,
  [829] = 686,
  [830] = 687,
  [831] = 687,
};

static bool ts_lex(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      if (eof) ADVANCE(20);
      ADVANCE_MAP(
        '"', 36,
        '$', 28,
        '(', 34,
        ')', 35,
        ';', 25,
        'C', 41,
        'E', 42,
        '\\', 8,
        '{', 29,
        '\t', 33,
        ' ', 33,
      );
      if (('\n' <= lookahead && lookahead <= '\r')) ADVANCE(33);
      if (lookahead != 0 &&
          (lookahead < '"' || '$' < lookahead)) ADVANCE(40);
      END_STATE();
    case 1:
      ADVANCE_MAP(
        '"', 36,
        '$', 28,
        '(', 34,
        ')', 35,
        ';', 25,
        'C', 41,
        'E', 42,
        '\\', 8,
        '{', 29,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(33);
      if (lookahead != 0 &&
          (lookahead < '"' || '$' < lookahead)) ADVANCE(40);
      END_STATE();
    case 2:
      if (lookahead == '"') ADVANCE(36);
      if (lookahead == '$') ADVANCE(28);
      if (lookahead == '(') ADVANCE(34);
      if (lookahead == ')') ADVANCE(35);
      if (lookahead == ';') ADVANCE(25);
      if (lookahead == '\\') ADVANCE(8);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(33);
      if (lookahead != 0 &&
          (lookahead < '"' || '$' < lookahead)) ADVANCE(40);
      END_STATE();
    case 3:
      if (lookahead == '"') ADVANCE(36);
      if (lookahead == '$') ADVANCE(28);
      if (lookahead == ')') ADVANCE(35);
      if (lookahead == ';') ADVANCE(25);
      if (lookahead == '\\') ADVANCE(8);
      if (lookahead != 0 &&
          (lookahead < '"' || '$' < lookahead) &&
          lookahead != '(' &&
          lookahead != ')') ADVANCE(40);
      END_STATE();
    case 4:
      if (lookahead == '"') ADVANCE(36);
      if (lookahead == '$') ADVANCE(28);
      if (lookahead == ';') ADVANCE(25);
      if (lookahead == 'C') ADVANCE(38);
      if (lookahead == 'E') ADVANCE(39);
      if (lookahead == '\\') ADVANCE(8);
      if (lookahead == '{') ADVANCE(29);
      if (lookahead != 0) ADVANCE(37);
      END_STATE();
    case 5:
      if (lookahead == '"') ADVANCE(36);
      if (lookahead == '$') ADVANCE(28);
      if (lookahead == ';') ADVANCE(25);
      if (lookahead == '\\') ADVANCE(8);
      if (lookahead != 0) ADVANCE(37);
      END_STATE();
    case 6:
      if (lookahead == '$') ADVANCE(28);
      if (lookahead == '(') ADVANCE(34);
      if (lookahead == ';') ADVANCE(25);
      if (lookahead == '\\') ADVANCE(8);
      if (lookahead == '}') ADVANCE(30);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(44);
      if (lookahead == '+' ||
          ('-' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(27);
      END_STATE();
    case 7:
      if (lookahead == '$') ADVANCE(28);
      if (lookahead == ')') ADVANCE(35);
      if (lookahead == ';') ADVANCE(25);
      if (lookahead == 'C') ADVANCE(41);
      if (lookahead == 'E') ADVANCE(42);
      if (lookahead == '\\') ADVANCE(8);
      if (lookahead == '{') ADVANCE(29);
      if (lookahead != 0 &&
          (lookahead < '"' || '$' < lookahead) &&
          lookahead != '(' &&
          lookahead != ')') ADVANCE(40);
      END_STATE();
    case 8:
      if (lookahead == ';') ADVANCE(26);
      if (lookahead == 'n') ADVANCE(24);
      if (lookahead == 'r') ADVANCE(23);
      if (lookahead == 't') ADVANCE(22);
      if (lookahead != 0 &&
          (lookahead < '0' || '9' < lookahead) &&
          (lookahead < 'A' || 'Z' < lookahead) &&
          (lookahead < 'a' || 'z' < lookahead)) ADVANCE(21);
      END_STATE();
    case 9:
      if (lookahead == 'C') ADVANCE(11);
      END_STATE();
    case 10:
      if (lookahead == 'E') ADVANCE(32);
      END_STATE();
    case 11:
      if (lookahead == 'H') ADVANCE(10);
      END_STATE();
    case 12:
      if (lookahead == 'V') ADVANCE(31);
      END_STATE();
    case 13:
      ADVANCE_MAP(
        'B', 103,
        'b', 103,
        'E', 104,
        'e', 104,
        'F', 118,
        'f', 118,
        'I', 87,
        'i', 87,
        'M', 63,
        'm', 63,
        'W', 92,
        'w', 92,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(33);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(135);
      END_STATE();
    case 14:
      ADVANCE_MAP(
        'B', 103,
        'b', 103,
        'E', 111,
        'e', 111,
        'F', 118,
        'f', 118,
        'I', 87,
        'i', 87,
        'M', 63,
        'm', 63,
        'W', 92,
        'w', 92,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(33);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(135);
      END_STATE();
    case 15:
      ADVANCE_MAP(
        'B', 103,
        'b', 103,
        'E', 113,
        'e', 113,
        'F', 118,
        'f', 118,
        'I', 87,
        'i', 87,
        'M', 63,
        'm', 63,
        'W', 92,
        'w', 92,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(33);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(135);
      END_STATE();
    case 16:
      ADVANCE_MAP(
        'B', 103,
        'b', 103,
        'E', 114,
        'e', 114,
        'F', 118,
        'f', 118,
        'I', 87,
        'i', 87,
        'M', 63,
        'm', 63,
        'W', 92,
        'w', 92,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(33);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(135);
      END_STATE();
    case 17:
      ADVANCE_MAP(
        'B', 103,
        'b', 103,
        'E', 115,
        'e', 115,
        'F', 118,
        'f', 118,
        'I', 87,
        'i', 87,
        'M', 63,
        'm', 63,
        'W', 92,
        'w', 92,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(33);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(135);
      END_STATE();
    case 18:
      ADVANCE_MAP(
        'B', 103,
        'b', 103,
        'E', 116,
        'e', 116,
        'F', 118,
        'f', 118,
        'I', 87,
        'i', 87,
        'M', 63,
        'm', 63,
        'W', 92,
        'w', 92,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(33);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(135);
      END_STATE();
    case 19:
      if (eof) ADVANCE(20);
      ADVANCE_MAP(
        '}', 30,
        'B', 103,
        'b', 103,
        'F', 118,
        'f', 118,
        'I', 87,
        'i', 87,
        'M', 63,
        'm', 63,
        'W', 92,
        'w', 92,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(33);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(135);
      END_STATE();
    case 20:
      ACCEPT_TOKEN(ts_builtin_sym_end);
      END_STATE();
    case 21:
      ACCEPT_TOKEN(sym__escape_identity);
      END_STATE();
    case 22:
      ACCEPT_TOKEN(anon_sym_BSLASHt);
      END_STATE();
    case 23:
      ACCEPT_TOKEN(anon_sym_BSLASHr);
      END_STATE();
    case 24:
      ACCEPT_TOKEN(anon_sym_BSLASHn);
      END_STATE();
    case 25:
      ACCEPT_TOKEN(anon_sym_SEMI);
      END_STATE();
    case 26:
      ACCEPT_TOKEN(anon_sym_BSLASH_SEMI);
      END_STATE();
    case 27:
      ACCEPT_TOKEN(aux_sym_variable_token1);
      END_STATE();
    case 28:
      ACCEPT_TOKEN(anon_sym_DOLLAR);
      END_STATE();
    case 29:
      ACCEPT_TOKEN(anon_sym_LBRACE);
      END_STATE();
    case 30:
      ACCEPT_TOKEN(anon_sym_RBRACE);
      END_STATE();
    case 31:
      ACCEPT_TOKEN(anon_sym_ENV);
      END_STATE();
    case 32:
      ACCEPT_TOKEN(anon_sym_CACHE);
      END_STATE();
    case 33:
      ACCEPT_TOKEN(aux_sym__untrimmed_argument_token1);
      END_STATE();
    case 34:
      ACCEPT_TOKEN(anon_sym_LPAREN);
      END_STATE();
    case 35:
      ACCEPT_TOKEN(anon_sym_RPAREN);
      END_STATE();
    case 36:
      ACCEPT_TOKEN(anon_sym_DQUOTE);
      END_STATE();
    case 37:
      ACCEPT_TOKEN(aux_sym__quoted_text_token1);
      END_STATE();
    case 38:
      ACCEPT_TOKEN(aux_sym__quoted_text_token1);
      if (lookahead == 'A') ADVANCE(9);
      END_STATE();
    case 39:
      ACCEPT_TOKEN(aux_sym__quoted_text_token1);
      if (lookahead == 'N') ADVANCE(12);
      END_STATE();
    case 40:
      ACCEPT_TOKEN(aux_sym__unquoted_text_token1);
      END_STATE();
    case 41:
      ACCEPT_TOKEN(aux_sym__unquoted_text_token1);
      if (lookahead == 'A') ADVANCE(9);
      END_STATE();
    case 42:
      ACCEPT_TOKEN(aux_sym__unquoted_text_token1);
      if (lookahead == 'N') ADVANCE(12);
      END_STATE();
    case 43:
      ACCEPT_TOKEN(aux_sym__unquoted_text_token1);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(48);
      END_STATE();
    case 44:
      ACCEPT_TOKEN(aux_sym_if_command_token1);
      END_STATE();
    case 45:
      ACCEPT_TOKEN(aux_sym_endwhile_command_token1);
      if (lookahead == '$') ADVANCE(28);
      if (lookahead == ';') ADVANCE(25);
      if (lookahead == 'C') ADVANCE(41);
      if (lookahead == 'E') ADVANCE(42);
      if (lookahead == '\\') ADVANCE(8);
      if (lookahead == '{') ADVANCE(29);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(43);
      if (lookahead != 0 &&
          (lookahead < '"' || '$' < lookahead) &&
          lookahead != '(' &&
          lookahead != ')') ADVANCE(40);
      END_STATE();
    case 46:
      ACCEPT_TOKEN(aux_sym_endwhile_command_token1);
      if (lookahead == '$') ADVANCE(28);
      if (lookahead == ';') ADVANCE(25);
      if (lookahead == '\\') ADVANCE(8);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(43);
      if (lookahead != 0 &&
          (lookahead < '"' || '$' < lookahead) &&
          lookahead != '(' &&
          lookahead != ')') ADVANCE(40);
      END_STATE();
    case 47:
      ACCEPT_TOKEN(aux_sym_endwhile_command_token1);
      if (lookahead == ')') ADVANCE(35);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(48);
      END_STATE();
    case 48:
      ACCEPT_TOKEN(aux_sym_endwhile_command_token1);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(48);
      END_STATE();
    case 49:
      ACCEPT_TOKEN(sym_if);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(135);
      END_STATE();
    case 50:
      ACCEPT_TOKEN(sym_elseif);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(135);
      END_STATE();
    case 51:
      ACCEPT_TOKEN(sym_else);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(89);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(135);
      END_STATE();
    case 52:
      ACCEPT_TOKEN(sym_endif);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(135);
      END_STATE();
    case 53:
      ACCEPT_TOKEN(sym_foreach);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(135);
      END_STATE();
    case 54:
      ACCEPT_TOKEN(sym_endforeach);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(135);
      END_STATE();
    case 55:
      ACCEPT_TOKEN(sym_while);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(135);
      END_STATE();
    case 56:
      ACCEPT_TOKEN(sym_endwhile);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(135);
      END_STATE();
    case 57:
      ACCEPT_TOKEN(sym_function);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(135);
      END_STATE();
    case 58:
      ACCEPT_TOKEN(sym_endfunction);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(135);
      END_STATE();
    case 59:
      ACCEPT_TOKEN(sym_macro);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(135);
      END_STATE();
    case 60:
      ACCEPT_TOKEN(sym_endmacro);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(135);
      END_STATE();
    case 61:
      ACCEPT_TOKEN(sym_block);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(135);
      END_STATE();
    case 62:
      ACCEPT_TOKEN(sym_endblock);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(135);
      END_STATE();
    case 63:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(71);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(135);
      END_STATE();
    case 64:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(70);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(135);
      END_STATE();
    case 65:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(73);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(135);
      END_STATE();
    case 66:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(74);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(135);
      END_STATE();
    case 67:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(107);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(135);
      END_STATE();
    case 68:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(101);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(135);
      END_STATE();
    case 69:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(131);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(135);
      END_STATE();
    case 70:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(93);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(135);
      END_STATE();
    case 71:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(127);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(135);
      END_STATE();
    case 72:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(102);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(135);
      END_STATE();
    case 73:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(94);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(135);
      END_STATE();
    case 74:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(128);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(135);
      END_STATE();
    case 75:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(132);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(135);
      END_STATE();
    case 76:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(134);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(135);
      END_STATE();
    case 77:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(108);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(135);
      END_STATE();
    case 78:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(67);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(135);
      END_STATE();
    case 79:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(97);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(135);
      END_STATE();
    case 80:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(91);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(135);
      END_STATE();
    case 81:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(90);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(135);
      END_STATE();
    case 82:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(55);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(135);
      END_STATE();
    case 83:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(51);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(135);
      END_STATE();
    case 84:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(56);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(135);
      END_STATE();
    case 85:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(64);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(135);
      END_STATE();
    case 86:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(65);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(135);
      END_STATE();
    case 87:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(49);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(135);
      END_STATE();
    case 88:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(52);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(135);
      END_STATE();
    case 89:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(50);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(135);
      END_STATE();
    case 90:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(133);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(135);
      END_STATE();
    case 91:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(125);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(135);
      END_STATE();
    case 92:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(96);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(135);
      END_STATE();
    case 93:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(53);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(135);
      END_STATE();
    case 94:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(54);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(135);
      END_STATE();
    case 95:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(100);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(135);
      END_STATE();
    case 96:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(105);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(135);
      END_STATE();
    case 97:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(88);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(135);
      END_STATE();
    case 98:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(121);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(135);
      END_STATE();
    case 99:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(123);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(135);
      END_STATE();
    case 100:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(106);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(135);
      END_STATE();
    case 101:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'K' ||
          lookahead == 'k') ADVANCE(61);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(135);
      END_STATE();
    case 102:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'K' ||
          lookahead == 'k') ADVANCE(62);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(135);
      END_STATE();
    case 103:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(122);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(135);
      END_STATE();
    case 104:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(130);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(79);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(135);
      END_STATE();
    case 105:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(82);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(135);
      END_STATE();
    case 106:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(84);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(135);
      END_STATE();
    case 107:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(124);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(135);
      END_STATE();
    case 108:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(66);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(135);
      END_STATE();
    case 109:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(57);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(135);
      END_STATE();
    case 110:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(58);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(135);
      END_STATE();
    case 111:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(76);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(135);
      END_STATE();
    case 112:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(69);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(135);
      END_STATE();
    case 113:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(80);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(135);
      END_STATE();
    case 114:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(77);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(135);
      END_STATE();
    case 115:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(78);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(135);
      END_STATE();
    case 116:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(81);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(135);
      END_STATE();
    case 117:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(75);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(135);
      END_STATE();
    case 118:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(126);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(112);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(135);
      END_STATE();
    case 119:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(59);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(135);
      END_STATE();
    case 120:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(60);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(135);
      END_STATE();
    case 121:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(109);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(135);
      END_STATE();
    case 122:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(68);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(135);
      END_STATE();
    case 123:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(110);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(135);
      END_STATE();
    case 124:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(72);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(135);
      END_STATE();
    case 125:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(129);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(135);
      END_STATE();
    case 126:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(85);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(135);
      END_STATE();
    case 127:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(119);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(135);
      END_STATE();
    case 128:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(120);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(135);
      END_STATE();
    case 129:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(86);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(135);
      END_STATE();
    case 130:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(83);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(135);
      END_STATE();
    case 131:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(98);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(135);
      END_STATE();
    case 132:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(99);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(135);
      END_STATE();
    case 133:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(117);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(135);
      END_STATE();
    case 134:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'W' ||
          lookahead == 'w') ADVANCE(95);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(135);
      END_STATE();
    case 135:
      ACCEPT_TOKEN(sym_identifier);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(135);
      END_STATE();
    default:
      return false;
  }
}

static const TSLexMode ts_lex_modes[STATE_COUNT] = {
  [0] = {.lex_state = 0, .external_lex_state = 1},
  [1] = {.lex_state = 19, .external_lex_state = 2},
  [2] = {.lex_state = 13, .external_lex_state = 2},
  [3] = {.lex_state = 13, .external_lex_state = 2},
  [4] = {.lex_state = 13, .external_lex_state = 2},
  [5] = {.lex_state = 13, .external_lex_state = 2},
  [6] = {.lex_state = 13, .external_lex_state = 2},
  [7] = {.lex_state = 13, .external_lex_state = 2},
  [8] = {.lex_state = 13, .external_lex_state = 2},
  [9] = {.lex_state = 13, .external_lex_state = 2},
  [10] = {.lex_state = 13, .external_lex_state = 2},
  [11] = {.lex_state = 13, .external_lex_state = 2},
  [12] = {.lex_state = 13, .external_lex_state = 2},
  [13] = {.lex_state = 13, .external_lex_state = 2},
  [14] = {.lex_state = 13, .external_lex_state = 2},
  [15] = {.lex_state = 13, .external_lex_state = 2},
  [16] = {.lex_state = 2, .external_lex_state = 3},
  [17] = {.lex_state = 2, .external_lex_state = 3},
  [18] = {.lex_state = 2, .external_lex_state = 3},
  [19] = {.lex_state = 2, .external_lex_state = 3},
  [20] = {.lex_state = 2, .external_lex_state = 3},
  [21] = {.lex_state = 2, .external_lex_state = 3},
  [22] = {.lex_state = 13, .external_lex_state = 2},
  [23] = {.lex_state = 2, .external_lex_state = 3},
  [24] = {.lex_state = 2, .external_lex_state = 3},
  [25] = {.lex_state = 2, .external_lex_state = 3},
  [26] = {.lex_state = 2, .external_lex_state = 3},
  [27] = {.lex_state = 2, .external_lex_state = 3},
  [28] = {.lex_state = 2, .external_lex_state = 3},
  [29] = {.lex_state = 2, .external_lex_state = 3},
  [30] = {.lex_state = 2, .external_lex_state = 3},
  [31] = {.lex_state = 2, .external_lex_state = 3},
  [32] = {.lex_state = 2, .external_lex_state = 3},
  [33] = {.lex_state = 2, .external_lex_state = 3},
  [34] = {.lex_state = 2, .external_lex_state = 3},
  [35] = {.lex_state = 2, .external_lex_state = 3},
  [36] = {.lex_state = 2, .external_lex_state = 3},
  [37] = {.lex_state = 2, .external_lex_state = 3},
  [38] = {.lex_state = 2, .external_lex_state = 3},
  [39] = {.lex_state = 2, .external_lex_state = 3},
  [40] = {.lex_state = 2, .external_lex_state = 3},
  [41] = {.lex_state = 2, .external_lex_state = 3},
  [42] = {.lex_state = 2, .external_lex_state = 3},
  [43] = {.lex_state = 2, .external_lex_state = 3},
  [44] = {.lex_state = 2, .external_lex_state = 3},
  [45] = {.lex_state = 2, .external_lex_state = 3},
  [46] = {.lex_state = 2, .external_lex_state = 3},
  [47] = {.lex_state = 2, .external_lex_state = 3},
  [48] = {.lex_state = 2, .external_lex_state = 3},
  [49] = {.lex_state = 2, .external_lex_state = 3},
  [50] = {.lex_state = 2, .external_lex_state = 3},
  [51] = {.lex_state = 2, .external_lex_state = 3},
  [52] = {.lex_state = 2, .external_lex_state = 3},
  [53] = {.lex_state = 2, .external_lex_state = 3},
  [54] = {.lex_state = 2, .external_lex_state = 3},
  [55] = {.lex_state = 2, .external_lex_state = 3},
  [56] = {.lex_state = 2, .external_lex_state = 3},
  [57] = {.lex_state = 2, .external_lex_state = 3},
  [58] = {.lex_state = 2, .external_lex_state = 3},
  [59] = {.lex_state = 2, .external_lex_state = 3},
  [60] = {.lex_state = 2, .external_lex_state = 3},
  [61] = {.lex_state = 2, .external_lex_state = 3},
  [62] = {.lex_state = 2, .external_lex_state = 3},
  [63] = {.lex_state = 2, .external_lex_state = 3},
  [64] = {.lex_state = 2, .external_lex_state = 3},
  [65] = {.lex_state = 2, .external_lex_state = 3},
  [66] = {.lex_state = 2, .external_lex_state = 3},
  [67] = {.lex_state = 2, .external_lex_state = 3},
  [68] = {.lex_state = 2, .external_lex_state = 3},
  [69] = {.lex_state = 2, .external_lex_state = 3},
  [70] = {.lex_state = 2, .external_lex_state = 3},
  [71] = {.lex_state = 2, .external_lex_state = 3},
  [72] = {.lex_state = 2, .external_lex_state = 3},
  [73] = {.lex_state = 2, .external_lex_state = 3},
  [74] = {.lex_state = 2, .external_lex_state = 3},
  [75] = {.lex_state = 2, .external_lex_state = 3},
  [76] = {.lex_state = 2, .external_lex_state = 3},
  [77] = {.lex_state = 2, .external_lex_state = 3},
  [78] = {.lex_state = 2, .external_lex_state = 3},
  [79] = {.lex_state = 2, .external_lex_state = 3},
  [80] = {.lex_state = 2, .external_lex_state = 3},
  [81] = {.lex_state = 2, .external_lex_state = 3},
  [82] = {.lex_state = 2, .external_lex_state = 3},
  [83] = {.lex_state = 2, .external_lex_state = 3},
  [84] = {.lex_state = 2, .external_lex_state = 3},
  [85] = {.lex_state = 2, .external_lex_state = 3},
  [86] = {.lex_state = 2, .external_lex_state = 3},
  [87] = {.lex_state = 2, .external_lex_state = 3},
  [88] = {.lex_state = 2, .external_lex_state = 3},
  [89] = {.lex_state = 2, .external_lex_state = 3},
  [90] = {.lex_state = 2, .external_lex_state = 3},
  [91] = {.lex_state = 2, .external_lex_state = 3},
  [92] = {.lex_state = 2, .external_lex_state = 3},
  [93] = {.lex_state = 2, .external_lex_state = 3},
  [94] = {.lex_state = 2, .external_lex_state = 3},
  [95] = {.lex_state = 2, .external_lex_state = 3},
  [96] = {.lex_state = 2, .external_lex_state = 3},
  [97] = {.lex_state = 2, .external_lex_state = 3},
  [98] = {.lex_state = 2, .external_lex_state = 3},
  [99] = {.lex_state = 2, .external_lex_state = 3},
  [100] = {.lex_state = 2, .external_lex_state = 3},
  [101] = {.lex_state = 2, .external_lex_state = 3},
  [102] = {.lex_state = 2, .external_lex_state = 3},
  [103] = {.lex_state = 2, .external_lex_state = 3},
  [104] = {.lex_state = 2, .external_lex_state = 3},
  [105] = {.lex_state = 2, .external_lex_state = 3},
  [106] = {.lex_state = 2, .external_lex_state = 3},
  [107] = {.lex_state = 13, .external_lex_state = 2},
  [108] = {.lex_state = 13, .external_lex_state = 2},
  [109] = {.lex_state = 19, .external_lex_state = 2},
  [110] = {.lex_state = 14, .external_lex_state = 2},
  [111] = {.lex_state = 15, .external_lex_state = 2},
  [112] = {.lex_state = 18, .external_lex_state = 2},
  [113] = {.lex_state = 14, .external_lex_state = 2},
  [114] = {.lex_state = 16, .external_lex_state = 2},
  [115] = {.lex_state = 18, .external_lex_state = 2},
  [116] = {.lex_state = 17, .external_lex_state = 2},
  [117] = {.lex_state = 16, .external_lex_state = 2},
  [118] = {.lex_state = 17, .external_lex_state = 2},
  [119] = {.lex_state = 19, .external_lex_state = 2},
  [120] = {.lex_state = 19, .external_lex_state = 2},
  [121] = {.lex_state = 19, .external_lex_state = 2},
  [122] = {.lex_state = 19, .external_lex_state = 2},
  [123] = {.lex_state = 19, .external_lex_state = 2},
  [124] = {.lex_state = 15, .external_lex_state = 2},
  [125] = {.lex_state = 19, .external_lex_state = 2},
  [126] = {.lex_state = 19, .external_lex_state = 2},
  [127] = {.lex_state = 19, .external_lex_state = 2},
  [128] = {.lex_state = 19, .external_lex_state = 2},
  [129] = {.lex_state = 19, .external_lex_state = 2},
  [130] = {.lex_state = 19, .external_lex_state = 2},
  [131] = {.lex_state = 19, .external_lex_state = 2},
  [132] = {.lex_state = 19, .external_lex_state = 2},
  [133] = {.lex_state = 19, .external_lex_state = 2},
  [134] = {.lex_state = 19, .external_lex_state = 2},
  [135] = {.lex_state = 19, .external_lex_state = 2},
  [136] = {.lex_state = 19, .external_lex_state = 2},
  [137] = {.lex_state = 19, .external_lex_state = 2},
  [138] = {.lex_state = 19, .external_lex_state = 2},
  [139] = {.lex_state = 19, .external_lex_state = 2},
  [140] = {.lex_state = 19, .external_lex_state = 2},
  [141] = {.lex_state = 19, .external_lex_state = 2},
  [142] = {.lex_state = 19, .external_lex_state = 2},
  [143] = {.lex_state = 19, .external_lex_state = 2},
  [144] = {.lex_state = 19, .external_lex_state = 2},
  [145] = {.lex_state = 19, .external_lex_state = 2},
  [146] = {.lex_state = 19, .external_lex_state = 2},
  [147] = {.lex_state = 19, .external_lex_state = 2},
  [148] = {.lex_state = 19, .external_lex_state = 2},
  [149] = {.lex_state = 19, .external_lex_state = 2},
  [150] = {.lex_state = 19, .external_lex_state = 2},
  [151] = {.lex_state = 19, .external_lex_state = 2},
  [152] = {.lex_state = 19, .external_lex_state = 2},
  [153] = {.lex_state = 19, .external_lex_state = 2},
  [154] = {.lex_state = 19, .external_lex_state = 2},
  [155] = {.lex_state = 19, .external_lex_state = 2},
  [156] = {.lex_state = 3, .external_lex_state = 4},
  [157] = {.lex_state = 2, .external_lex_state = 3},
  [158] = {.lex_state = 3, .external_lex_state = 4},
  [159] = {.lex_state = 3, .external_lex_state = 4},
  [160] = {.lex_state = 3, .external_lex_state = 4},
  [161] = {.lex_state = 3, .external_lex_state = 4},
  [162] = {.lex_state = 3, .external_lex_state = 4},
  [163] = {.lex_state = 3, .external_lex_state = 4},
  [164] = {.lex_state = 3, .external_lex_state = 4},
  [165] = {.lex_state = 3, .external_lex_state = 4},
  [166] = {.lex_state = 2, .external_lex_state = 3},
  [167] = {.lex_state = 3, .external_lex_state = 4},
  [168] = {.lex_state = 3, .external_lex_state = 4},
  [169] = {.lex_state = 3, .external_lex_state = 4},
  [170] = {.lex_state = 3, .external_lex_state = 4},
  [171] = {.lex_state = 3, .external_lex_state = 4},
  [172] = {.lex_state = 3, .external_lex_state = 4},
  [173] = {.lex_state = 3, .external_lex_state = 4},
  [174] = {.lex_state = 3, .external_lex_state = 4},
  [175] = {.lex_state = 3, .external_lex_state = 4},
  [176] = {.lex_state = 3, .external_lex_state = 4},
  [177] = {.lex_state = 3, .external_lex_state = 4},
  [178] = {.lex_state = 3, .external_lex_state = 4},
  [179] = {.lex_state = 3, .external_lex_state = 4},
  [180] = {.lex_state = 3, .external_lex_state = 4},
  [181] = {.lex_state = 3, .external_lex_state = 4},
  [182] = {.lex_state = 3, .external_lex_state = 4},
  [183] = {.lex_state = 3, .external_lex_state = 4},
  [184] = {.lex_state = 3, .external_lex_state = 4},
  [185] = {.lex_state = 3, .external_lex_state = 4},
  [186] = {.lex_state = 5},
  [187] = {.lex_state = 5},
  [188] = {.lex_state = 5},
  [189] = {.lex_state = 46},
  [190] = {.lex_state = 3},
  [191] = {.lex_state = 5},
  [192] = {.lex_state = 46},
  [193] = {.lex_state = 5},
  [194] = {.lex_state = 3},
  [195] = {.lex_state = 1, .external_lex_state = 3},
  [196] = {.lex_state = 6},
  [197] = {.lex_state = 6},
  [198] = {.lex_state = 6},
  [199] = {.lex_state = 6},
  [200] = {.lex_state = 6},
  [201] = {.lex_state = 6},
  [202] = {.lex_state = 6},
  [203] = {.lex_state = 6},
  [204] = {.lex_state = 6},
  [205] = {.lex_state = 6},
  [206] = {.lex_state = 6},
  [207] = {.lex_state = 6},
  [208] = {.lex_state = 6},
  [209] = {.lex_state = 6},
  [210] = {.lex_state = 6},
  [211] = {.lex_state = 6},
  [212] = {.lex_state = 6},
  [213] = {.lex_state = 2, .external_lex_state = 3},
  [214] = {.lex_state = 2, .external_lex_state = 3},
  [215] = {.lex_state = 2, .external_lex_state = 3},
  [216] = {.lex_state = 2, .external_lex_state = 3},
  [217] = {.lex_state = 2, .external_lex_state = 3},
  [218] = {.lex_state = 2, .external_lex_state = 3},
  [219] = {.lex_state = 2, .external_lex_state = 3},
  [220] = {.lex_state = 2, .external_lex_state = 3},
  [221] = {.lex_state = 2, .external_lex_state = 3},
  [222] = {.lex_state = 2, .external_lex_state = 3},
  [223] = {.lex_state = 2, .external_lex_state = 3},
  [224] = {.lex_state = 2, .external_lex_state = 3},
  [225] = {.lex_state = 2, .external_lex_state = 3},
  [226] = {.lex_state = 13, .external_lex_state = 2},
  [227] = {.lex_state = 13, .external_lex_state = 2},
  [228] = {.lex_state = 13, .external_lex_state = 2},
  [229] = {.lex_state = 13, .external_lex_state = 2},
  [230] = {.lex_state = 13, .external_lex_state = 2},
  [231] = {.lex_state = 13, .external_lex_state = 2},
  [232] = {.lex_state = 13, .external_lex_state = 2},
  [233] = {.lex_state = 13, .external_lex_state = 2},
  [234] = {.lex_state = 13, .external_lex_state = 2},
  [235] = {.lex_state = 13, .external_lex_state = 2},
  [236] = {.lex_state = 13, .external_lex_state = 2},
  [237] = {.lex_state = 13, .external_lex_state = 2},
  [238] = {.lex_state = 13, .external_lex_state = 2},
  [239] = {.lex_state = 13, .external_lex_state = 2},
  [240] = {.lex_state = 13, .external_lex_state = 2},
  [241] = {.lex_state = 13, .external_lex_state = 2},
  [242] = {.lex_state = 13, .external_lex_state = 2},
  [243] = {.lex_state = 13, .external_lex_state = 2},
  [244] = {.lex_state = 13, .external_lex_state = 2},
  [245] = {.lex_state = 13, .external_lex_state = 2},
  [246] = {.lex_state = 13, .external_lex_state = 2},
  [247] = {.lex_state = 13, .external_lex_state = 2},
  [248] = {.lex_state = 13, .external_lex_state = 2},
  [249] = {.lex_state = 13, .external_lex_state = 2},
  [250] = {.lex_state = 13, .external_lex_state = 2},
  [251] = {.lex_state = 13, .external_lex_state = 2},
  [252] = {.lex_state = 13, .external_lex_state = 2},
  [253] = {.lex_state = 13, .external_lex_state = 2},
  [254] = {.lex_state = 13, .external_lex_state = 2},
  [255] = {.lex_state = 13, .external_lex_state = 2},
  [256] = {.lex_state = 13, .external_lex_state = 2},
  [257] = {.lex_state = 13, .external_lex_state = 2},
  [258] = {.lex_state = 13, .external_lex_state = 2},
  [259] = {.lex_state = 13, .external_lex_state = 2},
  [260] = {.lex_state = 13, .external_lex_state = 2},
  [261] = {.lex_state = 13, .external_lex_state = 2},
  [262] = {.lex_state = 13, .external_lex_state = 2},
  [263] = {.lex_state = 4},
  [264] = {.lex_state = 7},
  [265] = {.lex_state = 45},
  [266] = {.lex_state = 17, .external_lex_state = 2},
  [267] = {.lex_state = 15, .external_lex_state = 2},
  [268] = {.lex_state = 15, .external_lex_state = 2},
  [269] = {.lex_state = 15, .external_lex_state = 2},
  [270] = {.lex_state = 15, .external_lex_state = 2},
  [271] = {.lex_state = 15, .external_lex_state = 2},
  [272] = {.lex_state = 15, .external_lex_state = 2},
  [273] = {.lex_state = 15, .external_lex_state = 2},
  [274] = {.lex_state = 15, .external_lex_state = 2},
  [275] = {.lex_state = 15, .external_lex_state = 2},
  [276] = {.lex_state = 15, .external_lex_state = 2},
  [277] = {.lex_state = 15, .external_lex_state = 2},
  [278] = {.lex_state = 15, .external_lex_state = 2},
  [279] = {.lex_state = 15, .external_lex_state = 2},
  [280] = {.lex_state = 15, .external_lex_state = 2},
  [281] = {.lex_state = 15, .external_lex_state = 2},
  [282] = {.lex_state = 15, .external_lex_state = 2},
  [283] = {.lex_state = 15, .external_lex_state = 2},
  [284] = {.lex_state = 15, .external_lex_state = 2},
  [285] = {.lex_state = 14, .external_lex_state = 2},
  [286] = {.lex_state = 14, .external_lex_state = 2},
  [287] = {.lex_state = 14, .external_lex_state = 2},
  [288] = {.lex_state = 14, .external_lex_state = 2},
  [289] = {.lex_state = 14, .external_lex_state = 2},
  [290] = {.lex_state = 14, .external_lex_state = 2},
  [291] = {.lex_state = 14, .external_lex_state = 2},
  [292] = {.lex_state = 14, .external_lex_state = 2},
  [293] = {.lex_state = 14, .external_lex_state = 2},
  [294] = {.lex_state = 14, .external_lex_state = 2},
  [295] = {.lex_state = 14, .external_lex_state = 2},
  [296] = {.lex_state = 14, .external_lex_state = 2},
  [297] = {.lex_state = 14, .external_lex_state = 2},
  [298] = {.lex_state = 14, .external_lex_state = 2},
  [299] = {.lex_state = 14, .external_lex_state = 2},
  [300] = {.lex_state = 14, .external_lex_state = 2},
  [301] = {.lex_state = 14, .external_lex_state = 2},
  [302] = {.lex_state = 14, .external_lex_state = 2},
  [303] = {.lex_state = 14, .external_lex_state = 2},
  [304] = {.lex_state = 14, .external_lex_state = 2},
  [305] = {.lex_state = 14, .external_lex_state = 2},
  [306] = {.lex_state = 14, .external_lex_state = 2},
  [307] = {.lex_state = 14, .external_lex_state = 2},
  [308] = {.lex_state = 14, .external_lex_state = 2},
  [309] = {.lex_state = 14, .external_lex_state = 2},
  [310] = {.lex_state = 14, .external_lex_state = 2},
  [311] = {.lex_state = 14, .external_lex_state = 2},
  [312] = {.lex_state = 14, .external_lex_state = 2},
  [313] = {.lex_state = 14, .external_lex_state = 2},
  [314] = {.lex_state = 14, .external_lex_state = 2},
  [315] = {.lex_state = 18, .external_lex_state = 2},
  [316] = {.lex_state = 18, .external_lex_state = 2},
  [317] = {.lex_state = 18, .external_lex_state = 2},
  [318] = {.lex_state = 18, .external_lex_state = 2},
  [319] = {.lex_state = 18, .external_lex_state = 2},
  [320] = {.lex_state = 18, .external_lex_state = 2},
  [321] = {.lex_state = 18, .external_lex_state = 2},
  [322] = {.lex_state = 18, .external_lex_state = 2},
  [323] = {.lex_state = 18, .external_lex_state = 2},
  [324] = {.lex_state = 18, .external_lex_state = 2},
  [325] = {.lex_state = 18, .external_lex_state = 2},
  [326] = {.lex_state = 18, .external_lex_state = 2},
  [327] = {.lex_state = 18, .external_lex_state = 2},
  [328] = {.lex_state = 18, .external_lex_state = 2},
  [329] = {.lex_state = 18, .external_lex_state = 2},
  [330] = {.lex_state = 18, .external_lex_state = 2},
  [331] = {.lex_state = 18, .external_lex_state = 2},
  [332] = {.lex_state = 18, .external_lex_state = 2},
  [333] = {.lex_state = 18, .external_lex_state = 2},
  [334] = {.lex_state = 18, .external_lex_state = 2},
  [335] = {.lex_state = 18, .external_lex_state = 2},
  [336] = {.lex_state = 18, .external_lex_state = 2},
  [337] = {.lex_state = 18, .external_lex_state = 2},
  [338] = {.lex_state = 18, .external_lex_state = 2},
  [339] = {.lex_state = 18, .external_lex_state = 2},
  [340] = {.lex_state = 18, .external_lex_state = 2},
  [341] = {.lex_state = 18, .external_lex_state = 2},
  [342] = {.lex_state = 18, .external_lex_state = 2},
  [343] = {.lex_state = 18, .external_lex_state = 2},
  [344] = {.lex_state = 18, .external_lex_state = 2},
  [345] = {.lex_state = 16, .external_lex_state = 2},
  [346] = {.lex_state = 19, .external_lex_state = 2},
  [347] = {.lex_state = 16, .external_lex_state = 2},
  [348] = {.lex_state = 16, .external_lex_state = 2},
  [349] = {.lex_state = 16, .external_lex_state = 2},
  [350] = {.lex_state = 16, .external_lex_state = 2},
  [351] = {.lex_state = 16, .external_lex_state = 2},
  [352] = {.lex_state = 16, .external_lex_state = 2},
  [353] = {.lex_state = 16, .external_lex_state = 2},
  [354] = {.lex_state = 16, .external_lex_state = 2},
  [355] = {.lex_state = 16, .external_lex_state = 2},
  [356] = {.lex_state = 16, .external_lex_state = 2},
  [357] = {.lex_state = 16, .external_lex_state = 2},
  [358] = {.lex_state = 16, .external_lex_state = 2},
  [359] = {.lex_state = 16, .external_lex_state = 2},
  [360] = {.lex_state = 16, .external_lex_state = 2},
  [361] = {.lex_state = 16, .external_lex_state = 2},
  [362] = {.lex_state = 15, .external_lex_state = 2},
  [363] = {.lex_state = 16, .external_lex_state = 2},
  [364] = {.lex_state = 16, .external_lex_state = 2},
  [365] = {.lex_state = 16, .external_lex_state = 2},
  [366] = {.lex_state = 16, .external_lex_state = 2},
  [367] = {.lex_state = 16, .external_lex_state = 2},
  [368] = {.lex_state = 16, .external_lex_state = 2},
  [369] = {.lex_state = 16, .external_lex_state = 2},
  [370] = {.lex_state = 16, .external_lex_state = 2},
  [371] = {.lex_state = 16, .external_lex_state = 2},
  [372] = {.lex_state = 16, .external_lex_state = 2},
  [373] = {.lex_state = 16, .external_lex_state = 2},
  [374] = {.lex_state = 16, .external_lex_state = 2},
  [375] = {.lex_state = 16, .external_lex_state = 2},
  [376] = {.lex_state = 17, .external_lex_state = 2},
  [377] = {.lex_state = 17, .external_lex_state = 2},
  [378] = {.lex_state = 17, .external_lex_state = 2},
  [379] = {.lex_state = 17, .external_lex_state = 2},
  [380] = {.lex_state = 17, .external_lex_state = 2},
  [381] = {.lex_state = 17, .external_lex_state = 2},
  [382] = {.lex_state = 17, .external_lex_state = 2},
  [383] = {.lex_state = 17, .external_lex_state = 2},
  [384] = {.lex_state = 17, .external_lex_state = 2},
  [385] = {.lex_state = 17, .external_lex_state = 2},
  [386] = {.lex_state = 17, .external_lex_state = 2},
  [387] = {.lex_state = 17, .external_lex_state = 2},
  [388] = {.lex_state = 17, .external_lex_state = 2},
  [389] = {.lex_state = 17, .external_lex_state = 2},
  [390] = {.lex_state = 17, .external_lex_state = 2},
  [391] = {.lex_state = 17, .external_lex_state = 2},
  [392] = {.lex_state = 17, .external_lex_state = 2},
  [393] = {.lex_state = 17, .external_lex_state = 2},
  [394] = {.lex_state = 17, .external_lex_state = 2},
  [395] = {.lex_state = 17, .external_lex_state = 2},
  [396] = {.lex_state = 17, .external_lex_state = 2},
  [397] = {.lex_state = 17, .external_lex_state = 2},
  [398] = {.lex_state = 17, .external_lex_state = 2},
  [399] = {.lex_state = 17, .external_lex_state = 2},
  [400] = {.lex_state = 17, .external_lex_state = 2},
  [401] = {.lex_state = 17, .external_lex_state = 2},
  [402] = {.lex_state = 17, .external_lex_state = 2},
  [403] = {.lex_state = 17, .external_lex_state = 2},
  [404] = {.lex_state = 17, .external_lex_state = 2},
  [405] = {.lex_state = 15, .external_lex_state = 2},
  [406] = {.lex_state = 19, .external_lex_state = 2},
  [407] = {.lex_state = 19, .external_lex_state = 2},
  [408] = {.lex_state = 19, .external_lex_state = 2},
  [409] = {.lex_state = 19, .external_lex_state = 2},
  [410] = {.lex_state = 19, .external_lex_state = 2},
  [411] = {.lex_state = 19, .external_lex_state = 2},
  [412] = {.lex_state = 19, .external_lex_state = 2},
  [413] = {.lex_state = 19, .external_lex_state = 2},
  [414] = {.lex_state = 19, .external_lex_state = 2},
  [415] = {.lex_state = 19, .external_lex_state = 2},
  [416] = {.lex_state = 19, .external_lex_state = 2},
  [417] = {.lex_state = 19, .external_lex_state = 2},
  [418] = {.lex_state = 19, .external_lex_state = 2},
  [419] = {.lex_state = 19, .external_lex_state = 2},
  [420] = {.lex_state = 19, .external_lex_state = 2},
  [421] = {.lex_state = 19, .external_lex_state = 2},
  [422] = {.lex_state = 19, .external_lex_state = 2},
  [423] = {.lex_state = 19, .external_lex_state = 2},
  [424] = {.lex_state = 19, .external_lex_state = 2},
  [425] = {.lex_state = 19, .external_lex_state = 2},
  [426] = {.lex_state = 19, .external_lex_state = 2},
  [427] = {.lex_state = 19, .external_lex_state = 2},
  [428] = {.lex_state = 19, .external_lex_state = 2},
  [429] = {.lex_state = 19, .external_lex_state = 2},
  [430] = {.lex_state = 19, .external_lex_state = 2},
  [431] = {.lex_state = 19, .external_lex_state = 2},
  [432] = {.lex_state = 19, .external_lex_state = 2},
  [433] = {.lex_state = 19, .external_lex_state = 2},
  [434] = {.lex_state = 15, .external_lex_state = 2},
  [435] = {.lex_state = 15, .external_lex_state = 2},
  [436] = {.lex_state = 19, .external_lex_state = 2},
  [437] = {.lex_state = 15, .external_lex_state = 2},
  [438] = {.lex_state = 15, .external_lex_state = 2},
  [439] = {.lex_state = 15, .external_lex_state = 2},
  [440] = {.lex_state = 15, .external_lex_state = 2},
  [441] = {.lex_state = 15, .external_lex_state = 2},
  [442] = {.lex_state = 15, .external_lex_state = 2},
  [443] = {.lex_state = 15, .external_lex_state = 2},
  [444] = {.lex_state = 15, .external_lex_state = 2},
  [445] = {.lex_state = 16, .external_lex_state = 2},
  [446] = {.lex_state = 19, .external_lex_state = 2},
  [447] = {.lex_state = 19, .external_lex_state = 2},
  [448] = {.lex_state = 19, .external_lex_state = 2},
  [449] = {.lex_state = 19, .external_lex_state = 2},
  [450] = {.lex_state = 19, .external_lex_state = 2},
  [451] = {.lex_state = 19, .external_lex_state = 2},
  [452] = {.lex_state = 3},
  [453] = {.lex_state = 19, .external_lex_state = 2},
  [454] = {.lex_state = 19, .external_lex_state = 2},
  [455] = {.lex_state = 19, .external_lex_state = 2},
  [456] = {.lex_state = 19, .external_lex_state = 2},
  [457] = {.lex_state = 19, .external_lex_state = 2},
  [458] = {.lex_state = 5},
  [459] = {.lex_state = 46},
  [460] = {.lex_state = 46},
  [461] = {.lex_state = 46},
  [462] = {.lex_state = 3},
  [463] = {.lex_state = 3},
  [464] = {.lex_state = 3},
  [465] = {.lex_state = 3},
  [466] = {.lex_state = 5},
  [467] = {.lex_state = 5},
  [468] = {.lex_state = 6},
  [469] = {.lex_state = 5},
  [470] = {.lex_state = 6},
  [471] = {.lex_state = 5},
  [472] = {.lex_state = 5},
  [473] = {.lex_state = 46},
  [474] = {.lex_state = 6},
  [475] = {.lex_state = 3},
  [476] = {.lex_state = 46},
  [477] = {.lex_state = 6},
  [478] = {.lex_state = 6},
  [479] = {.lex_state = 46},
  [480] = {.lex_state = 6},
  [481] = {.lex_state = 6},
  [482] = {.lex_state = 6},
  [483] = {.lex_state = 6},
  [484] = {.lex_state = 6},
  [485] = {.lex_state = 6},
  [486] = {.lex_state = 6},
  [487] = {.lex_state = 6},
  [488] = {.lex_state = 6},
  [489] = {.lex_state = 6},
  [490] = {.lex_state = 6},
  [491] = {.lex_state = 6},
  [492] = {.lex_state = 6},
  [493] = {.lex_state = 6},
  [494] = {.lex_state = 6},
  [495] = {.lex_state = 6},
  [496] = {.lex_state = 6},
  [497] = {.lex_state = 6},
  [498] = {.lex_state = 6},
  [499] = {.lex_state = 6},
  [500] = {.lex_state = 6},
  [501] = {.lex_state = 6},
  [502] = {.lex_state = 6},
  [503] = {.lex_state = 6},
  [504] = {.lex_state = 6},
  [505] = {.lex_state = 6},
  [506] = {.lex_state = 6},
  [507] = {.lex_state = 6},
  [508] = {.lex_state = 6},
  [509] = {.lex_state = 6},
  [510] = {.lex_state = 6},
  [511] = {.lex_state = 6},
  [512] = {.lex_state = 6},
  [513] = {.lex_state = 6},
  [514] = {.lex_state = 6},
  [515] = {.lex_state = 6},
  [516] = {.lex_state = 6},
  [517] = {.lex_state = 6},
  [518] = {.lex_state = 6},
  [519] = {.lex_state = 6},
  [520] = {.lex_state = 6},
  [521] = {.lex_state = 6},
  [522] = {.lex_state = 6},
  [523] = {.lex_state = 6},
  [524] = {.lex_state = 6},
  [525] = {.lex_state = 6},
  [526] = {.lex_state = 6},
  [527] = {.lex_state = 6},
  [528] = {.lex_state = 6},
  [529] = {.lex_state = 6},
  [530] = {.lex_state = 6},
  [531] = {.lex_state = 6},
  [532] = {.lex_state = 6},
  [533] = {.lex_state = 6},
  [534] = {.lex_state = 6},
  [535] = {.lex_state = 6},
  [536] = {.lex_state = 6},
  [537] = {.lex_state = 6},
  [538] = {.lex_state = 6},
  [539] = {.lex_state = 6},
  [540] = {.lex_state = 6},
  [541] = {.lex_state = 6},
  [542] = {.lex_state = 6},
  [543] = {.lex_state = 6},
  [544] = {.lex_state = 6},
  [545] = {.lex_state = 6},
  [546] = {.lex_state = 6},
  [547] = {.lex_state = 6},
  [548] = {.lex_state = 6},
  [549] = {.lex_state = 6},
  [550] = {.lex_state = 6},
  [551] = {.lex_state = 6},
  [552] = {.lex_state = 6},
  [553] = {.lex_state = 6},
  [554] = {.lex_state = 6},
  [555] = {.lex_state = 6},
  [556] = {.lex_state = 6},
  [557] = {.lex_state = 6},
  [558] = {.lex_state = 6},
  [559] = {.lex_state = 6},
  [560] = {.lex_state = 6},
  [561] = {.lex_state = 6},
  [562] = {.lex_state = 6},
  [563] = {.lex_state = 6},
  [564] = {.lex_state = 6},
  [565] = {.lex_state = 6},
  [566] = {.lex_state = 6},
  [567] = {.lex_state = 6},
  [568] = {.lex_state = 6},
  [569] = {.lex_state = 6},
  [570] = {.lex_state = 6},
  [571] = {.lex_state = 6},
  [572] = {.lex_state = 6},
  [573] = {.lex_state = 6},
  [574] = {.lex_state = 6},
  [575] = {.lex_state = 6},
  [576] = {.lex_state = 6},
  [577] = {.lex_state = 6},
  [578] = {.lex_state = 0},
  [579] = {.lex_state = 6},
  [580] = {.lex_state = 6},
  [581] = {.lex_state = 6},
  [582] = {.lex_state = 6},
  [583] = {.lex_state = 6},
  [584] = {.lex_state = 6},
  [585] = {.lex_state = 6},
  [586] = {.lex_state = 6},
  [587] = {.lex_state = 6},
  [588] = {.lex_state = 6},
  [589] = {.lex_state = 6},
  [590] = {.lex_state = 6},
  [591] = {.lex_state = 6},
  [592] = {.lex_state = 6},
  [593] = {.lex_state = 6},
  [594] = {.lex_state = 6},
  [595] = {.lex_state = 6},
  [596] = {.lex_state = 14},
  [597] = {.lex_state = 18},
  [598] = {.lex_state = 16},
  [599] = {.lex_state = 17},
  [600] = {.lex_state = 18},
  [601] = {.lex_state = 16},
  [602] = {.lex_state = 47},
  [603] = {.lex_state = 15},
  [604] = {.lex_state = 17},
  [605] = {.lex_state = 17},
  [606] = {.lex_state = 47},
  [607] = {.lex_state = 47},
  [608] = {.lex_state = 15},
  [609] = {.lex_state = 17},
  [610] = {.lex_state = 47},
  [611] = {.lex_state = 47},
  [612] = {.lex_state = 47},
  [613] = {.lex_state = 14},
  [614] = {.lex_state = 15},
  [615] = {.lex_state = 14},
  [616] = {.lex_state = 18},
  [617] = {.lex_state = 15},
  [618] = {.lex_state = 14},
  [619] = {.lex_state = 15},
  [620] = {.lex_state = 14},
  [621] = {.lex_state = 18},
  [622] = {.lex_state = 16},
  [623] = {.lex_state = 17},
  [624] = {.lex_state = 16},
  [625] = {.lex_state = 47},
  [626] = {.lex_state = 47},
  [627] = {.lex_state = 47},
  [628] = {.lex_state = 15},
  [629] = {.lex_state = 18},
  [630] = {.lex_state = 17},
  [631] = {.lex_state = 47},
  [632] = {.lex_state = 47},
  [633] = {.lex_state = 16},
  [634] = {.lex_state = 47},
  [635] = {.lex_state = 47},
  [636] = {.lex_state = 47},
  [637] = {.lex_state = 16},
  [638] = {.lex_state = 14},
  [639] = {.lex_state = 16},
  [640] = {.lex_state = 15},
  [641] = {.lex_state = 14},
  [642] = {.lex_state = 18},
  [643] = {.lex_state = 17},
  [644] = {.lex_state = 18},
  [645] = {.lex_state = 0},
  [646] = {.lex_state = 0},
  [647] = {.lex_state = 0},
  [648] = {.lex_state = 0},
  [649] = {.lex_state = 0},
  [650] = {.lex_state = 0},
  [651] = {.lex_state = 0},
  [652] = {.lex_state = 0},
  [653] = {.lex_state = 0},
  [654] = {.lex_state = 0},
  [655] = {.lex_state = 0},
  [656] = {.lex_state = 0},
  [657] = {.lex_state = 0},
  [658] = {.lex_state = 0},
  [659] = {.lex_state = 0},
  [660] = {.lex_state = 0},
  [661] = {.lex_state = 0},
  [662] = {.lex_state = 0},
  [663] = {.lex_state = 0, .external_lex_state = 5},
  [664] = {.lex_state = 0, .external_lex_state = 6},
  [665] = {.lex_state = 0},
  [666] = {.lex_state = 0},
  [667] = {.lex_state = 0},
  [668] = {.lex_state = 0},
  [669] = {.lex_state = 0},
  [670] = {.lex_state = 0, .external_lex_state = 7},
  [671] = {.lex_state = 0},
  [672] = {.lex_state = 0, .external_lex_state = 7},
  [673] = {.lex_state = 0, .external_lex_state = 8},
  [674] = {.lex_state = 19},
  [675] = {.lex_state = 0},
  [676] = {.lex_state = 0},
  [677] = {.lex_state = 0, .external_lex_state = 5},
  [678] = {.lex_state = 0},
  [679] = {.lex_state = 0},
  [680] = {.lex_state = 0},
  [681] = {.lex_state = 0},
  [682] = {.lex_state = 0},
  [683] = {.lex_state = 0},
  [684] = {.lex_state = 0},
  [685] = {.lex_state = 0},
  [686] = {.lex_state = 19},
  [687] = {.lex_state = 19},
  [688] = {.lex_state = 48},
  [689] = {.lex_state = 48},
  [690] = {.lex_state = 0, .external_lex_state = 6},
  [691] = {.lex_state = 0},
  [692] = {.lex_state = 0},
  [693] = {.lex_state = 0},
  [694] = {.lex_state = 0},
  [695] = {.lex_state = 0},
  [696] = {.lex_state = 0},
  [697] = {.lex_state = 0},
  [698] = {.lex_state = 0},
  [699] = {.lex_state = 0, .external_lex_state = 8},
  [700] = {.lex_state = 0},
  [701] = {.lex_state = 0},
  [702] = {.lex_state = 0},
  [703] = {.lex_state = 0, .external_lex_state = 5},
  [704] = {.lex_state = 0},
  [705] = {.lex_state = 0},
  [706] = {.lex_state = 0},
  [707] = {.lex_state = 0, .external_lex_state = 6},
  [708] = {.lex_state = 0},
  [709] = {.lex_state = 0, .external_lex_state = 5},
  [710] = {.lex_state = 0},
  [711] = {.lex_state = 0},
  [712] = {.lex_state = 0},
  [713] = {.lex_state = 19},
  [714] = {.lex_state = 48},
  [715] = {.lex_state = 48},
  [716] = {.lex_state = 0, .external_lex_state = 6},
  [717] = {.lex_state = 0},
  [718] = {.lex_state = 0},
  [719] = {.lex_state = 0},
  [720] = {.lex_state = 0, .external_lex_state = 5},
  [721] = {.lex_state = 19},
  [722] = {.lex_state = 19},
  [723] = {.lex_state = 0, .external_lex_state = 7},
  [724] = {.lex_state = 0},
  [725] = {.lex_state = 0},
  [726] = {.lex_state = 0},
  [727] = {.lex_state = 19},
  [728] = {.lex_state = 0},
  [729] = {.lex_state = 0},
  [730] = {.lex_state = 0},
  [731] = {.lex_state = 0, .external_lex_state = 8},
  [732] = {.lex_state = 19},
  [733] = {.lex_state = 0},
  [734] = {.lex_state = 48},
  [735] = {.lex_state = 0},
  [736] = {.lex_state = 0},
  [737] = {.lex_state = 0},
  [738] = {.lex_state = 0},
  [739] = {.lex_state = 48},
  [740] = {.lex_state = 48},
  [741] = {.lex_state = 0, .external_lex_state = 6},
  [742] = {.lex_state = 0},
  [743] = {.lex_state = 19},
  [744] = {.lex_state = 0},
  [745] = {.lex_state = 48},
  [746] = {.lex_state = 0},
  [747] = {.lex_state = 0},
  [748] = {.lex_state = 0},
  [749] = {.lex_state = 0},
  [750] = {.lex_state = 0},
  [751] = {.lex_state = 0},
  [752] = {.lex_state = 0},
  [753] = {.lex_state = 0, .external_lex_state = 5},
  [754] = {.lex_state = 0},
  [755] = {.lex_state = 0},
  [756] = {.lex_state = 0},
  [757] = {.lex_state = 0},
  [758] = {.lex_state = 19},
  [759] = {.lex_state = 0},
  [760] = {.lex_state = 0},
  [761] = {.lex_state = 0},
  [762] = {.lex_state = 0},
  [763] = {.lex_state = 0},
  [764] = {.lex_state = 48},
  [765] = {.lex_state = 48},
  [766] = {.lex_state = 0, .external_lex_state = 6},
  [767] = {.lex_state = 0},
  [768] = {.lex_state = 0},
  [769] = {.lex_state = 0},
  [770] = {.lex_state = 0},
  [771] = {.lex_state = 0},
  [772] = {.lex_state = 0},
  [773] = {.lex_state = 0},
  [774] = {.lex_state = 0},
  [775] = {.lex_state = 0},
  [776] = {.lex_state = 0},
  [777] = {.lex_state = 0},
  [778] = {.lex_state = 0},
  [779] = {.lex_state = 0},
  [780] = {.lex_state = 0},
  [781] = {.lex_state = 48},
  [782] = {.lex_state = 0},
  [783] = {.lex_state = 0},
  [784] = {.lex_state = 0},
  [785] = {.lex_state = 0},
  [786] = {.lex_state = 48},
  [787] = {.lex_state = 48},
  [788] = {.lex_state = 0, .external_lex_state = 6},
  [789] = {.lex_state = 19},
  [790] = {.lex_state = 0},
  [791] = {.lex_state = 19},
  [792] = {.lex_state = 0},
  [793] = {.lex_state = 0},
  [794] = {.lex_state = 48},
  [795] = {.lex_state = 0},
  [796] = {.lex_state = 0},
  [797] = {.lex_state = 0},
  [798] = {.lex_state = 0},
  [799] = {.lex_state = 0},
  [800] = {.lex_state = 0, .external_lex_state = 5},
  [801] = {.lex_state = 0},
  [802] = {.lex_state = 0},
  [803] = {.lex_state = 0},
  [804] = {.lex_state = 0},
  [805] = {.lex_state = 0},
  [806] = {.lex_state = 0},
  [807] = {.lex_state = 0},
  [808] = {.lex_state = 48},
  [809] = {.lex_state = 48},
  [810] = {.lex_state = 0, .external_lex_state = 6},
  [811] = {.lex_state = 0},
  [812] = {.lex_state = 0},
  [813] = {.lex_state = 0},
  [814] = {.lex_state = 0},
  [815] = {.lex_state = 0},
  [816] = {.lex_state = 0, .external_lex_state = 5},
  [817] = {.lex_state = 48},
  [818] = {.lex_state = 0},
  [819] = {.lex_state = 0},
  [820] = {.lex_state = 0},
  [821] = {.lex_state = 0},
  [822] = {.lex_state = 0},
  [823] = {.lex_state = 0},
  [824] = {.lex_state = 0},
  [825] = {.lex_state = 0},
  [826] = {.lex_state = 0},
  [827] = {.lex_state = 48},
  [828] = {.lex_state = 0},
  [829] = {.lex_state = 19},
  [830] = {.lex_state = 19},
  [831] = {.lex_state = 19},
};

static const uint16_t ts_parse_table[LARGE_STATE_COUNT][SYMBOL_COUNT] = {
  [STATE(0)] = {
    [ts_builtin_sym_end] = ACTIONS(1),
    [sym__escape_identity] = ACTIONS(1),
    [anon_sym_BSLASHt] = ACTIONS(1),
    [anon_sym_BSLASHr] = ACTIONS(1),
    [anon_sym_BSLASHn] = ACTIONS(1),
    [anon_sym_SEMI] = ACTIONS(1),
    [anon_sym_BSLASH_SEMI] = ACTIONS(1),
    [anon_sym_DOLLAR] = ACTIONS(1),
    [anon_sym_LBRACE] = ACTIONS(1),
    [anon_sym_ENV] = ACTIONS(1),
    [anon_sym_CACHE] = ACTIONS(1),
    [aux_sym__untrimmed_argument_token1] = ACTIONS(1),
    [anon_sym_LPAREN] = ACTIONS(1),
    [anon_sym_RPAREN] = ACTIONS(1),
    [anon_sym_DQUOTE] = ACTIONS(1),
    [aux_sym__unquoted_text_token1] = ACTIONS(1),
    [aux_sym_if_command_token1] = ACTIONS(1),
    [sym_bracket_argument_open] = ACTIONS(1),
    [sym_bracket_argument_content] = ACTIONS(1),
    [sym_bracket_argument_close] = ACTIONS(1),
    [sym_bracket_comment_open] = ACTIONS(1),
    [sym_bracket_comment_content] = ACTIONS(1),
    [sym_bracket_comment_close] = ACTIONS(1),
    [sym_line_comment] = ACTIONS(1),
  },
  [STATE(1)] = {
    [sym_source_file] = STATE(708),
    [sym_bracket_comment] = STATE(123),
    [sym_if_command] = STATE(5),
    [sym_if_condition] = STATE(123),
    [sym_foreach_command] = STATE(125),
    [sym_foreach_loop] = STATE(123),
    [sym_while_command] = STATE(119),
    [sym_while_loop] = STATE(123),
    [sym_function_command] = STATE(120),
    [sym_function_def] = STATE(123),
    [sym_macro_command] = STATE(121),
    [sym_macro_def] = STATE(123),
    [sym_block_command] = STATE(122),
    [sym_block_def] = STATE(123),
    [sym_normal_command] = STATE(123),
    [sym__command_invocation] = STATE(123),
    [sym__untrimmed_command_invocation] = STATE(123),
    [aux_sym_source_file_repeat1] = STATE(123),
    [ts_builtin_sym_end] = ACTIONS(3),
    [aux_sym__untrimmed_argument_token1] = ACTIONS(5),
    [sym_if] = ACTIONS(7),
    [sym_foreach] = ACTIONS(9),
    [sym_while] = ACTIONS(11),
    [sym_function] = ACTIONS(13),
    [sym_macro] = ACTIONS(15),
    [sym_block] = ACTIONS(17),
    [sym_identifier] = ACTIONS(19),
    [sym_bracket_comment_open] = ACTIONS(21),
    [sym_line_comment] = ACTIONS(5),
  },
};

static const uint16_t ts_small_parse_table[] = {
  [0] = 21,
    ACTIONS(7), 1,
      sym_if,
    ACTIONS(9), 1,
      sym_foreach,
    ACTIONS(11), 1,
      sym_while,
    ACTIONS(13), 1,
      sym_function,
    ACTIONS(15), 1,
      sym_macro,
    ACTIONS(17), 1,
      sym_block,
    ACTIONS(25), 1,
      sym_elseif,
    ACTIONS(27), 1,
      sym_else,
    ACTIONS(29), 1,
      sym_endif,
    ACTIONS(31), 1,
      sym_identifier,
    ACTIONS(33), 1,
      sym_bracket_comment_open,
    STATE(3), 1,
      sym_if_command,
    STATE(126), 1,
      sym_foreach_command,
    STATE(127), 1,
      sym_while_command,
    STATE(128), 1,
      sym_function_command,
    STATE(130), 1,
      sym_block_command,
    STATE(155), 1,
      sym_macro_command,
    STATE(427), 1,
      sym_endif_command,
    ACTIONS(23), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(22), 4,
      sym_body,
      sym_elseif_command,
      sym_else_command,
      aux_sym_if_condition_repeat1,
    STATE(107), 11,
      sym_bracket_comment,
      sym_if_condition,
      sym_foreach_loop,
      sym_while_loop,
      sym_function_def,
      sym_macro_def,
      sym_block_def,
      sym_normal_command,
      sym__command_invocation,
      sym__untrimmed_command_invocation,
      aux_sym_source_file_repeat1,
  [78] = 21,
    ACTIONS(7), 1,
      sym_if,
    ACTIONS(9), 1,
      sym_foreach,
    ACTIONS(11), 1,
      sym_while,
    ACTIONS(13), 1,
      sym_function,
    ACTIONS(15), 1,
      sym_macro,
    ACTIONS(17), 1,
      sym_block,
    ACTIONS(25), 1,
      sym_elseif,
    ACTIONS(27), 1,
      sym_else,
    ACTIONS(31), 1,
      sym_identifier,
    ACTIONS(33), 1,
      sym_bracket_comment_open,
    ACTIONS(35), 1,
      sym_endif,
    STATE(3), 1,
      sym_if_command,
    STATE(126), 1,
      sym_foreach_command,
    STATE(127), 1,
      sym_while_command,
    STATE(128), 1,
      sym_function_command,
    STATE(130), 1,
      sym_block_command,
    STATE(155), 1,
      sym_macro_command,
    STATE(239), 1,
      sym_endif_command,
    ACTIONS(23), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(4), 4,
      sym_body,
      sym_elseif_command,
      sym_else_command,
      aux_sym_if_condition_repeat1,
    STATE(107), 11,
      sym_bracket_comment,
      sym_if_condition,
      sym_foreach_loop,
      sym_while_loop,
      sym_function_def,
      sym_macro_def,
      sym_block_def,
      sym_normal_command,
      sym__command_invocation,
      sym__untrimmed_command_invocation,
      aux_sym_source_file_repeat1,
  [156] = 21,
    ACTIONS(7), 1,
      sym_if,
    ACTIONS(9), 1,
      sym_foreach,
    ACTIONS(11), 1,
      sym_while,
    ACTIONS(13), 1,
      sym_function,
    ACTIONS(15), 1,
      sym_macro,
    ACTIONS(17), 1,
      sym_block,
    ACTIONS(25), 1,
      sym_elseif,
    ACTIONS(27), 1,
      sym_else,
    ACTIONS(31), 1,
      sym_identifier,
    ACTIONS(33), 1,
      sym_bracket_comment_open,
    ACTIONS(35), 1,
      sym_endif,
    STATE(3), 1,
      sym_if_command,
    STATE(126), 1,
      sym_foreach_command,
    STATE(127), 1,
      sym_while_command,
    STATE(128), 1,
      sym_function_command,
    STATE(130), 1,
      sym_block_command,
    STATE(155), 1,
      sym_macro_command,
    STATE(251), 1,
      sym_endif_command,
    ACTIONS(23), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(22), 4,
      sym_body,
      sym_elseif_command,
      sym_else_command,
      aux_sym_if_condition_repeat1,
    STATE(107), 11,
      sym_bracket_comment,
      sym_if_condition,
      sym_foreach_loop,
      sym_while_loop,
      sym_function_def,
      sym_macro_def,
      sym_block_def,
      sym_normal_command,
      sym__command_invocation,
      sym__untrimmed_command_invocation,
      aux_sym_source_file_repeat1,
  [234] = 21,
    ACTIONS(7), 1,
      sym_if,
    ACTIONS(9), 1,
      sym_foreach,
    ACTIONS(11), 1,
      sym_while,
    ACTIONS(13), 1,
      sym_function,
    ACTIONS(15), 1,
      sym_macro,
    ACTIONS(17), 1,
      sym_block,
    ACTIONS(25), 1,
      sym_elseif,
    ACTIONS(27), 1,
      sym_else,
    ACTIONS(29), 1,
      sym_endif,
    ACTIONS(31), 1,
      sym_identifier,
    ACTIONS(33), 1,
      sym_bracket_comment_open,
    STATE(3), 1,
      sym_if_command,
    STATE(126), 1,
      sym_foreach_command,
    STATE(127), 1,
      sym_while_command,
    STATE(128), 1,
      sym_function_command,
    STATE(130), 1,
      sym_block_command,
    STATE(155), 1,
      sym_macro_command,
    STATE(420), 1,
      sym_endif_command,
    ACTIONS(23), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(2), 4,
      sym_body,
      sym_elseif_command,
      sym_else_command,
      aux_sym_if_condition_repeat1,
    STATE(107), 11,
      sym_bracket_comment,
      sym_if_condition,
      sym_foreach_loop,
      sym_while_loop,
      sym_function_def,
      sym_macro_def,
      sym_block_def,
      sym_normal_command,
      sym__command_invocation,
      sym__untrimmed_command_invocation,
      aux_sym_source_file_repeat1,
  [312] = 21,
    ACTIONS(7), 1,
      sym_if,
    ACTIONS(9), 1,
      sym_foreach,
    ACTIONS(11), 1,
      sym_while,
    ACTIONS(13), 1,
      sym_function,
    ACTIONS(15), 1,
      sym_macro,
    ACTIONS(17), 1,
      sym_block,
    ACTIONS(25), 1,
      sym_elseif,
    ACTIONS(27), 1,
      sym_else,
    ACTIONS(31), 1,
      sym_identifier,
    ACTIONS(33), 1,
      sym_bracket_comment_open,
    ACTIONS(37), 1,
      sym_endif,
    STATE(3), 1,
      sym_if_command,
    STATE(126), 1,
      sym_foreach_command,
    STATE(127), 1,
      sym_while_command,
    STATE(128), 1,
      sym_function_command,
    STATE(130), 1,
      sym_block_command,
    STATE(155), 1,
      sym_macro_command,
    STATE(434), 1,
      sym_endif_command,
    ACTIONS(23), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(7), 4,
      sym_body,
      sym_elseif_command,
      sym_else_command,
      aux_sym_if_condition_repeat1,
    STATE(107), 11,
      sym_bracket_comment,
      sym_if_condition,
      sym_foreach_loop,
      sym_while_loop,
      sym_function_def,
      sym_macro_def,
      sym_block_def,
      sym_normal_command,
      sym__command_invocation,
      sym__untrimmed_command_invocation,
      aux_sym_source_file_repeat1,
  [390] = 21,
    ACTIONS(7), 1,
      sym_if,
    ACTIONS(9), 1,
      sym_foreach,
    ACTIONS(11), 1,
      sym_while,
    ACTIONS(13), 1,
      sym_function,
    ACTIONS(15), 1,
      sym_macro,
    ACTIONS(17), 1,
      sym_block,
    ACTIONS(25), 1,
      sym_elseif,
    ACTIONS(27), 1,
      sym_else,
    ACTIONS(31), 1,
      sym_identifier,
    ACTIONS(33), 1,
      sym_bracket_comment_open,
    ACTIONS(37), 1,
      sym_endif,
    STATE(3), 1,
      sym_if_command,
    STATE(126), 1,
      sym_foreach_command,
    STATE(127), 1,
      sym_while_command,
    STATE(128), 1,
      sym_function_command,
    STATE(130), 1,
      sym_block_command,
    STATE(155), 1,
      sym_macro_command,
    STATE(439), 1,
      sym_endif_command,
    ACTIONS(23), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(22), 4,
      sym_body,
      sym_elseif_command,
      sym_else_command,
      aux_sym_if_condition_repeat1,
    STATE(107), 11,
      sym_bracket_comment,
      sym_if_condition,
      sym_foreach_loop,
      sym_while_loop,
      sym_function_def,
      sym_macro_def,
      sym_block_def,
      sym_normal_command,
      sym__command_invocation,
      sym__untrimmed_command_invocation,
      aux_sym_source_file_repeat1,
  [468] = 21,
    ACTIONS(7), 1,
      sym_if,
    ACTIONS(9), 1,
      sym_foreach,
    ACTIONS(11), 1,
      sym_while,
    ACTIONS(13), 1,
      sym_function,
    ACTIONS(15), 1,
      sym_macro,
    ACTIONS(17), 1,
      sym_block,
    ACTIONS(25), 1,
      sym_elseif,
    ACTIONS(27), 1,
      sym_else,
    ACTIONS(31), 1,
      sym_identifier,
    ACTIONS(33), 1,
      sym_bracket_comment_open,
    ACTIONS(39), 1,
      sym_endif,
    STATE(3), 1,
      sym_if_command,
    STATE(126), 1,
      sym_foreach_command,
    STATE(127), 1,
      sym_while_command,
    STATE(128), 1,
      sym_function_command,
    STATE(130), 1,
      sym_block_command,
    STATE(155), 1,
      sym_macro_command,
    STATE(285), 1,
      sym_endif_command,
    ACTIONS(23), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(9), 4,
      sym_body,
      sym_elseif_command,
      sym_else_command,
      aux_sym_if_condition_repeat1,
    STATE(107), 11,
      sym_bracket_comment,
      sym_if_condition,
      sym_foreach_loop,
      sym_while_loop,
      sym_function_def,
      sym_macro_def,
      sym_block_def,
      sym_normal_command,
      sym__command_invocation,
      sym__untrimmed_command_invocation,
      aux_sym_source_file_repeat1,
  [546] = 21,
    ACTIONS(7), 1,
      sym_if,
    ACTIONS(9), 1,
      sym_foreach,
    ACTIONS(11), 1,
      sym_while,
    ACTIONS(13), 1,
      sym_function,
    ACTIONS(15), 1,
      sym_macro,
    ACTIONS(17), 1,
      sym_block,
    ACTIONS(25), 1,
      sym_elseif,
    ACTIONS(27), 1,
      sym_else,
    ACTIONS(31), 1,
      sym_identifier,
    ACTIONS(33), 1,
      sym_bracket_comment_open,
    ACTIONS(39), 1,
      sym_endif,
    STATE(3), 1,
      sym_if_command,
    STATE(126), 1,
      sym_foreach_command,
    STATE(127), 1,
      sym_while_command,
    STATE(128), 1,
      sym_function_command,
    STATE(130), 1,
      sym_block_command,
    STATE(155), 1,
      sym_macro_command,
    STATE(288), 1,
      sym_endif_command,
    ACTIONS(23), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(22), 4,
      sym_body,
      sym_elseif_command,
      sym_else_command,
      aux_sym_if_condition_repeat1,
    STATE(107), 11,
      sym_bracket_comment,
      sym_if_condition,
      sym_foreach_loop,
      sym_while_loop,
      sym_function_def,
      sym_macro_def,
      sym_block_def,
      sym_normal_command,
      sym__command_invocation,
      sym__untrimmed_command_invocation,
      aux_sym_source_file_repeat1,
  [624] = 21,
    ACTIONS(7), 1,
      sym_if,
    ACTIONS(9), 1,
      sym_foreach,
    ACTIONS(11), 1,
      sym_while,
    ACTIONS(13), 1,
      sym_function,
    ACTIONS(15), 1,
      sym_macro,
    ACTIONS(17), 1,
      sym_block,
    ACTIONS(25), 1,
      sym_elseif,
    ACTIONS(27), 1,
      sym_else,
    ACTIONS(31), 1,
      sym_identifier,
    ACTIONS(33), 1,
      sym_bracket_comment_open,
    ACTIONS(41), 1,
      sym_endif,
    STATE(3), 1,
      sym_if_command,
    STATE(126), 1,
      sym_foreach_command,
    STATE(127), 1,
      sym_while_command,
    STATE(128), 1,
      sym_function_command,
    STATE(130), 1,
      sym_block_command,
    STATE(155), 1,
      sym_macro_command,
    STATE(315), 1,
      sym_endif_command,
    ACTIONS(23), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(11), 4,
      sym_body,
      sym_elseif_command,
      sym_else_command,
      aux_sym_if_condition_repeat1,
    STATE(107), 11,
      sym_bracket_comment,
      sym_if_condition,
      sym_foreach_loop,
      sym_while_loop,
      sym_function_def,
      sym_macro_def,
      sym_block_def,
      sym_normal_command,
      sym__command_invocation,
      sym__untrimmed_command_invocation,
      aux_sym_source_file_repeat1,
  [702] = 21,
    ACTIONS(7), 1,
      sym_if,
    ACTIONS(9), 1,
      sym_foreach,
    ACTIONS(11), 1,
      sym_while,
    ACTIONS(13), 1,
      sym_function,
    ACTIONS(15), 1,
      sym_macro,
    ACTIONS(17), 1,
      sym_block,
    ACTIONS(25), 1,
      sym_elseif,
    ACTIONS(27), 1,
      sym_else,
    ACTIONS(31), 1,
      sym_identifier,
    ACTIONS(33), 1,
      sym_bracket_comment_open,
    ACTIONS(41), 1,
      sym_endif,
    STATE(3), 1,
      sym_if_command,
    STATE(126), 1,
      sym_foreach_command,
    STATE(127), 1,
      sym_while_command,
    STATE(128), 1,
      sym_function_command,
    STATE(130), 1,
      sym_block_command,
    STATE(155), 1,
      sym_macro_command,
    STATE(318), 1,
      sym_endif_command,
    ACTIONS(23), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(22), 4,
      sym_body,
      sym_elseif_command,
      sym_else_command,
      aux_sym_if_condition_repeat1,
    STATE(107), 11,
      sym_bracket_comment,
      sym_if_condition,
      sym_foreach_loop,
      sym_while_loop,
      sym_function_def,
      sym_macro_def,
      sym_block_def,
      sym_normal_command,
      sym__command_invocation,
      sym__untrimmed_command_invocation,
      aux_sym_source_file_repeat1,
  [780] = 21,
    ACTIONS(7), 1,
      sym_if,
    ACTIONS(9), 1,
      sym_foreach,
    ACTIONS(11), 1,
      sym_while,
    ACTIONS(13), 1,
      sym_function,
    ACTIONS(15), 1,
      sym_macro,
    ACTIONS(17), 1,
      sym_block,
    ACTIONS(25), 1,
      sym_elseif,
    ACTIONS(27), 1,
      sym_else,
    ACTIONS(31), 1,
      sym_identifier,
    ACTIONS(33), 1,
      sym_bracket_comment_open,
    ACTIONS(43), 1,
      sym_endif,
    STATE(3), 1,
      sym_if_command,
    STATE(126), 1,
      sym_foreach_command,
    STATE(127), 1,
      sym_while_command,
    STATE(128), 1,
      sym_function_command,
    STATE(130), 1,
      sym_block_command,
    STATE(155), 1,
      sym_macro_command,
    STATE(345), 1,
      sym_endif_command,
    ACTIONS(23), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(13), 4,
      sym_body,
      sym_elseif_command,
      sym_else_command,
      aux_sym_if_condition_repeat1,
    STATE(107), 11,
      sym_bracket_comment,
      sym_if_condition,
      sym_foreach_loop,
      sym_while_loop,
      sym_function_def,
      sym_macro_def,
      sym_block_def,
      sym_normal_command,
      sym__command_invocation,
      sym__untrimmed_command_invocation,
      aux_sym_source_file_repeat1,
  [858] = 21,
    ACTIONS(7), 1,
      sym_if,
    ACTIONS(9), 1,
      sym_foreach,
    ACTIONS(11), 1,
      sym_while,
    ACTIONS(13), 1,
      sym_function,
    ACTIONS(15), 1,
      sym_macro,
    ACTIONS(17), 1,
      sym_block,
    ACTIONS(25), 1,
      sym_elseif,
    ACTIONS(27), 1,
      sym_else,
    ACTIONS(31), 1,
      sym_identifier,
    ACTIONS(33), 1,
      sym_bracket_comment_open,
    ACTIONS(43), 1,
      sym_endif,
    STATE(3), 1,
      sym_if_command,
    STATE(126), 1,
      sym_foreach_command,
    STATE(127), 1,
      sym_while_command,
    STATE(128), 1,
      sym_function_command,
    STATE(130), 1,
      sym_block_command,
    STATE(155), 1,
      sym_macro_command,
    STATE(349), 1,
      sym_endif_command,
    ACTIONS(23), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(22), 4,
      sym_body,
      sym_elseif_command,
      sym_else_command,
      aux_sym_if_condition_repeat1,
    STATE(107), 11,
      sym_bracket_comment,
      sym_if_condition,
      sym_foreach_loop,
      sym_while_loop,
      sym_function_def,
      sym_macro_def,
      sym_block_def,
      sym_normal_command,
      sym__command_invocation,
      sym__untrimmed_command_invocation,
      aux_sym_source_file_repeat1,
  [936] = 21,
    ACTIONS(7), 1,
      sym_if,
    ACTIONS(9), 1,
      sym_foreach,
    ACTIONS(11), 1,
      sym_while,
    ACTIONS(13), 1,
      sym_function,
    ACTIONS(15), 1,
      sym_macro,
    ACTIONS(17), 1,
      sym_block,
    ACTIONS(25), 1,
      sym_elseif,
    ACTIONS(27), 1,
      sym_else,
    ACTIONS(31), 1,
      sym_identifier,
    ACTIONS(33), 1,
      sym_bracket_comment_open,
    ACTIONS(45), 1,
      sym_endif,
    STATE(3), 1,
      sym_if_command,
    STATE(126), 1,
      sym_foreach_command,
    STATE(127), 1,
      sym_while_command,
    STATE(128), 1,
      sym_function_command,
    STATE(130), 1,
      sym_block_command,
    STATE(155), 1,
      sym_macro_command,
    STATE(376), 1,
      sym_endif_command,
    ACTIONS(23), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(15), 4,
      sym_body,
      sym_elseif_command,
      sym_else_command,
      aux_sym_if_condition_repeat1,
    STATE(107), 11,
      sym_bracket_comment,
      sym_if_condition,
      sym_foreach_loop,
      sym_while_loop,
      sym_function_def,
      sym_macro_def,
      sym_block_def,
      sym_normal_command,
      sym__command_invocation,
      sym__untrimmed_command_invocation,
      aux_sym_source_file_repeat1,
  [1014] = 21,
    ACTIONS(7), 1,
      sym_if,
    ACTIONS(9), 1,
      sym_foreach,
    ACTIONS(11), 1,
      sym_while,
    ACTIONS(13), 1,
      sym_function,
    ACTIONS(15), 1,
      sym_macro,
    ACTIONS(17), 1,
      sym_block,
    ACTIONS(25), 1,
      sym_elseif,
    ACTIONS(27), 1,
      sym_else,
    ACTIONS(31), 1,
      sym_identifier,
    ACTIONS(33), 1,
      sym_bracket_comment_open,
    ACTIONS(45), 1,
      sym_endif,
    STATE(3), 1,
      sym_if_command,
    STATE(126), 1,
      sym_foreach_command,
    STATE(127), 1,
      sym_while_command,
    STATE(128), 1,
      sym_function_command,
    STATE(130), 1,
      sym_block_command,
    STATE(155), 1,
      sym_macro_command,
    STATE(379), 1,
      sym_endif_command,
    ACTIONS(23), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(22), 4,
      sym_body,
      sym_elseif_command,
      sym_else_command,
      aux_sym_if_condition_repeat1,
    STATE(107), 11,
      sym_bracket_comment,
      sym_if_condition,
      sym_foreach_loop,
      sym_while_loop,
      sym_function_def,
      sym_macro_def,
      sym_block_def,
      sym_normal_command,
      sym__command_invocation,
      sym__untrimmed_command_invocation,
      aux_sym_source_file_repeat1,
  [1092] = 15,
    ACTIONS(49), 1,
      anon_sym_DOLLAR,
    ACTIONS(53), 1,
      anon_sym_LPAREN,
    ACTIONS(55), 1,
      anon_sym_RPAREN,
    ACTIONS(57), 1,
      anon_sym_DQUOTE,
    ACTIONS(59), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(61), 1,
      sym_bracket_argument_open,
    ACTIONS(63), 1,
      sym_bracket_comment_open,
    STATE(736), 1,
      sym_argument_list,
    ACTIONS(51), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(214), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(218), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(221), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(104), 5,
      sym_bracket_comment,
      sym_argument,
      sym__untrimmed_argument,
      sym__paren_argument,
      aux_sym__paren_argument_repeat1,
    STATE(157), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(47), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [1157] = 15,
    ACTIONS(49), 1,
      anon_sym_DOLLAR,
    ACTIONS(53), 1,
      anon_sym_LPAREN,
    ACTIONS(57), 1,
      anon_sym_DQUOTE,
    ACTIONS(59), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(61), 1,
      sym_bracket_argument_open,
    ACTIONS(63), 1,
      sym_bracket_comment_open,
    ACTIONS(65), 1,
      anon_sym_RPAREN,
    STATE(659), 1,
      sym_argument_list,
    ACTIONS(51), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(214), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(218), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(221), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(104), 5,
      sym_bracket_comment,
      sym_argument,
      sym__untrimmed_argument,
      sym__paren_argument,
      aux_sym__paren_argument_repeat1,
    STATE(157), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(47), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [1222] = 15,
    ACTIONS(49), 1,
      anon_sym_DOLLAR,
    ACTIONS(53), 1,
      anon_sym_LPAREN,
    ACTIONS(57), 1,
      anon_sym_DQUOTE,
    ACTIONS(59), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(61), 1,
      sym_bracket_argument_open,
    ACTIONS(63), 1,
      sym_bracket_comment_open,
    ACTIONS(67), 1,
      anon_sym_RPAREN,
    STATE(772), 1,
      sym_argument_list,
    ACTIONS(51), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(214), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(218), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(221), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(104), 5,
      sym_bracket_comment,
      sym_argument,
      sym__untrimmed_argument,
      sym__paren_argument,
      aux_sym__paren_argument_repeat1,
    STATE(157), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(47), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [1287] = 15,
    ACTIONS(49), 1,
      anon_sym_DOLLAR,
    ACTIONS(53), 1,
      anon_sym_LPAREN,
    ACTIONS(57), 1,
      anon_sym_DQUOTE,
    ACTIONS(59), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(61), 1,
      sym_bracket_argument_open,
    ACTIONS(63), 1,
      sym_bracket_comment_open,
    ACTIONS(69), 1,
      anon_sym_RPAREN,
    STATE(813), 1,
      sym_argument_list,
    ACTIONS(51), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(214), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(218), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(221), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(104), 5,
      sym_bracket_comment,
      sym_argument,
      sym__untrimmed_argument,
      sym__paren_argument,
      aux_sym__paren_argument_repeat1,
    STATE(157), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(47), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [1352] = 15,
    ACTIONS(49), 1,
      anon_sym_DOLLAR,
    ACTIONS(53), 1,
      anon_sym_LPAREN,
    ACTIONS(57), 1,
      anon_sym_DQUOTE,
    ACTIONS(59), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(61), 1,
      sym_bracket_argument_open,
    ACTIONS(63), 1,
      sym_bracket_comment_open,
    ACTIONS(71), 1,
      anon_sym_RPAREN,
    STATE(706), 1,
      sym_argument_list,
    ACTIONS(51), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(214), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(218), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(221), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(104), 5,
      sym_bracket_comment,
      sym_argument,
      sym__untrimmed_argument,
      sym__paren_argument,
      aux_sym__paren_argument_repeat1,
    STATE(157), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(47), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [1417] = 15,
    ACTIONS(49), 1,
      anon_sym_DOLLAR,
    ACTIONS(53), 1,
      anon_sym_LPAREN,
    ACTIONS(57), 1,
      anon_sym_DQUOTE,
    ACTIONS(59), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(61), 1,
      sym_bracket_argument_open,
    ACTIONS(63), 1,
      sym_bracket_comment_open,
    ACTIONS(73), 1,
      anon_sym_RPAREN,
    STATE(712), 1,
      sym_argument_list,
    ACTIONS(51), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(214), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(218), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(221), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(104), 5,
      sym_bracket_comment,
      sym_argument,
      sym__untrimmed_argument,
      sym__paren_argument,
      aux_sym__paren_argument_repeat1,
    STATE(157), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(47), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [1482] = 20,
    ACTIONS(78), 1,
      sym_if,
    ACTIONS(81), 1,
      sym_elseif,
    ACTIONS(84), 1,
      sym_else,
    ACTIONS(87), 1,
      sym_endif,
    ACTIONS(89), 1,
      sym_foreach,
    ACTIONS(92), 1,
      sym_while,
    ACTIONS(95), 1,
      sym_function,
    ACTIONS(98), 1,
      sym_macro,
    ACTIONS(101), 1,
      sym_block,
    ACTIONS(104), 1,
      sym_identifier,
    ACTIONS(107), 1,
      sym_bracket_comment_open,
    STATE(3), 1,
      sym_if_command,
    STATE(126), 1,
      sym_foreach_command,
    STATE(127), 1,
      sym_while_command,
    STATE(128), 1,
      sym_function_command,
    STATE(130), 1,
      sym_block_command,
    STATE(155), 1,
      sym_macro_command,
    ACTIONS(75), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(22), 4,
      sym_body,
      sym_elseif_command,
      sym_else_command,
      aux_sym_if_condition_repeat1,
    STATE(107), 11,
      sym_bracket_comment,
      sym_if_condition,
      sym_foreach_loop,
      sym_while_loop,
      sym_function_def,
      sym_macro_def,
      sym_block_def,
      sym_normal_command,
      sym__command_invocation,
      sym__untrimmed_command_invocation,
      aux_sym_source_file_repeat1,
  [1557] = 15,
    ACTIONS(49), 1,
      anon_sym_DOLLAR,
    ACTIONS(53), 1,
      anon_sym_LPAREN,
    ACTIONS(57), 1,
      anon_sym_DQUOTE,
    ACTIONS(59), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(61), 1,
      sym_bracket_argument_open,
    ACTIONS(63), 1,
      sym_bracket_comment_open,
    ACTIONS(110), 1,
      anon_sym_RPAREN,
    STATE(777), 1,
      sym_argument_list,
    ACTIONS(51), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(214), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(218), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(221), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(104), 5,
      sym_bracket_comment,
      sym_argument,
      sym__untrimmed_argument,
      sym__paren_argument,
      aux_sym__paren_argument_repeat1,
    STATE(157), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(47), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [1622] = 15,
    ACTIONS(49), 1,
      anon_sym_DOLLAR,
    ACTIONS(53), 1,
      anon_sym_LPAREN,
    ACTIONS(57), 1,
      anon_sym_DQUOTE,
    ACTIONS(59), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(61), 1,
      sym_bracket_argument_open,
    ACTIONS(63), 1,
      sym_bracket_comment_open,
    ACTIONS(112), 1,
      anon_sym_RPAREN,
    STATE(807), 1,
      sym_argument_list,
    ACTIONS(51), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(214), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(218), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(221), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(104), 5,
      sym_bracket_comment,
      sym_argument,
      sym__untrimmed_argument,
      sym__paren_argument,
      aux_sym__paren_argument_repeat1,
    STATE(157), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(47), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [1687] = 15,
    ACTIONS(49), 1,
      anon_sym_DOLLAR,
    ACTIONS(53), 1,
      anon_sym_LPAREN,
    ACTIONS(57), 1,
      anon_sym_DQUOTE,
    ACTIONS(59), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(61), 1,
      sym_bracket_argument_open,
    ACTIONS(63), 1,
      sym_bracket_comment_open,
    ACTIONS(114), 1,
      anon_sym_RPAREN,
    STATE(671), 1,
      sym_argument_list,
    ACTIONS(51), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(214), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(218), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(221), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(104), 5,
      sym_bracket_comment,
      sym_argument,
      sym__untrimmed_argument,
      sym__paren_argument,
      aux_sym__paren_argument_repeat1,
    STATE(157), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(47), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [1752] = 15,
    ACTIONS(49), 1,
      anon_sym_DOLLAR,
    ACTIONS(53), 1,
      anon_sym_LPAREN,
    ACTIONS(57), 1,
      anon_sym_DQUOTE,
    ACTIONS(59), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(61), 1,
      sym_bracket_argument_open,
    ACTIONS(63), 1,
      sym_bracket_comment_open,
    ACTIONS(116), 1,
      anon_sym_RPAREN,
    STATE(681), 1,
      sym_argument_list,
    ACTIONS(51), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(214), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(218), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(221), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(104), 5,
      sym_bracket_comment,
      sym_argument,
      sym__untrimmed_argument,
      sym__paren_argument,
      aux_sym__paren_argument_repeat1,
    STATE(157), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(47), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [1817] = 15,
    ACTIONS(49), 1,
      anon_sym_DOLLAR,
    ACTIONS(53), 1,
      anon_sym_LPAREN,
    ACTIONS(57), 1,
      anon_sym_DQUOTE,
    ACTIONS(59), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(61), 1,
      sym_bracket_argument_open,
    ACTIONS(63), 1,
      sym_bracket_comment_open,
    ACTIONS(118), 1,
      anon_sym_RPAREN,
    STATE(702), 1,
      sym_argument_list,
    ACTIONS(51), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(214), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(218), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(221), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(104), 5,
      sym_bracket_comment,
      sym_argument,
      sym__untrimmed_argument,
      sym__paren_argument,
      aux_sym__paren_argument_repeat1,
    STATE(157), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(47), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [1882] = 15,
    ACTIONS(49), 1,
      anon_sym_DOLLAR,
    ACTIONS(53), 1,
      anon_sym_LPAREN,
    ACTIONS(57), 1,
      anon_sym_DQUOTE,
    ACTIONS(59), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(61), 1,
      sym_bracket_argument_open,
    ACTIONS(63), 1,
      sym_bracket_comment_open,
    ACTIONS(120), 1,
      anon_sym_RPAREN,
    STATE(754), 1,
      sym_argument_list,
    ACTIONS(51), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(214), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(218), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(221), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(104), 5,
      sym_bracket_comment,
      sym_argument,
      sym__untrimmed_argument,
      sym__paren_argument,
      aux_sym__paren_argument_repeat1,
    STATE(157), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(47), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [1947] = 15,
    ACTIONS(49), 1,
      anon_sym_DOLLAR,
    ACTIONS(53), 1,
      anon_sym_LPAREN,
    ACTIONS(57), 1,
      anon_sym_DQUOTE,
    ACTIONS(59), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(61), 1,
      sym_bracket_argument_open,
    ACTIONS(63), 1,
      sym_bracket_comment_open,
    ACTIONS(122), 1,
      anon_sym_RPAREN,
    STATE(767), 1,
      sym_argument_list,
    ACTIONS(51), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(214), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(218), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(221), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(104), 5,
      sym_bracket_comment,
      sym_argument,
      sym__untrimmed_argument,
      sym__paren_argument,
      aux_sym__paren_argument_repeat1,
    STATE(157), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(47), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [2012] = 15,
    ACTIONS(49), 1,
      anon_sym_DOLLAR,
    ACTIONS(53), 1,
      anon_sym_LPAREN,
    ACTIONS(57), 1,
      anon_sym_DQUOTE,
    ACTIONS(59), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(61), 1,
      sym_bracket_argument_open,
    ACTIONS(63), 1,
      sym_bracket_comment_open,
    ACTIONS(124), 1,
      anon_sym_RPAREN,
    STATE(773), 1,
      sym_argument_list,
    ACTIONS(51), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(214), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(218), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(221), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(104), 5,
      sym_bracket_comment,
      sym_argument,
      sym__untrimmed_argument,
      sym__paren_argument,
      aux_sym__paren_argument_repeat1,
    STATE(157), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(47), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [2077] = 15,
    ACTIONS(49), 1,
      anon_sym_DOLLAR,
    ACTIONS(53), 1,
      anon_sym_LPAREN,
    ACTIONS(57), 1,
      anon_sym_DQUOTE,
    ACTIONS(59), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(61), 1,
      sym_bracket_argument_open,
    ACTIONS(63), 1,
      sym_bracket_comment_open,
    ACTIONS(126), 1,
      anon_sym_RPAREN,
    STATE(752), 1,
      sym_argument_list,
    ACTIONS(51), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(214), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(218), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(221), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(104), 5,
      sym_bracket_comment,
      sym_argument,
      sym__untrimmed_argument,
      sym__paren_argument,
      aux_sym__paren_argument_repeat1,
    STATE(157), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(47), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [2142] = 15,
    ACTIONS(49), 1,
      anon_sym_DOLLAR,
    ACTIONS(53), 1,
      anon_sym_LPAREN,
    ACTIONS(57), 1,
      anon_sym_DQUOTE,
    ACTIONS(59), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(61), 1,
      sym_bracket_argument_open,
    ACTIONS(63), 1,
      sym_bracket_comment_open,
    ACTIONS(128), 1,
      anon_sym_RPAREN,
    STATE(685), 1,
      sym_argument_list,
    ACTIONS(51), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(214), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(218), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(221), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(104), 5,
      sym_bracket_comment,
      sym_argument,
      sym__untrimmed_argument,
      sym__paren_argument,
      aux_sym__paren_argument_repeat1,
    STATE(157), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(47), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [2207] = 15,
    ACTIONS(49), 1,
      anon_sym_DOLLAR,
    ACTIONS(53), 1,
      anon_sym_LPAREN,
    ACTIONS(57), 1,
      anon_sym_DQUOTE,
    ACTIONS(59), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(61), 1,
      sym_bracket_argument_open,
    ACTIONS(63), 1,
      sym_bracket_comment_open,
    ACTIONS(130), 1,
      anon_sym_RPAREN,
    STATE(705), 1,
      sym_argument_list,
    ACTIONS(51), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(214), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(218), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(221), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(104), 5,
      sym_bracket_comment,
      sym_argument,
      sym__untrimmed_argument,
      sym__paren_argument,
      aux_sym__paren_argument_repeat1,
    STATE(157), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(47), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [2272] = 15,
    ACTIONS(49), 1,
      anon_sym_DOLLAR,
    ACTIONS(53), 1,
      anon_sym_LPAREN,
    ACTIONS(57), 1,
      anon_sym_DQUOTE,
    ACTIONS(59), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(61), 1,
      sym_bracket_argument_open,
    ACTIONS(63), 1,
      sym_bracket_comment_open,
    ACTIONS(132), 1,
      anon_sym_RPAREN,
    STATE(768), 1,
      sym_argument_list,
    ACTIONS(51), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(214), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(218), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(221), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(104), 5,
      sym_bracket_comment,
      sym_argument,
      sym__untrimmed_argument,
      sym__paren_argument,
      aux_sym__paren_argument_repeat1,
    STATE(157), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(47), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [2337] = 15,
    ACTIONS(49), 1,
      anon_sym_DOLLAR,
    ACTIONS(53), 1,
      anon_sym_LPAREN,
    ACTIONS(57), 1,
      anon_sym_DQUOTE,
    ACTIONS(59), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(61), 1,
      sym_bracket_argument_open,
    ACTIONS(63), 1,
      sym_bracket_comment_open,
    ACTIONS(134), 1,
      anon_sym_RPAREN,
    STATE(784), 1,
      sym_argument_list,
    ACTIONS(51), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(214), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(218), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(221), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(104), 5,
      sym_bracket_comment,
      sym_argument,
      sym__untrimmed_argument,
      sym__paren_argument,
      aux_sym__paren_argument_repeat1,
    STATE(157), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(47), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [2402] = 15,
    ACTIONS(49), 1,
      anon_sym_DOLLAR,
    ACTIONS(53), 1,
      anon_sym_LPAREN,
    ACTIONS(57), 1,
      anon_sym_DQUOTE,
    ACTIONS(59), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(61), 1,
      sym_bracket_argument_open,
    ACTIONS(63), 1,
      sym_bracket_comment_open,
    ACTIONS(136), 1,
      anon_sym_RPAREN,
    STATE(825), 1,
      sym_argument_list,
    ACTIONS(51), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(214), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(218), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(221), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(104), 5,
      sym_bracket_comment,
      sym_argument,
      sym__untrimmed_argument,
      sym__paren_argument,
      aux_sym__paren_argument_repeat1,
    STATE(157), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(47), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [2467] = 15,
    ACTIONS(49), 1,
      anon_sym_DOLLAR,
    ACTIONS(53), 1,
      anon_sym_LPAREN,
    ACTIONS(57), 1,
      anon_sym_DQUOTE,
    ACTIONS(59), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(61), 1,
      sym_bracket_argument_open,
    ACTIONS(63), 1,
      sym_bracket_comment_open,
    ACTIONS(138), 1,
      anon_sym_RPAREN,
    STATE(652), 1,
      sym_argument_list,
    ACTIONS(51), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(214), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(218), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(221), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(104), 5,
      sym_bracket_comment,
      sym_argument,
      sym__untrimmed_argument,
      sym__paren_argument,
      aux_sym__paren_argument_repeat1,
    STATE(157), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(47), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [2532] = 15,
    ACTIONS(49), 1,
      anon_sym_DOLLAR,
    ACTIONS(53), 1,
      anon_sym_LPAREN,
    ACTIONS(57), 1,
      anon_sym_DQUOTE,
    ACTIONS(59), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(61), 1,
      sym_bracket_argument_open,
    ACTIONS(63), 1,
      sym_bracket_comment_open,
    ACTIONS(140), 1,
      anon_sym_RPAREN,
    STATE(654), 1,
      sym_argument_list,
    ACTIONS(51), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(214), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(218), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(221), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(104), 5,
      sym_bracket_comment,
      sym_argument,
      sym__untrimmed_argument,
      sym__paren_argument,
      aux_sym__paren_argument_repeat1,
    STATE(157), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(47), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [2597] = 15,
    ACTIONS(49), 1,
      anon_sym_DOLLAR,
    ACTIONS(53), 1,
      anon_sym_LPAREN,
    ACTIONS(57), 1,
      anon_sym_DQUOTE,
    ACTIONS(59), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(61), 1,
      sym_bracket_argument_open,
    ACTIONS(63), 1,
      sym_bracket_comment_open,
    ACTIONS(142), 1,
      anon_sym_RPAREN,
    STATE(667), 1,
      sym_argument_list,
    ACTIONS(51), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(214), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(218), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(221), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(104), 5,
      sym_bracket_comment,
      sym_argument,
      sym__untrimmed_argument,
      sym__paren_argument,
      aux_sym__paren_argument_repeat1,
    STATE(157), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(47), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [2662] = 15,
    ACTIONS(49), 1,
      anon_sym_DOLLAR,
    ACTIONS(53), 1,
      anon_sym_LPAREN,
    ACTIONS(57), 1,
      anon_sym_DQUOTE,
    ACTIONS(59), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(61), 1,
      sym_bracket_argument_open,
    ACTIONS(63), 1,
      sym_bracket_comment_open,
    ACTIONS(144), 1,
      anon_sym_RPAREN,
    STATE(710), 1,
      sym_argument_list,
    ACTIONS(51), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(214), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(218), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(221), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(104), 5,
      sym_bracket_comment,
      sym_argument,
      sym__untrimmed_argument,
      sym__paren_argument,
      aux_sym__paren_argument_repeat1,
    STATE(157), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(47), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [2727] = 15,
    ACTIONS(49), 1,
      anon_sym_DOLLAR,
    ACTIONS(53), 1,
      anon_sym_LPAREN,
    ACTIONS(57), 1,
      anon_sym_DQUOTE,
    ACTIONS(59), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(61), 1,
      sym_bracket_argument_open,
    ACTIONS(63), 1,
      sym_bracket_comment_open,
    ACTIONS(146), 1,
      anon_sym_RPAREN,
    STATE(725), 1,
      sym_argument_list,
    ACTIONS(51), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(214), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(218), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(221), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(104), 5,
      sym_bracket_comment,
      sym_argument,
      sym__untrimmed_argument,
      sym__paren_argument,
      aux_sym__paren_argument_repeat1,
    STATE(157), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(47), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [2792] = 15,
    ACTIONS(49), 1,
      anon_sym_DOLLAR,
    ACTIONS(53), 1,
      anon_sym_LPAREN,
    ACTIONS(57), 1,
      anon_sym_DQUOTE,
    ACTIONS(59), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(61), 1,
      sym_bracket_argument_open,
    ACTIONS(63), 1,
      sym_bracket_comment_open,
    ACTIONS(148), 1,
      anon_sym_RPAREN,
    STATE(726), 1,
      sym_argument_list,
    ACTIONS(51), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(214), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(218), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(221), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(104), 5,
      sym_bracket_comment,
      sym_argument,
      sym__untrimmed_argument,
      sym__paren_argument,
      aux_sym__paren_argument_repeat1,
    STATE(157), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(47), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [2857] = 15,
    ACTIONS(49), 1,
      anon_sym_DOLLAR,
    ACTIONS(53), 1,
      anon_sym_LPAREN,
    ACTIONS(57), 1,
      anon_sym_DQUOTE,
    ACTIONS(59), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(61), 1,
      sym_bracket_argument_open,
    ACTIONS(63), 1,
      sym_bracket_comment_open,
    ACTIONS(150), 1,
      anon_sym_RPAREN,
    STATE(759), 1,
      sym_argument_list,
    ACTIONS(51), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(214), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(218), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(221), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(104), 5,
      sym_bracket_comment,
      sym_argument,
      sym__untrimmed_argument,
      sym__paren_argument,
      aux_sym__paren_argument_repeat1,
    STATE(157), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(47), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [2922] = 15,
    ACTIONS(49), 1,
      anon_sym_DOLLAR,
    ACTIONS(53), 1,
      anon_sym_LPAREN,
    ACTIONS(57), 1,
      anon_sym_DQUOTE,
    ACTIONS(59), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(61), 1,
      sym_bracket_argument_open,
    ACTIONS(63), 1,
      sym_bracket_comment_open,
    ACTIONS(152), 1,
      anon_sym_RPAREN,
    STATE(774), 1,
      sym_argument_list,
    ACTIONS(51), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(214), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(218), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(221), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(104), 5,
      sym_bracket_comment,
      sym_argument,
      sym__untrimmed_argument,
      sym__paren_argument,
      aux_sym__paren_argument_repeat1,
    STATE(157), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(47), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [2987] = 15,
    ACTIONS(49), 1,
      anon_sym_DOLLAR,
    ACTIONS(53), 1,
      anon_sym_LPAREN,
    ACTIONS(57), 1,
      anon_sym_DQUOTE,
    ACTIONS(59), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(61), 1,
      sym_bracket_argument_open,
    ACTIONS(63), 1,
      sym_bracket_comment_open,
    ACTIONS(154), 1,
      anon_sym_RPAREN,
    STATE(776), 1,
      sym_argument_list,
    ACTIONS(51), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(214), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(218), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(221), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(104), 5,
      sym_bracket_comment,
      sym_argument,
      sym__untrimmed_argument,
      sym__paren_argument,
      aux_sym__paren_argument_repeat1,
    STATE(157), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(47), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [3052] = 15,
    ACTIONS(49), 1,
      anon_sym_DOLLAR,
    ACTIONS(53), 1,
      anon_sym_LPAREN,
    ACTIONS(57), 1,
      anon_sym_DQUOTE,
    ACTIONS(59), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(61), 1,
      sym_bracket_argument_open,
    ACTIONS(63), 1,
      sym_bracket_comment_open,
    ACTIONS(156), 1,
      anon_sym_RPAREN,
    STATE(782), 1,
      sym_argument_list,
    ACTIONS(51), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(214), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(218), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(221), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(104), 5,
      sym_bracket_comment,
      sym_argument,
      sym__untrimmed_argument,
      sym__paren_argument,
      aux_sym__paren_argument_repeat1,
    STATE(157), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(47), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [3117] = 15,
    ACTIONS(49), 1,
      anon_sym_DOLLAR,
    ACTIONS(53), 1,
      anon_sym_LPAREN,
    ACTIONS(57), 1,
      anon_sym_DQUOTE,
    ACTIONS(59), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(61), 1,
      sym_bracket_argument_open,
    ACTIONS(63), 1,
      sym_bracket_comment_open,
    ACTIONS(158), 1,
      anon_sym_RPAREN,
    STATE(802), 1,
      sym_argument_list,
    ACTIONS(51), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(214), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(218), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(221), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(104), 5,
      sym_bracket_comment,
      sym_argument,
      sym__untrimmed_argument,
      sym__paren_argument,
      aux_sym__paren_argument_repeat1,
    STATE(157), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(47), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [3182] = 15,
    ACTIONS(49), 1,
      anon_sym_DOLLAR,
    ACTIONS(53), 1,
      anon_sym_LPAREN,
    ACTIONS(57), 1,
      anon_sym_DQUOTE,
    ACTIONS(59), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(61), 1,
      sym_bracket_argument_open,
    ACTIONS(63), 1,
      sym_bracket_comment_open,
    ACTIONS(160), 1,
      anon_sym_RPAREN,
    STATE(660), 1,
      sym_argument_list,
    ACTIONS(51), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(214), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(218), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(221), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(104), 5,
      sym_bracket_comment,
      sym_argument,
      sym__untrimmed_argument,
      sym__paren_argument,
      aux_sym__paren_argument_repeat1,
    STATE(157), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(47), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [3247] = 15,
    ACTIONS(49), 1,
      anon_sym_DOLLAR,
    ACTIONS(53), 1,
      anon_sym_LPAREN,
    ACTIONS(57), 1,
      anon_sym_DQUOTE,
    ACTIONS(59), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(61), 1,
      sym_bracket_argument_open,
    ACTIONS(63), 1,
      sym_bracket_comment_open,
    ACTIONS(162), 1,
      anon_sym_RPAREN,
    STATE(804), 1,
      sym_argument_list,
    ACTIONS(51), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(214), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(218), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(221), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(104), 5,
      sym_bracket_comment,
      sym_argument,
      sym__untrimmed_argument,
      sym__paren_argument,
      aux_sym__paren_argument_repeat1,
    STATE(157), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(47), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [3312] = 15,
    ACTIONS(49), 1,
      anon_sym_DOLLAR,
    ACTIONS(53), 1,
      anon_sym_LPAREN,
    ACTIONS(57), 1,
      anon_sym_DQUOTE,
    ACTIONS(59), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(61), 1,
      sym_bracket_argument_open,
    ACTIONS(63), 1,
      sym_bracket_comment_open,
    ACTIONS(164), 1,
      anon_sym_RPAREN,
    STATE(650), 1,
      sym_argument_list,
    ACTIONS(51), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(214), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(218), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(221), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(104), 5,
      sym_bracket_comment,
      sym_argument,
      sym__untrimmed_argument,
      sym__paren_argument,
      aux_sym__paren_argument_repeat1,
    STATE(157), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(47), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [3377] = 15,
    ACTIONS(49), 1,
      anon_sym_DOLLAR,
    ACTIONS(53), 1,
      anon_sym_LPAREN,
    ACTIONS(57), 1,
      anon_sym_DQUOTE,
    ACTIONS(59), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(61), 1,
      sym_bracket_argument_open,
    ACTIONS(63), 1,
      sym_bracket_comment_open,
    ACTIONS(166), 1,
      anon_sym_RPAREN,
    STATE(656), 1,
      sym_argument_list,
    ACTIONS(51), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(214), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(218), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(221), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(104), 5,
      sym_bracket_comment,
      sym_argument,
      sym__untrimmed_argument,
      sym__paren_argument,
      aux_sym__paren_argument_repeat1,
    STATE(157), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(47), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [3442] = 15,
    ACTIONS(49), 1,
      anon_sym_DOLLAR,
    ACTIONS(53), 1,
      anon_sym_LPAREN,
    ACTIONS(57), 1,
      anon_sym_DQUOTE,
    ACTIONS(59), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(61), 1,
      sym_bracket_argument_open,
    ACTIONS(63), 1,
      sym_bracket_comment_open,
    ACTIONS(168), 1,
      anon_sym_RPAREN,
    STATE(665), 1,
      sym_argument_list,
    ACTIONS(51), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(214), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(218), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(221), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(104), 5,
      sym_bracket_comment,
      sym_argument,
      sym__untrimmed_argument,
      sym__paren_argument,
      aux_sym__paren_argument_repeat1,
    STATE(157), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(47), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [3507] = 15,
    ACTIONS(49), 1,
      anon_sym_DOLLAR,
    ACTIONS(53), 1,
      anon_sym_LPAREN,
    ACTIONS(57), 1,
      anon_sym_DQUOTE,
    ACTIONS(59), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(61), 1,
      sym_bracket_argument_open,
    ACTIONS(63), 1,
      sym_bracket_comment_open,
    ACTIONS(170), 1,
      anon_sym_RPAREN,
    STATE(675), 1,
      sym_argument_list,
    ACTIONS(51), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(214), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(218), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(221), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(104), 5,
      sym_bracket_comment,
      sym_argument,
      sym__untrimmed_argument,
      sym__paren_argument,
      aux_sym__paren_argument_repeat1,
    STATE(157), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(47), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [3572] = 15,
    ACTIONS(49), 1,
      anon_sym_DOLLAR,
    ACTIONS(53), 1,
      anon_sym_LPAREN,
    ACTIONS(57), 1,
      anon_sym_DQUOTE,
    ACTIONS(59), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(61), 1,
      sym_bracket_argument_open,
    ACTIONS(63), 1,
      sym_bracket_comment_open,
    ACTIONS(172), 1,
      anon_sym_RPAREN,
    STATE(679), 1,
      sym_argument_list,
    ACTIONS(51), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(214), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(218), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(221), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(104), 5,
      sym_bracket_comment,
      sym_argument,
      sym__untrimmed_argument,
      sym__paren_argument,
      aux_sym__paren_argument_repeat1,
    STATE(157), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(47), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [3637] = 15,
    ACTIONS(49), 1,
      anon_sym_DOLLAR,
    ACTIONS(53), 1,
      anon_sym_LPAREN,
    ACTIONS(57), 1,
      anon_sym_DQUOTE,
    ACTIONS(59), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(61), 1,
      sym_bracket_argument_open,
    ACTIONS(63), 1,
      sym_bracket_comment_open,
    ACTIONS(174), 1,
      anon_sym_RPAREN,
    STATE(682), 1,
      sym_argument_list,
    ACTIONS(51), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(214), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(218), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(221), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(104), 5,
      sym_bracket_comment,
      sym_argument,
      sym__untrimmed_argument,
      sym__paren_argument,
      aux_sym__paren_argument_repeat1,
    STATE(157), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(47), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [3702] = 15,
    ACTIONS(49), 1,
      anon_sym_DOLLAR,
    ACTIONS(53), 1,
      anon_sym_LPAREN,
    ACTIONS(57), 1,
      anon_sym_DQUOTE,
    ACTIONS(59), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(61), 1,
      sym_bracket_argument_open,
    ACTIONS(63), 1,
      sym_bracket_comment_open,
    ACTIONS(176), 1,
      anon_sym_RPAREN,
    STATE(684), 1,
      sym_argument_list,
    ACTIONS(51), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(214), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(218), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(221), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(104), 5,
      sym_bracket_comment,
      sym_argument,
      sym__untrimmed_argument,
      sym__paren_argument,
      aux_sym__paren_argument_repeat1,
    STATE(157), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(47), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [3767] = 15,
    ACTIONS(49), 1,
      anon_sym_DOLLAR,
    ACTIONS(53), 1,
      anon_sym_LPAREN,
    ACTIONS(57), 1,
      anon_sym_DQUOTE,
    ACTIONS(59), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(61), 1,
      sym_bracket_argument_open,
    ACTIONS(63), 1,
      sym_bracket_comment_open,
    ACTIONS(178), 1,
      anon_sym_RPAREN,
    STATE(696), 1,
      sym_argument_list,
    ACTIONS(51), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(214), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(218), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(221), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(104), 5,
      sym_bracket_comment,
      sym_argument,
      sym__untrimmed_argument,
      sym__paren_argument,
      aux_sym__paren_argument_repeat1,
    STATE(157), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(47), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [3832] = 15,
    ACTIONS(49), 1,
      anon_sym_DOLLAR,
    ACTIONS(53), 1,
      anon_sym_LPAREN,
    ACTIONS(57), 1,
      anon_sym_DQUOTE,
    ACTIONS(59), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(61), 1,
      sym_bracket_argument_open,
    ACTIONS(63), 1,
      sym_bracket_comment_open,
    ACTIONS(180), 1,
      anon_sym_RPAREN,
    STATE(697), 1,
      sym_argument_list,
    ACTIONS(51), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(214), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(218), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(221), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(104), 5,
      sym_bracket_comment,
      sym_argument,
      sym__untrimmed_argument,
      sym__paren_argument,
      aux_sym__paren_argument_repeat1,
    STATE(157), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(47), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [3897] = 15,
    ACTIONS(49), 1,
      anon_sym_DOLLAR,
    ACTIONS(53), 1,
      anon_sym_LPAREN,
    ACTIONS(57), 1,
      anon_sym_DQUOTE,
    ACTIONS(59), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(61), 1,
      sym_bracket_argument_open,
    ACTIONS(63), 1,
      sym_bracket_comment_open,
    ACTIONS(182), 1,
      anon_sym_RPAREN,
    STATE(698), 1,
      sym_argument_list,
    ACTIONS(51), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(214), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(218), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(221), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(104), 5,
      sym_bracket_comment,
      sym_argument,
      sym__untrimmed_argument,
      sym__paren_argument,
      aux_sym__paren_argument_repeat1,
    STATE(157), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(47), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [3962] = 15,
    ACTIONS(49), 1,
      anon_sym_DOLLAR,
    ACTIONS(53), 1,
      anon_sym_LPAREN,
    ACTIONS(57), 1,
      anon_sym_DQUOTE,
    ACTIONS(59), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(61), 1,
      sym_bracket_argument_open,
    ACTIONS(63), 1,
      sym_bracket_comment_open,
    ACTIONS(184), 1,
      anon_sym_RPAREN,
    STATE(711), 1,
      sym_argument_list,
    ACTIONS(51), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(214), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(218), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(221), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(104), 5,
      sym_bracket_comment,
      sym_argument,
      sym__untrimmed_argument,
      sym__paren_argument,
      aux_sym__paren_argument_repeat1,
    STATE(157), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(47), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [4027] = 15,
    ACTIONS(49), 1,
      anon_sym_DOLLAR,
    ACTIONS(53), 1,
      anon_sym_LPAREN,
    ACTIONS(57), 1,
      anon_sym_DQUOTE,
    ACTIONS(59), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(61), 1,
      sym_bracket_argument_open,
    ACTIONS(63), 1,
      sym_bracket_comment_open,
    ACTIONS(186), 1,
      anon_sym_RPAREN,
    STATE(717), 1,
      sym_argument_list,
    ACTIONS(51), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(214), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(218), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(221), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(104), 5,
      sym_bracket_comment,
      sym_argument,
      sym__untrimmed_argument,
      sym__paren_argument,
      aux_sym__paren_argument_repeat1,
    STATE(157), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(47), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [4092] = 15,
    ACTIONS(49), 1,
      anon_sym_DOLLAR,
    ACTIONS(53), 1,
      anon_sym_LPAREN,
    ACTIONS(57), 1,
      anon_sym_DQUOTE,
    ACTIONS(59), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(61), 1,
      sym_bracket_argument_open,
    ACTIONS(63), 1,
      sym_bracket_comment_open,
    ACTIONS(188), 1,
      anon_sym_RPAREN,
    STATE(719), 1,
      sym_argument_list,
    ACTIONS(51), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(214), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(218), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(221), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(104), 5,
      sym_bracket_comment,
      sym_argument,
      sym__untrimmed_argument,
      sym__paren_argument,
      aux_sym__paren_argument_repeat1,
    STATE(157), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(47), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [4157] = 15,
    ACTIONS(49), 1,
      anon_sym_DOLLAR,
    ACTIONS(53), 1,
      anon_sym_LPAREN,
    ACTIONS(57), 1,
      anon_sym_DQUOTE,
    ACTIONS(59), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(61), 1,
      sym_bracket_argument_open,
    ACTIONS(63), 1,
      sym_bracket_comment_open,
    ACTIONS(190), 1,
      anon_sym_RPAREN,
    STATE(728), 1,
      sym_argument_list,
    ACTIONS(51), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(214), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(218), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(221), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(104), 5,
      sym_bracket_comment,
      sym_argument,
      sym__untrimmed_argument,
      sym__paren_argument,
      aux_sym__paren_argument_repeat1,
    STATE(157), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(47), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [4222] = 15,
    ACTIONS(49), 1,
      anon_sym_DOLLAR,
    ACTIONS(53), 1,
      anon_sym_LPAREN,
    ACTIONS(57), 1,
      anon_sym_DQUOTE,
    ACTIONS(59), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(61), 1,
      sym_bracket_argument_open,
    ACTIONS(63), 1,
      sym_bracket_comment_open,
    ACTIONS(192), 1,
      anon_sym_RPAREN,
    STATE(733), 1,
      sym_argument_list,
    ACTIONS(51), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(214), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(218), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(221), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(104), 5,
      sym_bracket_comment,
      sym_argument,
      sym__untrimmed_argument,
      sym__paren_argument,
      aux_sym__paren_argument_repeat1,
    STATE(157), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(47), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [4287] = 15,
    ACTIONS(49), 1,
      anon_sym_DOLLAR,
    ACTIONS(53), 1,
      anon_sym_LPAREN,
    ACTIONS(57), 1,
      anon_sym_DQUOTE,
    ACTIONS(59), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(61), 1,
      sym_bracket_argument_open,
    ACTIONS(63), 1,
      sym_bracket_comment_open,
    ACTIONS(194), 1,
      anon_sym_RPAREN,
    STATE(735), 1,
      sym_argument_list,
    ACTIONS(51), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(214), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(218), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(221), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(104), 5,
      sym_bracket_comment,
      sym_argument,
      sym__untrimmed_argument,
      sym__paren_argument,
      aux_sym__paren_argument_repeat1,
    STATE(157), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(47), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [4352] = 15,
    ACTIONS(49), 1,
      anon_sym_DOLLAR,
    ACTIONS(53), 1,
      anon_sym_LPAREN,
    ACTIONS(57), 1,
      anon_sym_DQUOTE,
    ACTIONS(59), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(61), 1,
      sym_bracket_argument_open,
    ACTIONS(63), 1,
      sym_bracket_comment_open,
    ACTIONS(196), 1,
      anon_sym_RPAREN,
    STATE(737), 1,
      sym_argument_list,
    ACTIONS(51), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(214), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(218), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(221), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(104), 5,
      sym_bracket_comment,
      sym_argument,
      sym__untrimmed_argument,
      sym__paren_argument,
      aux_sym__paren_argument_repeat1,
    STATE(157), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(47), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [4417] = 15,
    ACTIONS(49), 1,
      anon_sym_DOLLAR,
    ACTIONS(53), 1,
      anon_sym_LPAREN,
    ACTIONS(57), 1,
      anon_sym_DQUOTE,
    ACTIONS(59), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(61), 1,
      sym_bracket_argument_open,
    ACTIONS(63), 1,
      sym_bracket_comment_open,
    ACTIONS(198), 1,
      anon_sym_RPAREN,
    STATE(747), 1,
      sym_argument_list,
    ACTIONS(51), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(214), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(218), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(221), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(104), 5,
      sym_bracket_comment,
      sym_argument,
      sym__untrimmed_argument,
      sym__paren_argument,
      aux_sym__paren_argument_repeat1,
    STATE(157), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(47), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [4482] = 15,
    ACTIONS(49), 1,
      anon_sym_DOLLAR,
    ACTIONS(53), 1,
      anon_sym_LPAREN,
    ACTIONS(57), 1,
      anon_sym_DQUOTE,
    ACTIONS(59), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(61), 1,
      sym_bracket_argument_open,
    ACTIONS(63), 1,
      sym_bracket_comment_open,
    ACTIONS(200), 1,
      anon_sym_RPAREN,
    STATE(748), 1,
      sym_argument_list,
    ACTIONS(51), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(214), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(218), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(221), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(104), 5,
      sym_bracket_comment,
      sym_argument,
      sym__untrimmed_argument,
      sym__paren_argument,
      aux_sym__paren_argument_repeat1,
    STATE(157), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(47), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [4547] = 15,
    ACTIONS(49), 1,
      anon_sym_DOLLAR,
    ACTIONS(53), 1,
      anon_sym_LPAREN,
    ACTIONS(57), 1,
      anon_sym_DQUOTE,
    ACTIONS(59), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(61), 1,
      sym_bracket_argument_open,
    ACTIONS(63), 1,
      sym_bracket_comment_open,
    ACTIONS(202), 1,
      anon_sym_RPAREN,
    STATE(749), 1,
      sym_argument_list,
    ACTIONS(51), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(214), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(218), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(221), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(104), 5,
      sym_bracket_comment,
      sym_argument,
      sym__untrimmed_argument,
      sym__paren_argument,
      aux_sym__paren_argument_repeat1,
    STATE(157), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(47), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [4612] = 15,
    ACTIONS(49), 1,
      anon_sym_DOLLAR,
    ACTIONS(53), 1,
      anon_sym_LPAREN,
    ACTIONS(57), 1,
      anon_sym_DQUOTE,
    ACTIONS(59), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(61), 1,
      sym_bracket_argument_open,
    ACTIONS(63), 1,
      sym_bracket_comment_open,
    ACTIONS(204), 1,
      anon_sym_RPAREN,
    STATE(666), 1,
      sym_argument_list,
    ACTIONS(51), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(214), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(218), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(221), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(104), 5,
      sym_bracket_comment,
      sym_argument,
      sym__untrimmed_argument,
      sym__paren_argument,
      aux_sym__paren_argument_repeat1,
    STATE(157), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(47), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [4677] = 15,
    ACTIONS(49), 1,
      anon_sym_DOLLAR,
    ACTIONS(53), 1,
      anon_sym_LPAREN,
    ACTIONS(57), 1,
      anon_sym_DQUOTE,
    ACTIONS(59), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(61), 1,
      sym_bracket_argument_open,
    ACTIONS(63), 1,
      sym_bracket_comment_open,
    ACTIONS(206), 1,
      anon_sym_RPAREN,
    STATE(762), 1,
      sym_argument_list,
    ACTIONS(51), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(214), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(218), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(221), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(104), 5,
      sym_bracket_comment,
      sym_argument,
      sym__untrimmed_argument,
      sym__paren_argument,
      aux_sym__paren_argument_repeat1,
    STATE(157), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(47), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [4742] = 15,
    ACTIONS(49), 1,
      anon_sym_DOLLAR,
    ACTIONS(53), 1,
      anon_sym_LPAREN,
    ACTIONS(57), 1,
      anon_sym_DQUOTE,
    ACTIONS(59), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(61), 1,
      sym_bracket_argument_open,
    ACTIONS(63), 1,
      sym_bracket_comment_open,
    ACTIONS(208), 1,
      anon_sym_RPAREN,
    STATE(704), 1,
      sym_argument_list,
    ACTIONS(51), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(214), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(218), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(221), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(104), 5,
      sym_bracket_comment,
      sym_argument,
      sym__untrimmed_argument,
      sym__paren_argument,
      aux_sym__paren_argument_repeat1,
    STATE(157), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(47), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [4807] = 15,
    ACTIONS(49), 1,
      anon_sym_DOLLAR,
    ACTIONS(53), 1,
      anon_sym_LPAREN,
    ACTIONS(57), 1,
      anon_sym_DQUOTE,
    ACTIONS(59), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(61), 1,
      sym_bracket_argument_open,
    ACTIONS(63), 1,
      sym_bracket_comment_open,
    ACTIONS(210), 1,
      anon_sym_RPAREN,
    STATE(770), 1,
      sym_argument_list,
    ACTIONS(51), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(214), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(218), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(221), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(104), 5,
      sym_bracket_comment,
      sym_argument,
      sym__untrimmed_argument,
      sym__paren_argument,
      aux_sym__paren_argument_repeat1,
    STATE(157), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(47), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [4872] = 15,
    ACTIONS(49), 1,
      anon_sym_DOLLAR,
    ACTIONS(53), 1,
      anon_sym_LPAREN,
    ACTIONS(57), 1,
      anon_sym_DQUOTE,
    ACTIONS(59), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(61), 1,
      sym_bracket_argument_open,
    ACTIONS(63), 1,
      sym_bracket_comment_open,
    ACTIONS(212), 1,
      anon_sym_RPAREN,
    STATE(771), 1,
      sym_argument_list,
    ACTIONS(51), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(214), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(218), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(221), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(104), 5,
      sym_bracket_comment,
      sym_argument,
      sym__untrimmed_argument,
      sym__paren_argument,
      aux_sym__paren_argument_repeat1,
    STATE(157), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(47), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [4937] = 15,
    ACTIONS(49), 1,
      anon_sym_DOLLAR,
    ACTIONS(53), 1,
      anon_sym_LPAREN,
    ACTIONS(57), 1,
      anon_sym_DQUOTE,
    ACTIONS(59), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(61), 1,
      sym_bracket_argument_open,
    ACTIONS(63), 1,
      sym_bracket_comment_open,
    ACTIONS(214), 1,
      anon_sym_RPAREN,
    STATE(779), 1,
      sym_argument_list,
    ACTIONS(51), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(214), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(218), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(221), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(104), 5,
      sym_bracket_comment,
      sym_argument,
      sym__untrimmed_argument,
      sym__paren_argument,
      aux_sym__paren_argument_repeat1,
    STATE(157), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(47), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [5002] = 15,
    ACTIONS(49), 1,
      anon_sym_DOLLAR,
    ACTIONS(53), 1,
      anon_sym_LPAREN,
    ACTIONS(57), 1,
      anon_sym_DQUOTE,
    ACTIONS(59), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(61), 1,
      sym_bracket_argument_open,
    ACTIONS(63), 1,
      sym_bracket_comment_open,
    ACTIONS(216), 1,
      anon_sym_RPAREN,
    STATE(783), 1,
      sym_argument_list,
    ACTIONS(51), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(214), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(218), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(221), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(104), 5,
      sym_bracket_comment,
      sym_argument,
      sym__untrimmed_argument,
      sym__paren_argument,
      aux_sym__paren_argument_repeat1,
    STATE(157), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(47), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [5067] = 15,
    ACTIONS(49), 1,
      anon_sym_DOLLAR,
    ACTIONS(53), 1,
      anon_sym_LPAREN,
    ACTIONS(57), 1,
      anon_sym_DQUOTE,
    ACTIONS(59), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(61), 1,
      sym_bracket_argument_open,
    ACTIONS(63), 1,
      sym_bracket_comment_open,
    ACTIONS(218), 1,
      anon_sym_RPAREN,
    STATE(785), 1,
      sym_argument_list,
    ACTIONS(51), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(214), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(218), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(221), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(104), 5,
      sym_bracket_comment,
      sym_argument,
      sym__untrimmed_argument,
      sym__paren_argument,
      aux_sym__paren_argument_repeat1,
    STATE(157), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(47), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [5132] = 15,
    ACTIONS(49), 1,
      anon_sym_DOLLAR,
    ACTIONS(53), 1,
      anon_sym_LPAREN,
    ACTIONS(57), 1,
      anon_sym_DQUOTE,
    ACTIONS(59), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(61), 1,
      sym_bracket_argument_open,
    ACTIONS(63), 1,
      sym_bracket_comment_open,
    ACTIONS(220), 1,
      anon_sym_RPAREN,
    STATE(790), 1,
      sym_argument_list,
    ACTIONS(51), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(214), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(218), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(221), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(104), 5,
      sym_bracket_comment,
      sym_argument,
      sym__untrimmed_argument,
      sym__paren_argument,
      aux_sym__paren_argument_repeat1,
    STATE(157), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(47), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [5197] = 15,
    ACTIONS(49), 1,
      anon_sym_DOLLAR,
    ACTIONS(53), 1,
      anon_sym_LPAREN,
    ACTIONS(57), 1,
      anon_sym_DQUOTE,
    ACTIONS(59), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(61), 1,
      sym_bracket_argument_open,
    ACTIONS(63), 1,
      sym_bracket_comment_open,
    ACTIONS(222), 1,
      anon_sym_RPAREN,
    STATE(793), 1,
      sym_argument_list,
    ACTIONS(51), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(214), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(218), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(221), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(104), 5,
      sym_bracket_comment,
      sym_argument,
      sym__untrimmed_argument,
      sym__paren_argument,
      aux_sym__paren_argument_repeat1,
    STATE(157), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(47), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [5262] = 15,
    ACTIONS(49), 1,
      anon_sym_DOLLAR,
    ACTIONS(53), 1,
      anon_sym_LPAREN,
    ACTIONS(57), 1,
      anon_sym_DQUOTE,
    ACTIONS(59), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(61), 1,
      sym_bracket_argument_open,
    ACTIONS(63), 1,
      sym_bracket_comment_open,
    ACTIONS(224), 1,
      anon_sym_RPAREN,
    STATE(795), 1,
      sym_argument_list,
    ACTIONS(51), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(214), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(218), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(221), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(104), 5,
      sym_bracket_comment,
      sym_argument,
      sym__untrimmed_argument,
      sym__paren_argument,
      aux_sym__paren_argument_repeat1,
    STATE(157), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(47), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [5327] = 15,
    ACTIONS(49), 1,
      anon_sym_DOLLAR,
    ACTIONS(53), 1,
      anon_sym_LPAREN,
    ACTIONS(57), 1,
      anon_sym_DQUOTE,
    ACTIONS(59), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(61), 1,
      sym_bracket_argument_open,
    ACTIONS(63), 1,
      sym_bracket_comment_open,
    ACTIONS(226), 1,
      anon_sym_RPAREN,
    STATE(796), 1,
      sym_argument_list,
    ACTIONS(51), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(214), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(218), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(221), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(104), 5,
      sym_bracket_comment,
      sym_argument,
      sym__untrimmed_argument,
      sym__paren_argument,
      aux_sym__paren_argument_repeat1,
    STATE(157), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(47), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [5392] = 15,
    ACTIONS(49), 1,
      anon_sym_DOLLAR,
    ACTIONS(53), 1,
      anon_sym_LPAREN,
    ACTIONS(57), 1,
      anon_sym_DQUOTE,
    ACTIONS(59), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(61), 1,
      sym_bracket_argument_open,
    ACTIONS(63), 1,
      sym_bracket_comment_open,
    ACTIONS(228), 1,
      anon_sym_RPAREN,
    STATE(814), 1,
      sym_argument_list,
    ACTIONS(51), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(214), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(218), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(221), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(104), 5,
      sym_bracket_comment,
      sym_argument,
      sym__untrimmed_argument,
      sym__paren_argument,
      aux_sym__paren_argument_repeat1,
    STATE(157), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(47), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [5457] = 15,
    ACTIONS(49), 1,
      anon_sym_DOLLAR,
    ACTIONS(53), 1,
      anon_sym_LPAREN,
    ACTIONS(57), 1,
      anon_sym_DQUOTE,
    ACTIONS(59), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(61), 1,
      sym_bracket_argument_open,
    ACTIONS(63), 1,
      sym_bracket_comment_open,
    ACTIONS(230), 1,
      anon_sym_RPAREN,
    STATE(818), 1,
      sym_argument_list,
    ACTIONS(51), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(214), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(218), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(221), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(104), 5,
      sym_bracket_comment,
      sym_argument,
      sym__untrimmed_argument,
      sym__paren_argument,
      aux_sym__paren_argument_repeat1,
    STATE(157), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(47), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [5522] = 15,
    ACTIONS(49), 1,
      anon_sym_DOLLAR,
    ACTIONS(53), 1,
      anon_sym_LPAREN,
    ACTIONS(57), 1,
      anon_sym_DQUOTE,
    ACTIONS(59), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(61), 1,
      sym_bracket_argument_open,
    ACTIONS(63), 1,
      sym_bracket_comment_open,
    ACTIONS(232), 1,
      anon_sym_RPAREN,
    STATE(821), 1,
      sym_argument_list,
    ACTIONS(51), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(214), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(218), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(221), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(104), 5,
      sym_bracket_comment,
      sym_argument,
      sym__untrimmed_argument,
      sym__paren_argument,
      aux_sym__paren_argument_repeat1,
    STATE(157), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(47), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [5587] = 15,
    ACTIONS(49), 1,
      anon_sym_DOLLAR,
    ACTIONS(53), 1,
      anon_sym_LPAREN,
    ACTIONS(57), 1,
      anon_sym_DQUOTE,
    ACTIONS(59), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(61), 1,
      sym_bracket_argument_open,
    ACTIONS(63), 1,
      sym_bracket_comment_open,
    ACTIONS(234), 1,
      anon_sym_RPAREN,
    STATE(647), 1,
      sym_argument_list,
    ACTIONS(51), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(214), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(218), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(221), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(104), 5,
      sym_bracket_comment,
      sym_argument,
      sym__untrimmed_argument,
      sym__paren_argument,
      aux_sym__paren_argument_repeat1,
    STATE(157), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(47), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [5652] = 15,
    ACTIONS(49), 1,
      anon_sym_DOLLAR,
    ACTIONS(53), 1,
      anon_sym_LPAREN,
    ACTIONS(57), 1,
      anon_sym_DQUOTE,
    ACTIONS(59), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(61), 1,
      sym_bracket_argument_open,
    ACTIONS(63), 1,
      sym_bracket_comment_open,
    ACTIONS(236), 1,
      anon_sym_RPAREN,
    STATE(651), 1,
      sym_argument_list,
    ACTIONS(51), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(214), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(218), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(221), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(104), 5,
      sym_bracket_comment,
      sym_argument,
      sym__untrimmed_argument,
      sym__paren_argument,
      aux_sym__paren_argument_repeat1,
    STATE(157), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(47), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [5717] = 15,
    ACTIONS(49), 1,
      anon_sym_DOLLAR,
    ACTIONS(53), 1,
      anon_sym_LPAREN,
    ACTIONS(57), 1,
      anon_sym_DQUOTE,
    ACTIONS(59), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(61), 1,
      sym_bracket_argument_open,
    ACTIONS(63), 1,
      sym_bracket_comment_open,
    ACTIONS(238), 1,
      anon_sym_RPAREN,
    STATE(653), 1,
      sym_argument_list,
    ACTIONS(51), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(214), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(218), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(221), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(104), 5,
      sym_bracket_comment,
      sym_argument,
      sym__untrimmed_argument,
      sym__paren_argument,
      aux_sym__paren_argument_repeat1,
    STATE(157), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(47), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [5782] = 15,
    ACTIONS(49), 1,
      anon_sym_DOLLAR,
    ACTIONS(53), 1,
      anon_sym_LPAREN,
    ACTIONS(57), 1,
      anon_sym_DQUOTE,
    ACTIONS(59), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(61), 1,
      sym_bracket_argument_open,
    ACTIONS(63), 1,
      sym_bracket_comment_open,
    ACTIONS(240), 1,
      anon_sym_RPAREN,
    STATE(655), 1,
      sym_argument_list,
    ACTIONS(51), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(214), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(218), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(221), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(104), 5,
      sym_bracket_comment,
      sym_argument,
      sym__untrimmed_argument,
      sym__paren_argument,
      aux_sym__paren_argument_repeat1,
    STATE(157), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(47), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [5847] = 15,
    ACTIONS(49), 1,
      anon_sym_DOLLAR,
    ACTIONS(53), 1,
      anon_sym_LPAREN,
    ACTIONS(57), 1,
      anon_sym_DQUOTE,
    ACTIONS(59), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(61), 1,
      sym_bracket_argument_open,
    ACTIONS(63), 1,
      sym_bracket_comment_open,
    ACTIONS(242), 1,
      anon_sym_RPAREN,
    STATE(658), 1,
      sym_argument_list,
    ACTIONS(51), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(214), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(218), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(221), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(104), 5,
      sym_bracket_comment,
      sym_argument,
      sym__untrimmed_argument,
      sym__paren_argument,
      aux_sym__paren_argument_repeat1,
    STATE(157), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(47), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [5912] = 15,
    ACTIONS(49), 1,
      anon_sym_DOLLAR,
    ACTIONS(53), 1,
      anon_sym_LPAREN,
    ACTIONS(57), 1,
      anon_sym_DQUOTE,
    ACTIONS(59), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(61), 1,
      sym_bracket_argument_open,
    ACTIONS(63), 1,
      sym_bracket_comment_open,
    ACTIONS(244), 1,
      anon_sym_RPAREN,
    STATE(803), 1,
      sym_argument_list,
    ACTIONS(51), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(214), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(218), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(221), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(104), 5,
      sym_bracket_comment,
      sym_argument,
      sym__untrimmed_argument,
      sym__paren_argument,
      aux_sym__paren_argument_repeat1,
    STATE(157), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(47), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [5977] = 14,
    ACTIONS(49), 1,
      anon_sym_DOLLAR,
    ACTIONS(53), 1,
      anon_sym_LPAREN,
    ACTIONS(57), 1,
      anon_sym_DQUOTE,
    ACTIONS(59), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(61), 1,
      sym_bracket_argument_open,
    ACTIONS(63), 1,
      sym_bracket_comment_open,
    ACTIONS(248), 1,
      anon_sym_RPAREN,
    ACTIONS(246), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(214), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(218), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(221), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(98), 5,
      sym_bracket_comment,
      sym_argument,
      sym__untrimmed_argument,
      sym__paren_argument,
      aux_sym__paren_argument_repeat1,
    STATE(157), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(47), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [6039] = 14,
    ACTIONS(49), 1,
      anon_sym_DOLLAR,
    ACTIONS(53), 1,
      anon_sym_LPAREN,
    ACTIONS(57), 1,
      anon_sym_DQUOTE,
    ACTIONS(59), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(61), 1,
      sym_bracket_argument_open,
    ACTIONS(63), 1,
      sym_bracket_comment_open,
    STATE(744), 1,
      sym_argument_list,
    ACTIONS(51), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(214), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(218), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(221), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(104), 5,
      sym_bracket_comment,
      sym_argument,
      sym__untrimmed_argument,
      sym__paren_argument,
      aux_sym__paren_argument_repeat1,
    STATE(157), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(47), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [6101] = 14,
    ACTIONS(49), 1,
      anon_sym_DOLLAR,
    ACTIONS(53), 1,
      anon_sym_LPAREN,
    ACTIONS(57), 1,
      anon_sym_DQUOTE,
    ACTIONS(59), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(61), 1,
      sym_bracket_argument_open,
    ACTIONS(63), 1,
      sym_bracket_comment_open,
    STATE(757), 1,
      sym_argument_list,
    ACTIONS(51), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(214), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(218), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(221), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(104), 5,
      sym_bracket_comment,
      sym_argument,
      sym__untrimmed_argument,
      sym__paren_argument,
      aux_sym__paren_argument_repeat1,
    STATE(157), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(47), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [6163] = 14,
    ACTIONS(49), 1,
      anon_sym_DOLLAR,
    ACTIONS(53), 1,
      anon_sym_LPAREN,
    ACTIONS(57), 1,
      anon_sym_DQUOTE,
    ACTIONS(59), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(61), 1,
      sym_bracket_argument_open,
    ACTIONS(63), 1,
      sym_bracket_comment_open,
    STATE(756), 1,
      sym_argument_list,
    ACTIONS(51), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(214), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(218), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(221), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(104), 5,
      sym_bracket_comment,
      sym_argument,
      sym__untrimmed_argument,
      sym__paren_argument,
      aux_sym__paren_argument_repeat1,
    STATE(157), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(47), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [6225] = 14,
    ACTIONS(49), 1,
      anon_sym_DOLLAR,
    ACTIONS(53), 1,
      anon_sym_LPAREN,
    ACTIONS(57), 1,
      anon_sym_DQUOTE,
    ACTIONS(59), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(61), 1,
      sym_bracket_argument_open,
    ACTIONS(63), 1,
      sym_bracket_comment_open,
    STATE(775), 1,
      sym_argument_list,
    ACTIONS(51), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(214), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(218), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(221), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(104), 5,
      sym_bracket_comment,
      sym_argument,
      sym__untrimmed_argument,
      sym__paren_argument,
      aux_sym__paren_argument_repeat1,
    STATE(157), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(47), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [6287] = 14,
    ACTIONS(49), 1,
      anon_sym_DOLLAR,
    ACTIONS(53), 1,
      anon_sym_LPAREN,
    ACTIONS(57), 1,
      anon_sym_DQUOTE,
    ACTIONS(59), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(61), 1,
      sym_bracket_argument_open,
    ACTIONS(63), 1,
      sym_bracket_comment_open,
    STATE(763), 1,
      sym_argument_list,
    ACTIONS(51), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(214), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(218), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(221), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(104), 5,
      sym_bracket_comment,
      sym_argument,
      sym__untrimmed_argument,
      sym__paren_argument,
      aux_sym__paren_argument_repeat1,
    STATE(157), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(47), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [6349] = 14,
    ACTIONS(49), 1,
      anon_sym_DOLLAR,
    ACTIONS(53), 1,
      anon_sym_LPAREN,
    ACTIONS(57), 1,
      anon_sym_DQUOTE,
    ACTIONS(59), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(61), 1,
      sym_bracket_argument_open,
    ACTIONS(63), 1,
      sym_bracket_comment_open,
    STATE(826), 1,
      sym_argument_list,
    ACTIONS(51), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(214), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(218), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(221), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(104), 5,
      sym_bracket_comment,
      sym_argument,
      sym__untrimmed_argument,
      sym__paren_argument,
      aux_sym__paren_argument_repeat1,
    STATE(157), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(47), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [6411] = 14,
    ACTIONS(49), 1,
      anon_sym_DOLLAR,
    ACTIONS(53), 1,
      anon_sym_LPAREN,
    ACTIONS(57), 1,
      anon_sym_DQUOTE,
    ACTIONS(59), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(61), 1,
      sym_bracket_argument_open,
    ACTIONS(63), 1,
      sym_bracket_comment_open,
    ACTIONS(252), 1,
      anon_sym_RPAREN,
    ACTIONS(250), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(214), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(218), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(221), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(101), 5,
      sym_bracket_comment,
      sym_argument,
      sym__untrimmed_argument,
      sym__paren_argument,
      aux_sym__paren_argument_repeat1,
    STATE(157), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(47), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [6473] = 14,
    ACTIONS(49), 1,
      anon_sym_DOLLAR,
    ACTIONS(53), 1,
      anon_sym_LPAREN,
    ACTIONS(57), 1,
      anon_sym_DQUOTE,
    ACTIONS(59), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(61), 1,
      sym_bracket_argument_open,
    ACTIONS(63), 1,
      sym_bracket_comment_open,
    STATE(755), 1,
      sym_argument_list,
    ACTIONS(51), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(214), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(218), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(221), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(104), 5,
      sym_bracket_comment,
      sym_argument,
      sym__untrimmed_argument,
      sym__paren_argument,
      aux_sym__paren_argument_repeat1,
    STATE(157), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(47), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [6535] = 14,
    ACTIONS(49), 1,
      anon_sym_DOLLAR,
    ACTIONS(53), 1,
      anon_sym_LPAREN,
    ACTIONS(57), 1,
      anon_sym_DQUOTE,
    ACTIONS(59), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(61), 1,
      sym_bracket_argument_open,
    ACTIONS(63), 1,
      sym_bracket_comment_open,
    STATE(828), 1,
      sym_argument_list,
    ACTIONS(51), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(214), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(218), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(221), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(104), 5,
      sym_bracket_comment,
      sym_argument,
      sym__untrimmed_argument,
      sym__paren_argument,
      aux_sym__paren_argument_repeat1,
    STATE(157), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(47), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [6597] = 14,
    ACTIONS(257), 1,
      anon_sym_DOLLAR,
    ACTIONS(263), 1,
      anon_sym_LPAREN,
    ACTIONS(266), 1,
      anon_sym_RPAREN,
    ACTIONS(268), 1,
      anon_sym_DQUOTE,
    ACTIONS(271), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(274), 1,
      sym_bracket_argument_open,
    ACTIONS(277), 1,
      sym_bracket_comment_open,
    ACTIONS(260), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(214), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(218), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(221), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(101), 5,
      sym_bracket_comment,
      sym_argument,
      sym__untrimmed_argument,
      sym__paren_argument,
      aux_sym__paren_argument_repeat1,
    STATE(157), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(254), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [6659] = 14,
    ACTIONS(49), 1,
      anon_sym_DOLLAR,
    ACTIONS(53), 1,
      anon_sym_LPAREN,
    ACTIONS(57), 1,
      anon_sym_DQUOTE,
    ACTIONS(59), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(61), 1,
      sym_bracket_argument_open,
    ACTIONS(63), 1,
      sym_bracket_comment_open,
    STATE(761), 1,
      sym_argument_list,
    ACTIONS(51), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(214), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(218), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(221), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(104), 5,
      sym_bracket_comment,
      sym_argument,
      sym__untrimmed_argument,
      sym__paren_argument,
      aux_sym__paren_argument_repeat1,
    STATE(157), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(47), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [6721] = 14,
    ACTIONS(49), 1,
      anon_sym_DOLLAR,
    ACTIONS(53), 1,
      anon_sym_LPAREN,
    ACTIONS(57), 1,
      anon_sym_DQUOTE,
    ACTIONS(59), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(61), 1,
      sym_bracket_argument_open,
    ACTIONS(63), 1,
      sym_bracket_comment_open,
    STATE(769), 1,
      sym_argument_list,
    ACTIONS(51), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(214), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(218), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(221), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(104), 5,
      sym_bracket_comment,
      sym_argument,
      sym__untrimmed_argument,
      sym__paren_argument,
      aux_sym__paren_argument_repeat1,
    STATE(157), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(47), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [6783] = 14,
    ACTIONS(49), 1,
      anon_sym_DOLLAR,
    ACTIONS(53), 1,
      anon_sym_LPAREN,
    ACTIONS(57), 1,
      anon_sym_DQUOTE,
    ACTIONS(59), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(61), 1,
      sym_bracket_argument_open,
    ACTIONS(63), 1,
      sym_bracket_comment_open,
    ACTIONS(280), 1,
      anon_sym_RPAREN,
    ACTIONS(250), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(214), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(218), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(221), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(101), 5,
      sym_bracket_comment,
      sym_argument,
      sym__untrimmed_argument,
      sym__paren_argument,
      aux_sym__paren_argument_repeat1,
    STATE(157), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(47), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [6845] = 14,
    ACTIONS(49), 1,
      anon_sym_DOLLAR,
    ACTIONS(53), 1,
      anon_sym_LPAREN,
    ACTIONS(57), 1,
      anon_sym_DQUOTE,
    ACTIONS(59), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(61), 1,
      sym_bracket_argument_open,
    ACTIONS(63), 1,
      sym_bracket_comment_open,
    STATE(738), 1,
      sym_argument_list,
    ACTIONS(51), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(214), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(218), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(221), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(104), 5,
      sym_bracket_comment,
      sym_argument,
      sym__untrimmed_argument,
      sym__paren_argument,
      aux_sym__paren_argument_repeat1,
    STATE(157), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(47), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [6907] = 14,
    ACTIONS(49), 1,
      anon_sym_DOLLAR,
    ACTIONS(53), 1,
      anon_sym_LPAREN,
    ACTIONS(57), 1,
      anon_sym_DQUOTE,
    ACTIONS(59), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(61), 1,
      sym_bracket_argument_open,
    ACTIONS(63), 1,
      sym_bracket_comment_open,
    STATE(678), 1,
      sym_argument_list,
    ACTIONS(51), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(214), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(218), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(221), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(104), 5,
      sym_bracket_comment,
      sym_argument,
      sym__untrimmed_argument,
      sym__paren_argument,
      aux_sym__paren_argument_repeat1,
    STATE(157), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(47), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [6969] = 17,
    ACTIONS(7), 1,
      sym_if,
    ACTIONS(9), 1,
      sym_foreach,
    ACTIONS(11), 1,
      sym_while,
    ACTIONS(13), 1,
      sym_function,
    ACTIONS(15), 1,
      sym_macro,
    ACTIONS(17), 1,
      sym_block,
    ACTIONS(31), 1,
      sym_identifier,
    ACTIONS(33), 1,
      sym_bracket_comment_open,
    STATE(3), 1,
      sym_if_command,
    STATE(126), 1,
      sym_foreach_command,
    STATE(127), 1,
      sym_while_command,
    STATE(128), 1,
      sym_function_command,
    STATE(130), 1,
      sym_block_command,
    STATE(155), 1,
      sym_macro_command,
    ACTIONS(282), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(284), 3,
      sym_elseif,
      sym_else,
      sym_endif,
    STATE(108), 11,
      sym_bracket_comment,
      sym_if_condition,
      sym_foreach_loop,
      sym_while_loop,
      sym_function_def,
      sym_macro_def,
      sym_block_def,
      sym_normal_command,
      sym__command_invocation,
      sym__untrimmed_command_invocation,
      aux_sym_source_file_repeat1,
  [7034] = 17,
    ACTIONS(289), 1,
      sym_if,
    ACTIONS(294), 1,
      sym_foreach,
    ACTIONS(297), 1,
      sym_while,
    ACTIONS(300), 1,
      sym_function,
    ACTIONS(303), 1,
      sym_macro,
    ACTIONS(306), 1,
      sym_block,
    ACTIONS(309), 1,
      sym_identifier,
    ACTIONS(312), 1,
      sym_bracket_comment_open,
    STATE(3), 1,
      sym_if_command,
    STATE(126), 1,
      sym_foreach_command,
    STATE(127), 1,
      sym_while_command,
    STATE(128), 1,
      sym_function_command,
    STATE(130), 1,
      sym_block_command,
    STATE(155), 1,
      sym_macro_command,
    ACTIONS(286), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(292), 3,
      sym_elseif,
      sym_else,
      sym_endif,
    STATE(108), 11,
      sym_bracket_comment,
      sym_if_condition,
      sym_foreach_loop,
      sym_while_loop,
      sym_function_def,
      sym_macro_def,
      sym_block_def,
      sym_normal_command,
      sym__command_invocation,
      sym__untrimmed_command_invocation,
      aux_sym_source_file_repeat1,
  [7099] = 17,
    ACTIONS(289), 1,
      sym_if,
    ACTIONS(294), 1,
      sym_foreach,
    ACTIONS(297), 1,
      sym_while,
    ACTIONS(300), 1,
      sym_function,
    ACTIONS(303), 1,
      sym_macro,
    ACTIONS(306), 1,
      sym_block,
    ACTIONS(315), 1,
      ts_builtin_sym_end,
    ACTIONS(320), 1,
      sym_identifier,
    ACTIONS(323), 1,
      sym_bracket_comment_open,
    STATE(5), 1,
      sym_if_command,
    STATE(119), 1,
      sym_while_command,
    STATE(120), 1,
      sym_function_command,
    STATE(121), 1,
      sym_macro_command,
    STATE(122), 1,
      sym_block_command,
    STATE(125), 1,
      sym_foreach_command,
    ACTIONS(317), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(109), 11,
      sym_bracket_comment,
      sym_if_condition,
      sym_foreach_loop,
      sym_while_loop,
      sym_function_def,
      sym_macro_def,
      sym_block_def,
      sym_normal_command,
      sym__command_invocation,
      sym__untrimmed_command_invocation,
      aux_sym_source_file_repeat1,
  [7162] = 17,
    ACTIONS(7), 1,
      sym_if,
    ACTIONS(9), 1,
      sym_foreach,
    ACTIONS(11), 1,
      sym_while,
    ACTIONS(13), 1,
      sym_function,
    ACTIONS(15), 1,
      sym_macro,
    ACTIONS(17), 1,
      sym_block,
    ACTIONS(284), 1,
      sym_endwhile,
    ACTIONS(328), 1,
      sym_identifier,
    ACTIONS(330), 1,
      sym_bracket_comment_open,
    STATE(8), 1,
      sym_if_command,
    STATE(136), 1,
      sym_foreach_command,
    STATE(137), 1,
      sym_while_command,
    STATE(138), 1,
      sym_function_command,
    STATE(139), 1,
      sym_macro_command,
    STATE(140), 1,
      sym_block_command,
    ACTIONS(326), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(113), 11,
      sym_bracket_comment,
      sym_if_condition,
      sym_foreach_loop,
      sym_while_loop,
      sym_function_def,
      sym_macro_def,
      sym_block_def,
      sym_normal_command,
      sym__command_invocation,
      sym__untrimmed_command_invocation,
      aux_sym_source_file_repeat1,
  [7225] = 17,
    ACTIONS(289), 1,
      sym_if,
    ACTIONS(292), 1,
      sym_endforeach,
    ACTIONS(294), 1,
      sym_foreach,
    ACTIONS(297), 1,
      sym_while,
    ACTIONS(300), 1,
      sym_function,
    ACTIONS(303), 1,
      sym_macro,
    ACTIONS(306), 1,
      sym_block,
    ACTIONS(335), 1,
      sym_identifier,
    ACTIONS(338), 1,
      sym_bracket_comment_open,
    STATE(6), 1,
      sym_if_command,
    STATE(131), 1,
      sym_foreach_command,
    STATE(132), 1,
      sym_while_command,
    STATE(133), 1,
      sym_function_command,
    STATE(134), 1,
      sym_macro_command,
    STATE(135), 1,
      sym_block_command,
    ACTIONS(332), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(111), 11,
      sym_bracket_comment,
      sym_if_condition,
      sym_foreach_loop,
      sym_while_loop,
      sym_function_def,
      sym_macro_def,
      sym_block_def,
      sym_normal_command,
      sym__command_invocation,
      sym__untrimmed_command_invocation,
      aux_sym_source_file_repeat1,
  [7288] = 17,
    ACTIONS(7), 1,
      sym_if,
    ACTIONS(9), 1,
      sym_foreach,
    ACTIONS(11), 1,
      sym_while,
    ACTIONS(13), 1,
      sym_function,
    ACTIONS(15), 1,
      sym_macro,
    ACTIONS(17), 1,
      sym_block,
    ACTIONS(284), 1,
      sym_endfunction,
    ACTIONS(343), 1,
      sym_identifier,
    ACTIONS(345), 1,
      sym_bracket_comment_open,
    STATE(10), 1,
      sym_if_command,
    STATE(141), 1,
      sym_foreach_command,
    STATE(142), 1,
      sym_while_command,
    STATE(143), 1,
      sym_function_command,
    STATE(144), 1,
      sym_macro_command,
    STATE(145), 1,
      sym_block_command,
    ACTIONS(341), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(115), 11,
      sym_bracket_comment,
      sym_if_condition,
      sym_foreach_loop,
      sym_while_loop,
      sym_function_def,
      sym_macro_def,
      sym_block_def,
      sym_normal_command,
      sym__command_invocation,
      sym__untrimmed_command_invocation,
      aux_sym_source_file_repeat1,
  [7351] = 17,
    ACTIONS(289), 1,
      sym_if,
    ACTIONS(292), 1,
      sym_endwhile,
    ACTIONS(294), 1,
      sym_foreach,
    ACTIONS(297), 1,
      sym_while,
    ACTIONS(300), 1,
      sym_function,
    ACTIONS(303), 1,
      sym_macro,
    ACTIONS(306), 1,
      sym_block,
    ACTIONS(350), 1,
      sym_identifier,
    ACTIONS(353), 1,
      sym_bracket_comment_open,
    STATE(8), 1,
      sym_if_command,
    STATE(136), 1,
      sym_foreach_command,
    STATE(137), 1,
      sym_while_command,
    STATE(138), 1,
      sym_function_command,
    STATE(139), 1,
      sym_macro_command,
    STATE(140), 1,
      sym_block_command,
    ACTIONS(347), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(113), 11,
      sym_bracket_comment,
      sym_if_condition,
      sym_foreach_loop,
      sym_while_loop,
      sym_function_def,
      sym_macro_def,
      sym_block_def,
      sym_normal_command,
      sym__command_invocation,
      sym__untrimmed_command_invocation,
      aux_sym_source_file_repeat1,
  [7414] = 17,
    ACTIONS(7), 1,
      sym_if,
    ACTIONS(9), 1,
      sym_foreach,
    ACTIONS(11), 1,
      sym_while,
    ACTIONS(13), 1,
      sym_function,
    ACTIONS(15), 1,
      sym_macro,
    ACTIONS(17), 1,
      sym_block,
    ACTIONS(284), 1,
      sym_endmacro,
    ACTIONS(358), 1,
      sym_identifier,
    ACTIONS(360), 1,
      sym_bracket_comment_open,
    STATE(12), 1,
      sym_if_command,
    STATE(146), 1,
      sym_foreach_command,
    STATE(147), 1,
      sym_while_command,
    STATE(148), 1,
      sym_function_command,
    STATE(149), 1,
      sym_macro_command,
    STATE(150), 1,
      sym_block_command,
    ACTIONS(356), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(117), 11,
      sym_bracket_comment,
      sym_if_condition,
      sym_foreach_loop,
      sym_while_loop,
      sym_function_def,
      sym_macro_def,
      sym_block_def,
      sym_normal_command,
      sym__command_invocation,
      sym__untrimmed_command_invocation,
      aux_sym_source_file_repeat1,
  [7477] = 17,
    ACTIONS(289), 1,
      sym_if,
    ACTIONS(292), 1,
      sym_endfunction,
    ACTIONS(294), 1,
      sym_foreach,
    ACTIONS(297), 1,
      sym_while,
    ACTIONS(300), 1,
      sym_function,
    ACTIONS(303), 1,
      sym_macro,
    ACTIONS(306), 1,
      sym_block,
    ACTIONS(365), 1,
      sym_identifier,
    ACTIONS(368), 1,
      sym_bracket_comment_open,
    STATE(10), 1,
      sym_if_command,
    STATE(141), 1,
      sym_foreach_command,
    STATE(142), 1,
      sym_while_command,
    STATE(143), 1,
      sym_function_command,
    STATE(144), 1,
      sym_macro_command,
    STATE(145), 1,
      sym_block_command,
    ACTIONS(362), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(115), 11,
      sym_bracket_comment,
      sym_if_condition,
      sym_foreach_loop,
      sym_while_loop,
      sym_function_def,
      sym_macro_def,
      sym_block_def,
      sym_normal_command,
      sym__command_invocation,
      sym__untrimmed_command_invocation,
      aux_sym_source_file_repeat1,
  [7540] = 17,
    ACTIONS(7), 1,
      sym_if,
    ACTIONS(9), 1,
      sym_foreach,
    ACTIONS(11), 1,
      sym_while,
    ACTIONS(13), 1,
      sym_function,
    ACTIONS(15), 1,
      sym_macro,
    ACTIONS(17), 1,
      sym_block,
    ACTIONS(284), 1,
      sym_endblock,
    ACTIONS(373), 1,
      sym_identifier,
    ACTIONS(375), 1,
      sym_bracket_comment_open,
    STATE(14), 1,
      sym_if_command,
    STATE(129), 1,
      sym_block_command,
    STATE(151), 1,
      sym_foreach_command,
    STATE(152), 1,
      sym_while_command,
    STATE(153), 1,
      sym_function_command,
    STATE(154), 1,
      sym_macro_command,
    ACTIONS(371), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(118), 11,
      sym_bracket_comment,
      sym_if_condition,
      sym_foreach_loop,
      sym_while_loop,
      sym_function_def,
      sym_macro_def,
      sym_block_def,
      sym_normal_command,
      sym__command_invocation,
      sym__untrimmed_command_invocation,
      aux_sym_source_file_repeat1,
  [7603] = 17,
    ACTIONS(289), 1,
      sym_if,
    ACTIONS(292), 1,
      sym_endmacro,
    ACTIONS(294), 1,
      sym_foreach,
    ACTIONS(297), 1,
      sym_while,
    ACTIONS(300), 1,
      sym_function,
    ACTIONS(303), 1,
      sym_macro,
    ACTIONS(306), 1,
      sym_block,
    ACTIONS(380), 1,
      sym_identifier,
    ACTIONS(383), 1,
      sym_bracket_comment_open,
    STATE(12), 1,
      sym_if_command,
    STATE(146), 1,
      sym_foreach_command,
    STATE(147), 1,
      sym_while_command,
    STATE(148), 1,
      sym_function_command,
    STATE(149), 1,
      sym_macro_command,
    STATE(150), 1,
      sym_block_command,
    ACTIONS(377), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(117), 11,
      sym_bracket_comment,
      sym_if_condition,
      sym_foreach_loop,
      sym_while_loop,
      sym_function_def,
      sym_macro_def,
      sym_block_def,
      sym_normal_command,
      sym__command_invocation,
      sym__untrimmed_command_invocation,
      aux_sym_source_file_repeat1,
  [7666] = 17,
    ACTIONS(289), 1,
      sym_if,
    ACTIONS(292), 1,
      sym_endblock,
    ACTIONS(294), 1,
      sym_foreach,
    ACTIONS(297), 1,
      sym_while,
    ACTIONS(300), 1,
      sym_function,
    ACTIONS(303), 1,
      sym_macro,
    ACTIONS(306), 1,
      sym_block,
    ACTIONS(389), 1,
      sym_identifier,
    ACTIONS(392), 1,
      sym_bracket_comment_open,
    STATE(14), 1,
      sym_if_command,
    STATE(129), 1,
      sym_block_command,
    STATE(151), 1,
      sym_foreach_command,
    STATE(152), 1,
      sym_while_command,
    STATE(153), 1,
      sym_function_command,
    STATE(154), 1,
      sym_macro_command,
    ACTIONS(386), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(118), 11,
      sym_bracket_comment,
      sym_if_condition,
      sym_foreach_loop,
      sym_while_loop,
      sym_function_def,
      sym_macro_def,
      sym_block_def,
      sym_normal_command,
      sym__command_invocation,
      sym__untrimmed_command_invocation,
      aux_sym_source_file_repeat1,
  [7729] = 17,
    ACTIONS(7), 1,
      sym_if,
    ACTIONS(9), 1,
      sym_foreach,
    ACTIONS(11), 1,
      sym_while,
    ACTIONS(13), 1,
      sym_function,
    ACTIONS(15), 1,
      sym_macro,
    ACTIONS(17), 1,
      sym_block,
    ACTIONS(328), 1,
      sym_identifier,
    ACTIONS(330), 1,
      sym_bracket_comment_open,
    STATE(8), 1,
      sym_if_command,
    STATE(136), 1,
      sym_foreach_command,
    STATE(137), 1,
      sym_while_command,
    STATE(138), 1,
      sym_function_command,
    STATE(139), 1,
      sym_macro_command,
    STATE(140), 1,
      sym_block_command,
    STATE(638), 1,
      sym_body,
    ACTIONS(395), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(110), 11,
      sym_bracket_comment,
      sym_if_condition,
      sym_foreach_loop,
      sym_while_loop,
      sym_function_def,
      sym_macro_def,
      sym_block_def,
      sym_normal_command,
      sym__command_invocation,
      sym__untrimmed_command_invocation,
      aux_sym_source_file_repeat1,
  [7792] = 17,
    ACTIONS(7), 1,
      sym_if,
    ACTIONS(9), 1,
      sym_foreach,
    ACTIONS(11), 1,
      sym_while,
    ACTIONS(13), 1,
      sym_function,
    ACTIONS(15), 1,
      sym_macro,
    ACTIONS(17), 1,
      sym_block,
    ACTIONS(343), 1,
      sym_identifier,
    ACTIONS(345), 1,
      sym_bracket_comment_open,
    STATE(10), 1,
      sym_if_command,
    STATE(141), 1,
      sym_foreach_command,
    STATE(142), 1,
      sym_while_command,
    STATE(143), 1,
      sym_function_command,
    STATE(144), 1,
      sym_macro_command,
    STATE(145), 1,
      sym_block_command,
    STATE(600), 1,
      sym_body,
    ACTIONS(397), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(112), 11,
      sym_bracket_comment,
      sym_if_condition,
      sym_foreach_loop,
      sym_while_loop,
      sym_function_def,
      sym_macro_def,
      sym_block_def,
      sym_normal_command,
      sym__command_invocation,
      sym__untrimmed_command_invocation,
      aux_sym_source_file_repeat1,
  [7855] = 17,
    ACTIONS(7), 1,
      sym_if,
    ACTIONS(9), 1,
      sym_foreach,
    ACTIONS(11), 1,
      sym_while,
    ACTIONS(13), 1,
      sym_function,
    ACTIONS(15), 1,
      sym_macro,
    ACTIONS(17), 1,
      sym_block,
    ACTIONS(358), 1,
      sym_identifier,
    ACTIONS(360), 1,
      sym_bracket_comment_open,
    STATE(12), 1,
      sym_if_command,
    STATE(146), 1,
      sym_foreach_command,
    STATE(147), 1,
      sym_while_command,
    STATE(148), 1,
      sym_function_command,
    STATE(149), 1,
      sym_macro_command,
    STATE(150), 1,
      sym_block_command,
    STATE(601), 1,
      sym_body,
    ACTIONS(399), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(114), 11,
      sym_bracket_comment,
      sym_if_condition,
      sym_foreach_loop,
      sym_while_loop,
      sym_function_def,
      sym_macro_def,
      sym_block_def,
      sym_normal_command,
      sym__command_invocation,
      sym__untrimmed_command_invocation,
      aux_sym_source_file_repeat1,
  [7918] = 17,
    ACTIONS(7), 1,
      sym_if,
    ACTIONS(9), 1,
      sym_foreach,
    ACTIONS(11), 1,
      sym_while,
    ACTIONS(13), 1,
      sym_function,
    ACTIONS(15), 1,
      sym_macro,
    ACTIONS(17), 1,
      sym_block,
    ACTIONS(373), 1,
      sym_identifier,
    ACTIONS(375), 1,
      sym_bracket_comment_open,
    STATE(14), 1,
      sym_if_command,
    STATE(129), 1,
      sym_block_command,
    STATE(151), 1,
      sym_foreach_command,
    STATE(152), 1,
      sym_while_command,
    STATE(153), 1,
      sym_function_command,
    STATE(154), 1,
      sym_macro_command,
    STATE(605), 1,
      sym_body,
    ACTIONS(401), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(116), 11,
      sym_bracket_comment,
      sym_if_condition,
      sym_foreach_loop,
      sym_while_loop,
      sym_function_def,
      sym_macro_def,
      sym_block_def,
      sym_normal_command,
      sym__command_invocation,
      sym__untrimmed_command_invocation,
      aux_sym_source_file_repeat1,
  [7981] = 17,
    ACTIONS(7), 1,
      sym_if,
    ACTIONS(9), 1,
      sym_foreach,
    ACTIONS(11), 1,
      sym_while,
    ACTIONS(13), 1,
      sym_function,
    ACTIONS(15), 1,
      sym_macro,
    ACTIONS(17), 1,
      sym_block,
    ACTIONS(19), 1,
      sym_identifier,
    ACTIONS(21), 1,
      sym_bracket_comment_open,
    ACTIONS(403), 1,
      ts_builtin_sym_end,
    STATE(5), 1,
      sym_if_command,
    STATE(119), 1,
      sym_while_command,
    STATE(120), 1,
      sym_function_command,
    STATE(121), 1,
      sym_macro_command,
    STATE(122), 1,
      sym_block_command,
    STATE(125), 1,
      sym_foreach_command,
    ACTIONS(405), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(109), 11,
      sym_bracket_comment,
      sym_if_condition,
      sym_foreach_loop,
      sym_while_loop,
      sym_function_def,
      sym_macro_def,
      sym_block_def,
      sym_normal_command,
      sym__command_invocation,
      sym__untrimmed_command_invocation,
      aux_sym_source_file_repeat1,
  [8044] = 17,
    ACTIONS(7), 1,
      sym_if,
    ACTIONS(9), 1,
      sym_foreach,
    ACTIONS(11), 1,
      sym_while,
    ACTIONS(13), 1,
      sym_function,
    ACTIONS(15), 1,
      sym_macro,
    ACTIONS(17), 1,
      sym_block,
    ACTIONS(284), 1,
      sym_endforeach,
    ACTIONS(409), 1,
      sym_identifier,
    ACTIONS(411), 1,
      sym_bracket_comment_open,
    STATE(6), 1,
      sym_if_command,
    STATE(131), 1,
      sym_foreach_command,
    STATE(132), 1,
      sym_while_command,
    STATE(133), 1,
      sym_function_command,
    STATE(134), 1,
      sym_macro_command,
    STATE(135), 1,
      sym_block_command,
    ACTIONS(407), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(111), 11,
      sym_bracket_comment,
      sym_if_condition,
      sym_foreach_loop,
      sym_while_loop,
      sym_function_def,
      sym_macro_def,
      sym_block_def,
      sym_normal_command,
      sym__command_invocation,
      sym__untrimmed_command_invocation,
      aux_sym_source_file_repeat1,
  [8107] = 17,
    ACTIONS(7), 1,
      sym_if,
    ACTIONS(9), 1,
      sym_foreach,
    ACTIONS(11), 1,
      sym_while,
    ACTIONS(13), 1,
      sym_function,
    ACTIONS(15), 1,
      sym_macro,
    ACTIONS(17), 1,
      sym_block,
    ACTIONS(409), 1,
      sym_identifier,
    ACTIONS(411), 1,
      sym_bracket_comment_open,
    STATE(6), 1,
      sym_if_command,
    STATE(131), 1,
      sym_foreach_command,
    STATE(132), 1,
      sym_while_command,
    STATE(133), 1,
      sym_function_command,
    STATE(134), 1,
      sym_macro_command,
    STATE(135), 1,
      sym_block_command,
    STATE(628), 1,
      sym_body,
    ACTIONS(413), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(124), 11,
      sym_bracket_comment,
      sym_if_condition,
      sym_foreach_loop,
      sym_while_loop,
      sym_function_def,
      sym_macro_def,
      sym_block_def,
      sym_normal_command,
      sym__command_invocation,
      sym__untrimmed_command_invocation,
      aux_sym_source_file_repeat1,
  [8170] = 17,
    ACTIONS(7), 1,
      sym_if,
    ACTIONS(9), 1,
      sym_foreach,
    ACTIONS(11), 1,
      sym_while,
    ACTIONS(13), 1,
      sym_function,
    ACTIONS(15), 1,
      sym_macro,
    ACTIONS(17), 1,
      sym_block,
    ACTIONS(409), 1,
      sym_identifier,
    ACTIONS(411), 1,
      sym_bracket_comment_open,
    STATE(6), 1,
      sym_if_command,
    STATE(131), 1,
      sym_foreach_command,
    STATE(132), 1,
      sym_while_command,
    STATE(133), 1,
      sym_function_command,
    STATE(134), 1,
      sym_macro_command,
    STATE(135), 1,
      sym_block_command,
    STATE(614), 1,
      sym_body,
    ACTIONS(413), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(124), 11,
      sym_bracket_comment,
      sym_if_condition,
      sym_foreach_loop,
      sym_while_loop,
      sym_function_def,
      sym_macro_def,
      sym_block_def,
      sym_normal_command,
      sym__command_invocation,
      sym__untrimmed_command_invocation,
      aux_sym_source_file_repeat1,
  [8233] = 17,
    ACTIONS(7), 1,
      sym_if,
    ACTIONS(9), 1,
      sym_foreach,
    ACTIONS(11), 1,
      sym_while,
    ACTIONS(13), 1,
      sym_function,
    ACTIONS(15), 1,
      sym_macro,
    ACTIONS(17), 1,
      sym_block,
    ACTIONS(328), 1,
      sym_identifier,
    ACTIONS(330), 1,
      sym_bracket_comment_open,
    STATE(8), 1,
      sym_if_command,
    STATE(136), 1,
      sym_foreach_command,
    STATE(137), 1,
      sym_while_command,
    STATE(138), 1,
      sym_function_command,
    STATE(139), 1,
      sym_macro_command,
    STATE(140), 1,
      sym_block_command,
    STATE(615), 1,
      sym_body,
    ACTIONS(395), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(110), 11,
      sym_bracket_comment,
      sym_if_condition,
      sym_foreach_loop,
      sym_while_loop,
      sym_function_def,
      sym_macro_def,
      sym_block_def,
      sym_normal_command,
      sym__command_invocation,
      sym__untrimmed_command_invocation,
      aux_sym_source_file_repeat1,
  [8296] = 17,
    ACTIONS(7), 1,
      sym_if,
    ACTIONS(9), 1,
      sym_foreach,
    ACTIONS(11), 1,
      sym_while,
    ACTIONS(13), 1,
      sym_function,
    ACTIONS(15), 1,
      sym_macro,
    ACTIONS(17), 1,
      sym_block,
    ACTIONS(343), 1,
      sym_identifier,
    ACTIONS(345), 1,
      sym_bracket_comment_open,
    STATE(10), 1,
      sym_if_command,
    STATE(141), 1,
      sym_foreach_command,
    STATE(142), 1,
      sym_while_command,
    STATE(143), 1,
      sym_function_command,
    STATE(144), 1,
      sym_macro_command,
    STATE(145), 1,
      sym_block_command,
    STATE(616), 1,
      sym_body,
    ACTIONS(397), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(112), 11,
      sym_bracket_comment,
      sym_if_condition,
      sym_foreach_loop,
      sym_while_loop,
      sym_function_def,
      sym_macro_def,
      sym_block_def,
      sym_normal_command,
      sym__command_invocation,
      sym__untrimmed_command_invocation,
      aux_sym_source_file_repeat1,
  [8359] = 17,
    ACTIONS(7), 1,
      sym_if,
    ACTIONS(9), 1,
      sym_foreach,
    ACTIONS(11), 1,
      sym_while,
    ACTIONS(13), 1,
      sym_function,
    ACTIONS(15), 1,
      sym_macro,
    ACTIONS(17), 1,
      sym_block,
    ACTIONS(373), 1,
      sym_identifier,
    ACTIONS(375), 1,
      sym_bracket_comment_open,
    STATE(14), 1,
      sym_if_command,
    STATE(129), 1,
      sym_block_command,
    STATE(151), 1,
      sym_foreach_command,
    STATE(152), 1,
      sym_while_command,
    STATE(153), 1,
      sym_function_command,
    STATE(154), 1,
      sym_macro_command,
    STATE(623), 1,
      sym_body,
    ACTIONS(401), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(116), 11,
      sym_bracket_comment,
      sym_if_condition,
      sym_foreach_loop,
      sym_while_loop,
      sym_function_def,
      sym_macro_def,
      sym_block_def,
      sym_normal_command,
      sym__command_invocation,
      sym__untrimmed_command_invocation,
      aux_sym_source_file_repeat1,
  [8422] = 17,
    ACTIONS(7), 1,
      sym_if,
    ACTIONS(9), 1,
      sym_foreach,
    ACTIONS(11), 1,
      sym_while,
    ACTIONS(13), 1,
      sym_function,
    ACTIONS(15), 1,
      sym_macro,
    ACTIONS(17), 1,
      sym_block,
    ACTIONS(373), 1,
      sym_identifier,
    ACTIONS(375), 1,
      sym_bracket_comment_open,
    STATE(14), 1,
      sym_if_command,
    STATE(129), 1,
      sym_block_command,
    STATE(151), 1,
      sym_foreach_command,
    STATE(152), 1,
      sym_while_command,
    STATE(153), 1,
      sym_function_command,
    STATE(154), 1,
      sym_macro_command,
    STATE(630), 1,
      sym_body,
    ACTIONS(401), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(116), 11,
      sym_bracket_comment,
      sym_if_condition,
      sym_foreach_loop,
      sym_while_loop,
      sym_function_def,
      sym_macro_def,
      sym_block_def,
      sym_normal_command,
      sym__command_invocation,
      sym__untrimmed_command_invocation,
      aux_sym_source_file_repeat1,
  [8485] = 17,
    ACTIONS(7), 1,
      sym_if,
    ACTIONS(9), 1,
      sym_foreach,
    ACTIONS(11), 1,
      sym_while,
    ACTIONS(13), 1,
      sym_function,
    ACTIONS(15), 1,
      sym_macro,
    ACTIONS(17), 1,
      sym_block,
    ACTIONS(409), 1,
      sym_identifier,
    ACTIONS(411), 1,
      sym_bracket_comment_open,
    STATE(6), 1,
      sym_if_command,
    STATE(131), 1,
      sym_foreach_command,
    STATE(132), 1,
      sym_while_command,
    STATE(133), 1,
      sym_function_command,
    STATE(134), 1,
      sym_macro_command,
    STATE(135), 1,
      sym_block_command,
    STATE(640), 1,
      sym_body,
    ACTIONS(413), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(124), 11,
      sym_bracket_comment,
      sym_if_condition,
      sym_foreach_loop,
      sym_while_loop,
      sym_function_def,
      sym_macro_def,
      sym_block_def,
      sym_normal_command,
      sym__command_invocation,
      sym__untrimmed_command_invocation,
      aux_sym_source_file_repeat1,
  [8548] = 17,
    ACTIONS(7), 1,
      sym_if,
    ACTIONS(9), 1,
      sym_foreach,
    ACTIONS(11), 1,
      sym_while,
    ACTIONS(13), 1,
      sym_function,
    ACTIONS(15), 1,
      sym_macro,
    ACTIONS(17), 1,
      sym_block,
    ACTIONS(328), 1,
      sym_identifier,
    ACTIONS(330), 1,
      sym_bracket_comment_open,
    STATE(8), 1,
      sym_if_command,
    STATE(136), 1,
      sym_foreach_command,
    STATE(137), 1,
      sym_while_command,
    STATE(138), 1,
      sym_function_command,
    STATE(139), 1,
      sym_macro_command,
    STATE(140), 1,
      sym_block_command,
    STATE(641), 1,
      sym_body,
    ACTIONS(395), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(110), 11,
      sym_bracket_comment,
      sym_if_condition,
      sym_foreach_loop,
      sym_while_loop,
      sym_function_def,
      sym_macro_def,
      sym_block_def,
      sym_normal_command,
      sym__command_invocation,
      sym__untrimmed_command_invocation,
      aux_sym_source_file_repeat1,
  [8611] = 17,
    ACTIONS(7), 1,
      sym_if,
    ACTIONS(9), 1,
      sym_foreach,
    ACTIONS(11), 1,
      sym_while,
    ACTIONS(13), 1,
      sym_function,
    ACTIONS(15), 1,
      sym_macro,
    ACTIONS(17), 1,
      sym_block,
    ACTIONS(343), 1,
      sym_identifier,
    ACTIONS(345), 1,
      sym_bracket_comment_open,
    STATE(10), 1,
      sym_if_command,
    STATE(141), 1,
      sym_foreach_command,
    STATE(142), 1,
      sym_while_command,
    STATE(143), 1,
      sym_function_command,
    STATE(144), 1,
      sym_macro_command,
    STATE(145), 1,
      sym_block_command,
    STATE(642), 1,
      sym_body,
    ACTIONS(397), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(112), 11,
      sym_bracket_comment,
      sym_if_condition,
      sym_foreach_loop,
      sym_while_loop,
      sym_function_def,
      sym_macro_def,
      sym_block_def,
      sym_normal_command,
      sym__command_invocation,
      sym__untrimmed_command_invocation,
      aux_sym_source_file_repeat1,
  [8674] = 17,
    ACTIONS(7), 1,
      sym_if,
    ACTIONS(9), 1,
      sym_foreach,
    ACTIONS(11), 1,
      sym_while,
    ACTIONS(13), 1,
      sym_function,
    ACTIONS(15), 1,
      sym_macro,
    ACTIONS(17), 1,
      sym_block,
    ACTIONS(358), 1,
      sym_identifier,
    ACTIONS(360), 1,
      sym_bracket_comment_open,
    STATE(12), 1,
      sym_if_command,
    STATE(146), 1,
      sym_foreach_command,
    STATE(147), 1,
      sym_while_command,
    STATE(148), 1,
      sym_function_command,
    STATE(149), 1,
      sym_macro_command,
    STATE(150), 1,
      sym_block_command,
    STATE(637), 1,
      sym_body,
    ACTIONS(399), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(114), 11,
      sym_bracket_comment,
      sym_if_condition,
      sym_foreach_loop,
      sym_while_loop,
      sym_function_def,
      sym_macro_def,
      sym_block_def,
      sym_normal_command,
      sym__command_invocation,
      sym__untrimmed_command_invocation,
      aux_sym_source_file_repeat1,
  [8737] = 17,
    ACTIONS(7), 1,
      sym_if,
    ACTIONS(9), 1,
      sym_foreach,
    ACTIONS(11), 1,
      sym_while,
    ACTIONS(13), 1,
      sym_function,
    ACTIONS(15), 1,
      sym_macro,
    ACTIONS(17), 1,
      sym_block,
    ACTIONS(373), 1,
      sym_identifier,
    ACTIONS(375), 1,
      sym_bracket_comment_open,
    STATE(14), 1,
      sym_if_command,
    STATE(129), 1,
      sym_block_command,
    STATE(151), 1,
      sym_foreach_command,
    STATE(152), 1,
      sym_while_command,
    STATE(153), 1,
      sym_function_command,
    STATE(154), 1,
      sym_macro_command,
    STATE(609), 1,
      sym_body,
    ACTIONS(401), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(116), 11,
      sym_bracket_comment,
      sym_if_condition,
      sym_foreach_loop,
      sym_while_loop,
      sym_function_def,
      sym_macro_def,
      sym_block_def,
      sym_normal_command,
      sym__command_invocation,
      sym__untrimmed_command_invocation,
      aux_sym_source_file_repeat1,
  [8800] = 17,
    ACTIONS(7), 1,
      sym_if,
    ACTIONS(9), 1,
      sym_foreach,
    ACTIONS(11), 1,
      sym_while,
    ACTIONS(13), 1,
      sym_function,
    ACTIONS(15), 1,
      sym_macro,
    ACTIONS(17), 1,
      sym_block,
    ACTIONS(409), 1,
      sym_identifier,
    ACTIONS(411), 1,
      sym_bracket_comment_open,
    STATE(6), 1,
      sym_if_command,
    STATE(131), 1,
      sym_foreach_command,
    STATE(132), 1,
      sym_while_command,
    STATE(133), 1,
      sym_function_command,
    STATE(134), 1,
      sym_macro_command,
    STATE(135), 1,
      sym_block_command,
    STATE(608), 1,
      sym_body,
    ACTIONS(413), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(124), 11,
      sym_bracket_comment,
      sym_if_condition,
      sym_foreach_loop,
      sym_while_loop,
      sym_function_def,
      sym_macro_def,
      sym_block_def,
      sym_normal_command,
      sym__command_invocation,
      sym__untrimmed_command_invocation,
      aux_sym_source_file_repeat1,
  [8863] = 17,
    ACTIONS(7), 1,
      sym_if,
    ACTIONS(9), 1,
      sym_foreach,
    ACTIONS(11), 1,
      sym_while,
    ACTIONS(13), 1,
      sym_function,
    ACTIONS(15), 1,
      sym_macro,
    ACTIONS(17), 1,
      sym_block,
    ACTIONS(328), 1,
      sym_identifier,
    ACTIONS(330), 1,
      sym_bracket_comment_open,
    STATE(8), 1,
      sym_if_command,
    STATE(136), 1,
      sym_foreach_command,
    STATE(137), 1,
      sym_while_command,
    STATE(138), 1,
      sym_function_command,
    STATE(139), 1,
      sym_macro_command,
    STATE(140), 1,
      sym_block_command,
    STATE(613), 1,
      sym_body,
    ACTIONS(395), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(110), 11,
      sym_bracket_comment,
      sym_if_condition,
      sym_foreach_loop,
      sym_while_loop,
      sym_function_def,
      sym_macro_def,
      sym_block_def,
      sym_normal_command,
      sym__command_invocation,
      sym__untrimmed_command_invocation,
      aux_sym_source_file_repeat1,
  [8926] = 17,
    ACTIONS(7), 1,
      sym_if,
    ACTIONS(9), 1,
      sym_foreach,
    ACTIONS(11), 1,
      sym_while,
    ACTIONS(13), 1,
      sym_function,
    ACTIONS(15), 1,
      sym_macro,
    ACTIONS(17), 1,
      sym_block,
    ACTIONS(343), 1,
      sym_identifier,
    ACTIONS(345), 1,
      sym_bracket_comment_open,
    STATE(10), 1,
      sym_if_command,
    STATE(141), 1,
      sym_foreach_command,
    STATE(142), 1,
      sym_while_command,
    STATE(143), 1,
      sym_function_command,
    STATE(144), 1,
      sym_macro_command,
    STATE(145), 1,
      sym_block_command,
    STATE(629), 1,
      sym_body,
    ACTIONS(397), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(112), 11,
      sym_bracket_comment,
      sym_if_condition,
      sym_foreach_loop,
      sym_while_loop,
      sym_function_def,
      sym_macro_def,
      sym_block_def,
      sym_normal_command,
      sym__command_invocation,
      sym__untrimmed_command_invocation,
      aux_sym_source_file_repeat1,
  [8989] = 17,
    ACTIONS(7), 1,
      sym_if,
    ACTIONS(9), 1,
      sym_foreach,
    ACTIONS(11), 1,
      sym_while,
    ACTIONS(13), 1,
      sym_function,
    ACTIONS(15), 1,
      sym_macro,
    ACTIONS(17), 1,
      sym_block,
    ACTIONS(358), 1,
      sym_identifier,
    ACTIONS(360), 1,
      sym_bracket_comment_open,
    STATE(12), 1,
      sym_if_command,
    STATE(146), 1,
      sym_foreach_command,
    STATE(147), 1,
      sym_while_command,
    STATE(148), 1,
      sym_function_command,
    STATE(149), 1,
      sym_macro_command,
    STATE(150), 1,
      sym_block_command,
    STATE(633), 1,
      sym_body,
    ACTIONS(399), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(114), 11,
      sym_bracket_comment,
      sym_if_condition,
      sym_foreach_loop,
      sym_while_loop,
      sym_function_def,
      sym_macro_def,
      sym_block_def,
      sym_normal_command,
      sym__command_invocation,
      sym__untrimmed_command_invocation,
      aux_sym_source_file_repeat1,
  [9052] = 17,
    ACTIONS(7), 1,
      sym_if,
    ACTIONS(9), 1,
      sym_foreach,
    ACTIONS(11), 1,
      sym_while,
    ACTIONS(13), 1,
      sym_function,
    ACTIONS(15), 1,
      sym_macro,
    ACTIONS(17), 1,
      sym_block,
    ACTIONS(373), 1,
      sym_identifier,
    ACTIONS(375), 1,
      sym_bracket_comment_open,
    STATE(14), 1,
      sym_if_command,
    STATE(129), 1,
      sym_block_command,
    STATE(151), 1,
      sym_foreach_command,
    STATE(152), 1,
      sym_while_command,
    STATE(153), 1,
      sym_function_command,
    STATE(154), 1,
      sym_macro_command,
    STATE(604), 1,
      sym_body,
    ACTIONS(401), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(116), 11,
      sym_bracket_comment,
      sym_if_condition,
      sym_foreach_loop,
      sym_while_loop,
      sym_function_def,
      sym_macro_def,
      sym_block_def,
      sym_normal_command,
      sym__command_invocation,
      sym__untrimmed_command_invocation,
      aux_sym_source_file_repeat1,
  [9115] = 17,
    ACTIONS(7), 1,
      sym_if,
    ACTIONS(9), 1,
      sym_foreach,
    ACTIONS(11), 1,
      sym_while,
    ACTIONS(13), 1,
      sym_function,
    ACTIONS(15), 1,
      sym_macro,
    ACTIONS(17), 1,
      sym_block,
    ACTIONS(409), 1,
      sym_identifier,
    ACTIONS(411), 1,
      sym_bracket_comment_open,
    STATE(6), 1,
      sym_if_command,
    STATE(131), 1,
      sym_foreach_command,
    STATE(132), 1,
      sym_while_command,
    STATE(133), 1,
      sym_function_command,
    STATE(134), 1,
      sym_macro_command,
    STATE(135), 1,
      sym_block_command,
    STATE(603), 1,
      sym_body,
    ACTIONS(413), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(124), 11,
      sym_bracket_comment,
      sym_if_condition,
      sym_foreach_loop,
      sym_while_loop,
      sym_function_def,
      sym_macro_def,
      sym_block_def,
      sym_normal_command,
      sym__command_invocation,
      sym__untrimmed_command_invocation,
      aux_sym_source_file_repeat1,
  [9178] = 17,
    ACTIONS(7), 1,
      sym_if,
    ACTIONS(9), 1,
      sym_foreach,
    ACTIONS(11), 1,
      sym_while,
    ACTIONS(13), 1,
      sym_function,
    ACTIONS(15), 1,
      sym_macro,
    ACTIONS(17), 1,
      sym_block,
    ACTIONS(328), 1,
      sym_identifier,
    ACTIONS(330), 1,
      sym_bracket_comment_open,
    STATE(8), 1,
      sym_if_command,
    STATE(136), 1,
      sym_foreach_command,
    STATE(137), 1,
      sym_while_command,
    STATE(138), 1,
      sym_function_command,
    STATE(139), 1,
      sym_macro_command,
    STATE(140), 1,
      sym_block_command,
    STATE(596), 1,
      sym_body,
    ACTIONS(395), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(110), 11,
      sym_bracket_comment,
      sym_if_condition,
      sym_foreach_loop,
      sym_while_loop,
      sym_function_def,
      sym_macro_def,
      sym_block_def,
      sym_normal_command,
      sym__command_invocation,
      sym__untrimmed_command_invocation,
      aux_sym_source_file_repeat1,
  [9241] = 17,
    ACTIONS(7), 1,
      sym_if,
    ACTIONS(9), 1,
      sym_foreach,
    ACTIONS(11), 1,
      sym_while,
    ACTIONS(13), 1,
      sym_function,
    ACTIONS(15), 1,
      sym_macro,
    ACTIONS(17), 1,
      sym_block,
    ACTIONS(343), 1,
      sym_identifier,
    ACTIONS(345), 1,
      sym_bracket_comment_open,
    STATE(10), 1,
      sym_if_command,
    STATE(141), 1,
      sym_foreach_command,
    STATE(142), 1,
      sym_while_command,
    STATE(143), 1,
      sym_function_command,
    STATE(144), 1,
      sym_macro_command,
    STATE(145), 1,
      sym_block_command,
    STATE(621), 1,
      sym_body,
    ACTIONS(397), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(112), 11,
      sym_bracket_comment,
      sym_if_condition,
      sym_foreach_loop,
      sym_while_loop,
      sym_function_def,
      sym_macro_def,
      sym_block_def,
      sym_normal_command,
      sym__command_invocation,
      sym__untrimmed_command_invocation,
      aux_sym_source_file_repeat1,
  [9304] = 17,
    ACTIONS(7), 1,
      sym_if,
    ACTIONS(9), 1,
      sym_foreach,
    ACTIONS(11), 1,
      sym_while,
    ACTIONS(13), 1,
      sym_function,
    ACTIONS(15), 1,
      sym_macro,
    ACTIONS(17), 1,
      sym_block,
    ACTIONS(358), 1,
      sym_identifier,
    ACTIONS(360), 1,
      sym_bracket_comment_open,
    STATE(12), 1,
      sym_if_command,
    STATE(146), 1,
      sym_foreach_command,
    STATE(147), 1,
      sym_while_command,
    STATE(148), 1,
      sym_function_command,
    STATE(149), 1,
      sym_macro_command,
    STATE(150), 1,
      sym_block_command,
    STATE(639), 1,
      sym_body,
    ACTIONS(399), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(114), 11,
      sym_bracket_comment,
      sym_if_condition,
      sym_foreach_loop,
      sym_while_loop,
      sym_function_def,
      sym_macro_def,
      sym_block_def,
      sym_normal_command,
      sym__command_invocation,
      sym__untrimmed_command_invocation,
      aux_sym_source_file_repeat1,
  [9367] = 17,
    ACTIONS(7), 1,
      sym_if,
    ACTIONS(9), 1,
      sym_foreach,
    ACTIONS(11), 1,
      sym_while,
    ACTIONS(13), 1,
      sym_function,
    ACTIONS(15), 1,
      sym_macro,
    ACTIONS(17), 1,
      sym_block,
    ACTIONS(373), 1,
      sym_identifier,
    ACTIONS(375), 1,
      sym_bracket_comment_open,
    STATE(14), 1,
      sym_if_command,
    STATE(129), 1,
      sym_block_command,
    STATE(151), 1,
      sym_foreach_command,
    STATE(152), 1,
      sym_while_command,
    STATE(153), 1,
      sym_function_command,
    STATE(154), 1,
      sym_macro_command,
    STATE(643), 1,
      sym_body,
    ACTIONS(401), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(116), 11,
      sym_bracket_comment,
      sym_if_condition,
      sym_foreach_loop,
      sym_while_loop,
      sym_function_def,
      sym_macro_def,
      sym_block_def,
      sym_normal_command,
      sym__command_invocation,
      sym__untrimmed_command_invocation,
      aux_sym_source_file_repeat1,
  [9430] = 17,
    ACTIONS(7), 1,
      sym_if,
    ACTIONS(9), 1,
      sym_foreach,
    ACTIONS(11), 1,
      sym_while,
    ACTIONS(13), 1,
      sym_function,
    ACTIONS(15), 1,
      sym_macro,
    ACTIONS(17), 1,
      sym_block,
    ACTIONS(409), 1,
      sym_identifier,
    ACTIONS(411), 1,
      sym_bracket_comment_open,
    STATE(6), 1,
      sym_if_command,
    STATE(131), 1,
      sym_foreach_command,
    STATE(132), 1,
      sym_while_command,
    STATE(133), 1,
      sym_function_command,
    STATE(134), 1,
      sym_macro_command,
    STATE(135), 1,
      sym_block_command,
    STATE(619), 1,
      sym_body,
    ACTIONS(413), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(124), 11,
      sym_bracket_comment,
      sym_if_condition,
      sym_foreach_loop,
      sym_while_loop,
      sym_function_def,
      sym_macro_def,
      sym_block_def,
      sym_normal_command,
      sym__command_invocation,
      sym__untrimmed_command_invocation,
      aux_sym_source_file_repeat1,
  [9493] = 17,
    ACTIONS(7), 1,
      sym_if,
    ACTIONS(9), 1,
      sym_foreach,
    ACTIONS(11), 1,
      sym_while,
    ACTIONS(13), 1,
      sym_function,
    ACTIONS(15), 1,
      sym_macro,
    ACTIONS(17), 1,
      sym_block,
    ACTIONS(328), 1,
      sym_identifier,
    ACTIONS(330), 1,
      sym_bracket_comment_open,
    STATE(8), 1,
      sym_if_command,
    STATE(136), 1,
      sym_foreach_command,
    STATE(137), 1,
      sym_while_command,
    STATE(138), 1,
      sym_function_command,
    STATE(139), 1,
      sym_macro_command,
    STATE(140), 1,
      sym_block_command,
    STATE(620), 1,
      sym_body,
    ACTIONS(395), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(110), 11,
      sym_bracket_comment,
      sym_if_condition,
      sym_foreach_loop,
      sym_while_loop,
      sym_function_def,
      sym_macro_def,
      sym_block_def,
      sym_normal_command,
      sym__command_invocation,
      sym__untrimmed_command_invocation,
      aux_sym_source_file_repeat1,
  [9556] = 17,
    ACTIONS(7), 1,
      sym_if,
    ACTIONS(9), 1,
      sym_foreach,
    ACTIONS(11), 1,
      sym_while,
    ACTIONS(13), 1,
      sym_function,
    ACTIONS(15), 1,
      sym_macro,
    ACTIONS(17), 1,
      sym_block,
    ACTIONS(343), 1,
      sym_identifier,
    ACTIONS(345), 1,
      sym_bracket_comment_open,
    STATE(10), 1,
      sym_if_command,
    STATE(141), 1,
      sym_foreach_command,
    STATE(142), 1,
      sym_while_command,
    STATE(143), 1,
      sym_function_command,
    STATE(144), 1,
      sym_macro_command,
    STATE(145), 1,
      sym_block_command,
    STATE(597), 1,
      sym_body,
    ACTIONS(397), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(112), 11,
      sym_bracket_comment,
      sym_if_condition,
      sym_foreach_loop,
      sym_while_loop,
      sym_function_def,
      sym_macro_def,
      sym_block_def,
      sym_normal_command,
      sym__command_invocation,
      sym__untrimmed_command_invocation,
      aux_sym_source_file_repeat1,
  [9619] = 17,
    ACTIONS(7), 1,
      sym_if,
    ACTIONS(9), 1,
      sym_foreach,
    ACTIONS(11), 1,
      sym_while,
    ACTIONS(13), 1,
      sym_function,
    ACTIONS(15), 1,
      sym_macro,
    ACTIONS(17), 1,
      sym_block,
    ACTIONS(358), 1,
      sym_identifier,
    ACTIONS(360), 1,
      sym_bracket_comment_open,
    STATE(12), 1,
      sym_if_command,
    STATE(146), 1,
      sym_foreach_command,
    STATE(147), 1,
      sym_while_command,
    STATE(148), 1,
      sym_function_command,
    STATE(149), 1,
      sym_macro_command,
    STATE(150), 1,
      sym_block_command,
    STATE(598), 1,
      sym_body,
    ACTIONS(399), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(114), 11,
      sym_bracket_comment,
      sym_if_condition,
      sym_foreach_loop,
      sym_while_loop,
      sym_function_def,
      sym_macro_def,
      sym_block_def,
      sym_normal_command,
      sym__command_invocation,
      sym__untrimmed_command_invocation,
      aux_sym_source_file_repeat1,
  [9682] = 17,
    ACTIONS(7), 1,
      sym_if,
    ACTIONS(9), 1,
      sym_foreach,
    ACTIONS(11), 1,
      sym_while,
    ACTIONS(13), 1,
      sym_function,
    ACTIONS(15), 1,
      sym_macro,
    ACTIONS(17), 1,
      sym_block,
    ACTIONS(373), 1,
      sym_identifier,
    ACTIONS(375), 1,
      sym_bracket_comment_open,
    STATE(14), 1,
      sym_if_command,
    STATE(129), 1,
      sym_block_command,
    STATE(151), 1,
      sym_foreach_command,
    STATE(152), 1,
      sym_while_command,
    STATE(153), 1,
      sym_function_command,
    STATE(154), 1,
      sym_macro_command,
    STATE(599), 1,
      sym_body,
    ACTIONS(401), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(116), 11,
      sym_bracket_comment,
      sym_if_condition,
      sym_foreach_loop,
      sym_while_loop,
      sym_function_def,
      sym_macro_def,
      sym_block_def,
      sym_normal_command,
      sym__command_invocation,
      sym__untrimmed_command_invocation,
      aux_sym_source_file_repeat1,
  [9745] = 17,
    ACTIONS(7), 1,
      sym_if,
    ACTIONS(9), 1,
      sym_foreach,
    ACTIONS(11), 1,
      sym_while,
    ACTIONS(13), 1,
      sym_function,
    ACTIONS(15), 1,
      sym_macro,
    ACTIONS(17), 1,
      sym_block,
    ACTIONS(409), 1,
      sym_identifier,
    ACTIONS(411), 1,
      sym_bracket_comment_open,
    STATE(6), 1,
      sym_if_command,
    STATE(131), 1,
      sym_foreach_command,
    STATE(132), 1,
      sym_while_command,
    STATE(133), 1,
      sym_function_command,
    STATE(134), 1,
      sym_macro_command,
    STATE(135), 1,
      sym_block_command,
    STATE(617), 1,
      sym_body,
    ACTIONS(413), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(124), 11,
      sym_bracket_comment,
      sym_if_condition,
      sym_foreach_loop,
      sym_while_loop,
      sym_function_def,
      sym_macro_def,
      sym_block_def,
      sym_normal_command,
      sym__command_invocation,
      sym__untrimmed_command_invocation,
      aux_sym_source_file_repeat1,
  [9808] = 17,
    ACTIONS(7), 1,
      sym_if,
    ACTIONS(9), 1,
      sym_foreach,
    ACTIONS(11), 1,
      sym_while,
    ACTIONS(13), 1,
      sym_function,
    ACTIONS(15), 1,
      sym_macro,
    ACTIONS(17), 1,
      sym_block,
    ACTIONS(328), 1,
      sym_identifier,
    ACTIONS(330), 1,
      sym_bracket_comment_open,
    STATE(8), 1,
      sym_if_command,
    STATE(136), 1,
      sym_foreach_command,
    STATE(137), 1,
      sym_while_command,
    STATE(138), 1,
      sym_function_command,
    STATE(139), 1,
      sym_macro_command,
    STATE(140), 1,
      sym_block_command,
    STATE(618), 1,
      sym_body,
    ACTIONS(395), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(110), 11,
      sym_bracket_comment,
      sym_if_condition,
      sym_foreach_loop,
      sym_while_loop,
      sym_function_def,
      sym_macro_def,
      sym_block_def,
      sym_normal_command,
      sym__command_invocation,
      sym__untrimmed_command_invocation,
      aux_sym_source_file_repeat1,
  [9871] = 17,
    ACTIONS(7), 1,
      sym_if,
    ACTIONS(9), 1,
      sym_foreach,
    ACTIONS(11), 1,
      sym_while,
    ACTIONS(13), 1,
      sym_function,
    ACTIONS(15), 1,
      sym_macro,
    ACTIONS(17), 1,
      sym_block,
    ACTIONS(343), 1,
      sym_identifier,
    ACTIONS(345), 1,
      sym_bracket_comment_open,
    STATE(10), 1,
      sym_if_command,
    STATE(141), 1,
      sym_foreach_command,
    STATE(142), 1,
      sym_while_command,
    STATE(143), 1,
      sym_function_command,
    STATE(144), 1,
      sym_macro_command,
    STATE(145), 1,
      sym_block_command,
    STATE(644), 1,
      sym_body,
    ACTIONS(397), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(112), 11,
      sym_bracket_comment,
      sym_if_condition,
      sym_foreach_loop,
      sym_while_loop,
      sym_function_def,
      sym_macro_def,
      sym_block_def,
      sym_normal_command,
      sym__command_invocation,
      sym__untrimmed_command_invocation,
      aux_sym_source_file_repeat1,
  [9934] = 17,
    ACTIONS(7), 1,
      sym_if,
    ACTIONS(9), 1,
      sym_foreach,
    ACTIONS(11), 1,
      sym_while,
    ACTIONS(13), 1,
      sym_function,
    ACTIONS(15), 1,
      sym_macro,
    ACTIONS(17), 1,
      sym_block,
    ACTIONS(358), 1,
      sym_identifier,
    ACTIONS(360), 1,
      sym_bracket_comment_open,
    STATE(12), 1,
      sym_if_command,
    STATE(146), 1,
      sym_foreach_command,
    STATE(147), 1,
      sym_while_command,
    STATE(148), 1,
      sym_function_command,
    STATE(149), 1,
      sym_macro_command,
    STATE(150), 1,
      sym_block_command,
    STATE(622), 1,
      sym_body,
    ACTIONS(399), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(114), 11,
      sym_bracket_comment,
      sym_if_condition,
      sym_foreach_loop,
      sym_while_loop,
      sym_function_def,
      sym_macro_def,
      sym_block_def,
      sym_normal_command,
      sym__command_invocation,
      sym__untrimmed_command_invocation,
      aux_sym_source_file_repeat1,
  [9997] = 17,
    ACTIONS(7), 1,
      sym_if,
    ACTIONS(9), 1,
      sym_foreach,
    ACTIONS(11), 1,
      sym_while,
    ACTIONS(13), 1,
      sym_function,
    ACTIONS(15), 1,
      sym_macro,
    ACTIONS(17), 1,
      sym_block,
    ACTIONS(358), 1,
      sym_identifier,
    ACTIONS(360), 1,
      sym_bracket_comment_open,
    STATE(12), 1,
      sym_if_command,
    STATE(146), 1,
      sym_foreach_command,
    STATE(147), 1,
      sym_while_command,
    STATE(148), 1,
      sym_function_command,
    STATE(149), 1,
      sym_macro_command,
    STATE(150), 1,
      sym_block_command,
    STATE(624), 1,
      sym_body,
    ACTIONS(399), 2,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    STATE(114), 11,
      sym_bracket_comment,
      sym_if_condition,
      sym_foreach_loop,
      sym_while_loop,
      sym_function_def,
      sym_macro_def,
      sym_block_def,
      sym_normal_command,
      sym__command_invocation,
      sym__untrimmed_command_invocation,
      aux_sym_source_file_repeat1,
  [10060] = 11,
    ACTIONS(417), 1,
      anon_sym_DOLLAR,
    ACTIONS(419), 1,
      anon_sym_RPAREN,
    ACTIONS(421), 1,
      anon_sym_DQUOTE,
    ACTIONS(423), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(425), 1,
      sym_bracket_argument_open,
    STATE(792), 1,
      sym_argument,
    STATE(464), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(465), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(649), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(194), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(415), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [10108] = 7,
    ACTIONS(49), 1,
      anon_sym_DOLLAR,
    ACTIONS(429), 1,
      aux_sym__unquoted_text_token1,
    STATE(214), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(221), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(166), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(47), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
    ACTIONS(427), 7,
      sym_bracket_argument_open,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DQUOTE,
  [10148] = 11,
    ACTIONS(417), 1,
      anon_sym_DOLLAR,
    ACTIONS(421), 1,
      anon_sym_DQUOTE,
    ACTIONS(423), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(425), 1,
      sym_bracket_argument_open,
    ACTIONS(431), 1,
      anon_sym_RPAREN,
    STATE(676), 1,
      sym_argument,
    STATE(464), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(465), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(649), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(194), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(415), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [10196] = 11,
    ACTIONS(417), 1,
      anon_sym_DOLLAR,
    ACTIONS(421), 1,
      anon_sym_DQUOTE,
    ACTIONS(423), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(425), 1,
      sym_bracket_argument_open,
    ACTIONS(433), 1,
      anon_sym_RPAREN,
    STATE(691), 1,
      sym_argument,
    STATE(464), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(465), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(649), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(194), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(415), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [10244] = 11,
    ACTIONS(417), 1,
      anon_sym_DOLLAR,
    ACTIONS(421), 1,
      anon_sym_DQUOTE,
    ACTIONS(423), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(425), 1,
      sym_bracket_argument_open,
    ACTIONS(435), 1,
      anon_sym_RPAREN,
    STATE(648), 1,
      sym_argument,
    STATE(464), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(465), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(649), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(194), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(415), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [10292] = 11,
    ACTIONS(417), 1,
      anon_sym_DOLLAR,
    ACTIONS(421), 1,
      anon_sym_DQUOTE,
    ACTIONS(423), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(425), 1,
      sym_bracket_argument_open,
    ACTIONS(437), 1,
      anon_sym_RPAREN,
    STATE(729), 1,
      sym_argument,
    STATE(464), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(465), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(649), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(194), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(415), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [10340] = 11,
    ACTIONS(417), 1,
      anon_sym_DOLLAR,
    ACTIONS(421), 1,
      anon_sym_DQUOTE,
    ACTIONS(423), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(425), 1,
      sym_bracket_argument_open,
    ACTIONS(439), 1,
      anon_sym_RPAREN,
    STATE(746), 1,
      sym_argument,
    STATE(464), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(465), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(649), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(194), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(415), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [10388] = 11,
    ACTIONS(417), 1,
      anon_sym_DOLLAR,
    ACTIONS(421), 1,
      anon_sym_DQUOTE,
    ACTIONS(423), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(425), 1,
      sym_bracket_argument_open,
    ACTIONS(441), 1,
      anon_sym_RPAREN,
    STATE(780), 1,
      sym_argument,
    STATE(464), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(465), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(649), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(194), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(415), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [10436] = 11,
    ACTIONS(417), 1,
      anon_sym_DOLLAR,
    ACTIONS(421), 1,
      anon_sym_DQUOTE,
    ACTIONS(423), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(425), 1,
      sym_bracket_argument_open,
    ACTIONS(443), 1,
      anon_sym_RPAREN,
    STATE(657), 1,
      sym_argument,
    STATE(464), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(465), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(649), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(194), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(415), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [10484] = 11,
    ACTIONS(417), 1,
      anon_sym_DOLLAR,
    ACTIONS(421), 1,
      anon_sym_DQUOTE,
    ACTIONS(423), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(425), 1,
      sym_bracket_argument_open,
    ACTIONS(445), 1,
      anon_sym_RPAREN,
    STATE(742), 1,
      sym_argument,
    STATE(464), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(465), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(649), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(194), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(415), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [10532] = 7,
    ACTIONS(450), 1,
      anon_sym_DOLLAR,
    ACTIONS(455), 1,
      aux_sym__unquoted_text_token1,
    STATE(214), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(221), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(166), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(447), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
    ACTIONS(453), 7,
      sym_bracket_argument_open,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DQUOTE,
  [10572] = 11,
    ACTIONS(417), 1,
      anon_sym_DOLLAR,
    ACTIONS(421), 1,
      anon_sym_DQUOTE,
    ACTIONS(423), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(425), 1,
      sym_bracket_argument_open,
    ACTIONS(458), 1,
      anon_sym_RPAREN,
    STATE(646), 1,
      sym_argument,
    STATE(464), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(465), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(649), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(194), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(415), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [10620] = 11,
    ACTIONS(417), 1,
      anon_sym_DOLLAR,
    ACTIONS(421), 1,
      anon_sym_DQUOTE,
    ACTIONS(423), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(425), 1,
      sym_bracket_argument_open,
    ACTIONS(460), 1,
      anon_sym_RPAREN,
    STATE(822), 1,
      sym_argument,
    STATE(464), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(465), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(649), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(194), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(415), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [10668] = 11,
    ACTIONS(417), 1,
      anon_sym_DOLLAR,
    ACTIONS(421), 1,
      anon_sym_DQUOTE,
    ACTIONS(423), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(425), 1,
      sym_bracket_argument_open,
    ACTIONS(462), 1,
      anon_sym_RPAREN,
    STATE(760), 1,
      sym_argument,
    STATE(464), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(465), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(649), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(194), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(415), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [10716] = 11,
    ACTIONS(417), 1,
      anon_sym_DOLLAR,
    ACTIONS(421), 1,
      anon_sym_DQUOTE,
    ACTIONS(423), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(425), 1,
      sym_bracket_argument_open,
    ACTIONS(464), 1,
      anon_sym_RPAREN,
    STATE(730), 1,
      sym_argument,
    STATE(464), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(465), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(649), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(194), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(415), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [10764] = 11,
    ACTIONS(417), 1,
      anon_sym_DOLLAR,
    ACTIONS(421), 1,
      anon_sym_DQUOTE,
    ACTIONS(423), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(425), 1,
      sym_bracket_argument_open,
    ACTIONS(466), 1,
      anon_sym_RPAREN,
    STATE(799), 1,
      sym_argument,
    STATE(464), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(465), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(649), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(194), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(415), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [10812] = 10,
    ACTIONS(470), 1,
      anon_sym_DOLLAR,
    ACTIONS(472), 1,
      anon_sym_DQUOTE,
    ACTIONS(474), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(476), 1,
      sym_bracket_argument_open,
    STATE(734), 1,
      sym_argument,
    STATE(460), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(461), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(794), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(189), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(468), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [10857] = 10,
    ACTIONS(470), 1,
      anon_sym_DOLLAR,
    ACTIONS(472), 1,
      anon_sym_DQUOTE,
    ACTIONS(474), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(476), 1,
      sym_bracket_argument_open,
    STATE(781), 1,
      sym_argument,
    STATE(460), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(461), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(794), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(189), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(468), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [10902] = 10,
    ACTIONS(470), 1,
      anon_sym_DOLLAR,
    ACTIONS(472), 1,
      anon_sym_DQUOTE,
    ACTIONS(474), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(476), 1,
      sym_bracket_argument_open,
    STATE(786), 1,
      sym_argument,
    STATE(460), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(461), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(794), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(189), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(468), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [10947] = 10,
    ACTIONS(470), 1,
      anon_sym_DOLLAR,
    ACTIONS(472), 1,
      anon_sym_DQUOTE,
    ACTIONS(474), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(476), 1,
      sym_bracket_argument_open,
    STATE(688), 1,
      sym_argument,
    STATE(460), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(461), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(794), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(189), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(468), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [10992] = 10,
    ACTIONS(470), 1,
      anon_sym_DOLLAR,
    ACTIONS(472), 1,
      anon_sym_DQUOTE,
    ACTIONS(474), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(476), 1,
      sym_bracket_argument_open,
    STATE(689), 1,
      sym_argument,
    STATE(460), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(461), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(794), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(189), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(468), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [11037] = 10,
    ACTIONS(470), 1,
      anon_sym_DOLLAR,
    ACTIONS(472), 1,
      anon_sym_DQUOTE,
    ACTIONS(474), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(476), 1,
      sym_bracket_argument_open,
    STATE(714), 1,
      sym_argument,
    STATE(460), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(461), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(794), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(189), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(468), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [11082] = 10,
    ACTIONS(470), 1,
      anon_sym_DOLLAR,
    ACTIONS(472), 1,
      anon_sym_DQUOTE,
    ACTIONS(474), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(476), 1,
      sym_bracket_argument_open,
    STATE(715), 1,
      sym_argument,
    STATE(460), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(461), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(794), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(189), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(468), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [11127] = 10,
    ACTIONS(470), 1,
      anon_sym_DOLLAR,
    ACTIONS(472), 1,
      anon_sym_DQUOTE,
    ACTIONS(474), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(476), 1,
      sym_bracket_argument_open,
    STATE(739), 1,
      sym_argument,
    STATE(460), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(461), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(794), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(189), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(468), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [11172] = 10,
    ACTIONS(470), 1,
      anon_sym_DOLLAR,
    ACTIONS(472), 1,
      anon_sym_DQUOTE,
    ACTIONS(474), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(476), 1,
      sym_bracket_argument_open,
    STATE(740), 1,
      sym_argument,
    STATE(460), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(461), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(794), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(189), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(468), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [11217] = 10,
    ACTIONS(470), 1,
      anon_sym_DOLLAR,
    ACTIONS(472), 1,
      anon_sym_DQUOTE,
    ACTIONS(474), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(476), 1,
      sym_bracket_argument_open,
    STATE(764), 1,
      sym_argument,
    STATE(460), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(461), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(794), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(189), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(468), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [11262] = 10,
    ACTIONS(470), 1,
      anon_sym_DOLLAR,
    ACTIONS(472), 1,
      anon_sym_DQUOTE,
    ACTIONS(474), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(476), 1,
      sym_bracket_argument_open,
    STATE(765), 1,
      sym_argument,
    STATE(460), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(461), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(794), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(189), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(468), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [11307] = 10,
    ACTIONS(470), 1,
      anon_sym_DOLLAR,
    ACTIONS(472), 1,
      anon_sym_DQUOTE,
    ACTIONS(474), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(476), 1,
      sym_bracket_argument_open,
    STATE(787), 1,
      sym_argument,
    STATE(460), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(461), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(794), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(189), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(468), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [11352] = 10,
    ACTIONS(470), 1,
      anon_sym_DOLLAR,
    ACTIONS(472), 1,
      anon_sym_DQUOTE,
    ACTIONS(474), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(476), 1,
      sym_bracket_argument_open,
    STATE(808), 1,
      sym_argument,
    STATE(460), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(461), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(794), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(189), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(468), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [11397] = 10,
    ACTIONS(470), 1,
      anon_sym_DOLLAR,
    ACTIONS(472), 1,
      anon_sym_DQUOTE,
    ACTIONS(474), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(476), 1,
      sym_bracket_argument_open,
    STATE(809), 1,
      sym_argument,
    STATE(460), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(461), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(794), 3,
      sym_bracket_argument,
      sym_quoted_argument,
      sym_unquoted_argument,
    STATE(189), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(468), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [11442] = 8,
    ACTIONS(480), 1,
      anon_sym_DOLLAR,
    ACTIONS(482), 1,
      anon_sym_DQUOTE,
    ACTIONS(484), 1,
      aux_sym__quoted_text_token1,
    STATE(683), 1,
      sym_quoted_element,
    STATE(466), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(467), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(191), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__quoted_text,
      aux_sym_quoted_element_repeat1,
      aux_sym__quoted_text_repeat1,
    ACTIONS(478), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [11479] = 8,
    ACTIONS(480), 1,
      anon_sym_DOLLAR,
    ACTIONS(484), 1,
      aux_sym__quoted_text_token1,
    ACTIONS(486), 1,
      anon_sym_DQUOTE,
    STATE(718), 1,
      sym_quoted_element,
    STATE(466), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(467), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(191), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__quoted_text,
      aux_sym_quoted_element_repeat1,
      aux_sym__quoted_text_repeat1,
    ACTIONS(478), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [11516] = 8,
    ACTIONS(480), 1,
      anon_sym_DOLLAR,
    ACTIONS(484), 1,
      aux_sym__quoted_text_token1,
    ACTIONS(488), 1,
      anon_sym_DQUOTE,
    STATE(724), 1,
      sym_quoted_element,
    STATE(466), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(467), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(191), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__quoted_text,
      aux_sym_quoted_element_repeat1,
      aux_sym__quoted_text_repeat1,
    ACTIONS(478), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [11553] = 7,
    ACTIONS(470), 1,
      anon_sym_DOLLAR,
    ACTIONS(490), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(492), 1,
      aux_sym_endwhile_command_token1,
    STATE(460), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(461), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(192), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(468), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [11587] = 7,
    ACTIONS(453), 1,
      anon_sym_RPAREN,
    ACTIONS(497), 1,
      anon_sym_DOLLAR,
    ACTIONS(500), 1,
      aux_sym__unquoted_text_token1,
    STATE(464), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(465), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(190), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(494), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [11621] = 7,
    ACTIONS(480), 1,
      anon_sym_DOLLAR,
    ACTIONS(503), 1,
      anon_sym_DQUOTE,
    ACTIONS(505), 1,
      aux_sym__quoted_text_token1,
    STATE(466), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(467), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(193), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__quoted_text,
      aux_sym_quoted_element_repeat1,
      aux_sym__quoted_text_repeat1,
    ACTIONS(478), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [11655] = 7,
    ACTIONS(510), 1,
      anon_sym_DOLLAR,
    ACTIONS(513), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(516), 1,
      aux_sym_endwhile_command_token1,
    STATE(460), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(461), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(192), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(507), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [11689] = 7,
    ACTIONS(521), 1,
      anon_sym_DOLLAR,
    ACTIONS(524), 1,
      anon_sym_DQUOTE,
    ACTIONS(526), 1,
      aux_sym__quoted_text_token1,
    STATE(466), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(467), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(193), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__quoted_text,
      aux_sym_quoted_element_repeat1,
      aux_sym__quoted_text_repeat1,
    ACTIONS(518), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [11723] = 7,
    ACTIONS(417), 1,
      anon_sym_DOLLAR,
    ACTIONS(427), 1,
      anon_sym_RPAREN,
    ACTIONS(529), 1,
      aux_sym__unquoted_text_token1,
    STATE(464), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(465), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    STATE(190), 5,
      sym_escape_sequence,
      sym_variable_ref,
      sym__unquoted_text,
      aux_sym_unquoted_argument_repeat1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(415), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [11757] = 5,
    ACTIONS(533), 1,
      anon_sym_LBRACE,
    ACTIONS(535), 1,
      anon_sym_ENV,
    ACTIONS(537), 1,
      anon_sym_CACHE,
    ACTIONS(539), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(531), 14,
      sym_bracket_argument_open,
      sym_bracket_comment_open,
      sym_line_comment,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
      anon_sym_DOLLAR,
      aux_sym__untrimmed_argument_token1,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DQUOTE,
  [11786] = 7,
    ACTIONS(543), 1,
      aux_sym_variable_token1,
    ACTIONS(545), 1,
      anon_sym_DOLLAR,
    STATE(758), 1,
      sym_variable,
    STATE(477), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(207), 3,
      sym_escape_sequence,
      sym_variable_ref,
      aux_sym_variable_repeat1,
    STATE(478), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    ACTIONS(541), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [11818] = 7,
    ACTIONS(543), 1,
      aux_sym_variable_token1,
    ACTIONS(545), 1,
      anon_sym_DOLLAR,
    STATE(732), 1,
      sym_variable,
    STATE(477), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(207), 3,
      sym_escape_sequence,
      sym_variable_ref,
      aux_sym_variable_repeat1,
    STATE(478), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    ACTIONS(541), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [11850] = 7,
    ACTIONS(543), 1,
      aux_sym_variable_token1,
    ACTIONS(545), 1,
      anon_sym_DOLLAR,
    STATE(829), 1,
      sym_variable,
    STATE(477), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(207), 3,
      sym_escape_sequence,
      sym_variable_ref,
      aux_sym_variable_repeat1,
    STATE(478), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    ACTIONS(541), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [11882] = 7,
    ACTIONS(543), 1,
      aux_sym_variable_token1,
    ACTIONS(545), 1,
      anon_sym_DOLLAR,
    STATE(830), 1,
      sym_variable,
    STATE(477), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(207), 3,
      sym_escape_sequence,
      sym_variable_ref,
      aux_sym_variable_repeat1,
    STATE(478), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    ACTIONS(541), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [11914] = 7,
    ACTIONS(550), 1,
      aux_sym_variable_token1,
    ACTIONS(553), 1,
      anon_sym_DOLLAR,
    ACTIONS(556), 1,
      anon_sym_RBRACE,
    STATE(477), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(200), 3,
      sym_escape_sequence,
      sym_variable_ref,
      aux_sym_variable_repeat1,
    STATE(478), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    ACTIONS(547), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [11946] = 7,
    ACTIONS(543), 1,
      aux_sym_variable_token1,
    ACTIONS(545), 1,
      anon_sym_DOLLAR,
    STATE(789), 1,
      sym_variable,
    STATE(477), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(207), 3,
      sym_escape_sequence,
      sym_variable_ref,
      aux_sym_variable_repeat1,
    STATE(478), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    ACTIONS(541), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [11978] = 7,
    ACTIONS(543), 1,
      aux_sym_variable_token1,
    ACTIONS(545), 1,
      anon_sym_DOLLAR,
    STATE(791), 1,
      sym_variable,
    STATE(477), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(207), 3,
      sym_escape_sequence,
      sym_variable_ref,
      aux_sym_variable_repeat1,
    STATE(478), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    ACTIONS(541), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [12010] = 7,
    ACTIONS(543), 1,
      aux_sym_variable_token1,
    ACTIONS(545), 1,
      anon_sym_DOLLAR,
    STATE(722), 1,
      sym_variable,
    STATE(477), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(207), 3,
      sym_escape_sequence,
      sym_variable_ref,
      aux_sym_variable_repeat1,
    STATE(478), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    ACTIONS(541), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [12042] = 7,
    ACTIONS(543), 1,
      aux_sym_variable_token1,
    ACTIONS(545), 1,
      anon_sym_DOLLAR,
    STATE(674), 1,
      sym_variable,
    STATE(477), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(207), 3,
      sym_escape_sequence,
      sym_variable_ref,
      aux_sym_variable_repeat1,
    STATE(478), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    ACTIONS(541), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [12074] = 7,
    ACTIONS(543), 1,
      aux_sym_variable_token1,
    ACTIONS(545), 1,
      anon_sym_DOLLAR,
    STATE(686), 1,
      sym_variable,
    STATE(477), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(207), 3,
      sym_escape_sequence,
      sym_variable_ref,
      aux_sym_variable_repeat1,
    STATE(478), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    ACTIONS(541), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [12106] = 7,
    ACTIONS(543), 1,
      aux_sym_variable_token1,
    ACTIONS(545), 1,
      anon_sym_DOLLAR,
    STATE(687), 1,
      sym_variable,
    STATE(477), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(207), 3,
      sym_escape_sequence,
      sym_variable_ref,
      aux_sym_variable_repeat1,
    STATE(478), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    ACTIONS(541), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [12138] = 7,
    ACTIONS(545), 1,
      anon_sym_DOLLAR,
    ACTIONS(558), 1,
      aux_sym_variable_token1,
    ACTIONS(560), 1,
      anon_sym_RBRACE,
    STATE(477), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(200), 3,
      sym_escape_sequence,
      sym_variable_ref,
      aux_sym_variable_repeat1,
    STATE(478), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    ACTIONS(541), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [12170] = 7,
    ACTIONS(543), 1,
      aux_sym_variable_token1,
    ACTIONS(545), 1,
      anon_sym_DOLLAR,
    STATE(713), 1,
      sym_variable,
    STATE(477), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(207), 3,
      sym_escape_sequence,
      sym_variable_ref,
      aux_sym_variable_repeat1,
    STATE(478), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    ACTIONS(541), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [12202] = 7,
    ACTIONS(543), 1,
      aux_sym_variable_token1,
    ACTIONS(545), 1,
      anon_sym_DOLLAR,
    STATE(727), 1,
      sym_variable,
    STATE(477), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(207), 3,
      sym_escape_sequence,
      sym_variable_ref,
      aux_sym_variable_repeat1,
    STATE(478), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    ACTIONS(541), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [12234] = 7,
    ACTIONS(543), 1,
      aux_sym_variable_token1,
    ACTIONS(545), 1,
      anon_sym_DOLLAR,
    STATE(743), 1,
      sym_variable,
    STATE(477), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(207), 3,
      sym_escape_sequence,
      sym_variable_ref,
      aux_sym_variable_repeat1,
    STATE(478), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    ACTIONS(541), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [12266] = 7,
    ACTIONS(543), 1,
      aux_sym_variable_token1,
    ACTIONS(545), 1,
      anon_sym_DOLLAR,
    STATE(831), 1,
      sym_variable,
    STATE(477), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(207), 3,
      sym_escape_sequence,
      sym_variable_ref,
      aux_sym_variable_repeat1,
    STATE(478), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    ACTIONS(541), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [12298] = 7,
    ACTIONS(543), 1,
      aux_sym_variable_token1,
    ACTIONS(545), 1,
      anon_sym_DOLLAR,
    STATE(721), 1,
      sym_variable,
    STATE(477), 2,
      sym__escape_encoded,
      sym__escape_semicolon,
    STATE(207), 3,
      sym_escape_sequence,
      sym_variable_ref,
      aux_sym_variable_repeat1,
    STATE(478), 3,
      sym_normal_var,
      sym_env_var,
      sym_cache_var,
    ACTIONS(541), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [12330] = 4,
    ACTIONS(564), 1,
      anon_sym_DOLLAR,
    ACTIONS(567), 1,
      aux_sym__unquoted_text_token1,
    STATE(213), 1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(562), 13,
      sym_bracket_argument_open,
      sym_bracket_comment_open,
      sym_line_comment,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
      aux_sym__untrimmed_argument_token1,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DQUOTE,
  [12355] = 2,
    ACTIONS(572), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(570), 14,
      sym_bracket_argument_open,
      sym_bracket_comment_open,
      sym_line_comment,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
      anon_sym_DOLLAR,
      aux_sym__untrimmed_argument_token1,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DQUOTE,
  [12375] = 2,
    ACTIONS(576), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(574), 14,
      sym_bracket_argument_open,
      sym_bracket_comment_open,
      sym_line_comment,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
      anon_sym_DOLLAR,
      aux_sym__untrimmed_argument_token1,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DQUOTE,
  [12395] = 2,
    ACTIONS(580), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(578), 14,
      sym_bracket_argument_open,
      sym_bracket_comment_open,
      sym_line_comment,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
      anon_sym_DOLLAR,
      aux_sym__untrimmed_argument_token1,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DQUOTE,
  [12415] = 2,
    ACTIONS(584), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(582), 14,
      sym_bracket_argument_open,
      sym_bracket_comment_open,
      sym_line_comment,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
      anon_sym_DOLLAR,
      aux_sym__untrimmed_argument_token1,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DQUOTE,
  [12435] = 2,
    ACTIONS(588), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(586), 14,
      sym_bracket_argument_open,
      sym_bracket_comment_open,
      sym_line_comment,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
      anon_sym_DOLLAR,
      aux_sym__untrimmed_argument_token1,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DQUOTE,
  [12455] = 2,
    ACTIONS(592), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(590), 14,
      sym_bracket_argument_open,
      sym_bracket_comment_open,
      sym_line_comment,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
      anon_sym_DOLLAR,
      aux_sym__untrimmed_argument_token1,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DQUOTE,
  [12475] = 2,
    ACTIONS(596), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(594), 14,
      sym_bracket_argument_open,
      sym_bracket_comment_open,
      sym_line_comment,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
      anon_sym_DOLLAR,
      aux_sym__untrimmed_argument_token1,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DQUOTE,
  [12495] = 2,
    ACTIONS(600), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(598), 14,
      sym_bracket_argument_open,
      sym_bracket_comment_open,
      sym_line_comment,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
      anon_sym_DOLLAR,
      aux_sym__untrimmed_argument_token1,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DQUOTE,
  [12515] = 2,
    ACTIONS(604), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(602), 14,
      sym_bracket_argument_open,
      sym_bracket_comment_open,
      sym_line_comment,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
      anon_sym_DOLLAR,
      aux_sym__untrimmed_argument_token1,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DQUOTE,
  [12535] = 2,
    ACTIONS(608), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(606), 14,
      sym_bracket_argument_open,
      sym_bracket_comment_open,
      sym_line_comment,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
      anon_sym_DOLLAR,
      aux_sym__untrimmed_argument_token1,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DQUOTE,
  [12555] = 2,
    ACTIONS(612), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(610), 14,
      sym_bracket_argument_open,
      sym_bracket_comment_open,
      sym_line_comment,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
      anon_sym_DOLLAR,
      aux_sym__untrimmed_argument_token1,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DQUOTE,
  [12575] = 2,
    ACTIONS(616), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(614), 14,
      sym_bracket_argument_open,
      sym_bracket_comment_open,
      sym_line_comment,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
      anon_sym_DOLLAR,
      aux_sym__untrimmed_argument_token1,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DQUOTE,
  [12595] = 2,
    ACTIONS(618), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(620), 10,
      sym_if,
      sym_elseif,
      sym_else,
      sym_endif,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [12613] = 2,
    ACTIONS(622), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(624), 10,
      sym_if,
      sym_elseif,
      sym_else,
      sym_endif,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [12631] = 2,
    ACTIONS(626), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(628), 10,
      sym_if,
      sym_elseif,
      sym_else,
      sym_endif,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [12649] = 2,
    ACTIONS(630), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(632), 10,
      sym_if,
      sym_elseif,
      sym_else,
      sym_endif,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [12667] = 2,
    ACTIONS(634), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(636), 10,
      sym_if,
      sym_elseif,
      sym_else,
      sym_endif,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [12685] = 2,
    ACTIONS(638), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(640), 10,
      sym_if,
      sym_elseif,
      sym_else,
      sym_endif,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [12703] = 2,
    ACTIONS(642), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(644), 10,
      sym_if,
      sym_elseif,
      sym_else,
      sym_endif,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [12721] = 2,
    ACTIONS(646), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(648), 10,
      sym_if,
      sym_elseif,
      sym_else,
      sym_endif,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [12739] = 2,
    ACTIONS(650), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(652), 10,
      sym_if,
      sym_elseif,
      sym_else,
      sym_endif,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [12757] = 2,
    ACTIONS(654), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(656), 10,
      sym_if,
      sym_elseif,
      sym_else,
      sym_endif,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [12775] = 2,
    ACTIONS(590), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(592), 10,
      sym_if,
      sym_elseif,
      sym_else,
      sym_endif,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [12793] = 2,
    ACTIONS(658), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(660), 10,
      sym_if,
      sym_elseif,
      sym_else,
      sym_endif,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [12811] = 2,
    ACTIONS(662), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(664), 10,
      sym_if,
      sym_elseif,
      sym_else,
      sym_endif,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [12829] = 2,
    ACTIONS(666), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(668), 10,
      sym_if,
      sym_elseif,
      sym_else,
      sym_endif,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [12847] = 2,
    ACTIONS(670), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(672), 10,
      sym_if,
      sym_elseif,
      sym_else,
      sym_endif,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [12865] = 2,
    ACTIONS(674), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(676), 10,
      sym_if,
      sym_elseif,
      sym_else,
      sym_endif,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [12883] = 2,
    ACTIONS(678), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(680), 10,
      sym_if,
      sym_elseif,
      sym_else,
      sym_endif,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [12901] = 2,
    ACTIONS(682), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(684), 10,
      sym_if,
      sym_elseif,
      sym_else,
      sym_endif,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [12919] = 2,
    ACTIONS(686), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(688), 10,
      sym_if,
      sym_elseif,
      sym_else,
      sym_endif,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [12937] = 2,
    ACTIONS(690), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(692), 10,
      sym_if,
      sym_elseif,
      sym_else,
      sym_endif,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [12955] = 2,
    ACTIONS(694), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(696), 10,
      sym_if,
      sym_elseif,
      sym_else,
      sym_endif,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [12973] = 2,
    ACTIONS(698), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(700), 10,
      sym_if,
      sym_elseif,
      sym_else,
      sym_endif,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [12991] = 2,
    ACTIONS(702), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(704), 10,
      sym_if,
      sym_elseif,
      sym_else,
      sym_endif,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [13009] = 2,
    ACTIONS(706), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(708), 10,
      sym_if,
      sym_elseif,
      sym_else,
      sym_endif,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [13027] = 2,
    ACTIONS(710), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(712), 10,
      sym_if,
      sym_elseif,
      sym_else,
      sym_endif,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [13045] = 2,
    ACTIONS(714), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(716), 10,
      sym_if,
      sym_elseif,
      sym_else,
      sym_endif,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [13063] = 2,
    ACTIONS(718), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(720), 10,
      sym_if,
      sym_elseif,
      sym_else,
      sym_endif,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [13081] = 2,
    ACTIONS(722), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(724), 10,
      sym_if,
      sym_elseif,
      sym_else,
      sym_endif,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [13099] = 2,
    ACTIONS(726), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(728), 10,
      sym_if,
      sym_elseif,
      sym_else,
      sym_endif,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [13117] = 2,
    ACTIONS(730), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(732), 10,
      sym_if,
      sym_elseif,
      sym_else,
      sym_endif,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [13135] = 2,
    ACTIONS(734), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(736), 10,
      sym_if,
      sym_elseif,
      sym_else,
      sym_endif,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [13153] = 2,
    ACTIONS(738), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(740), 10,
      sym_if,
      sym_elseif,
      sym_else,
      sym_endif,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [13171] = 2,
    ACTIONS(742), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(744), 10,
      sym_if,
      sym_elseif,
      sym_else,
      sym_endif,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [13189] = 2,
    ACTIONS(746), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(748), 10,
      sym_if,
      sym_elseif,
      sym_else,
      sym_endif,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [13207] = 2,
    ACTIONS(750), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(752), 10,
      sym_if,
      sym_elseif,
      sym_else,
      sym_endif,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [13225] = 2,
    ACTIONS(754), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(756), 10,
      sym_if,
      sym_elseif,
      sym_else,
      sym_endif,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [13243] = 2,
    ACTIONS(758), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(760), 10,
      sym_if,
      sym_elseif,
      sym_else,
      sym_endif,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [13261] = 5,
    ACTIONS(764), 1,
      anon_sym_LBRACE,
    ACTIONS(766), 1,
      anon_sym_ENV,
    ACTIONS(768), 1,
      anon_sym_CACHE,
    ACTIONS(770), 1,
      aux_sym__quoted_text_token1,
    ACTIONS(762), 8,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
  [13284] = 5,
    ACTIONS(539), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(772), 1,
      anon_sym_LBRACE,
    ACTIONS(774), 1,
      anon_sym_ENV,
    ACTIONS(776), 1,
      anon_sym_CACHE,
    ACTIONS(531), 8,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
      anon_sym_DOLLAR,
      anon_sym_RPAREN,
  [13307] = 5,
    ACTIONS(778), 1,
      anon_sym_LBRACE,
    ACTIONS(780), 1,
      anon_sym_ENV,
    ACTIONS(782), 1,
      anon_sym_CACHE,
    ACTIONS(539), 2,
      aux_sym__unquoted_text_token1,
      aux_sym_endwhile_command_token1,
    ACTIONS(531), 7,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
      anon_sym_DOLLAR,
  [13330] = 2,
    ACTIONS(622), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(624), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_endblock,
      sym_identifier,
  [13346] = 2,
    ACTIONS(662), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(664), 8,
      sym_if,
      sym_foreach,
      sym_endforeach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [13362] = 2,
    ACTIONS(742), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(744), 8,
      sym_if,
      sym_foreach,
      sym_endforeach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [13378] = 2,
    ACTIONS(706), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(708), 8,
      sym_if,
      sym_foreach,
      sym_endforeach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [13394] = 2,
    ACTIONS(634), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(636), 8,
      sym_if,
      sym_foreach,
      sym_endforeach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [13410] = 2,
    ACTIONS(658), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(660), 8,
      sym_if,
      sym_foreach,
      sym_endforeach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [13426] = 2,
    ACTIONS(686), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(688), 8,
      sym_if,
      sym_foreach,
      sym_endforeach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [13442] = 2,
    ACTIONS(638), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(640), 8,
      sym_if,
      sym_foreach,
      sym_endforeach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [13458] = 2,
    ACTIONS(682), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(684), 8,
      sym_if,
      sym_foreach,
      sym_endforeach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [13474] = 2,
    ACTIONS(718), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(720), 8,
      sym_if,
      sym_foreach,
      sym_endforeach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [13490] = 2,
    ACTIONS(622), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(624), 8,
      sym_if,
      sym_foreach,
      sym_endforeach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [13506] = 2,
    ACTIONS(630), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(632), 8,
      sym_if,
      sym_foreach,
      sym_endforeach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [13522] = 2,
    ACTIONS(646), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(648), 8,
      sym_if,
      sym_foreach,
      sym_endforeach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [13538] = 2,
    ACTIONS(650), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(652), 8,
      sym_if,
      sym_foreach,
      sym_endforeach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [13554] = 2,
    ACTIONS(618), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(620), 8,
      sym_if,
      sym_foreach,
      sym_endforeach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [13570] = 2,
    ACTIONS(670), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(672), 8,
      sym_if,
      sym_foreach,
      sym_endforeach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [13586] = 2,
    ACTIONS(674), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(676), 8,
      sym_if,
      sym_foreach,
      sym_endforeach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [13602] = 2,
    ACTIONS(758), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(760), 8,
      sym_if,
      sym_foreach,
      sym_endforeach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [13618] = 2,
    ACTIONS(678), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(680), 8,
      sym_if,
      sym_foreach,
      sym_endforeach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [13634] = 2,
    ACTIONS(666), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(668), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_endwhile,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [13650] = 2,
    ACTIONS(590), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(592), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_endwhile,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [13666] = 2,
    ACTIONS(710), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(712), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_endwhile,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [13682] = 2,
    ACTIONS(714), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(716), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_endwhile,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [13698] = 2,
    ACTIONS(722), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(724), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_endwhile,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [13714] = 2,
    ACTIONS(726), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(728), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_endwhile,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [13730] = 2,
    ACTIONS(730), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(732), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_endwhile,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [13746] = 2,
    ACTIONS(734), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(736), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_endwhile,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [13762] = 2,
    ACTIONS(738), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(740), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_endwhile,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [13778] = 2,
    ACTIONS(746), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(748), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_endwhile,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [13794] = 2,
    ACTIONS(750), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(752), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_endwhile,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [13810] = 2,
    ACTIONS(754), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(756), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_endwhile,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [13826] = 2,
    ACTIONS(662), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(664), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_endwhile,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [13842] = 2,
    ACTIONS(742), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(744), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_endwhile,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [13858] = 2,
    ACTIONS(706), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(708), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_endwhile,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [13874] = 2,
    ACTIONS(634), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(636), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_endwhile,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [13890] = 2,
    ACTIONS(658), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(660), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_endwhile,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [13906] = 2,
    ACTIONS(686), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(688), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_endwhile,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [13922] = 2,
    ACTIONS(638), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(640), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_endwhile,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [13938] = 2,
    ACTIONS(682), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(684), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_endwhile,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [13954] = 2,
    ACTIONS(718), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(720), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_endwhile,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [13970] = 2,
    ACTIONS(622), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(624), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_endwhile,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [13986] = 2,
    ACTIONS(630), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(632), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_endwhile,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [14002] = 2,
    ACTIONS(646), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(648), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_endwhile,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [14018] = 2,
    ACTIONS(650), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(652), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_endwhile,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [14034] = 2,
    ACTIONS(618), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(620), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_endwhile,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [14050] = 2,
    ACTIONS(670), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(672), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_endwhile,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [14066] = 2,
    ACTIONS(674), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(676), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_endwhile,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [14082] = 2,
    ACTIONS(758), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(760), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_endwhile,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [14098] = 2,
    ACTIONS(678), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(680), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_endwhile,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [14114] = 2,
    ACTIONS(666), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(668), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_endfunction,
      sym_macro,
      sym_block,
      sym_identifier,
  [14130] = 2,
    ACTIONS(590), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(592), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_endfunction,
      sym_macro,
      sym_block,
      sym_identifier,
  [14146] = 2,
    ACTIONS(710), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(712), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_endfunction,
      sym_macro,
      sym_block,
      sym_identifier,
  [14162] = 2,
    ACTIONS(714), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(716), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_endfunction,
      sym_macro,
      sym_block,
      sym_identifier,
  [14178] = 2,
    ACTIONS(722), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(724), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_endfunction,
      sym_macro,
      sym_block,
      sym_identifier,
  [14194] = 2,
    ACTIONS(726), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(728), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_endfunction,
      sym_macro,
      sym_block,
      sym_identifier,
  [14210] = 2,
    ACTIONS(730), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(732), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_endfunction,
      sym_macro,
      sym_block,
      sym_identifier,
  [14226] = 2,
    ACTIONS(734), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(736), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_endfunction,
      sym_macro,
      sym_block,
      sym_identifier,
  [14242] = 2,
    ACTIONS(738), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(740), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_endfunction,
      sym_macro,
      sym_block,
      sym_identifier,
  [14258] = 2,
    ACTIONS(746), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(748), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_endfunction,
      sym_macro,
      sym_block,
      sym_identifier,
  [14274] = 2,
    ACTIONS(750), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(752), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_endfunction,
      sym_macro,
      sym_block,
      sym_identifier,
  [14290] = 2,
    ACTIONS(754), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(756), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_endfunction,
      sym_macro,
      sym_block,
      sym_identifier,
  [14306] = 2,
    ACTIONS(662), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(664), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_endfunction,
      sym_macro,
      sym_block,
      sym_identifier,
  [14322] = 2,
    ACTIONS(742), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(744), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_endfunction,
      sym_macro,
      sym_block,
      sym_identifier,
  [14338] = 2,
    ACTIONS(706), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(708), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_endfunction,
      sym_macro,
      sym_block,
      sym_identifier,
  [14354] = 2,
    ACTIONS(634), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(636), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_endfunction,
      sym_macro,
      sym_block,
      sym_identifier,
  [14370] = 2,
    ACTIONS(658), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(660), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_endfunction,
      sym_macro,
      sym_block,
      sym_identifier,
  [14386] = 2,
    ACTIONS(686), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(688), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_endfunction,
      sym_macro,
      sym_block,
      sym_identifier,
  [14402] = 2,
    ACTIONS(638), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(640), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_endfunction,
      sym_macro,
      sym_block,
      sym_identifier,
  [14418] = 2,
    ACTIONS(682), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(684), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_endfunction,
      sym_macro,
      sym_block,
      sym_identifier,
  [14434] = 2,
    ACTIONS(718), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(720), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_endfunction,
      sym_macro,
      sym_block,
      sym_identifier,
  [14450] = 2,
    ACTIONS(622), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(624), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_endfunction,
      sym_macro,
      sym_block,
      sym_identifier,
  [14466] = 2,
    ACTIONS(630), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(632), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_endfunction,
      sym_macro,
      sym_block,
      sym_identifier,
  [14482] = 2,
    ACTIONS(646), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(648), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_endfunction,
      sym_macro,
      sym_block,
      sym_identifier,
  [14498] = 2,
    ACTIONS(650), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(652), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_endfunction,
      sym_macro,
      sym_block,
      sym_identifier,
  [14514] = 2,
    ACTIONS(618), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(620), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_endfunction,
      sym_macro,
      sym_block,
      sym_identifier,
  [14530] = 2,
    ACTIONS(670), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(672), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_endfunction,
      sym_macro,
      sym_block,
      sym_identifier,
  [14546] = 2,
    ACTIONS(674), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(676), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_endfunction,
      sym_macro,
      sym_block,
      sym_identifier,
  [14562] = 2,
    ACTIONS(758), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(760), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_endfunction,
      sym_macro,
      sym_block,
      sym_identifier,
  [14578] = 2,
    ACTIONS(678), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(680), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_endfunction,
      sym_macro,
      sym_block,
      sym_identifier,
  [14594] = 2,
    ACTIONS(666), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(668), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_endmacro,
      sym_block,
      sym_identifier,
  [14610] = 2,
    ACTIONS(750), 4,
      sym_bracket_comment_open,
      sym_line_comment,
      ts_builtin_sym_end,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(752), 7,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [14626] = 2,
    ACTIONS(590), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(592), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_endmacro,
      sym_block,
      sym_identifier,
  [14642] = 2,
    ACTIONS(710), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(712), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_endmacro,
      sym_block,
      sym_identifier,
  [14658] = 2,
    ACTIONS(714), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(716), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_endmacro,
      sym_block,
      sym_identifier,
  [14674] = 2,
    ACTIONS(722), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(724), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_endmacro,
      sym_block,
      sym_identifier,
  [14690] = 2,
    ACTIONS(726), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(728), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_endmacro,
      sym_block,
      sym_identifier,
  [14706] = 2,
    ACTIONS(730), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(732), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_endmacro,
      sym_block,
      sym_identifier,
  [14722] = 2,
    ACTIONS(734), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(736), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_endmacro,
      sym_block,
      sym_identifier,
  [14738] = 2,
    ACTIONS(738), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(740), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_endmacro,
      sym_block,
      sym_identifier,
  [14754] = 2,
    ACTIONS(746), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(748), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_endmacro,
      sym_block,
      sym_identifier,
  [14770] = 2,
    ACTIONS(750), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(752), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_endmacro,
      sym_block,
      sym_identifier,
  [14786] = 2,
    ACTIONS(754), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(756), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_endmacro,
      sym_block,
      sym_identifier,
  [14802] = 2,
    ACTIONS(662), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(664), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_endmacro,
      sym_block,
      sym_identifier,
  [14818] = 2,
    ACTIONS(742), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(744), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_endmacro,
      sym_block,
      sym_identifier,
  [14834] = 2,
    ACTIONS(706), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(708), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_endmacro,
      sym_block,
      sym_identifier,
  [14850] = 2,
    ACTIONS(634), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(636), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_endmacro,
      sym_block,
      sym_identifier,
  [14866] = 2,
    ACTIONS(754), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(756), 8,
      sym_if,
      sym_foreach,
      sym_endforeach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [14882] = 2,
    ACTIONS(686), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(688), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_endmacro,
      sym_block,
      sym_identifier,
  [14898] = 2,
    ACTIONS(638), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(640), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_endmacro,
      sym_block,
      sym_identifier,
  [14914] = 2,
    ACTIONS(682), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(684), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_endmacro,
      sym_block,
      sym_identifier,
  [14930] = 2,
    ACTIONS(718), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(720), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_endmacro,
      sym_block,
      sym_identifier,
  [14946] = 2,
    ACTIONS(622), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(624), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_endmacro,
      sym_block,
      sym_identifier,
  [14962] = 2,
    ACTIONS(630), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(632), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_endmacro,
      sym_block,
      sym_identifier,
  [14978] = 2,
    ACTIONS(646), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(648), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_endmacro,
      sym_block,
      sym_identifier,
  [14994] = 2,
    ACTIONS(650), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(652), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_endmacro,
      sym_block,
      sym_identifier,
  [15010] = 2,
    ACTIONS(618), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(620), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_endmacro,
      sym_block,
      sym_identifier,
  [15026] = 2,
    ACTIONS(670), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(672), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_endmacro,
      sym_block,
      sym_identifier,
  [15042] = 2,
    ACTIONS(674), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(676), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_endmacro,
      sym_block,
      sym_identifier,
  [15058] = 2,
    ACTIONS(758), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(760), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_endmacro,
      sym_block,
      sym_identifier,
  [15074] = 2,
    ACTIONS(678), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(680), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_endmacro,
      sym_block,
      sym_identifier,
  [15090] = 2,
    ACTIONS(666), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(668), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_endblock,
      sym_identifier,
  [15106] = 2,
    ACTIONS(590), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(592), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_endblock,
      sym_identifier,
  [15122] = 2,
    ACTIONS(710), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(712), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_endblock,
      sym_identifier,
  [15138] = 2,
    ACTIONS(714), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(716), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_endblock,
      sym_identifier,
  [15154] = 2,
    ACTIONS(722), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(724), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_endblock,
      sym_identifier,
  [15170] = 2,
    ACTIONS(726), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(728), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_endblock,
      sym_identifier,
  [15186] = 2,
    ACTIONS(730), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(732), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_endblock,
      sym_identifier,
  [15202] = 2,
    ACTIONS(734), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(736), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_endblock,
      sym_identifier,
  [15218] = 2,
    ACTIONS(738), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(740), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_endblock,
      sym_identifier,
  [15234] = 2,
    ACTIONS(746), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(748), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_endblock,
      sym_identifier,
  [15250] = 2,
    ACTIONS(750), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(752), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_endblock,
      sym_identifier,
  [15266] = 2,
    ACTIONS(754), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(756), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_endblock,
      sym_identifier,
  [15282] = 2,
    ACTIONS(662), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(664), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_endblock,
      sym_identifier,
  [15298] = 2,
    ACTIONS(742), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(744), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_endblock,
      sym_identifier,
  [15314] = 2,
    ACTIONS(706), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(708), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_endblock,
      sym_identifier,
  [15330] = 2,
    ACTIONS(634), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(636), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_endblock,
      sym_identifier,
  [15346] = 2,
    ACTIONS(658), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(660), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_endblock,
      sym_identifier,
  [15362] = 2,
    ACTIONS(686), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(688), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_endblock,
      sym_identifier,
  [15378] = 2,
    ACTIONS(638), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(640), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_endblock,
      sym_identifier,
  [15394] = 2,
    ACTIONS(682), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(684), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_endblock,
      sym_identifier,
  [15410] = 2,
    ACTIONS(718), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(720), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_endblock,
      sym_identifier,
  [15426] = 2,
    ACTIONS(630), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(632), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_endblock,
      sym_identifier,
  [15442] = 2,
    ACTIONS(646), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(648), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_endblock,
      sym_identifier,
  [15458] = 2,
    ACTIONS(650), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(652), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_endblock,
      sym_identifier,
  [15474] = 2,
    ACTIONS(618), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(620), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_endblock,
      sym_identifier,
  [15490] = 2,
    ACTIONS(670), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(672), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_endblock,
      sym_identifier,
  [15506] = 2,
    ACTIONS(674), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(676), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_endblock,
      sym_identifier,
  [15522] = 2,
    ACTIONS(758), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(760), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_endblock,
      sym_identifier,
  [15538] = 2,
    ACTIONS(678), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(680), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_endblock,
      sym_identifier,
  [15554] = 2,
    ACTIONS(746), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(748), 8,
      sym_if,
      sym_foreach,
      sym_endforeach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [15570] = 2,
    ACTIONS(754), 4,
      sym_bracket_comment_open,
      sym_line_comment,
      ts_builtin_sym_end,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(756), 7,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [15586] = 2,
    ACTIONS(662), 4,
      sym_bracket_comment_open,
      sym_line_comment,
      ts_builtin_sym_end,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(664), 7,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [15602] = 2,
    ACTIONS(742), 4,
      sym_bracket_comment_open,
      sym_line_comment,
      ts_builtin_sym_end,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(744), 7,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [15618] = 2,
    ACTIONS(706), 4,
      sym_bracket_comment_open,
      sym_line_comment,
      ts_builtin_sym_end,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(708), 7,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [15634] = 2,
    ACTIONS(634), 4,
      sym_bracket_comment_open,
      sym_line_comment,
      ts_builtin_sym_end,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(636), 7,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [15650] = 2,
    ACTIONS(658), 4,
      sym_bracket_comment_open,
      sym_line_comment,
      ts_builtin_sym_end,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(660), 7,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [15666] = 2,
    ACTIONS(710), 4,
      sym_bracket_comment_open,
      sym_line_comment,
      ts_builtin_sym_end,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(712), 7,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [15682] = 2,
    ACTIONS(686), 4,
      sym_bracket_comment_open,
      sym_line_comment,
      ts_builtin_sym_end,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(688), 7,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [15698] = 2,
    ACTIONS(638), 4,
      sym_bracket_comment_open,
      sym_line_comment,
      ts_builtin_sym_end,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(640), 7,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [15714] = 2,
    ACTIONS(682), 4,
      sym_bracket_comment_open,
      sym_line_comment,
      ts_builtin_sym_end,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(684), 7,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [15730] = 2,
    ACTIONS(718), 4,
      sym_bracket_comment_open,
      sym_line_comment,
      ts_builtin_sym_end,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(720), 7,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [15746] = 2,
    ACTIONS(622), 4,
      sym_bracket_comment_open,
      sym_line_comment,
      ts_builtin_sym_end,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(624), 7,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [15762] = 2,
    ACTIONS(630), 4,
      sym_bracket_comment_open,
      sym_line_comment,
      ts_builtin_sym_end,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(632), 7,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [15778] = 2,
    ACTIONS(646), 4,
      sym_bracket_comment_open,
      sym_line_comment,
      ts_builtin_sym_end,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(648), 7,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [15794] = 2,
    ACTIONS(666), 4,
      sym_bracket_comment_open,
      sym_line_comment,
      ts_builtin_sym_end,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(668), 7,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [15810] = 2,
    ACTIONS(650), 4,
      sym_bracket_comment_open,
      sym_line_comment,
      ts_builtin_sym_end,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(652), 7,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [15826] = 2,
    ACTIONS(618), 4,
      sym_bracket_comment_open,
      sym_line_comment,
      ts_builtin_sym_end,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(620), 7,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [15842] = 2,
    ACTIONS(670), 4,
      sym_bracket_comment_open,
      sym_line_comment,
      ts_builtin_sym_end,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(672), 7,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [15858] = 2,
    ACTIONS(674), 4,
      sym_bracket_comment_open,
      sym_line_comment,
      ts_builtin_sym_end,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(676), 7,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [15874] = 2,
    ACTIONS(758), 4,
      sym_bracket_comment_open,
      sym_line_comment,
      ts_builtin_sym_end,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(760), 7,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [15890] = 2,
    ACTIONS(678), 4,
      sym_bracket_comment_open,
      sym_line_comment,
      ts_builtin_sym_end,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(680), 7,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [15906] = 2,
    ACTIONS(714), 4,
      sym_bracket_comment_open,
      sym_line_comment,
      ts_builtin_sym_end,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(716), 7,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [15922] = 2,
    ACTIONS(722), 4,
      sym_bracket_comment_open,
      sym_line_comment,
      ts_builtin_sym_end,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(724), 7,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [15938] = 2,
    ACTIONS(726), 4,
      sym_bracket_comment_open,
      sym_line_comment,
      ts_builtin_sym_end,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(728), 7,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [15954] = 2,
    ACTIONS(730), 4,
      sym_bracket_comment_open,
      sym_line_comment,
      ts_builtin_sym_end,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(732), 7,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [15970] = 2,
    ACTIONS(734), 4,
      sym_bracket_comment_open,
      sym_line_comment,
      ts_builtin_sym_end,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(736), 7,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [15986] = 2,
    ACTIONS(738), 4,
      sym_bracket_comment_open,
      sym_line_comment,
      ts_builtin_sym_end,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(740), 7,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [16002] = 2,
    ACTIONS(590), 4,
      sym_bracket_comment_open,
      sym_line_comment,
      ts_builtin_sym_end,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(592), 7,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [16018] = 2,
    ACTIONS(666), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(668), 8,
      sym_if,
      sym_foreach,
      sym_endforeach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [16034] = 2,
    ACTIONS(590), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(592), 8,
      sym_if,
      sym_foreach,
      sym_endforeach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [16050] = 2,
    ACTIONS(746), 4,
      sym_bracket_comment_open,
      sym_line_comment,
      ts_builtin_sym_end,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(748), 7,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [16066] = 2,
    ACTIONS(710), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(712), 8,
      sym_if,
      sym_foreach,
      sym_endforeach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [16082] = 2,
    ACTIONS(750), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(752), 8,
      sym_if,
      sym_foreach,
      sym_endforeach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [16098] = 2,
    ACTIONS(714), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(716), 8,
      sym_if,
      sym_foreach,
      sym_endforeach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [16114] = 2,
    ACTIONS(722), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(724), 8,
      sym_if,
      sym_foreach,
      sym_endforeach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [16130] = 2,
    ACTIONS(726), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(728), 8,
      sym_if,
      sym_foreach,
      sym_endforeach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [16146] = 2,
    ACTIONS(730), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(732), 8,
      sym_if,
      sym_foreach,
      sym_endforeach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [16162] = 2,
    ACTIONS(734), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(736), 8,
      sym_if,
      sym_foreach,
      sym_endforeach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [16178] = 2,
    ACTIONS(738), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(740), 8,
      sym_if,
      sym_foreach,
      sym_endforeach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [16194] = 2,
    ACTIONS(658), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(660), 8,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_endmacro,
      sym_block,
      sym_identifier,
  [16210] = 2,
    ACTIONS(784), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(786), 7,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [16225] = 2,
    ACTIONS(788), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(790), 7,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [16240] = 2,
    ACTIONS(792), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(794), 7,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [16255] = 2,
    ACTIONS(796), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(798), 7,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [16270] = 2,
    ACTIONS(800), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(802), 7,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [16285] = 2,
    ACTIONS(804), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(806), 7,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [16300] = 4,
    ACTIONS(808), 1,
      anon_sym_DOLLAR,
    ACTIONS(811), 1,
      aux_sym__unquoted_text_token1,
    STATE(452), 1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(562), 7,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
      anon_sym_RPAREN,
  [16319] = 2,
    ACTIONS(814), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(816), 7,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [16334] = 2,
    ACTIONS(818), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(820), 7,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [16349] = 2,
    ACTIONS(822), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(824), 7,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [16364] = 2,
    ACTIONS(826), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(828), 7,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [16379] = 2,
    ACTIONS(830), 3,
      sym_bracket_comment_open,
      sym_line_comment,
      aux_sym__untrimmed_argument_token1,
    ACTIONS(832), 7,
      sym_if,
      sym_foreach,
      sym_while,
      sym_function,
      sym_macro,
      sym_block,
      sym_identifier,
  [16394] = 4,
    ACTIONS(836), 1,
      anon_sym_DOLLAR,
    ACTIONS(839), 1,
      aux_sym__quoted_text_token1,
    STATE(458), 1,
      aux_sym__quoted_text_repeat1,
    ACTIONS(834), 7,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
      anon_sym_DQUOTE,
  [16413] = 5,
    ACTIONS(842), 1,
      anon_sym_DOLLAR,
    ACTIONS(845), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(848), 1,
      aux_sym_endwhile_command_token1,
    STATE(459), 1,
      aux_sym__unquoted_text_repeat1,
    ACTIONS(562), 6,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
  [16434] = 2,
    ACTIONS(572), 2,
      aux_sym__unquoted_text_token1,
      aux_sym_endwhile_command_token1,
    ACTIONS(570), 7,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
      anon_sym_DOLLAR,
  [16448] = 2,
    ACTIONS(600), 2,
      aux_sym__unquoted_text_token1,
      aux_sym_endwhile_command_token1,
    ACTIONS(598), 7,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
      anon_sym_DOLLAR,
  [16462] = 2,
    ACTIONS(584), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(582), 8,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
      anon_sym_DOLLAR,
      anon_sym_RPAREN,
  [16476] = 2,
    ACTIONS(576), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(574), 8,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
      anon_sym_DOLLAR,
      anon_sym_RPAREN,
  [16490] = 2,
    ACTIONS(572), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(570), 8,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
      anon_sym_DOLLAR,
      anon_sym_RPAREN,
  [16504] = 2,
    ACTIONS(600), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(598), 8,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
      anon_sym_DOLLAR,
      anon_sym_RPAREN,
  [16518] = 2,
    ACTIONS(572), 1,
      aux_sym__quoted_text_token1,
    ACTIONS(570), 8,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
  [16532] = 2,
    ACTIONS(600), 1,
      aux_sym__quoted_text_token1,
    ACTIONS(598), 8,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
  [16546] = 1,
    ACTIONS(582), 9,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
      aux_sym_variable_token1,
      anon_sym_DOLLAR,
      anon_sym_RBRACE,
  [16558] = 2,
    ACTIONS(576), 1,
      aux_sym__quoted_text_token1,
    ACTIONS(574), 8,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
  [16572] = 1,
    ACTIONS(574), 9,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
      aux_sym_variable_token1,
      anon_sym_DOLLAR,
      anon_sym_RBRACE,
  [16584] = 2,
    ACTIONS(580), 1,
      aux_sym__quoted_text_token1,
    ACTIONS(578), 8,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
  [16598] = 2,
    ACTIONS(584), 1,
      aux_sym__quoted_text_token1,
    ACTIONS(582), 8,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
  [16612] = 2,
    ACTIONS(576), 2,
      aux_sym__unquoted_text_token1,
      aux_sym_endwhile_command_token1,
    ACTIONS(574), 7,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
      anon_sym_DOLLAR,
  [16626] = 1,
    ACTIONS(578), 9,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
      aux_sym_variable_token1,
      anon_sym_DOLLAR,
      anon_sym_RBRACE,
  [16638] = 2,
    ACTIONS(580), 1,
      aux_sym__unquoted_text_token1,
    ACTIONS(578), 8,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
      anon_sym_DOLLAR,
      anon_sym_RPAREN,
  [16652] = 2,
    ACTIONS(580), 2,
      aux_sym__unquoted_text_token1,
      aux_sym_endwhile_command_token1,
    ACTIONS(578), 7,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
      anon_sym_DOLLAR,
  [16666] = 1,
    ACTIONS(570), 9,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
      aux_sym_variable_token1,
      anon_sym_DOLLAR,
      anon_sym_RBRACE,
  [16678] = 1,
    ACTIONS(598), 9,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
      aux_sym_variable_token1,
      anon_sym_DOLLAR,
      anon_sym_RBRACE,
  [16690] = 2,
    ACTIONS(584), 2,
      aux_sym__unquoted_text_token1,
      aux_sym_endwhile_command_token1,
    ACTIONS(582), 7,
      sym__escape_identity,
      anon_sym_BSLASHt,
      anon_sym_BSLASHr,
      anon_sym_BSLASHn,
      anon_sym_SEMI,
      anon_sym_BSLASH_SEMI,
      anon_sym_DOLLAR,
  [16704] = 3,
    ACTIONS(850), 1,
      anon_sym_LPAREN,
    ACTIONS(852), 1,
      aux_sym_if_command_token1,
    STATE(526), 1,
      aux_sym_if_command_repeat1,
  [16714] = 3,
    ACTIONS(854), 1,
      anon_sym_LPAREN,
    ACTIONS(856), 1,
      aux_sym_if_command_token1,
    STATE(485), 1,
      aux_sym_if_command_repeat1,
  [16724] = 3,
    ACTIONS(858), 1,
      anon_sym_LPAREN,
    ACTIONS(860), 1,
      aux_sym_if_command_token1,
    STATE(592), 1,
      aux_sym_if_command_repeat1,
  [16734] = 3,
    ACTIONS(862), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      aux_sym_if_command_token1,
    STATE(486), 1,
      aux_sym_if_command_repeat1,
  [16744] = 3,
    ACTIONS(860), 1,
      aux_sym_if_command_token1,
    ACTIONS(866), 1,
      anon_sym_LPAREN,
    STATE(592), 1,
      aux_sym_if_command_repeat1,
  [16754] = 3,
    ACTIONS(860), 1,
      aux_sym_if_command_token1,
    ACTIONS(868), 1,
      anon_sym_LPAREN,
    STATE(592), 1,
      aux_sym_if_command_repeat1,
  [16764] = 3,
    ACTIONS(860), 1,
      aux_sym_if_command_token1,
    ACTIONS(870), 1,
      anon_sym_LPAREN,
    STATE(592), 1,
      aux_sym_if_command_repeat1,
  [16774] = 3,
    ACTIONS(860), 1,
      aux_sym_if_command_token1,
    ACTIONS(872), 1,
      anon_sym_LPAREN,
    STATE(592), 1,
      aux_sym_if_command_repeat1,
  [16784] = 3,
    ACTIONS(860), 1,
      aux_sym_if_command_token1,
    ACTIONS(874), 1,
      anon_sym_LPAREN,
    STATE(592), 1,
      aux_sym_if_command_repeat1,
  [16794] = 3,
    ACTIONS(876), 1,
      anon_sym_LPAREN,
    ACTIONS(878), 1,
      aux_sym_if_command_token1,
    STATE(593), 1,
      aux_sym_if_command_repeat1,
  [16804] = 3,
    ACTIONS(880), 1,
      anon_sym_LPAREN,
    ACTIONS(882), 1,
      aux_sym_if_command_token1,
    STATE(487), 1,
      aux_sym_if_command_repeat1,
  [16814] = 3,
    ACTIONS(884), 1,
      anon_sym_LPAREN,
    ACTIONS(886), 1,
      aux_sym_if_command_token1,
    STATE(488), 1,
      aux_sym_if_command_repeat1,
  [16824] = 3,
    ACTIONS(860), 1,
      aux_sym_if_command_token1,
    ACTIONS(888), 1,
      anon_sym_LPAREN,
    STATE(592), 1,
      aux_sym_if_command_repeat1,
  [16834] = 3,
    ACTIONS(890), 1,
      anon_sym_LPAREN,
    ACTIONS(892), 1,
      aux_sym_if_command_token1,
    STATE(492), 1,
      aux_sym_if_command_repeat1,
  [16844] = 3,
    ACTIONS(894), 1,
      anon_sym_LPAREN,
    ACTIONS(896), 1,
      aux_sym_if_command_token1,
    STATE(484), 1,
      aux_sym_if_command_repeat1,
  [16854] = 3,
    ACTIONS(898), 1,
      anon_sym_LPAREN,
    ACTIONS(900), 1,
      aux_sym_if_command_token1,
    STATE(500), 1,
      aux_sym_if_command_repeat1,
  [16864] = 3,
    ACTIONS(902), 1,
      anon_sym_LPAREN,
    ACTIONS(904), 1,
      aux_sym_if_command_token1,
    STATE(497), 1,
      aux_sym_if_command_repeat1,
  [16874] = 3,
    ACTIONS(860), 1,
      aux_sym_if_command_token1,
    ACTIONS(906), 1,
      anon_sym_LPAREN,
    STATE(592), 1,
      aux_sym_if_command_repeat1,
  [16884] = 3,
    ACTIONS(908), 1,
      anon_sym_LPAREN,
    ACTIONS(910), 1,
      aux_sym_if_command_token1,
    STATE(529), 1,
      aux_sym_if_command_repeat1,
  [16894] = 3,
    ACTIONS(860), 1,
      aux_sym_if_command_token1,
    ACTIONS(912), 1,
      anon_sym_LPAREN,
    STATE(592), 1,
      aux_sym_if_command_repeat1,
  [16904] = 3,
    ACTIONS(860), 1,
      aux_sym_if_command_token1,
    ACTIONS(914), 1,
      anon_sym_LPAREN,
    STATE(592), 1,
      aux_sym_if_command_repeat1,
  [16914] = 3,
    ACTIONS(916), 1,
      anon_sym_LPAREN,
    ACTIONS(918), 1,
      aux_sym_if_command_token1,
    STATE(502), 1,
      aux_sym_if_command_repeat1,
  [16924] = 3,
    ACTIONS(860), 1,
      aux_sym_if_command_token1,
    ACTIONS(920), 1,
      anon_sym_LPAREN,
    STATE(592), 1,
      aux_sym_if_command_repeat1,
  [16934] = 3,
    ACTIONS(922), 1,
      anon_sym_LPAREN,
    ACTIONS(924), 1,
      aux_sym_if_command_token1,
    STATE(508), 1,
      aux_sym_if_command_repeat1,
  [16944] = 3,
    ACTIONS(926), 1,
      anon_sym_LPAREN,
    ACTIONS(928), 1,
      aux_sym_if_command_token1,
    STATE(509), 1,
      aux_sym_if_command_repeat1,
  [16954] = 3,
    ACTIONS(930), 1,
      anon_sym_LPAREN,
    ACTIONS(932), 1,
      aux_sym_if_command_token1,
    STATE(510), 1,
      aux_sym_if_command_repeat1,
  [16964] = 3,
    ACTIONS(934), 1,
      anon_sym_LPAREN,
    ACTIONS(936), 1,
      aux_sym_if_command_token1,
    STATE(511), 1,
      aux_sym_if_command_repeat1,
  [16974] = 3,
    ACTIONS(938), 1,
      anon_sym_LPAREN,
    ACTIONS(940), 1,
      aux_sym_if_command_token1,
    STATE(512), 1,
      aux_sym_if_command_repeat1,
  [16984] = 3,
    ACTIONS(860), 1,
      aux_sym_if_command_token1,
    ACTIONS(942), 1,
      anon_sym_LPAREN,
    STATE(592), 1,
      aux_sym_if_command_repeat1,
  [16994] = 3,
    ACTIONS(860), 1,
      aux_sym_if_command_token1,
    ACTIONS(944), 1,
      anon_sym_LPAREN,
    STATE(592), 1,
      aux_sym_if_command_repeat1,
  [17004] = 3,
    ACTIONS(860), 1,
      aux_sym_if_command_token1,
    ACTIONS(946), 1,
      anon_sym_LPAREN,
    STATE(592), 1,
      aux_sym_if_command_repeat1,
  [17014] = 3,
    ACTIONS(860), 1,
      aux_sym_if_command_token1,
    ACTIONS(948), 1,
      anon_sym_LPAREN,
    STATE(592), 1,
      aux_sym_if_command_repeat1,
  [17024] = 3,
    ACTIONS(860), 1,
      aux_sym_if_command_token1,
    ACTIONS(950), 1,
      anon_sym_LPAREN,
    STATE(592), 1,
      aux_sym_if_command_repeat1,
  [17034] = 3,
    ACTIONS(952), 1,
      anon_sym_LPAREN,
    ACTIONS(954), 1,
      aux_sym_if_command_token1,
    STATE(560), 1,
      aux_sym_if_command_repeat1,
  [17044] = 3,
    ACTIONS(956), 1,
      anon_sym_LPAREN,
    ACTIONS(958), 1,
      aux_sym_if_command_token1,
    STATE(515), 1,
      aux_sym_if_command_repeat1,
  [17054] = 3,
    ACTIONS(860), 1,
      aux_sym_if_command_token1,
    ACTIONS(960), 1,
      anon_sym_LPAREN,
    STATE(592), 1,
      aux_sym_if_command_repeat1,
  [17064] = 3,
    ACTIONS(962), 1,
      anon_sym_LPAREN,
    ACTIONS(964), 1,
      aux_sym_if_command_token1,
    STATE(517), 1,
      aux_sym_if_command_repeat1,
  [17074] = 3,
    ACTIONS(860), 1,
      aux_sym_if_command_token1,
    ACTIONS(966), 1,
      anon_sym_LPAREN,
    STATE(592), 1,
      aux_sym_if_command_repeat1,
  [17084] = 3,
    ACTIONS(968), 1,
      anon_sym_LPAREN,
    ACTIONS(970), 1,
      aux_sym_if_command_token1,
    STATE(522), 1,
      aux_sym_if_command_repeat1,
  [17094] = 3,
    ACTIONS(972), 1,
      anon_sym_LPAREN,
    ACTIONS(974), 1,
      aux_sym_if_command_token1,
    STATE(523), 1,
      aux_sym_if_command_repeat1,
  [17104] = 3,
    ACTIONS(976), 1,
      anon_sym_LPAREN,
    ACTIONS(978), 1,
      aux_sym_if_command_token1,
    STATE(524), 1,
      aux_sym_if_command_repeat1,
  [17114] = 3,
    ACTIONS(980), 1,
      anon_sym_LPAREN,
    ACTIONS(982), 1,
      aux_sym_if_command_token1,
    STATE(525), 1,
      aux_sym_if_command_repeat1,
  [17124] = 3,
    ACTIONS(860), 1,
      aux_sym_if_command_token1,
    ACTIONS(984), 1,
      anon_sym_LPAREN,
    STATE(592), 1,
      aux_sym_if_command_repeat1,
  [17134] = 3,
    ACTIONS(860), 1,
      aux_sym_if_command_token1,
    ACTIONS(986), 1,
      anon_sym_LPAREN,
    STATE(592), 1,
      aux_sym_if_command_repeat1,
  [17144] = 3,
    ACTIONS(860), 1,
      aux_sym_if_command_token1,
    ACTIONS(988), 1,
      anon_sym_LPAREN,
    STATE(592), 1,
      aux_sym_if_command_repeat1,
  [17154] = 3,
    ACTIONS(860), 1,
      aux_sym_if_command_token1,
    ACTIONS(990), 1,
      anon_sym_LPAREN,
    STATE(592), 1,
      aux_sym_if_command_repeat1,
  [17164] = 3,
    ACTIONS(860), 1,
      aux_sym_if_command_token1,
    ACTIONS(992), 1,
      anon_sym_LPAREN,
    STATE(592), 1,
      aux_sym_if_command_repeat1,
  [17174] = 3,
    ACTIONS(994), 1,
      anon_sym_LPAREN,
    ACTIONS(996), 1,
      aux_sym_if_command_token1,
    STATE(530), 1,
      aux_sym_if_command_repeat1,
  [17184] = 3,
    ACTIONS(860), 1,
      aux_sym_if_command_token1,
    ACTIONS(998), 1,
      anon_sym_LPAREN,
    STATE(592), 1,
      aux_sym_if_command_repeat1,
  [17194] = 3,
    ACTIONS(860), 1,
      aux_sym_if_command_token1,
    ACTIONS(1000), 1,
      anon_sym_LPAREN,
    STATE(592), 1,
      aux_sym_if_command_repeat1,
  [17204] = 3,
    ACTIONS(860), 1,
      aux_sym_if_command_token1,
    ACTIONS(1002), 1,
      anon_sym_LPAREN,
    STATE(592), 1,
      aux_sym_if_command_repeat1,
  [17214] = 3,
    ACTIONS(860), 1,
      aux_sym_if_command_token1,
    ACTIONS(1004), 1,
      anon_sym_LPAREN,
    STATE(592), 1,
      aux_sym_if_command_repeat1,
  [17224] = 3,
    ACTIONS(1006), 1,
      anon_sym_LPAREN,
    ACTIONS(1008), 1,
      aux_sym_if_command_token1,
    STATE(537), 1,
      aux_sym_if_command_repeat1,
  [17234] = 3,
    ACTIONS(1010), 1,
      anon_sym_LPAREN,
    ACTIONS(1012), 1,
      aux_sym_if_command_token1,
    STATE(538), 1,
      aux_sym_if_command_repeat1,
  [17244] = 3,
    ACTIONS(1014), 1,
      anon_sym_LPAREN,
    ACTIONS(1016), 1,
      aux_sym_if_command_token1,
    STATE(539), 1,
      aux_sym_if_command_repeat1,
  [17254] = 3,
    ACTIONS(1018), 1,
      anon_sym_LPAREN,
    ACTIONS(1020), 1,
      aux_sym_if_command_token1,
    STATE(540), 1,
      aux_sym_if_command_repeat1,
  [17264] = 3,
    ACTIONS(1022), 1,
      anon_sym_LPAREN,
    ACTIONS(1024), 1,
      aux_sym_if_command_token1,
    STATE(541), 1,
      aux_sym_if_command_repeat1,
  [17274] = 3,
    ACTIONS(860), 1,
      aux_sym_if_command_token1,
    ACTIONS(1026), 1,
      anon_sym_LPAREN,
    STATE(592), 1,
      aux_sym_if_command_repeat1,
  [17284] = 3,
    ACTIONS(860), 1,
      aux_sym_if_command_token1,
    ACTIONS(1028), 1,
      anon_sym_LPAREN,
    STATE(592), 1,
      aux_sym_if_command_repeat1,
  [17294] = 3,
    ACTIONS(860), 1,
      aux_sym_if_command_token1,
    ACTIONS(1030), 1,
      anon_sym_LPAREN,
    STATE(592), 1,
      aux_sym_if_command_repeat1,
  [17304] = 3,
    ACTIONS(860), 1,
      aux_sym_if_command_token1,
    ACTIONS(1032), 1,
      anon_sym_LPAREN,
    STATE(592), 1,
      aux_sym_if_command_repeat1,
  [17314] = 3,
    ACTIONS(860), 1,
      aux_sym_if_command_token1,
    ACTIONS(1034), 1,
      anon_sym_LPAREN,
    STATE(592), 1,
      aux_sym_if_command_repeat1,
  [17324] = 3,
    ACTIONS(1036), 1,
      anon_sym_LPAREN,
    ACTIONS(1038), 1,
      aux_sym_if_command_token1,
    STATE(544), 1,
      aux_sym_if_command_repeat1,
  [17334] = 3,
    ACTIONS(1040), 1,
      anon_sym_LPAREN,
    ACTIONS(1042), 1,
      aux_sym_if_command_token1,
    STATE(547), 1,
      aux_sym_if_command_repeat1,
  [17344] = 3,
    ACTIONS(860), 1,
      aux_sym_if_command_token1,
    ACTIONS(1044), 1,
      anon_sym_LPAREN,
    STATE(592), 1,
      aux_sym_if_command_repeat1,
  [17354] = 3,
    ACTIONS(1046), 1,
      anon_sym_LPAREN,
    ACTIONS(1048), 1,
      aux_sym_if_command_token1,
    STATE(499), 1,
      aux_sym_if_command_repeat1,
  [17364] = 3,
    ACTIONS(860), 1,
      aux_sym_if_command_token1,
    ACTIONS(1050), 1,
      anon_sym_LPAREN,
    STATE(592), 1,
      aux_sym_if_command_repeat1,
  [17374] = 3,
    ACTIONS(860), 1,
      aux_sym_if_command_token1,
    ACTIONS(1052), 1,
      anon_sym_LPAREN,
    STATE(592), 1,
      aux_sym_if_command_repeat1,
  [17384] = 3,
    ACTIONS(1054), 1,
      anon_sym_LPAREN,
    ACTIONS(1056), 1,
      aux_sym_if_command_token1,
    STATE(549), 1,
      aux_sym_if_command_repeat1,
  [17394] = 3,
    ACTIONS(860), 1,
      aux_sym_if_command_token1,
    ACTIONS(1058), 1,
      anon_sym_LPAREN,
    STATE(592), 1,
      aux_sym_if_command_repeat1,
  [17404] = 3,
    ACTIONS(1060), 1,
      anon_sym_LPAREN,
    ACTIONS(1062), 1,
      aux_sym_if_command_token1,
    STATE(555), 1,
      aux_sym_if_command_repeat1,
  [17414] = 3,
    ACTIONS(1064), 1,
      anon_sym_LPAREN,
    ACTIONS(1066), 1,
      aux_sym_if_command_token1,
    STATE(556), 1,
      aux_sym_if_command_repeat1,
  [17424] = 3,
    ACTIONS(1068), 1,
      anon_sym_LPAREN,
    ACTIONS(1070), 1,
      aux_sym_if_command_token1,
    STATE(557), 1,
      aux_sym_if_command_repeat1,
  [17434] = 3,
    ACTIONS(1072), 1,
      anon_sym_LPAREN,
    ACTIONS(1074), 1,
      aux_sym_if_command_token1,
    STATE(558), 1,
      aux_sym_if_command_repeat1,
  [17444] = 3,
    ACTIONS(1076), 1,
      anon_sym_LPAREN,
    ACTIONS(1078), 1,
      aux_sym_if_command_token1,
    STATE(559), 1,
      aux_sym_if_command_repeat1,
  [17454] = 3,
    ACTIONS(860), 1,
      aux_sym_if_command_token1,
    ACTIONS(1080), 1,
      anon_sym_LPAREN,
    STATE(592), 1,
      aux_sym_if_command_repeat1,
  [17464] = 3,
    ACTIONS(860), 1,
      aux_sym_if_command_token1,
    ACTIONS(1082), 1,
      anon_sym_LPAREN,
    STATE(592), 1,
      aux_sym_if_command_repeat1,
  [17474] = 3,
    ACTIONS(860), 1,
      aux_sym_if_command_token1,
    ACTIONS(1084), 1,
      anon_sym_LPAREN,
    STATE(592), 1,
      aux_sym_if_command_repeat1,
  [17484] = 3,
    ACTIONS(860), 1,
      aux_sym_if_command_token1,
    ACTIONS(1086), 1,
      anon_sym_LPAREN,
    STATE(592), 1,
      aux_sym_if_command_repeat1,
  [17494] = 3,
    ACTIONS(860), 1,
      aux_sym_if_command_token1,
    ACTIONS(1088), 1,
      anon_sym_LPAREN,
    STATE(592), 1,
      aux_sym_if_command_repeat1,
  [17504] = 3,
    ACTIONS(860), 1,
      aux_sym_if_command_token1,
    ACTIONS(1090), 1,
      anon_sym_LPAREN,
    STATE(592), 1,
      aux_sym_if_command_repeat1,
  [17514] = 3,
    ACTIONS(1092), 1,
      anon_sym_LPAREN,
    ACTIONS(1094), 1,
      aux_sym_if_command_token1,
    STATE(563), 1,
      aux_sym_if_command_repeat1,
  [17524] = 3,
    ACTIONS(1096), 1,
      anon_sym_LPAREN,
    ACTIONS(1098), 1,
      aux_sym_if_command_token1,
    STATE(482), 1,
      aux_sym_if_command_repeat1,
  [17534] = 3,
    ACTIONS(860), 1,
      aux_sym_if_command_token1,
    ACTIONS(1100), 1,
      anon_sym_LPAREN,
    STATE(592), 1,
      aux_sym_if_command_repeat1,
  [17544] = 3,
    ACTIONS(1102), 1,
      anon_sym_LPAREN,
    ACTIONS(1104), 1,
      aux_sym_if_command_token1,
    STATE(565), 1,
      aux_sym_if_command_repeat1,
  [17554] = 3,
    ACTIONS(860), 1,
      aux_sym_if_command_token1,
    ACTIONS(1106), 1,
      anon_sym_LPAREN,
    STATE(592), 1,
      aux_sym_if_command_repeat1,
  [17564] = 3,
    ACTIONS(1108), 1,
      anon_sym_LPAREN,
    ACTIONS(1110), 1,
      aux_sym_if_command_token1,
    STATE(571), 1,
      aux_sym_if_command_repeat1,
  [17574] = 3,
    ACTIONS(1112), 1,
      anon_sym_LPAREN,
    ACTIONS(1114), 1,
      aux_sym_if_command_token1,
    STATE(572), 1,
      aux_sym_if_command_repeat1,
  [17584] = 3,
    ACTIONS(1116), 1,
      anon_sym_LPAREN,
    ACTIONS(1118), 1,
      aux_sym_if_command_token1,
    STATE(573), 1,
      aux_sym_if_command_repeat1,
  [17594] = 3,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      aux_sym_if_command_token1,
    STATE(574), 1,
      aux_sym_if_command_repeat1,
  [17604] = 3,
    ACTIONS(1124), 1,
      anon_sym_LPAREN,
    ACTIONS(1126), 1,
      aux_sym_if_command_token1,
    STATE(575), 1,
      aux_sym_if_command_repeat1,
  [17614] = 3,
    ACTIONS(860), 1,
      aux_sym_if_command_token1,
    ACTIONS(1128), 1,
      anon_sym_LPAREN,
    STATE(592), 1,
      aux_sym_if_command_repeat1,
  [17624] = 3,
    ACTIONS(860), 1,
      aux_sym_if_command_token1,
    ACTIONS(1130), 1,
      anon_sym_LPAREN,
    STATE(592), 1,
      aux_sym_if_command_repeat1,
  [17634] = 3,
    ACTIONS(860), 1,
      aux_sym_if_command_token1,
    ACTIONS(1132), 1,
      anon_sym_LPAREN,
    STATE(592), 1,
      aux_sym_if_command_repeat1,
  [17644] = 3,
    ACTIONS(860), 1,
      aux_sym_if_command_token1,
    ACTIONS(1134), 1,
      anon_sym_LPAREN,
    STATE(592), 1,
      aux_sym_if_command_repeat1,
  [17654] = 3,
    ACTIONS(860), 1,
      aux_sym_if_command_token1,
    ACTIONS(1136), 1,
      anon_sym_LPAREN,
    STATE(592), 1,
      aux_sym_if_command_repeat1,
  [17664] = 3,
    ACTIONS(1138), 1,
      anon_sym_LPAREN,
    ACTIONS(1140), 1,
      aux_sym_if_command_token1,
    STATE(579), 1,
      aux_sym_if_command_repeat1,
  [17674] = 3,
    ACTIONS(1142), 1,
      anon_sym_LPAREN,
    ACTIONS(1144), 1,
      aux_sym_if_command_token1,
    STATE(528), 1,
      aux_sym_if_command_repeat1,
  [17684] = 3,
    ACTIONS(1146), 1,
      anon_sym_LBRACE,
    ACTIONS(1148), 1,
      anon_sym_ENV,
    ACTIONS(1150), 1,
      anon_sym_CACHE,
  [17694] = 3,
    ACTIONS(860), 1,
      aux_sym_if_command_token1,
    ACTIONS(1152), 1,
      anon_sym_LPAREN,
    STATE(592), 1,
      aux_sym_if_command_repeat1,
  [17704] = 3,
    ACTIONS(1154), 1,
      anon_sym_LPAREN,
    ACTIONS(1156), 1,
      aux_sym_if_command_token1,
    STATE(581), 1,
      aux_sym_if_command_repeat1,
  [17714] = 3,
    ACTIONS(860), 1,
      aux_sym_if_command_token1,
    ACTIONS(1158), 1,
      anon_sym_LPAREN,
    STATE(592), 1,
      aux_sym_if_command_repeat1,
  [17724] = 3,
    ACTIONS(1160), 1,
      anon_sym_LPAREN,
    ACTIONS(1162), 1,
      aux_sym_if_command_token1,
    STATE(587), 1,
      aux_sym_if_command_repeat1,
  [17734] = 3,
    ACTIONS(1164), 1,
      anon_sym_LPAREN,
    ACTIONS(1166), 1,
      aux_sym_if_command_token1,
    STATE(588), 1,
      aux_sym_if_command_repeat1,
  [17744] = 3,
    ACTIONS(1168), 1,
      anon_sym_LPAREN,
    ACTIONS(1170), 1,
      aux_sym_if_command_token1,
    STATE(589), 1,
      aux_sym_if_command_repeat1,
  [17754] = 3,
    ACTIONS(1172), 1,
      anon_sym_LPAREN,
    ACTIONS(1174), 1,
      aux_sym_if_command_token1,
    STATE(590), 1,
      aux_sym_if_command_repeat1,
  [17764] = 3,
    ACTIONS(1176), 1,
      anon_sym_LPAREN,
    ACTIONS(1178), 1,
      aux_sym_if_command_token1,
    STATE(591), 1,
      aux_sym_if_command_repeat1,
  [17774] = 3,
    ACTIONS(860), 1,
      aux_sym_if_command_token1,
    ACTIONS(1180), 1,
      anon_sym_LPAREN,
    STATE(592), 1,
      aux_sym_if_command_repeat1,
  [17784] = 3,
    ACTIONS(860), 1,
      aux_sym_if_command_token1,
    ACTIONS(1182), 1,
      anon_sym_LPAREN,
    STATE(592), 1,
      aux_sym_if_command_repeat1,
  [17794] = 3,
    ACTIONS(860), 1,
      aux_sym_if_command_token1,
    ACTIONS(1184), 1,
      anon_sym_LPAREN,
    STATE(592), 1,
      aux_sym_if_command_repeat1,
  [17804] = 3,
    ACTIONS(860), 1,
      aux_sym_if_command_token1,
    ACTIONS(1186), 1,
      anon_sym_LPAREN,
    STATE(592), 1,
      aux_sym_if_command_repeat1,
  [17814] = 3,
    ACTIONS(860), 1,
      aux_sym_if_command_token1,
    ACTIONS(1188), 1,
      anon_sym_LPAREN,
    STATE(592), 1,
      aux_sym_if_command_repeat1,
  [17824] = 3,
    ACTIONS(1190), 1,
      anon_sym_LPAREN,
    ACTIONS(1192), 1,
      aux_sym_if_command_token1,
    STATE(592), 1,
      aux_sym_if_command_repeat1,
  [17834] = 3,
    ACTIONS(860), 1,
      aux_sym_if_command_token1,
    ACTIONS(1195), 1,
      anon_sym_LPAREN,
    STATE(592), 1,
      aux_sym_if_command_repeat1,
  [17844] = 3,
    ACTIONS(1197), 1,
      anon_sym_LPAREN,
    ACTIONS(1199), 1,
      aux_sym_if_command_token1,
    STATE(546), 1,
      aux_sym_if_command_repeat1,
  [17854] = 3,
    ACTIONS(1201), 1,
      anon_sym_LPAREN,
    ACTIONS(1203), 1,
      aux_sym_if_command_token1,
    STATE(531), 1,
      aux_sym_if_command_repeat1,
  [17864] = 2,
    ACTIONS(1205), 1,
      sym_endwhile,
    STATE(320), 1,
      sym_endwhile_command,
  [17871] = 2,
    ACTIONS(1207), 1,
      sym_endfunction,
    STATE(352), 1,
      sym_endfunction_command,
  [17878] = 2,
    ACTIONS(1209), 1,
      sym_endmacro,
    STATE(353), 1,
      sym_endmacro_command,
  [17885] = 2,
    ACTIONS(1211), 1,
      sym_endblock,
    STATE(354), 1,
      sym_endblock_command,
  [17892] = 2,
    ACTIONS(1213), 1,
      sym_endfunction,
    STATE(430), 1,
      sym_endfunction_command,
  [17899] = 2,
    ACTIONS(1215), 1,
      sym_endmacro,
    STATE(431), 1,
      sym_endmacro_command,
  [17906] = 2,
    ACTIONS(1217), 1,
      anon_sym_RPAREN,
    ACTIONS(1219), 1,
      aux_sym_endwhile_command_token1,
  [17913] = 2,
    ACTIONS(1221), 1,
      sym_endforeach,
    STATE(319), 1,
      sym_endforeach_command,
  [17920] = 2,
    ACTIONS(1223), 1,
      sym_endblock,
    STATE(293), 1,
      sym_endblock_command,
  [17927] = 2,
    ACTIONS(1225), 1,
      sym_endblock,
    STATE(432), 1,
      sym_endblock_command,
  [17934] = 2,
    ACTIONS(1227), 1,
      anon_sym_RPAREN,
    ACTIONS(1229), 1,
      aux_sym_endwhile_command_token1,
  [17941] = 2,
    ACTIONS(1231), 1,
      anon_sym_RPAREN,
    ACTIONS(1233), 1,
      aux_sym_endwhile_command_token1,
  [17948] = 2,
    ACTIONS(1235), 1,
      sym_endforeach,
    STATE(289), 1,
      sym_endforeach_command,
  [17955] = 2,
    ACTIONS(1237), 1,
      sym_endblock,
    STATE(444), 1,
      sym_endblock_command,
  [17962] = 2,
    ACTIONS(1239), 1,
      anon_sym_RPAREN,
    ACTIONS(1241), 1,
      aux_sym_endwhile_command_token1,
  [17969] = 2,
    ACTIONS(1243), 1,
      anon_sym_RPAREN,
    ACTIONS(1245), 1,
      aux_sym_endwhile_command_token1,
  [17976] = 2,
    ACTIONS(1247), 1,
      anon_sym_RPAREN,
    ACTIONS(1249), 1,
      aux_sym_endwhile_command_token1,
  [17983] = 2,
    ACTIONS(1251), 1,
      sym_endwhile,
    STATE(290), 1,
      sym_endwhile_command,
  [17990] = 2,
    ACTIONS(1253), 1,
      sym_endforeach,
    STATE(253), 1,
      sym_endforeach_command,
  [17997] = 2,
    ACTIONS(1255), 1,
      sym_endwhile,
    STATE(254), 1,
      sym_endwhile_command,
  [18004] = 2,
    ACTIONS(1257), 1,
      sym_endfunction,
    STATE(255), 1,
      sym_endfunction_command,
  [18011] = 2,
    ACTIONS(1259), 1,
      sym_endforeach,
    STATE(380), 1,
      sym_endforeach_command,
  [18018] = 2,
    ACTIONS(1261), 1,
      sym_endwhile,
    STATE(381), 1,
      sym_endwhile_command,
  [18025] = 2,
    ACTIONS(1263), 1,
      sym_endforeach,
    STATE(350), 1,
      sym_endforeach_command,
  [18032] = 2,
    ACTIONS(1265), 1,
      sym_endwhile,
    STATE(351), 1,
      sym_endwhile_command,
  [18039] = 2,
    ACTIONS(1267), 1,
      sym_endfunction,
    STATE(321), 1,
      sym_endfunction_command,
  [18046] = 2,
    ACTIONS(1269), 1,
      sym_endmacro,
    STATE(383), 1,
      sym_endmacro_command,
  [18053] = 2,
    ACTIONS(1271), 1,
      sym_endblock,
    STATE(384), 1,
      sym_endblock_command,
  [18060] = 2,
    ACTIONS(1273), 1,
      sym_endmacro,
    STATE(256), 1,
      sym_endmacro_command,
  [18067] = 2,
    ACTIONS(1275), 1,
      anon_sym_RPAREN,
    ACTIONS(1277), 1,
      aux_sym_endwhile_command_token1,
  [18074] = 2,
    ACTIONS(1279), 1,
      anon_sym_RPAREN,
    ACTIONS(1281), 1,
      aux_sym_endwhile_command_token1,
  [18081] = 2,
    ACTIONS(1283), 1,
      anon_sym_RPAREN,
    ACTIONS(1285), 1,
      aux_sym_endwhile_command_token1,
  [18088] = 2,
    ACTIONS(1287), 1,
      sym_endforeach,
    STATE(428), 1,
      sym_endforeach_command,
  [18095] = 2,
    ACTIONS(1289), 1,
      sym_endfunction,
    STATE(291), 1,
      sym_endfunction_command,
  [18102] = 2,
    ACTIONS(1291), 1,
      sym_endblock,
    STATE(257), 1,
      sym_endblock_command,
  [18109] = 2,
    ACTIONS(1293), 1,
      anon_sym_RPAREN,
    ACTIONS(1295), 1,
      aux_sym_endwhile_command_token1,
  [18116] = 2,
    ACTIONS(1297), 1,
      anon_sym_RPAREN,
    ACTIONS(1299), 1,
      aux_sym_endwhile_command_token1,
  [18123] = 2,
    ACTIONS(1301), 1,
      sym_endmacro,
    STATE(292), 1,
      sym_endmacro_command,
  [18130] = 2,
    ACTIONS(1303), 1,
      anon_sym_RPAREN,
    ACTIONS(1305), 1,
      aux_sym_endwhile_command_token1,
  [18137] = 2,
    ACTIONS(1307), 1,
      anon_sym_RPAREN,
    ACTIONS(1309), 1,
      aux_sym_endwhile_command_token1,
  [18144] = 2,
    ACTIONS(1311), 1,
      anon_sym_RPAREN,
    ACTIONS(1313), 1,
      aux_sym_endwhile_command_token1,
  [18151] = 2,
    ACTIONS(1315), 1,
      sym_endmacro,
    STATE(443), 1,
      sym_endmacro_command,
  [18158] = 2,
    ACTIONS(1317), 1,
      sym_endwhile,
    STATE(429), 1,
      sym_endwhile_command,
  [18165] = 2,
    ACTIONS(1319), 1,
      sym_endmacro,
    STATE(322), 1,
      sym_endmacro_command,
  [18172] = 2,
    ACTIONS(1321), 1,
      sym_endforeach,
    STATE(440), 1,
      sym_endforeach_command,
  [18179] = 2,
    ACTIONS(1323), 1,
      sym_endwhile,
    STATE(441), 1,
      sym_endwhile_command,
  [18186] = 2,
    ACTIONS(1325), 1,
      sym_endfunction,
    STATE(442), 1,
      sym_endfunction_command,
  [18193] = 2,
    ACTIONS(1327), 1,
      sym_endblock,
    STATE(323), 1,
      sym_endblock_command,
  [18200] = 2,
    ACTIONS(1329), 1,
      sym_endfunction,
    STATE(382), 1,
      sym_endfunction_command,
  [18207] = 1,
    ACTIONS(1331), 1,
      anon_sym_LBRACE,
  [18211] = 1,
    ACTIONS(1333), 1,
      anon_sym_RPAREN,
  [18215] = 1,
    ACTIONS(1335), 1,
      anon_sym_RPAREN,
  [18219] = 1,
    ACTIONS(443), 1,
      anon_sym_RPAREN,
  [18223] = 1,
    ACTIONS(586), 1,
      anon_sym_RPAREN,
  [18227] = 1,
    ACTIONS(166), 1,
      anon_sym_RPAREN,
  [18231] = 1,
    ACTIONS(242), 1,
      anon_sym_RPAREN,
  [18235] = 1,
    ACTIONS(1337), 1,
      anon_sym_RPAREN,
  [18239] = 1,
    ACTIONS(65), 1,
      anon_sym_RPAREN,
  [18243] = 1,
    ACTIONS(1339), 1,
      anon_sym_RPAREN,
  [18247] = 1,
    ACTIONS(160), 1,
      anon_sym_RPAREN,
  [18251] = 1,
    ACTIONS(1341), 1,
      anon_sym_RPAREN,
  [18255] = 1,
    ACTIONS(1343), 1,
      anon_sym_RPAREN,
  [18259] = 1,
    ACTIONS(1345), 1,
      anon_sym_RPAREN,
  [18263] = 1,
    ACTIONS(1347), 1,
      anon_sym_RPAREN,
  [18267] = 1,
    ACTIONS(1349), 1,
      anon_sym_RPAREN,
  [18271] = 1,
    ACTIONS(1351), 1,
      anon_sym_RPAREN,
  [18275] = 1,
    ACTIONS(1353), 1,
      anon_sym_RPAREN,
  [18279] = 1,
    ACTIONS(1355), 1,
      sym_bracket_comment_close,
  [18283] = 1,
    ACTIONS(1357), 1,
      sym_bracket_comment_content,
  [18287] = 1,
    ACTIONS(170), 1,
      anon_sym_RPAREN,
  [18291] = 1,
    ACTIONS(67), 1,
      anon_sym_RPAREN,
  [18295] = 1,
    ACTIONS(1359), 1,
      anon_sym_RPAREN,
  [18299] = 1,
    ACTIONS(1361), 1,
      anon_sym_RPAREN,
  [18303] = 1,
    ACTIONS(1363), 1,
      anon_sym_RPAREN,
  [18307] = 1,
    ACTIONS(1365), 1,
      sym_bracket_argument_close,
  [18311] = 1,
    ACTIONS(120), 1,
      anon_sym_RPAREN,
  [18315] = 1,
    ACTIONS(1367), 1,
      sym_bracket_argument_close,
  [18319] = 1,
    ACTIONS(1369), 1,
      sym_bracket_argument_content,
  [18323] = 1,
    ACTIONS(1371), 1,
      anon_sym_RBRACE,
  [18327] = 1,
    ACTIONS(1373), 1,
      anon_sym_RPAREN,
  [18331] = 1,
    ACTIONS(433), 1,
      anon_sym_RPAREN,
  [18335] = 1,
    ACTIONS(1375), 1,
      sym_bracket_comment_close,
  [18339] = 1,
    ACTIONS(1377), 1,
      anon_sym_RPAREN,
  [18343] = 1,
    ACTIONS(178), 1,
      anon_sym_RPAREN,
  [18347] = 1,
    ACTIONS(606), 1,
      anon_sym_RPAREN,
  [18351] = 1,
    ACTIONS(122), 1,
      anon_sym_RPAREN,
  [18355] = 1,
    ACTIONS(180), 1,
      anon_sym_RPAREN,
  [18359] = 1,
    ACTIONS(1379), 1,
      anon_sym_DQUOTE,
  [18363] = 1,
    ACTIONS(182), 1,
      anon_sym_RPAREN,
  [18367] = 1,
    ACTIONS(1381), 1,
      anon_sym_RPAREN,
  [18371] = 1,
    ACTIONS(1383), 1,
      anon_sym_RBRACE,
  [18375] = 1,
    ACTIONS(1385), 1,
      anon_sym_RBRACE,
  [18379] = 1,
    ACTIONS(1387), 1,
      aux_sym_endwhile_command_token1,
  [18383] = 1,
    ACTIONS(1389), 1,
      aux_sym_endwhile_command_token1,
  [18387] = 1,
    ACTIONS(1391), 1,
      sym_bracket_comment_content,
  [18391] = 1,
    ACTIONS(1393), 1,
      anon_sym_RPAREN,
  [18395] = 1,
    ACTIONS(1395), 1,
      anon_sym_LBRACE,
  [18399] = 1,
    ACTIONS(1397), 1,
      anon_sym_LBRACE,
  [18403] = 1,
    ACTIONS(602), 1,
      anon_sym_RPAREN,
  [18407] = 1,
    ACTIONS(614), 1,
      anon_sym_RPAREN,
  [18411] = 1,
    ACTIONS(1399), 1,
      anon_sym_RPAREN,
  [18415] = 1,
    ACTIONS(1401), 1,
      anon_sym_RPAREN,
  [18419] = 1,
    ACTIONS(1403), 1,
      anon_sym_RPAREN,
  [18423] = 1,
    ACTIONS(1405), 1,
      sym_bracket_argument_content,
  [18427] = 1,
    ACTIONS(1407), 1,
      anon_sym_RPAREN,
  [18431] = 1,
    ACTIONS(1409), 1,
      anon_sym_RPAREN,
  [18435] = 1,
    ACTIONS(124), 1,
      anon_sym_RPAREN,
  [18439] = 1,
    ACTIONS(1411), 1,
      sym_bracket_comment_close,
  [18443] = 1,
    ACTIONS(69), 1,
      anon_sym_RPAREN,
  [18447] = 1,
    ACTIONS(55), 1,
      anon_sym_RPAREN,
  [18451] = 1,
    ACTIONS(110), 1,
      anon_sym_RPAREN,
  [18455] = 1,
    ACTIONS(1413), 1,
      sym_bracket_comment_content,
  [18459] = 1,
    ACTIONS(1415), 1,
      ts_builtin_sym_end,
  [18463] = 1,
    ACTIONS(1417), 1,
      sym_bracket_comment_close,
  [18467] = 1,
    ACTIONS(146), 1,
      anon_sym_RPAREN,
  [18471] = 1,
    ACTIONS(186), 1,
      anon_sym_RPAREN,
  [18475] = 1,
    ACTIONS(112), 1,
      anon_sym_RPAREN,
  [18479] = 1,
    ACTIONS(1419), 1,
      anon_sym_RBRACE,
  [18483] = 1,
    ACTIONS(1421), 1,
      aux_sym_endwhile_command_token1,
  [18487] = 1,
    ACTIONS(1423), 1,
      aux_sym_endwhile_command_token1,
  [18491] = 1,
    ACTIONS(1425), 1,
      sym_bracket_comment_content,
  [18495] = 1,
    ACTIONS(1427), 1,
      anon_sym_RPAREN,
  [18499] = 1,
    ACTIONS(1429), 1,
      anon_sym_DQUOTE,
  [18503] = 1,
    ACTIONS(190), 1,
      anon_sym_RPAREN,
  [18507] = 1,
    ACTIONS(1431), 1,
      sym_bracket_comment_close,
  [18511] = 1,
    ACTIONS(1433), 1,
      anon_sym_RBRACE,
  [18515] = 1,
    ACTIONS(1435), 1,
      anon_sym_RBRACE,
  [18519] = 1,
    ACTIONS(1437), 1,
      sym_bracket_argument_close,
  [18523] = 1,
    ACTIONS(1439), 1,
      anon_sym_DQUOTE,
  [18527] = 1,
    ACTIONS(1441), 1,
      anon_sym_RPAREN,
  [18531] = 1,
    ACTIONS(150), 1,
      anon_sym_RPAREN,
  [18535] = 1,
    ACTIONS(1443), 1,
      anon_sym_RBRACE,
  [18539] = 1,
    ACTIONS(1445), 1,
      anon_sym_RPAREN,
  [18543] = 1,
    ACTIONS(439), 1,
      anon_sym_RPAREN,
  [18547] = 1,
    ACTIONS(1447), 1,
      anon_sym_RPAREN,
  [18551] = 1,
    ACTIONS(1449), 1,
      sym_bracket_argument_content,
  [18555] = 1,
    ACTIONS(1451), 1,
      anon_sym_RBRACE,
  [18559] = 1,
    ACTIONS(198), 1,
      anon_sym_RPAREN,
  [18563] = 1,
    ACTIONS(1453), 1,
      aux_sym_endwhile_command_token1,
  [18567] = 1,
    ACTIONS(200), 1,
      anon_sym_RPAREN,
  [18571] = 1,
    ACTIONS(1455), 1,
      anon_sym_RPAREN,
  [18575] = 1,
    ACTIONS(202), 1,
      anon_sym_RPAREN,
  [18579] = 1,
    ACTIONS(1457), 1,
      anon_sym_RPAREN,
  [18583] = 1,
    ACTIONS(1459), 1,
      aux_sym_endwhile_command_token1,
  [18587] = 1,
    ACTIONS(1461), 1,
      aux_sym_endwhile_command_token1,
  [18591] = 1,
    ACTIONS(1463), 1,
      sym_bracket_comment_content,
  [18595] = 1,
    ACTIONS(458), 1,
      anon_sym_RPAREN,
  [18599] = 1,
    ACTIONS(1465), 1,
      anon_sym_RBRACE,
  [18603] = 1,
    ACTIONS(1467), 1,
      anon_sym_RPAREN,
  [18607] = 1,
    ACTIONS(602), 1,
      aux_sym_endwhile_command_token1,
  [18611] = 1,
    ACTIONS(1469), 1,
      anon_sym_RPAREN,
  [18615] = 1,
    ACTIONS(1471), 1,
      anon_sym_RPAREN,
  [18619] = 1,
    ACTIONS(1473), 1,
      anon_sym_RPAREN,
  [18623] = 1,
    ACTIONS(1475), 1,
      anon_sym_RPAREN,
  [18627] = 1,
    ACTIONS(1477), 1,
      anon_sym_RPAREN,
  [18631] = 1,
    ACTIONS(1479), 1,
      anon_sym_RPAREN,
  [18635] = 1,
    ACTIONS(128), 1,
      anon_sym_RPAREN,
  [18639] = 1,
    ACTIONS(1481), 1,
      sym_bracket_comment_close,
  [18643] = 1,
    ACTIONS(1483), 1,
      anon_sym_RPAREN,
  [18647] = 1,
    ACTIONS(1485), 1,
      anon_sym_RPAREN,
  [18651] = 1,
    ACTIONS(1487), 1,
      anon_sym_RPAREN,
  [18655] = 1,
    ACTIONS(1489), 1,
      anon_sym_RPAREN,
  [18659] = 1,
    ACTIONS(1491), 1,
      anon_sym_RBRACE,
  [18663] = 1,
    ACTIONS(1493), 1,
      anon_sym_RPAREN,
  [18667] = 1,
    ACTIONS(466), 1,
      anon_sym_RPAREN,
  [18671] = 1,
    ACTIONS(1495), 1,
      anon_sym_RPAREN,
  [18675] = 1,
    ACTIONS(210), 1,
      anon_sym_RPAREN,
  [18679] = 1,
    ACTIONS(1497), 1,
      anon_sym_RPAREN,
  [18683] = 1,
    ACTIONS(1499), 1,
      aux_sym_endwhile_command_token1,
  [18687] = 1,
    ACTIONS(1501), 1,
      aux_sym_endwhile_command_token1,
  [18691] = 1,
    ACTIONS(1503), 1,
      sym_bracket_comment_content,
  [18695] = 1,
    ACTIONS(1505), 1,
      anon_sym_RPAREN,
  [18699] = 1,
    ACTIONS(138), 1,
      anon_sym_RPAREN,
  [18703] = 1,
    ACTIONS(1507), 1,
      anon_sym_RPAREN,
  [18707] = 1,
    ACTIONS(1509), 1,
      anon_sym_RPAREN,
  [18711] = 1,
    ACTIONS(214), 1,
      anon_sym_RPAREN,
  [18715] = 1,
    ACTIONS(1511), 1,
      anon_sym_RPAREN,
  [18719] = 1,
    ACTIONS(1513), 1,
      anon_sym_RPAREN,
  [18723] = 1,
    ACTIONS(158), 1,
      anon_sym_RPAREN,
  [18727] = 1,
    ACTIONS(1515), 1,
      anon_sym_RPAREN,
  [18731] = 1,
    ACTIONS(244), 1,
      anon_sym_RPAREN,
  [18735] = 1,
    ACTIONS(1517), 1,
      anon_sym_RPAREN,
  [18739] = 1,
    ACTIONS(1519), 1,
      anon_sym_RPAREN,
  [18743] = 1,
    ACTIONS(1521), 1,
      anon_sym_RPAREN,
  [18747] = 1,
    ACTIONS(419), 1,
      anon_sym_RPAREN,
  [18751] = 1,
    ACTIONS(1523), 1,
      aux_sym_endwhile_command_token1,
  [18755] = 1,
    ACTIONS(162), 1,
      anon_sym_RPAREN,
  [18759] = 1,
    ACTIONS(222), 1,
      anon_sym_RPAREN,
  [18763] = 1,
    ACTIONS(140), 1,
      anon_sym_RPAREN,
  [18767] = 1,
    ACTIONS(224), 1,
      anon_sym_RPAREN,
  [18771] = 1,
    ACTIONS(1525), 1,
      aux_sym_endwhile_command_token1,
  [18775] = 1,
    ACTIONS(1527), 1,
      aux_sym_endwhile_command_token1,
  [18779] = 1,
    ACTIONS(1529), 1,
      sym_bracket_comment_content,
  [18783] = 1,
    ACTIONS(1531), 1,
      anon_sym_RBRACE,
  [18787] = 1,
    ACTIONS(226), 1,
      anon_sym_RPAREN,
  [18791] = 1,
    ACTIONS(1533), 1,
      anon_sym_RBRACE,
  [18795] = 1,
    ACTIONS(1535), 1,
      anon_sym_RPAREN,
  [18799] = 1,
    ACTIONS(1537), 1,
      anon_sym_RPAREN,
  [18803] = 1,
    ACTIONS(586), 1,
      aux_sym_endwhile_command_token1,
  [18807] = 1,
    ACTIONS(1539), 1,
      anon_sym_RPAREN,
  [18811] = 1,
    ACTIONS(1541), 1,
      anon_sym_RPAREN,
  [18815] = 1,
    ACTIONS(1543), 1,
      anon_sym_RPAREN,
  [18819] = 1,
    ACTIONS(1545), 1,
      anon_sym_RPAREN,
  [18823] = 1,
    ACTIONS(1547), 1,
      anon_sym_RPAREN,
  [18827] = 1,
    ACTIONS(1549), 1,
      sym_bracket_comment_close,
  [18831] = 1,
    ACTIONS(1551), 1,
      anon_sym_RPAREN,
  [18835] = 1,
    ACTIONS(1553), 1,
      anon_sym_RPAREN,
  [18839] = 1,
    ACTIONS(1555), 1,
      anon_sym_RPAREN,
  [18843] = 1,
    ACTIONS(1557), 1,
      anon_sym_RPAREN,
  [18847] = 1,
    ACTIONS(1559), 1,
      anon_sym_RPAREN,
  [18851] = 1,
    ACTIONS(1561), 1,
      anon_sym_RPAREN,
  [18855] = 1,
    ACTIONS(1563), 1,
      anon_sym_RPAREN,
  [18859] = 1,
    ACTIONS(1565), 1,
      aux_sym_endwhile_command_token1,
  [18863] = 1,
    ACTIONS(1567), 1,
      aux_sym_endwhile_command_token1,
  [18867] = 1,
    ACTIONS(1569), 1,
      sym_bracket_comment_content,
  [18871] = 1,
    ACTIONS(1571), 1,
      anon_sym_LBRACE,
  [18875] = 1,
    ACTIONS(1573), 1,
      anon_sym_LBRACE,
  [18879] = 1,
    ACTIONS(1575), 1,
      anon_sym_RPAREN,
  [18883] = 1,
    ACTIONS(230), 1,
      anon_sym_RPAREN,
  [18887] = 1,
    ACTIONS(1577), 1,
      anon_sym_LBRACE,
  [18891] = 1,
    ACTIONS(1579), 1,
      sym_bracket_comment_close,
  [18895] = 1,
    ACTIONS(614), 1,
      aux_sym_endwhile_command_token1,
  [18899] = 1,
    ACTIONS(1581), 1,
      anon_sym_RPAREN,
  [18903] = 1,
    ACTIONS(1583), 1,
      anon_sym_LBRACE,
  [18907] = 1,
    ACTIONS(1585), 1,
      anon_sym_LBRACE,
  [18911] = 1,
    ACTIONS(234), 1,
      anon_sym_RPAREN,
  [18915] = 1,
    ACTIONS(464), 1,
      anon_sym_RPAREN,
  [18919] = 1,
    ACTIONS(1587), 1,
      anon_sym_LBRACE,
  [18923] = 1,
    ACTIONS(1589), 1,
      anon_sym_LBRACE,
  [18927] = 1,
    ACTIONS(142), 1,
      anon_sym_RPAREN,
  [18931] = 1,
    ACTIONS(1591), 1,
      anon_sym_RPAREN,
  [18935] = 1,
    ACTIONS(606), 1,
      aux_sym_endwhile_command_token1,
  [18939] = 1,
    ACTIONS(1593), 1,
      anon_sym_RPAREN,
  [18943] = 1,
    ACTIONS(1595), 1,
      anon_sym_RBRACE,
  [18947] = 1,
    ACTIONS(1597), 1,
      anon_sym_RBRACE,
  [18951] = 1,
    ACTIONS(1599), 1,
      anon_sym_RBRACE,
};

static const uint32_t ts_small_parse_table_map[] = {
  [SMALL_STATE(2)] = 0,
  [SMALL_STATE(3)] = 78,
  [SMALL_STATE(4)] = 156,
  [SMALL_STATE(5)] = 234,
  [SMALL_STATE(6)] = 312,
  [SMALL_STATE(7)] = 390,
  [SMALL_STATE(8)] = 468,
  [SMALL_STATE(9)] = 546,
  [SMALL_STATE(10)] = 624,
  [SMALL_STATE(11)] = 702,
  [SMALL_STATE(12)] = 780,
  [SMALL_STATE(13)] = 858,
  [SMALL_STATE(14)] = 936,
  [SMALL_STATE(15)] = 1014,
  [SMALL_STATE(16)] = 1092,
  [SMALL_STATE(17)] = 1157,
  [SMALL_STATE(18)] = 1222,
  [SMALL_STATE(19)] = 1287,
  [SMALL_STATE(20)] = 1352,
  [SMALL_STATE(21)] = 1417,
  [SMALL_STATE(22)] = 1482,
  [SMALL_STATE(23)] = 1557,
  [SMALL_STATE(24)] = 1622,
  [SMALL_STATE(25)] = 1687,
  [SMALL_STATE(26)] = 1752,
  [SMALL_STATE(27)] = 1817,
  [SMALL_STATE(28)] = 1882,
  [SMALL_STATE(29)] = 1947,
  [SMALL_STATE(30)] = 2012,
  [SMALL_STATE(31)] = 2077,
  [SMALL_STATE(32)] = 2142,
  [SMALL_STATE(33)] = 2207,
  [SMALL_STATE(34)] = 2272,
  [SMALL_STATE(35)] = 2337,
  [SMALL_STATE(36)] = 2402,
  [SMALL_STATE(37)] = 2467,
  [SMALL_STATE(38)] = 2532,
  [SMALL_STATE(39)] = 2597,
  [SMALL_STATE(40)] = 2662,
  [SMALL_STATE(41)] = 2727,
  [SMALL_STATE(42)] = 2792,
  [SMALL_STATE(43)] = 2857,
  [SMALL_STATE(44)] = 2922,
  [SMALL_STATE(45)] = 2987,
  [SMALL_STATE(46)] = 3052,
  [SMALL_STATE(47)] = 3117,
  [SMALL_STATE(48)] = 3182,
  [SMALL_STATE(49)] = 3247,
  [SMALL_STATE(50)] = 3312,
  [SMALL_STATE(51)] = 3377,
  [SMALL_STATE(52)] = 3442,
  [SMALL_STATE(53)] = 3507,
  [SMALL_STATE(54)] = 3572,
  [SMALL_STATE(55)] = 3637,
  [SMALL_STATE(56)] = 3702,
  [SMALL_STATE(57)] = 3767,
  [SMALL_STATE(58)] = 3832,
  [SMALL_STATE(59)] = 3897,
  [SMALL_STATE(60)] = 3962,
  [SMALL_STATE(61)] = 4027,
  [SMALL_STATE(62)] = 4092,
  [SMALL_STATE(63)] = 4157,
  [SMALL_STATE(64)] = 4222,
  [SMALL_STATE(65)] = 4287,
  [SMALL_STATE(66)] = 4352,
  [SMALL_STATE(67)] = 4417,
  [SMALL_STATE(68)] = 4482,
  [SMALL_STATE(69)] = 4547,
  [SMALL_STATE(70)] = 4612,
  [SMALL_STATE(71)] = 4677,
  [SMALL_STATE(72)] = 4742,
  [SMALL_STATE(73)] = 4807,
  [SMALL_STATE(74)] = 4872,
  [SMALL_STATE(75)] = 4937,
  [SMALL_STATE(76)] = 5002,
  [SMALL_STATE(77)] = 5067,
  [SMALL_STATE(78)] = 5132,
  [SMALL_STATE(79)] = 5197,
  [SMALL_STATE(80)] = 5262,
  [SMALL_STATE(81)] = 5327,
  [SMALL_STATE(82)] = 5392,
  [SMALL_STATE(83)] = 5457,
  [SMALL_STATE(84)] = 5522,
  [SMALL_STATE(85)] = 5587,
  [SMALL_STATE(86)] = 5652,
  [SMALL_STATE(87)] = 5717,
  [SMALL_STATE(88)] = 5782,
  [SMALL_STATE(89)] = 5847,
  [SMALL_STATE(90)] = 5912,
  [SMALL_STATE(91)] = 5977,
  [SMALL_STATE(92)] = 6039,
  [SMALL_STATE(93)] = 6101,
  [SMALL_STATE(94)] = 6163,
  [SMALL_STATE(95)] = 6225,
  [SMALL_STATE(96)] = 6287,
  [SMALL_STATE(97)] = 6349,
  [SMALL_STATE(98)] = 6411,
  [SMALL_STATE(99)] = 6473,
  [SMALL_STATE(100)] = 6535,
  [SMALL_STATE(101)] = 6597,
  [SMALL_STATE(102)] = 6659,
  [SMALL_STATE(103)] = 6721,
  [SMALL_STATE(104)] = 6783,
  [SMALL_STATE(105)] = 6845,
  [SMALL_STATE(106)] = 6907,
  [SMALL_STATE(107)] = 6969,
  [SMALL_STATE(108)] = 7034,
  [SMALL_STATE(109)] = 7099,
  [SMALL_STATE(110)] = 7162,
  [SMALL_STATE(111)] = 7225,
  [SMALL_STATE(112)] = 7288,
  [SMALL_STATE(113)] = 7351,
  [SMALL_STATE(114)] = 7414,
  [SMALL_STATE(115)] = 7477,
  [SMALL_STATE(116)] = 7540,
  [SMALL_STATE(117)] = 7603,
  [SMALL_STATE(118)] = 7666,
  [SMALL_STATE(119)] = 7729,
  [SMALL_STATE(120)] = 7792,
  [SMALL_STATE(121)] = 7855,
  [SMALL_STATE(122)] = 7918,
  [SMALL_STATE(123)] = 7981,
  [SMALL_STATE(124)] = 8044,
  [SMALL_STATE(125)] = 8107,
  [SMALL_STATE(126)] = 8170,
  [SMALL_STATE(127)] = 8233,
  [SMALL_STATE(128)] = 8296,
  [SMALL_STATE(129)] = 8359,
  [SMALL_STATE(130)] = 8422,
  [SMALL_STATE(131)] = 8485,
  [SMALL_STATE(132)] = 8548,
  [SMALL_STATE(133)] = 8611,
  [SMALL_STATE(134)] = 8674,
  [SMALL_STATE(135)] = 8737,
  [SMALL_STATE(136)] = 8800,
  [SMALL_STATE(137)] = 8863,
  [SMALL_STATE(138)] = 8926,
  [SMALL_STATE(139)] = 8989,
  [SMALL_STATE(140)] = 9052,
  [SMALL_STATE(141)] = 9115,
  [SMALL_STATE(142)] = 9178,
  [SMALL_STATE(143)] = 9241,
  [SMALL_STATE(144)] = 9304,
  [SMALL_STATE(145)] = 9367,
  [SMALL_STATE(146)] = 9430,
  [SMALL_STATE(147)] = 9493,
  [SMALL_STATE(148)] = 9556,
  [SMALL_STATE(149)] = 9619,
  [SMALL_STATE(150)] = 9682,
  [SMALL_STATE(151)] = 9745,
  [SMALL_STATE(152)] = 9808,
  [SMALL_STATE(153)] = 9871,
  [SMALL_STATE(154)] = 9934,
  [SMALL_STATE(155)] = 9997,
  [SMALL_STATE(156)] = 10060,
  [SMALL_STATE(157)] = 10108,
  [SMALL_STATE(158)] = 10148,
  [SMALL_STATE(159)] = 10196,
  [SMALL_STATE(160)] = 10244,
  [SMALL_STATE(161)] = 10292,
  [SMALL_STATE(162)] = 10340,
  [SMALL_STATE(163)] = 10388,
  [SMALL_STATE(164)] = 10436,
  [SMALL_STATE(165)] = 10484,
  [SMALL_STATE(166)] = 10532,
  [SMALL_STATE(167)] = 10572,
  [SMALL_STATE(168)] = 10620,
  [SMALL_STATE(169)] = 10668,
  [SMALL_STATE(170)] = 10716,
  [SMALL_STATE(171)] = 10764,
  [SMALL_STATE(172)] = 10812,
  [SMALL_STATE(173)] = 10857,
  [SMALL_STATE(174)] = 10902,
  [SMALL_STATE(175)] = 10947,
  [SMALL_STATE(176)] = 10992,
  [SMALL_STATE(177)] = 11037,
  [SMALL_STATE(178)] = 11082,
  [SMALL_STATE(179)] = 11127,
  [SMALL_STATE(180)] = 11172,
  [SMALL_STATE(181)] = 11217,
  [SMALL_STATE(182)] = 11262,
  [SMALL_STATE(183)] = 11307,
  [SMALL_STATE(184)] = 11352,
  [SMALL_STATE(185)] = 11397,
  [SMALL_STATE(186)] = 11442,
  [SMALL_STATE(187)] = 11479,
  [SMALL_STATE(188)] = 11516,
  [SMALL_STATE(189)] = 11553,
  [SMALL_STATE(190)] = 11587,
  [SMALL_STATE(191)] = 11621,
  [SMALL_STATE(192)] = 11655,
  [SMALL_STATE(193)] = 11689,
  [SMALL_STATE(194)] = 11723,
  [SMALL_STATE(195)] = 11757,
  [SMALL_STATE(196)] = 11786,
  [SMALL_STATE(197)] = 11818,
  [SMALL_STATE(198)] = 11850,
  [SMALL_STATE(199)] = 11882,
  [SMALL_STATE(200)] = 11914,
  [SMALL_STATE(201)] = 11946,
  [SMALL_STATE(202)] = 11978,
  [SMALL_STATE(203)] = 12010,
  [SMALL_STATE(204)] = 12042,
  [SMALL_STATE(205)] = 12074,
  [SMALL_STATE(206)] = 12106,
  [SMALL_STATE(207)] = 12138,
  [SMALL_STATE(208)] = 12170,
  [SMALL_STATE(209)] = 12202,
  [SMALL_STATE(210)] = 12234,
  [SMALL_STATE(211)] = 12266,
  [SMALL_STATE(212)] = 12298,
  [SMALL_STATE(213)] = 12330,
  [SMALL_STATE(214)] = 12355,
  [SMALL_STATE(215)] = 12375,
  [SMALL_STATE(216)] = 12395,
  [SMALL_STATE(217)] = 12415,
  [SMALL_STATE(218)] = 12435,
  [SMALL_STATE(219)] = 12455,
  [SMALL_STATE(220)] = 12475,
  [SMALL_STATE(221)] = 12495,
  [SMALL_STATE(222)] = 12515,
  [SMALL_STATE(223)] = 12535,
  [SMALL_STATE(224)] = 12555,
  [SMALL_STATE(225)] = 12575,
  [SMALL_STATE(226)] = 12595,
  [SMALL_STATE(227)] = 12613,
  [SMALL_STATE(228)] = 12631,
  [SMALL_STATE(229)] = 12649,
  [SMALL_STATE(230)] = 12667,
  [SMALL_STATE(231)] = 12685,
  [SMALL_STATE(232)] = 12703,
  [SMALL_STATE(233)] = 12721,
  [SMALL_STATE(234)] = 12739,
  [SMALL_STATE(235)] = 12757,
  [SMALL_STATE(236)] = 12775,
  [SMALL_STATE(237)] = 12793,
  [SMALL_STATE(238)] = 12811,
  [SMALL_STATE(239)] = 12829,
  [SMALL_STATE(240)] = 12847,
  [SMALL_STATE(241)] = 12865,
  [SMALL_STATE(242)] = 12883,
  [SMALL_STATE(243)] = 12901,
  [SMALL_STATE(244)] = 12919,
  [SMALL_STATE(245)] = 12937,
  [SMALL_STATE(246)] = 12955,
  [SMALL_STATE(247)] = 12973,
  [SMALL_STATE(248)] = 12991,
  [SMALL_STATE(249)] = 13009,
  [SMALL_STATE(250)] = 13027,
  [SMALL_STATE(251)] = 13045,
  [SMALL_STATE(252)] = 13063,
  [SMALL_STATE(253)] = 13081,
  [SMALL_STATE(254)] = 13099,
  [SMALL_STATE(255)] = 13117,
  [SMALL_STATE(256)] = 13135,
  [SMALL_STATE(257)] = 13153,
  [SMALL_STATE(258)] = 13171,
  [SMALL_STATE(259)] = 13189,
  [SMALL_STATE(260)] = 13207,
  [SMALL_STATE(261)] = 13225,
  [SMALL_STATE(262)] = 13243,
  [SMALL_STATE(263)] = 13261,
  [SMALL_STATE(264)] = 13284,
  [SMALL_STATE(265)] = 13307,
  [SMALL_STATE(266)] = 13330,
  [SMALL_STATE(267)] = 13346,
  [SMALL_STATE(268)] = 13362,
  [SMALL_STATE(269)] = 13378,
  [SMALL_STATE(270)] = 13394,
  [SMALL_STATE(271)] = 13410,
  [SMALL_STATE(272)] = 13426,
  [SMALL_STATE(273)] = 13442,
  [SMALL_STATE(274)] = 13458,
  [SMALL_STATE(275)] = 13474,
  [SMALL_STATE(276)] = 13490,
  [SMALL_STATE(277)] = 13506,
  [SMALL_STATE(278)] = 13522,
  [SMALL_STATE(279)] = 13538,
  [SMALL_STATE(280)] = 13554,
  [SMALL_STATE(281)] = 13570,
  [SMALL_STATE(282)] = 13586,
  [SMALL_STATE(283)] = 13602,
  [SMALL_STATE(284)] = 13618,
  [SMALL_STATE(285)] = 13634,
  [SMALL_STATE(286)] = 13650,
  [SMALL_STATE(287)] = 13666,
  [SMALL_STATE(288)] = 13682,
  [SMALL_STATE(289)] = 13698,
  [SMALL_STATE(290)] = 13714,
  [SMALL_STATE(291)] = 13730,
  [SMALL_STATE(292)] = 13746,
  [SMALL_STATE(293)] = 13762,
  [SMALL_STATE(294)] = 13778,
  [SMALL_STATE(295)] = 13794,
  [SMALL_STATE(296)] = 13810,
  [SMALL_STATE(297)] = 13826,
  [SMALL_STATE(298)] = 13842,
  [SMALL_STATE(299)] = 13858,
  [SMALL_STATE(300)] = 13874,
  [SMALL_STATE(301)] = 13890,
  [SMALL_STATE(302)] = 13906,
  [SMALL_STATE(303)] = 13922,
  [SMALL_STATE(304)] = 13938,
  [SMALL_STATE(305)] = 13954,
  [SMALL_STATE(306)] = 13970,
  [SMALL_STATE(307)] = 13986,
  [SMALL_STATE(308)] = 14002,
  [SMALL_STATE(309)] = 14018,
  [SMALL_STATE(310)] = 14034,
  [SMALL_STATE(311)] = 14050,
  [SMALL_STATE(312)] = 14066,
  [SMALL_STATE(313)] = 14082,
  [SMALL_STATE(314)] = 14098,
  [SMALL_STATE(315)] = 14114,
  [SMALL_STATE(316)] = 14130,
  [SMALL_STATE(317)] = 14146,
  [SMALL_STATE(318)] = 14162,
  [SMALL_STATE(319)] = 14178,
  [SMALL_STATE(320)] = 14194,
  [SMALL_STATE(321)] = 14210,
  [SMALL_STATE(322)] = 14226,
  [SMALL_STATE(323)] = 14242,
  [SMALL_STATE(324)] = 14258,
  [SMALL_STATE(325)] = 14274,
  [SMALL_STATE(326)] = 14290,
  [SMALL_STATE(327)] = 14306,
  [SMALL_STATE(328)] = 14322,
  [SMALL_STATE(329)] = 14338,
  [SMALL_STATE(330)] = 14354,
  [SMALL_STATE(331)] = 14370,
  [SMALL_STATE(332)] = 14386,
  [SMALL_STATE(333)] = 14402,
  [SMALL_STATE(334)] = 14418,
  [SMALL_STATE(335)] = 14434,
  [SMALL_STATE(336)] = 14450,
  [SMALL_STATE(337)] = 14466,
  [SMALL_STATE(338)] = 14482,
  [SMALL_STATE(339)] = 14498,
  [SMALL_STATE(340)] = 14514,
  [SMALL_STATE(341)] = 14530,
  [SMALL_STATE(342)] = 14546,
  [SMALL_STATE(343)] = 14562,
  [SMALL_STATE(344)] = 14578,
  [SMALL_STATE(345)] = 14594,
  [SMALL_STATE(346)] = 14610,
  [SMALL_STATE(347)] = 14626,
  [SMALL_STATE(348)] = 14642,
  [SMALL_STATE(349)] = 14658,
  [SMALL_STATE(350)] = 14674,
  [SMALL_STATE(351)] = 14690,
  [SMALL_STATE(352)] = 14706,
  [SMALL_STATE(353)] = 14722,
  [SMALL_STATE(354)] = 14738,
  [SMALL_STATE(355)] = 14754,
  [SMALL_STATE(356)] = 14770,
  [SMALL_STATE(357)] = 14786,
  [SMALL_STATE(358)] = 14802,
  [SMALL_STATE(359)] = 14818,
  [SMALL_STATE(360)] = 14834,
  [SMALL_STATE(361)] = 14850,
  [SMALL_STATE(362)] = 14866,
  [SMALL_STATE(363)] = 14882,
  [SMALL_STATE(364)] = 14898,
  [SMALL_STATE(365)] = 14914,
  [SMALL_STATE(366)] = 14930,
  [SMALL_STATE(367)] = 14946,
  [SMALL_STATE(368)] = 14962,
  [SMALL_STATE(369)] = 14978,
  [SMALL_STATE(370)] = 14994,
  [SMALL_STATE(371)] = 15010,
  [SMALL_STATE(372)] = 15026,
  [SMALL_STATE(373)] = 15042,
  [SMALL_STATE(374)] = 15058,
  [SMALL_STATE(375)] = 15074,
  [SMALL_STATE(376)] = 15090,
  [SMALL_STATE(377)] = 15106,
  [SMALL_STATE(378)] = 15122,
  [SMALL_STATE(379)] = 15138,
  [SMALL_STATE(380)] = 15154,
  [SMALL_STATE(381)] = 15170,
  [SMALL_STATE(382)] = 15186,
  [SMALL_STATE(383)] = 15202,
  [SMALL_STATE(384)] = 15218,
  [SMALL_STATE(385)] = 15234,
  [SMALL_STATE(386)] = 15250,
  [SMALL_STATE(387)] = 15266,
  [SMALL_STATE(388)] = 15282,
  [SMALL_STATE(389)] = 15298,
  [SMALL_STATE(390)] = 15314,
  [SMALL_STATE(391)] = 15330,
  [SMALL_STATE(392)] = 15346,
  [SMALL_STATE(393)] = 15362,
  [SMALL_STATE(394)] = 15378,
  [SMALL_STATE(395)] = 15394,
  [SMALL_STATE(396)] = 15410,
  [SMALL_STATE(397)] = 15426,
  [SMALL_STATE(398)] = 15442,
  [SMALL_STATE(399)] = 15458,
  [SMALL_STATE(400)] = 15474,
  [SMALL_STATE(401)] = 15490,
  [SMALL_STATE(402)] = 15506,
  [SMALL_STATE(403)] = 15522,
  [SMALL_STATE(404)] = 15538,
  [SMALL_STATE(405)] = 15554,
  [SMALL_STATE(406)] = 15570,
  [SMALL_STATE(407)] = 15586,
  [SMALL_STATE(408)] = 15602,
  [SMALL_STATE(409)] = 15618,
  [SMALL_STATE(410)] = 15634,
  [SMALL_STATE(411)] = 15650,
  [SMALL_STATE(412)] = 15666,
  [SMALL_STATE(413)] = 15682,
  [SMALL_STATE(414)] = 15698,
  [SMALL_STATE(415)] = 15714,
  [SMALL_STATE(416)] = 15730,
  [SMALL_STATE(417)] = 15746,
  [SMALL_STATE(418)] = 15762,
  [SMALL_STATE(419)] = 15778,
  [SMALL_STATE(420)] = 15794,
  [SMALL_STATE(421)] = 15810,
  [SMALL_STATE(422)] = 15826,
  [SMALL_STATE(423)] = 15842,
  [SMALL_STATE(424)] = 15858,
  [SMALL_STATE(425)] = 15874,
  [SMALL_STATE(426)] = 15890,
  [SMALL_STATE(427)] = 15906,
  [SMALL_STATE(428)] = 15922,
  [SMALL_STATE(429)] = 15938,
  [SMALL_STATE(430)] = 15954,
  [SMALL_STATE(431)] = 15970,
  [SMALL_STATE(432)] = 15986,
  [SMALL_STATE(433)] = 16002,
  [SMALL_STATE(434)] = 16018,
  [SMALL_STATE(435)] = 16034,
  [SMALL_STATE(436)] = 16050,
  [SMALL_STATE(437)] = 16066,
  [SMALL_STATE(438)] = 16082,
  [SMALL_STATE(439)] = 16098,
  [SMALL_STATE(440)] = 16114,
  [SMALL_STATE(441)] = 16130,
  [SMALL_STATE(442)] = 16146,
  [SMALL_STATE(443)] = 16162,
  [SMALL_STATE(444)] = 16178,
  [SMALL_STATE(445)] = 16194,
  [SMALL_STATE(446)] = 16210,
  [SMALL_STATE(447)] = 16225,
  [SMALL_STATE(448)] = 16240,
  [SMALL_STATE(449)] = 16255,
  [SMALL_STATE(450)] = 16270,
  [SMALL_STATE(451)] = 16285,
  [SMALL_STATE(452)] = 16300,
  [SMALL_STATE(453)] = 16319,
  [SMALL_STATE(454)] = 16334,
  [SMALL_STATE(455)] = 16349,
  [SMALL_STATE(456)] = 16364,
  [SMALL_STATE(457)] = 16379,
  [SMALL_STATE(458)] = 16394,
  [SMALL_STATE(459)] = 16413,
  [SMALL_STATE(460)] = 16434,
  [SMALL_STATE(461)] = 16448,
  [SMALL_STATE(462)] = 16462,
  [SMALL_STATE(463)] = 16476,
  [SMALL_STATE(464)] = 16490,
  [SMALL_STATE(465)] = 16504,
  [SMALL_STATE(466)] = 16518,
  [SMALL_STATE(467)] = 16532,
  [SMALL_STATE(468)] = 16546,
  [SMALL_STATE(469)] = 16558,
  [SMALL_STATE(470)] = 16572,
  [SMALL_STATE(471)] = 16584,
  [SMALL_STATE(472)] = 16598,
  [SMALL_STATE(473)] = 16612,
  [SMALL_STATE(474)] = 16626,
  [SMALL_STATE(475)] = 16638,
  [SMALL_STATE(476)] = 16652,
  [SMALL_STATE(477)] = 16666,
  [SMALL_STATE(478)] = 16678,
  [SMALL_STATE(479)] = 16690,
  [SMALL_STATE(480)] = 16704,
  [SMALL_STATE(481)] = 16714,
  [SMALL_STATE(482)] = 16724,
  [SMALL_STATE(483)] = 16734,
  [SMALL_STATE(484)] = 16744,
  [SMALL_STATE(485)] = 16754,
  [SMALL_STATE(486)] = 16764,
  [SMALL_STATE(487)] = 16774,
  [SMALL_STATE(488)] = 16784,
  [SMALL_STATE(489)] = 16794,
  [SMALL_STATE(490)] = 16804,
  [SMALL_STATE(491)] = 16814,
  [SMALL_STATE(492)] = 16824,
  [SMALL_STATE(493)] = 16834,
  [SMALL_STATE(494)] = 16844,
  [SMALL_STATE(495)] = 16854,
  [SMALL_STATE(496)] = 16864,
  [SMALL_STATE(497)] = 16874,
  [SMALL_STATE(498)] = 16884,
  [SMALL_STATE(499)] = 16894,
  [SMALL_STATE(500)] = 16904,
  [SMALL_STATE(501)] = 16914,
  [SMALL_STATE(502)] = 16924,
  [SMALL_STATE(503)] = 16934,
  [SMALL_STATE(504)] = 16944,
  [SMALL_STATE(505)] = 16954,
  [SMALL_STATE(506)] = 16964,
  [SMALL_STATE(507)] = 16974,
  [SMALL_STATE(508)] = 16984,
  [SMALL_STATE(509)] = 16994,
  [SMALL_STATE(510)] = 17004,
  [SMALL_STATE(511)] = 17014,
  [SMALL_STATE(512)] = 17024,
  [SMALL_STATE(513)] = 17034,
  [SMALL_STATE(514)] = 17044,
  [SMALL_STATE(515)] = 17054,
  [SMALL_STATE(516)] = 17064,
  [SMALL_STATE(517)] = 17074,
  [SMALL_STATE(518)] = 17084,
  [SMALL_STATE(519)] = 17094,
  [SMALL_STATE(520)] = 17104,
  [SMALL_STATE(521)] = 17114,
  [SMALL_STATE(522)] = 17124,
  [SMALL_STATE(523)] = 17134,
  [SMALL_STATE(524)] = 17144,
  [SMALL_STATE(525)] = 17154,
  [SMALL_STATE(526)] = 17164,
  [SMALL_STATE(527)] = 17174,
  [SMALL_STATE(528)] = 17184,
  [SMALL_STATE(529)] = 17194,
  [SMALL_STATE(530)] = 17204,
  [SMALL_STATE(531)] = 17214,
  [SMALL_STATE(532)] = 17224,
  [SMALL_STATE(533)] = 17234,
  [SMALL_STATE(534)] = 17244,
  [SMALL_STATE(535)] = 17254,
  [SMALL_STATE(536)] = 17264,
  [SMALL_STATE(537)] = 17274,
  [SMALL_STATE(538)] = 17284,
  [SMALL_STATE(539)] = 17294,
  [SMALL_STATE(540)] = 17304,
  [SMALL_STATE(541)] = 17314,
  [SMALL_STATE(542)] = 17324,
  [SMALL_STATE(543)] = 17334,
  [SMALL_STATE(544)] = 17344,
  [SMALL_STATE(545)] = 17354,
  [SMALL_STATE(546)] = 17364,
  [SMALL_STATE(547)] = 17374,
  [SMALL_STATE(548)] = 17384,
  [SMALL_STATE(549)] = 17394,
  [SMALL_STATE(550)] = 17404,
  [SMALL_STATE(551)] = 17414,
  [SMALL_STATE(552)] = 17424,
  [SMALL_STATE(553)] = 17434,
  [SMALL_STATE(554)] = 17444,
  [SMALL_STATE(555)] = 17454,
  [SMALL_STATE(556)] = 17464,
  [SMALL_STATE(557)] = 17474,
  [SMALL_STATE(558)] = 17484,
  [SMALL_STATE(559)] = 17494,
  [SMALL_STATE(560)] = 17504,
  [SMALL_STATE(561)] = 17514,
  [SMALL_STATE(562)] = 17524,
  [SMALL_STATE(563)] = 17534,
  [SMALL_STATE(564)] = 17544,
  [SMALL_STATE(565)] = 17554,
  [SMALL_STATE(566)] = 17564,
  [SMALL_STATE(567)] = 17574,
  [SMALL_STATE(568)] = 17584,
  [SMALL_STATE(569)] = 17594,
  [SMALL_STATE(570)] = 17604,
  [SMALL_STATE(571)] = 17614,
  [SMALL_STATE(572)] = 17624,
  [SMALL_STATE(573)] = 17634,
  [SMALL_STATE(574)] = 17644,
  [SMALL_STATE(575)] = 17654,
  [SMALL_STATE(576)] = 17664,
  [SMALL_STATE(577)] = 17674,
  [SMALL_STATE(578)] = 17684,
  [SMALL_STATE(579)] = 17694,
  [SMALL_STATE(580)] = 17704,
  [SMALL_STATE(581)] = 17714,
  [SMALL_STATE(582)] = 17724,
  [SMALL_STATE(583)] = 17734,
  [SMALL_STATE(584)] = 17744,
  [SMALL_STATE(585)] = 17754,
  [SMALL_STATE(586)] = 17764,
  [SMALL_STATE(587)] = 17774,
  [SMALL_STATE(588)] = 17784,
  [SMALL_STATE(589)] = 17794,
  [SMALL_STATE(590)] = 17804,
  [SMALL_STATE(591)] = 17814,
  [SMALL_STATE(592)] = 17824,
  [SMALL_STATE(593)] = 17834,
  [SMALL_STATE(594)] = 17844,
  [SMALL_STATE(595)] = 17854,
  [SMALL_STATE(596)] = 17864,
  [SMALL_STATE(597)] = 17871,
  [SMALL_STATE(598)] = 17878,
  [SMALL_STATE(599)] = 17885,
  [SMALL_STATE(600)] = 17892,
  [SMALL_STATE(601)] = 17899,
  [SMALL_STATE(602)] = 17906,
  [SMALL_STATE(603)] = 17913,
  [SMALL_STATE(604)] = 17920,
  [SMALL_STATE(605)] = 17927,
  [SMALL_STATE(606)] = 17934,
  [SMALL_STATE(607)] = 17941,
  [SMALL_STATE(608)] = 17948,
  [SMALL_STATE(609)] = 17955,
  [SMALL_STATE(610)] = 17962,
  [SMALL_STATE(611)] = 17969,
  [SMALL_STATE(612)] = 17976,
  [SMALL_STATE(613)] = 17983,
  [SMALL_STATE(614)] = 17990,
  [SMALL_STATE(615)] = 17997,
  [SMALL_STATE(616)] = 18004,
  [SMALL_STATE(617)] = 18011,
  [SMALL_STATE(618)] = 18018,
  [SMALL_STATE(619)] = 18025,
  [SMALL_STATE(620)] = 18032,
  [SMALL_STATE(621)] = 18039,
  [SMALL_STATE(622)] = 18046,
  [SMALL_STATE(623)] = 18053,
  [SMALL_STATE(624)] = 18060,
  [SMALL_STATE(625)] = 18067,
  [SMALL_STATE(626)] = 18074,
  [SMALL_STATE(627)] = 18081,
  [SMALL_STATE(628)] = 18088,
  [SMALL_STATE(629)] = 18095,
  [SMALL_STATE(630)] = 18102,
  [SMALL_STATE(631)] = 18109,
  [SMALL_STATE(632)] = 18116,
  [SMALL_STATE(633)] = 18123,
  [SMALL_STATE(634)] = 18130,
  [SMALL_STATE(635)] = 18137,
  [SMALL_STATE(636)] = 18144,
  [SMALL_STATE(637)] = 18151,
  [SMALL_STATE(638)] = 18158,
  [SMALL_STATE(639)] = 18165,
  [SMALL_STATE(640)] = 18172,
  [SMALL_STATE(641)] = 18179,
  [SMALL_STATE(642)] = 18186,
  [SMALL_STATE(643)] = 18193,
  [SMALL_STATE(644)] = 18200,
  [SMALL_STATE(645)] = 18207,
  [SMALL_STATE(646)] = 18211,
  [SMALL_STATE(647)] = 18215,
  [SMALL_STATE(648)] = 18219,
  [SMALL_STATE(649)] = 18223,
  [SMALL_STATE(650)] = 18227,
  [SMALL_STATE(651)] = 18231,
  [SMALL_STATE(652)] = 18235,
  [SMALL_STATE(653)] = 18239,
  [SMALL_STATE(654)] = 18243,
  [SMALL_STATE(655)] = 18247,
  [SMALL_STATE(656)] = 18251,
  [SMALL_STATE(657)] = 18255,
  [SMALL_STATE(658)] = 18259,
  [SMALL_STATE(659)] = 18263,
  [SMALL_STATE(660)] = 18267,
  [SMALL_STATE(661)] = 18271,
  [SMALL_STATE(662)] = 18275,
  [SMALL_STATE(663)] = 18279,
  [SMALL_STATE(664)] = 18283,
  [SMALL_STATE(665)] = 18287,
  [SMALL_STATE(666)] = 18291,
  [SMALL_STATE(667)] = 18295,
  [SMALL_STATE(668)] = 18299,
  [SMALL_STATE(669)] = 18303,
  [SMALL_STATE(670)] = 18307,
  [SMALL_STATE(671)] = 18311,
  [SMALL_STATE(672)] = 18315,
  [SMALL_STATE(673)] = 18319,
  [SMALL_STATE(674)] = 18323,
  [SMALL_STATE(675)] = 18327,
  [SMALL_STATE(676)] = 18331,
  [SMALL_STATE(677)] = 18335,
  [SMALL_STATE(678)] = 18339,
  [SMALL_STATE(679)] = 18343,
  [SMALL_STATE(680)] = 18347,
  [SMALL_STATE(681)] = 18351,
  [SMALL_STATE(682)] = 18355,
  [SMALL_STATE(683)] = 18359,
  [SMALL_STATE(684)] = 18363,
  [SMALL_STATE(685)] = 18367,
  [SMALL_STATE(686)] = 18371,
  [SMALL_STATE(687)] = 18375,
  [SMALL_STATE(688)] = 18379,
  [SMALL_STATE(689)] = 18383,
  [SMALL_STATE(690)] = 18387,
  [SMALL_STATE(691)] = 18391,
  [SMALL_STATE(692)] = 18395,
  [SMALL_STATE(693)] = 18399,
  [SMALL_STATE(694)] = 18403,
  [SMALL_STATE(695)] = 18407,
  [SMALL_STATE(696)] = 18411,
  [SMALL_STATE(697)] = 18415,
  [SMALL_STATE(698)] = 18419,
  [SMALL_STATE(699)] = 18423,
  [SMALL_STATE(700)] = 18427,
  [SMALL_STATE(701)] = 18431,
  [SMALL_STATE(702)] = 18435,
  [SMALL_STATE(703)] = 18439,
  [SMALL_STATE(704)] = 18443,
  [SMALL_STATE(705)] = 18447,
  [SMALL_STATE(706)] = 18451,
  [SMALL_STATE(707)] = 18455,
  [SMALL_STATE(708)] = 18459,
  [SMALL_STATE(709)] = 18463,
  [SMALL_STATE(710)] = 18467,
  [SMALL_STATE(711)] = 18471,
  [SMALL_STATE(712)] = 18475,
  [SMALL_STATE(713)] = 18479,
  [SMALL_STATE(714)] = 18483,
  [SMALL_STATE(715)] = 18487,
  [SMALL_STATE(716)] = 18491,
  [SMALL_STATE(717)] = 18495,
  [SMALL_STATE(718)] = 18499,
  [SMALL_STATE(719)] = 18503,
  [SMALL_STATE(720)] = 18507,
  [SMALL_STATE(721)] = 18511,
  [SMALL_STATE(722)] = 18515,
  [SMALL_STATE(723)] = 18519,
  [SMALL_STATE(724)] = 18523,
  [SMALL_STATE(725)] = 18527,
  [SMALL_STATE(726)] = 18531,
  [SMALL_STATE(727)] = 18535,
  [SMALL_STATE(728)] = 18539,
  [SMALL_STATE(729)] = 18543,
  [SMALL_STATE(730)] = 18547,
  [SMALL_STATE(731)] = 18551,
  [SMALL_STATE(732)] = 18555,
  [SMALL_STATE(733)] = 18559,
  [SMALL_STATE(734)] = 18563,
  [SMALL_STATE(735)] = 18567,
  [SMALL_STATE(736)] = 18571,
  [SMALL_STATE(737)] = 18575,
  [SMALL_STATE(738)] = 18579,
  [SMALL_STATE(739)] = 18583,
  [SMALL_STATE(740)] = 18587,
  [SMALL_STATE(741)] = 18591,
  [SMALL_STATE(742)] = 18595,
  [SMALL_STATE(743)] = 18599,
  [SMALL_STATE(744)] = 18603,
  [SMALL_STATE(745)] = 18607,
  [SMALL_STATE(746)] = 18611,
  [SMALL_STATE(747)] = 18615,
  [SMALL_STATE(748)] = 18619,
  [SMALL_STATE(749)] = 18623,
  [SMALL_STATE(750)] = 18627,
  [SMALL_STATE(751)] = 18631,
  [SMALL_STATE(752)] = 18635,
  [SMALL_STATE(753)] = 18639,
  [SMALL_STATE(754)] = 18643,
  [SMALL_STATE(755)] = 18647,
  [SMALL_STATE(756)] = 18651,
  [SMALL_STATE(757)] = 18655,
  [SMALL_STATE(758)] = 18659,
  [SMALL_STATE(759)] = 18663,
  [SMALL_STATE(760)] = 18667,
  [SMALL_STATE(761)] = 18671,
  [SMALL_STATE(762)] = 18675,
  [SMALL_STATE(763)] = 18679,
  [SMALL_STATE(764)] = 18683,
  [SMALL_STATE(765)] = 18687,
  [SMALL_STATE(766)] = 18691,
  [SMALL_STATE(767)] = 18695,
  [SMALL_STATE(768)] = 18699,
  [SMALL_STATE(769)] = 18703,
  [SMALL_STATE(770)] = 18707,
  [SMALL_STATE(771)] = 18711,
  [SMALL_STATE(772)] = 18715,
  [SMALL_STATE(773)] = 18719,
  [SMALL_STATE(774)] = 18723,
  [SMALL_STATE(775)] = 18727,
  [SMALL_STATE(776)] = 18731,
  [SMALL_STATE(777)] = 18735,
  [SMALL_STATE(778)] = 18739,
  [SMALL_STATE(779)] = 18743,
  [SMALL_STATE(780)] = 18747,
  [SMALL_STATE(781)] = 18751,
  [SMALL_STATE(782)] = 18755,
  [SMALL_STATE(783)] = 18759,
  [SMALL_STATE(784)] = 18763,
  [SMALL_STATE(785)] = 18767,
  [SMALL_STATE(786)] = 18771,
  [SMALL_STATE(787)] = 18775,
  [SMALL_STATE(788)] = 18779,
  [SMALL_STATE(789)] = 18783,
  [SMALL_STATE(790)] = 18787,
  [SMALL_STATE(791)] = 18791,
  [SMALL_STATE(792)] = 18795,
  [SMALL_STATE(793)] = 18799,
  [SMALL_STATE(794)] = 18803,
  [SMALL_STATE(795)] = 18807,
  [SMALL_STATE(796)] = 18811,
  [SMALL_STATE(797)] = 18815,
  [SMALL_STATE(798)] = 18819,
  [SMALL_STATE(799)] = 18823,
  [SMALL_STATE(800)] = 18827,
  [SMALL_STATE(801)] = 18831,
  [SMALL_STATE(802)] = 18835,
  [SMALL_STATE(803)] = 18839,
  [SMALL_STATE(804)] = 18843,
  [SMALL_STATE(805)] = 18847,
  [SMALL_STATE(806)] = 18851,
  [SMALL_STATE(807)] = 18855,
  [SMALL_STATE(808)] = 18859,
  [SMALL_STATE(809)] = 18863,
  [SMALL_STATE(810)] = 18867,
  [SMALL_STATE(811)] = 18871,
  [SMALL_STATE(812)] = 18875,
  [SMALL_STATE(813)] = 18879,
  [SMALL_STATE(814)] = 18883,
  [SMALL_STATE(815)] = 18887,
  [SMALL_STATE(816)] = 18891,
  [SMALL_STATE(817)] = 18895,
  [SMALL_STATE(818)] = 18899,
  [SMALL_STATE(819)] = 18903,
  [SMALL_STATE(820)] = 18907,
  [SMALL_STATE(821)] = 18911,
  [SMALL_STATE(822)] = 18915,
  [SMALL_STATE(823)] = 18919,
  [SMALL_STATE(824)] = 18923,
  [SMALL_STATE(825)] = 18927,
  [SMALL_STATE(826)] = 18931,
  [SMALL_STATE(827)] = 18935,
  [SMALL_STATE(828)] = 18939,
  [SMALL_STATE(829)] = 18943,
  [SMALL_STATE(830)] = 18947,
  [SMALL_STATE(831)] = 18951,
};

static const TSParseActionEntry ts_parse_actions[] = {
  [0] = {.entry = {.count = 0, .reusable = false}},
  [1] = {.entry = {.count = 1, .reusable = false}}, RECOVER(),
  [3] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source_file, 0, 0, 0),
  [5] = {.entry = {.count = 1, .reusable = true}}, SHIFT(123),
  [7] = {.entry = {.count = 1, .reusable = false}}, SHIFT(494),
  [9] = {.entry = {.count = 1, .reusable = false}}, SHIFT(577),
  [11] = {.entry = {.count = 1, .reusable = false}}, SHIFT(594),
  [13] = {.entry = {.count = 1, .reusable = false}}, SHIFT(545),
  [15] = {.entry = {.count = 1, .reusable = false}}, SHIFT(489),
  [17] = {.entry = {.count = 1, .reusable = false}}, SHIFT(513),
  [19] = {.entry = {.count = 1, .reusable = false}}, SHIFT(542),
  [21] = {.entry = {.count = 1, .reusable = true}}, SHIFT(707),
  [23] = {.entry = {.count = 1, .reusable = true}}, SHIFT(107),
  [25] = {.entry = {.count = 1, .reusable = false}}, SHIFT(562),
  [27] = {.entry = {.count = 1, .reusable = false}}, SHIFT(481),
  [29] = {.entry = {.count = 1, .reusable = false}}, SHIFT(483),
  [31] = {.entry = {.count = 1, .reusable = false}}, SHIFT(495),
  [33] = {.entry = {.count = 1, .reusable = true}}, SHIFT(664),
  [35] = {.entry = {.count = 1, .reusable = false}}, SHIFT(501),
  [37] = {.entry = {.count = 1, .reusable = false}}, SHIFT(516),
  [39] = {.entry = {.count = 1, .reusable = false}}, SHIFT(595),
  [41] = {.entry = {.count = 1, .reusable = false}}, SHIFT(548),
  [43] = {.entry = {.count = 1, .reusable = false}}, SHIFT(564),
  [45] = {.entry = {.count = 1, .reusable = false}}, SHIFT(580),
  [47] = {.entry = {.count = 1, .reusable = true}}, SHIFT(214),
  [49] = {.entry = {.count = 1, .reusable = true}}, SHIFT(195),
  [51] = {.entry = {.count = 1, .reusable = true}}, SHIFT(104),
  [53] = {.entry = {.count = 1, .reusable = true}}, SHIFT(91),
  [55] = {.entry = {.count = 1, .reusable = true}}, SHIFT(238),
  [57] = {.entry = {.count = 1, .reusable = true}}, SHIFT(187),
  [59] = {.entry = {.count = 1, .reusable = false}}, SHIFT(157),
  [61] = {.entry = {.count = 1, .reusable = true}}, SHIFT(731),
  [63] = {.entry = {.count = 1, .reusable = true}}, SHIFT(810),
  [65] = {.entry = {.count = 1, .reusable = true}}, SHIFT(397),
  [67] = {.entry = {.count = 1, .reusable = true}}, SHIFT(457),
  [69] = {.entry = {.count = 1, .reusable = true}}, SHIFT(436),
  [71] = {.entry = {.count = 1, .reusable = true}}, SHIFT(235),
  [73] = {.entry = {.count = 1, .reusable = true}}, SHIFT(346),
  [75] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_if_condition_repeat1, 2, 0, 0), SHIFT_REPEAT(107),
  [78] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_if_condition_repeat1, 2, 0, 0), SHIFT_REPEAT(494),
  [81] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_if_condition_repeat1, 2, 0, 0), SHIFT_REPEAT(562),
  [84] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_if_condition_repeat1, 2, 0, 0), SHIFT_REPEAT(481),
  [87] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_if_condition_repeat1, 2, 0, 0),
  [89] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_if_condition_repeat1, 2, 0, 0), SHIFT_REPEAT(577),
  [92] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_if_condition_repeat1, 2, 0, 0), SHIFT_REPEAT(594),
  [95] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_if_condition_repeat1, 2, 0, 0), SHIFT_REPEAT(545),
  [98] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_if_condition_repeat1, 2, 0, 0), SHIFT_REPEAT(489),
  [101] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_if_condition_repeat1, 2, 0, 0), SHIFT_REPEAT(513),
  [104] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_if_condition_repeat1, 2, 0, 0), SHIFT_REPEAT(495),
  [107] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_if_condition_repeat1, 2, 0, 0), SHIFT_REPEAT(664),
  [110] = {.entry = {.count = 1, .reusable = true}}, SHIFT(248),
  [112] = {.entry = {.count = 1, .reusable = true}}, SHIFT(407),
  [114] = {.entry = {.count = 1, .reusable = true}}, SHIFT(410),
  [116] = {.entry = {.count = 1, .reusable = true}}, SHIFT(411),
  [118] = {.entry = {.count = 1, .reusable = true}}, SHIFT(413),
  [120] = {.entry = {.count = 1, .reusable = true}}, SHIFT(417),
  [122] = {.entry = {.count = 1, .reusable = true}}, SHIFT(418),
  [124] = {.entry = {.count = 1, .reusable = true}}, SHIFT(419),
  [126] = {.entry = {.count = 1, .reusable = true}}, SHIFT(250),
  [128] = {.entry = {.count = 1, .reusable = true}}, SHIFT(259),
  [130] = {.entry = {.count = 1, .reusable = true}}, SHIFT(260),
  [132] = {.entry = {.count = 1, .reusable = true}}, SHIFT(230),
  [134] = {.entry = {.count = 1, .reusable = true}}, SHIFT(237),
  [136] = {.entry = {.count = 1, .reusable = true}}, SHIFT(244),
  [138] = {.entry = {.count = 1, .reusable = true}}, SHIFT(227),
  [140] = {.entry = {.count = 1, .reusable = true}}, SHIFT(229),
  [142] = {.entry = {.count = 1, .reusable = true}}, SHIFT(233),
  [144] = {.entry = {.count = 1, .reusable = true}}, SHIFT(437),
  [146] = {.entry = {.count = 1, .reusable = true}}, SHIFT(405),
  [148] = {.entry = {.count = 1, .reusable = true}}, SHIFT(438),
  [150] = {.entry = {.count = 1, .reusable = true}}, SHIFT(267),
  [152] = {.entry = {.count = 1, .reusable = true}}, SHIFT(270),
  [154] = {.entry = {.count = 1, .reusable = true}}, SHIFT(271),
  [156] = {.entry = {.count = 1, .reusable = true}}, SHIFT(272),
  [158] = {.entry = {.count = 1, .reusable = true}}, SHIFT(276),
  [160] = {.entry = {.count = 1, .reusable = true}}, SHIFT(398),
  [162] = {.entry = {.count = 1, .reusable = true}}, SHIFT(278),
  [164] = {.entry = {.count = 1, .reusable = true}}, SHIFT(287),
  [166] = {.entry = {.count = 1, .reusable = true}}, SHIFT(294),
  [168] = {.entry = {.count = 1, .reusable = true}}, SHIFT(295),
  [170] = {.entry = {.count = 1, .reusable = true}}, SHIFT(297),
  [172] = {.entry = {.count = 1, .reusable = true}}, SHIFT(300),
  [174] = {.entry = {.count = 1, .reusable = true}}, SHIFT(301),
  [176] = {.entry = {.count = 1, .reusable = true}}, SHIFT(302),
  [178] = {.entry = {.count = 1, .reusable = true}}, SHIFT(306),
  [180] = {.entry = {.count = 1, .reusable = true}}, SHIFT(307),
  [182] = {.entry = {.count = 1, .reusable = true}}, SHIFT(308),
  [184] = {.entry = {.count = 1, .reusable = true}}, SHIFT(317),
  [186] = {.entry = {.count = 1, .reusable = true}}, SHIFT(324),
  [188] = {.entry = {.count = 1, .reusable = true}}, SHIFT(325),
  [190] = {.entry = {.count = 1, .reusable = true}}, SHIFT(327),
  [192] = {.entry = {.count = 1, .reusable = true}}, SHIFT(330),
  [194] = {.entry = {.count = 1, .reusable = true}}, SHIFT(331),
  [196] = {.entry = {.count = 1, .reusable = true}}, SHIFT(332),
  [198] = {.entry = {.count = 1, .reusable = true}}, SHIFT(336),
  [200] = {.entry = {.count = 1, .reusable = true}}, SHIFT(337),
  [202] = {.entry = {.count = 1, .reusable = true}}, SHIFT(338),
  [204] = {.entry = {.count = 1, .reusable = true}}, SHIFT(451),
  [206] = {.entry = {.count = 1, .reusable = true}}, SHIFT(348),
  [208] = {.entry = {.count = 1, .reusable = true}}, SHIFT(412),
  [210] = {.entry = {.count = 1, .reusable = true}}, SHIFT(355),
  [212] = {.entry = {.count = 1, .reusable = true}}, SHIFT(356),
  [214] = {.entry = {.count = 1, .reusable = true}}, SHIFT(358),
  [216] = {.entry = {.count = 1, .reusable = true}}, SHIFT(361),
  [218] = {.entry = {.count = 1, .reusable = true}}, SHIFT(445),
  [220] = {.entry = {.count = 1, .reusable = true}}, SHIFT(363),
  [222] = {.entry = {.count = 1, .reusable = true}}, SHIFT(367),
  [224] = {.entry = {.count = 1, .reusable = true}}, SHIFT(368),
  [226] = {.entry = {.count = 1, .reusable = true}}, SHIFT(369),
  [228] = {.entry = {.count = 1, .reusable = true}}, SHIFT(378),
  [230] = {.entry = {.count = 1, .reusable = true}}, SHIFT(385),
  [232] = {.entry = {.count = 1, .reusable = true}}, SHIFT(386),
  [234] = {.entry = {.count = 1, .reusable = true}}, SHIFT(388),
  [236] = {.entry = {.count = 1, .reusable = true}}, SHIFT(391),
  [238] = {.entry = {.count = 1, .reusable = true}}, SHIFT(392),
  [240] = {.entry = {.count = 1, .reusable = true}}, SHIFT(393),
  [242] = {.entry = {.count = 1, .reusable = true}}, SHIFT(266),
  [244] = {.entry = {.count = 1, .reusable = true}}, SHIFT(277),
  [246] = {.entry = {.count = 1, .reusable = true}}, SHIFT(98),
  [248] = {.entry = {.count = 1, .reusable = true}}, SHIFT(220),
  [250] = {.entry = {.count = 1, .reusable = true}}, SHIFT(101),
  [252] = {.entry = {.count = 1, .reusable = true}}, SHIFT(224),
  [254] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__paren_argument_repeat1, 2, 0, 0), SHIFT_REPEAT(214),
  [257] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__paren_argument_repeat1, 2, 0, 0), SHIFT_REPEAT(195),
  [260] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__paren_argument_repeat1, 2, 0, 0), SHIFT_REPEAT(101),
  [263] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__paren_argument_repeat1, 2, 0, 0), SHIFT_REPEAT(91),
  [266] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__paren_argument_repeat1, 2, 0, 0),
  [268] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__paren_argument_repeat1, 2, 0, 0), SHIFT_REPEAT(187),
  [271] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__paren_argument_repeat1, 2, 0, 0), SHIFT_REPEAT(157),
  [274] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__paren_argument_repeat1, 2, 0, 0), SHIFT_REPEAT(731),
  [277] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__paren_argument_repeat1, 2, 0, 0), SHIFT_REPEAT(810),
  [280] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_argument_list, 1, 0, 0),
  [282] = {.entry = {.count = 1, .reusable = true}}, SHIFT(108),
  [284] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_body, 1, 0, 0),
  [286] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(108),
  [289] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(494),
  [292] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0),
  [294] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(577),
  [297] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(594),
  [300] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(545),
  [303] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(489),
  [306] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(513),
  [309] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(495),
  [312] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(664),
  [315] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0),
  [317] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(109),
  [320] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(542),
  [323] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(707),
  [326] = {.entry = {.count = 1, .reusable = true}}, SHIFT(113),
  [328] = {.entry = {.count = 1, .reusable = false}}, SHIFT(527),
  [330] = {.entry = {.count = 1, .reusable = true}}, SHIFT(716),
  [332] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(111),
  [335] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(514),
  [338] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(690),
  [341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(115),
  [343] = {.entry = {.count = 1, .reusable = false}}, SHIFT(543),
  [345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(741),
  [347] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(113),
  [350] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(527),
  [353] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(716),
  [356] = {.entry = {.count = 1, .reusable = true}}, SHIFT(117),
  [358] = {.entry = {.count = 1, .reusable = false}}, SHIFT(561),
  [360] = {.entry = {.count = 1, .reusable = true}}, SHIFT(766),
  [362] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(115),
  [365] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(543),
  [368] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(741),
  [371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(118),
  [373] = {.entry = {.count = 1, .reusable = false}}, SHIFT(576),
  [375] = {.entry = {.count = 1, .reusable = true}}, SHIFT(788),
  [377] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(117),
  [380] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(561),
  [383] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(766),
  [386] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(118),
  [389] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(576),
  [392] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(788),
  [395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(110),
  [397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(112),
  [399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(114),
  [401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(116),
  [403] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source_file, 1, 0, 0),
  [405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(109),
  [407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(111),
  [409] = {.entry = {.count = 1, .reusable = false}}, SHIFT(514),
  [411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(690),
  [413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(124),
  [415] = {.entry = {.count = 1, .reusable = true}}, SHIFT(464),
  [417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(264),
  [419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(365),
  [421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(186),
  [423] = {.entry = {.count = 1, .reusable = false}}, SHIFT(194),
  [425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(673),
  [427] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_unquoted_argument, 1, 0, 0),
  [429] = {.entry = {.count = 1, .reusable = false}}, SHIFT(166),
  [431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(298),
  [433] = {.entry = {.count = 1, .reusable = true}}, SHIFT(304),
  [435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(389),
  [437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(328),
  [439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(334),
  [441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(359),
  [443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(395),
  [445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(258),
  [447] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_unquoted_argument_repeat1, 2, 0, 0), SHIFT_REPEAT(214),
  [450] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_unquoted_argument_repeat1, 2, 0, 0), SHIFT_REPEAT(195),
  [453] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_unquoted_argument_repeat1, 2, 0, 0),
  [455] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_unquoted_argument_repeat1, 2, 0, 0), SHIFT_REPEAT(166),
  [458] = {.entry = {.count = 1, .reusable = true}}, SHIFT(243),
  [460] = {.entry = {.count = 1, .reusable = true}}, SHIFT(408),
  [462] = {.entry = {.count = 1, .reusable = true}}, SHIFT(268),
  [464] = {.entry = {.count = 1, .reusable = true}}, SHIFT(415),
  [466] = {.entry = {.count = 1, .reusable = true}}, SHIFT(274),
  [468] = {.entry = {.count = 1, .reusable = true}}, SHIFT(460),
  [470] = {.entry = {.count = 1, .reusable = true}}, SHIFT(265),
  [472] = {.entry = {.count = 1, .reusable = true}}, SHIFT(188),
  [474] = {.entry = {.count = 1, .reusable = false}}, SHIFT(189),
  [476] = {.entry = {.count = 1, .reusable = true}}, SHIFT(699),
  [478] = {.entry = {.count = 1, .reusable = true}}, SHIFT(466),
  [480] = {.entry = {.count = 1, .reusable = true}}, SHIFT(263),
  [482] = {.entry = {.count = 1, .reusable = true}}, SHIFT(680),
  [484] = {.entry = {.count = 1, .reusable = false}}, SHIFT(191),
  [486] = {.entry = {.count = 1, .reusable = true}}, SHIFT(223),
  [488] = {.entry = {.count = 1, .reusable = true}}, SHIFT(827),
  [490] = {.entry = {.count = 1, .reusable = false}}, SHIFT(192),
  [492] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_unquoted_argument, 1, 0, 0),
  [494] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_unquoted_argument_repeat1, 2, 0, 0), SHIFT_REPEAT(464),
  [497] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_unquoted_argument_repeat1, 2, 0, 0), SHIFT_REPEAT(264),
  [500] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_unquoted_argument_repeat1, 2, 0, 0), SHIFT_REPEAT(190),
  [503] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_quoted_element, 1, 0, 0),
  [505] = {.entry = {.count = 1, .reusable = false}}, SHIFT(193),
  [507] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_unquoted_argument_repeat1, 2, 0, 0), SHIFT_REPEAT(460),
  [510] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_unquoted_argument_repeat1, 2, 0, 0), SHIFT_REPEAT(265),
  [513] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_unquoted_argument_repeat1, 2, 0, 0), SHIFT_REPEAT(192),
  [516] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_unquoted_argument_repeat1, 2, 0, 0),
  [518] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_quoted_element_repeat1, 2, 0, 0), SHIFT_REPEAT(466),
  [521] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_quoted_element_repeat1, 2, 0, 0), SHIFT_REPEAT(263),
  [524] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_quoted_element_repeat1, 2, 0, 0),
  [526] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_quoted_element_repeat1, 2, 0, 0), SHIFT_REPEAT(193),
  [529] = {.entry = {.count = 1, .reusable = false}}, SHIFT(190),
  [531] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__unquoted_text_repeat1, 1, 0, 0),
  [533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(203),
  [535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(692),
  [537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(693),
  [539] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__unquoted_text_repeat1, 1, 0, 0),
  [541] = {.entry = {.count = 1, .reusable = true}}, SHIFT(477),
  [543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(207),
  [545] = {.entry = {.count = 1, .reusable = true}}, SHIFT(578),
  [547] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_variable_repeat1, 2, 0, 0), SHIFT_REPEAT(477),
  [550] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_variable_repeat1, 2, 0, 0), SHIFT_REPEAT(200),
  [553] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_variable_repeat1, 2, 0, 0), SHIFT_REPEAT(578),
  [556] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_variable_repeat1, 2, 0, 0),
  [558] = {.entry = {.count = 1, .reusable = true}}, SHIFT(200),
  [560] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable, 1, 0, 0),
  [562] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__unquoted_text_repeat1, 2, 0, 0),
  [564] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__unquoted_text_repeat1, 2, 0, 0), SHIFT_REPEAT(213),
  [567] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__unquoted_text_repeat1, 2, 0, 0), SHIFT_REPEAT(213),
  [570] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_escape_sequence, 1, 0, 0),
  [572] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_escape_sequence, 1, 0, 0),
  [574] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_normal_var, 4, 0, 0),
  [576] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_normal_var, 4, 0, 0),
  [578] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_env_var, 5, 0, 0),
  [580] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_env_var, 5, 0, 0),
  [582] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_cache_var, 5, 0, 0),
  [584] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_cache_var, 5, 0, 0),
  [586] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_argument, 1, 0, 0),
  [588] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_argument, 1, 0, 0),
  [590] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_bracket_comment, 3, 0, 0),
  [592] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_bracket_comment, 3, 0, 0),
  [594] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__paren_argument, 2, 0, 0),
  [596] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__paren_argument, 2, 0, 0),
  [598] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_ref, 1, 0, 0),
  [600] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variable_ref, 1, 0, 0),
  [602] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_bracket_argument, 3, 0, 0),
  [604] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_bracket_argument, 3, 0, 0),
  [606] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_quoted_argument, 2, 0, 0),
  [608] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_quoted_argument, 2, 0, 0),
  [610] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__paren_argument, 3, 0, 0),
  [612] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__paren_argument, 3, 0, 0),
  [614] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_quoted_argument, 3, 0, 0),
  [616] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_quoted_argument, 3, 0, 0),
  [618] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_endfunction_command, 5, 0, 0),
  [620] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_endfunction_command, 5, 0, 0),
  [622] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_endfunction_command, 4, 0, 0),
  [624] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_endfunction_command, 4, 0, 0),
  [626] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_command, 4, 0, 0),
  [628] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_command, 4, 0, 0),
  [630] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_endmacro_command, 4, 0, 0),
  [632] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_endmacro_command, 4, 0, 0),
  [634] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_endfunction_command, 3, 0, 0),
  [636] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_endfunction_command, 3, 0, 0),
  [638] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_endif_command, 5, 0, 0),
  [640] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_endif_command, 5, 0, 0),
  [642] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_elseif_command, 5, 0, 0),
  [644] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_elseif_command, 5, 0, 0),
  [646] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_endblock_command, 4, 0, 0),
  [648] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_endblock_command, 4, 0, 0),
  [650] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_endforeach_command, 5, 0, 0),
  [652] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_endforeach_command, 5, 0, 0),
  [654] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_else_command, 3, 0, 0),
  [656] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_else_command, 3, 0, 0),
  [658] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_endmacro_command, 3, 0, 0),
  [660] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_endmacro_command, 3, 0, 0),
  [662] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_endif_command, 4, 0, 0),
  [664] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_endif_command, 4, 0, 0),
  [666] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_condition, 2, 0, 0),
  [668] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_condition, 2, 0, 0),
  [670] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_endmacro_command, 5, 0, 0),
  [672] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_endmacro_command, 5, 0, 0),
  [674] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_endblock_command, 5, 0, 0),
  [676] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_endblock_command, 5, 0, 0),
  [678] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_endwhile_command, 7, 0, 0),
  [680] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_endwhile_command, 7, 0, 0),
  [682] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_endforeach_command, 4, 0, 0),
  [684] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_endforeach_command, 4, 0, 0),
  [686] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_endblock_command, 3, 0, 0),
  [688] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_endblock_command, 3, 0, 0),
  [690] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_else_command, 5, 0, 0),
  [692] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_else_command, 5, 0, 0),
  [694] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_command, 5, 0, 0),
  [696] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_command, 5, 0, 0),
  [698] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_elseif_command, 4, 0, 0),
  [700] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_elseif_command, 4, 0, 0),
  [702] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_else_command, 4, 0, 0),
  [704] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_else_command, 4, 0, 0),
  [706] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_endwhile_command, 3, 0, 0),
  [708] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_endwhile_command, 3, 0, 0),
  [710] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_normal_command, 3, 0, 0),
  [712] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_normal_command, 3, 0, 0),
  [714] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_condition, 3, 0, 0),
  [716] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_condition, 3, 0, 0),
  [718] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_endwhile_command, 4, 0, 0),
  [720] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_endwhile_command, 4, 0, 0),
  [722] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_foreach_loop, 3, 0, 0),
  [724] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_foreach_loop, 3, 0, 0),
  [726] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_while_loop, 3, 0, 0),
  [728] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_while_loop, 3, 0, 0),
  [730] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_def, 3, 0, 0),
  [732] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_def, 3, 0, 0),
  [734] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_macro_def, 3, 0, 0),
  [736] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_macro_def, 3, 0, 0),
  [738] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_block_def, 3, 0, 0),
  [740] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_block_def, 3, 0, 0),
  [742] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_endforeach_command, 3, 0, 0),
  [744] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_endforeach_command, 3, 0, 0),
  [746] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_normal_command, 4, 0, 0),
  [748] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_normal_command, 4, 0, 0),
  [750] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_endif_command, 3, 0, 0),
  [752] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_endif_command, 3, 0, 0),
  [754] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_normal_command, 5, 0, 0),
  [756] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_normal_command, 5, 0, 0),
  [758] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_endwhile_command, 6, 0, 0),
  [760] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_endwhile_command, 6, 0, 0),
  [762] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__quoted_text_repeat1, 1, 0, 0),
  [764] = {.entry = {.count = 1, .reusable = true}}, SHIFT(197),
  [766] = {.entry = {.count = 1, .reusable = true}}, SHIFT(811),
  [768] = {.entry = {.count = 1, .reusable = true}}, SHIFT(812),
  [770] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__quoted_text_repeat1, 1, 0, 0),
  [772] = {.entry = {.count = 1, .reusable = true}}, SHIFT(204),
  [774] = {.entry = {.count = 1, .reusable = true}}, SHIFT(819),
  [776] = {.entry = {.count = 1, .reusable = true}}, SHIFT(820),
  [778] = {.entry = {.count = 1, .reusable = true}}, SHIFT(209),
  [780] = {.entry = {.count = 1, .reusable = true}}, SHIFT(823),
  [782] = {.entry = {.count = 1, .reusable = true}}, SHIFT(824),
  [784] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_block_command, 5, 0, 0),
  [786] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_block_command, 5, 0, 0),
  [788] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_foreach_command, 5, 0, 0),
  [790] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_foreach_command, 5, 0, 0),
  [792] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_while_command, 5, 0, 0),
  [794] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_while_command, 5, 0, 0),
  [796] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_command, 5, 0, 0),
  [798] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_command, 5, 0, 0),
  [800] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_macro_command, 5, 0, 0),
  [802] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_macro_command, 5, 0, 0),
  [804] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_block_command, 3, 0, 0),
  [806] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_block_command, 3, 0, 0),
  [808] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__unquoted_text_repeat1, 2, 0, 0), SHIFT_REPEAT(452),
  [811] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__unquoted_text_repeat1, 2, 0, 0), SHIFT_REPEAT(452),
  [814] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_foreach_command, 4, 0, 0),
  [816] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_foreach_command, 4, 0, 0),
  [818] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_while_command, 4, 0, 0),
  [820] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_while_command, 4, 0, 0),
  [822] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_command, 4, 0, 0),
  [824] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_command, 4, 0, 0),
  [826] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_macro_command, 4, 0, 0),
  [828] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_macro_command, 4, 0, 0),
  [830] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_block_command, 4, 0, 0),
  [832] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_block_command, 4, 0, 0),
  [834] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__quoted_text_repeat1, 2, 0, 0),
  [836] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__quoted_text_repeat1, 2, 0, 0), SHIFT_REPEAT(458),
  [839] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__quoted_text_repeat1, 2, 0, 0), SHIFT_REPEAT(458),
  [842] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__unquoted_text_repeat1, 2, 0, 0), SHIFT_REPEAT(459),
  [845] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__unquoted_text_repeat1, 2, 0, 0), SHIFT_REPEAT(459),
  [848] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__unquoted_text_repeat1, 2, 0, 0),
  [850] = {.entry = {.count = 1, .reusable = true}}, SHIFT(46),
  [852] = {.entry = {.count = 1, .reusable = true}}, SHIFT(526),
  [854] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20),
  [856] = {.entry = {.count = 1, .reusable = true}}, SHIFT(485),
  [858] = {.entry = {.count = 1, .reusable = true}}, SHIFT(102),
  [860] = {.entry = {.count = 1, .reusable = true}}, SHIFT(592),
  [862] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21),
  [864] = {.entry = {.count = 1, .reusable = true}}, SHIFT(486),
  [866] = {.entry = {.count = 1, .reusable = true}}, SHIFT(105),
  [868] = {.entry = {.count = 1, .reusable = true}}, SHIFT(23),
  [870] = {.entry = {.count = 1, .reusable = true}}, SHIFT(24),
  [872] = {.entry = {.count = 1, .reusable = true}}, SHIFT(170),
  [874] = {.entry = {.count = 1, .reusable = true}}, SHIFT(634),
  [876] = {.entry = {.count = 1, .reusable = true}}, SHIFT(93),
  [878] = {.entry = {.count = 1, .reusable = true}}, SHIFT(593),
  [880] = {.entry = {.count = 1, .reusable = true}}, SHIFT(168),
  [882] = {.entry = {.count = 1, .reusable = true}}, SHIFT(487),
  [884] = {.entry = {.count = 1, .reusable = true}}, SHIFT(612),
  [886] = {.entry = {.count = 1, .reusable = true}}, SHIFT(488),
  [888] = {.entry = {.count = 1, .reusable = true}}, SHIFT(28),
  [890] = {.entry = {.count = 1, .reusable = true}}, SHIFT(25),
  [892] = {.entry = {.count = 1, .reusable = true}}, SHIFT(492),
  [894] = {.entry = {.count = 1, .reusable = true}}, SHIFT(99),
  [896] = {.entry = {.count = 1, .reusable = true}}, SHIFT(484),
  [898] = {.entry = {.count = 1, .reusable = true}}, SHIFT(31),
  [900] = {.entry = {.count = 1, .reusable = true}}, SHIFT(500),
  [902] = {.entry = {.count = 1, .reusable = true}}, SHIFT(26),
  [904] = {.entry = {.count = 1, .reusable = true}}, SHIFT(497),
  [906] = {.entry = {.count = 1, .reusable = true}}, SHIFT(29),
  [908] = {.entry = {.count = 1, .reusable = true}}, SHIFT(27),
  [910] = {.entry = {.count = 1, .reusable = true}}, SHIFT(529),
  [912] = {.entry = {.count = 1, .reusable = true}}, SHIFT(96),
  [914] = {.entry = {.count = 1, .reusable = true}}, SHIFT(32),
  [916] = {.entry = {.count = 1, .reusable = true}}, SHIFT(33),
  [918] = {.entry = {.count = 1, .reusable = true}}, SHIFT(502),
  [920] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16),
  [922] = {.entry = {.count = 1, .reusable = true}}, SHIFT(165),
  [924] = {.entry = {.count = 1, .reusable = true}}, SHIFT(508),
  [926] = {.entry = {.count = 1, .reusable = true}}, SHIFT(602),
  [928] = {.entry = {.count = 1, .reusable = true}}, SHIFT(509),
  [930] = {.entry = {.count = 1, .reusable = true}}, SHIFT(34),
  [932] = {.entry = {.count = 1, .reusable = true}}, SHIFT(510),
  [934] = {.entry = {.count = 1, .reusable = true}}, SHIFT(35),
  [936] = {.entry = {.count = 1, .reusable = true}}, SHIFT(511),
  [938] = {.entry = {.count = 1, .reusable = true}}, SHIFT(36),
  [940] = {.entry = {.count = 1, .reusable = true}}, SHIFT(512),
  [942] = {.entry = {.count = 1, .reusable = true}}, SHIFT(167),
  [944] = {.entry = {.count = 1, .reusable = true}}, SHIFT(636),
  [946] = {.entry = {.count = 1, .reusable = true}}, SHIFT(37),
  [948] = {.entry = {.count = 1, .reusable = true}}, SHIFT(38),
  [950] = {.entry = {.count = 1, .reusable = true}}, SHIFT(39),
  [952] = {.entry = {.count = 1, .reusable = true}}, SHIFT(70),
  [954] = {.entry = {.count = 1, .reusable = true}}, SHIFT(560),
  [956] = {.entry = {.count = 1, .reusable = true}}, SHIFT(40),
  [958] = {.entry = {.count = 1, .reusable = true}}, SHIFT(515),
  [960] = {.entry = {.count = 1, .reusable = true}}, SHIFT(41),
  [962] = {.entry = {.count = 1, .reusable = true}}, SHIFT(42),
  [964] = {.entry = {.count = 1, .reusable = true}}, SHIFT(517),
  [966] = {.entry = {.count = 1, .reusable = true}}, SHIFT(43),
  [968] = {.entry = {.count = 1, .reusable = true}}, SHIFT(169),
  [970] = {.entry = {.count = 1, .reusable = true}}, SHIFT(522),
  [972] = {.entry = {.count = 1, .reusable = true}}, SHIFT(606),
  [974] = {.entry = {.count = 1, .reusable = true}}, SHIFT(523),
  [976] = {.entry = {.count = 1, .reusable = true}}, SHIFT(44),
  [978] = {.entry = {.count = 1, .reusable = true}}, SHIFT(524),
  [980] = {.entry = {.count = 1, .reusable = true}}, SHIFT(45),
  [982] = {.entry = {.count = 1, .reusable = true}}, SHIFT(525),
  [984] = {.entry = {.count = 1, .reusable = true}}, SHIFT(171),
  [986] = {.entry = {.count = 1, .reusable = true}}, SHIFT(632),
  [988] = {.entry = {.count = 1, .reusable = true}}, SHIFT(47),
  [990] = {.entry = {.count = 1, .reusable = true}}, SHIFT(90),
  [992] = {.entry = {.count = 1, .reusable = true}}, SHIFT(49),
  [994] = {.entry = {.count = 1, .reusable = true}}, SHIFT(50),
  [996] = {.entry = {.count = 1, .reusable = true}}, SHIFT(530),
  [998] = {.entry = {.count = 1, .reusable = true}}, SHIFT(92),
  [1000] = {.entry = {.count = 1, .reusable = true}}, SHIFT(30),
  [1002] = {.entry = {.count = 1, .reusable = true}}, SHIFT(51),
  [1004] = {.entry = {.count = 1, .reusable = true}}, SHIFT(53),
  [1006] = {.entry = {.count = 1, .reusable = true}}, SHIFT(158),
  [1008] = {.entry = {.count = 1, .reusable = true}}, SHIFT(537),
  [1010] = {.entry = {.count = 1, .reusable = true}}, SHIFT(625),
  [1012] = {.entry = {.count = 1, .reusable = true}}, SHIFT(538),
  [1014] = {.entry = {.count = 1, .reusable = true}}, SHIFT(54),
  [1016] = {.entry = {.count = 1, .reusable = true}}, SHIFT(539),
  [1018] = {.entry = {.count = 1, .reusable = true}}, SHIFT(55),
  [1020] = {.entry = {.count = 1, .reusable = true}}, SHIFT(540),
  [1022] = {.entry = {.count = 1, .reusable = true}}, SHIFT(56),
  [1024] = {.entry = {.count = 1, .reusable = true}}, SHIFT(541),
  [1026] = {.entry = {.count = 1, .reusable = true}}, SHIFT(159),
  [1028] = {.entry = {.count = 1, .reusable = true}}, SHIFT(627),
  [1030] = {.entry = {.count = 1, .reusable = true}}, SHIFT(57),
  [1032] = {.entry = {.count = 1, .reusable = true}}, SHIFT(58),
  [1034] = {.entry = {.count = 1, .reusable = true}}, SHIFT(59),
  [1036] = {.entry = {.count = 1, .reusable = true}}, SHIFT(72),
  [1038] = {.entry = {.count = 1, .reusable = true}}, SHIFT(544),
  [1040] = {.entry = {.count = 1, .reusable = true}}, SHIFT(60),
  [1042] = {.entry = {.count = 1, .reusable = true}}, SHIFT(547),
  [1044] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19),
  [1046] = {.entry = {.count = 1, .reusable = true}}, SHIFT(106),
  [1048] = {.entry = {.count = 1, .reusable = true}}, SHIFT(499),
  [1050] = {.entry = {.count = 1, .reusable = true}}, SHIFT(94),
  [1052] = {.entry = {.count = 1, .reusable = true}}, SHIFT(61),
  [1054] = {.entry = {.count = 1, .reusable = true}}, SHIFT(62),
  [1056] = {.entry = {.count = 1, .reusable = true}}, SHIFT(549),
  [1058] = {.entry = {.count = 1, .reusable = true}}, SHIFT(63),
  [1060] = {.entry = {.count = 1, .reusable = true}}, SHIFT(161),
  [1062] = {.entry = {.count = 1, .reusable = true}}, SHIFT(555),
  [1064] = {.entry = {.count = 1, .reusable = true}}, SHIFT(626),
  [1066] = {.entry = {.count = 1, .reusable = true}}, SHIFT(556),
  [1068] = {.entry = {.count = 1, .reusable = true}}, SHIFT(64),
  [1070] = {.entry = {.count = 1, .reusable = true}}, SHIFT(557),
  [1072] = {.entry = {.count = 1, .reusable = true}}, SHIFT(65),
  [1074] = {.entry = {.count = 1, .reusable = true}}, SHIFT(558),
  [1076] = {.entry = {.count = 1, .reusable = true}}, SHIFT(66),
  [1078] = {.entry = {.count = 1, .reusable = true}}, SHIFT(559),
  [1080] = {.entry = {.count = 1, .reusable = true}}, SHIFT(162),
  [1082] = {.entry = {.count = 1, .reusable = true}}, SHIFT(610),
  [1084] = {.entry = {.count = 1, .reusable = true}}, SHIFT(67),
  [1086] = {.entry = {.count = 1, .reusable = true}}, SHIFT(68),
  [1088] = {.entry = {.count = 1, .reusable = true}}, SHIFT(69),
  [1090] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18),
  [1092] = {.entry = {.count = 1, .reusable = true}}, SHIFT(71),
  [1094] = {.entry = {.count = 1, .reusable = true}}, SHIFT(563),
  [1096] = {.entry = {.count = 1, .reusable = true}}, SHIFT(100),
  [1098] = {.entry = {.count = 1, .reusable = true}}, SHIFT(482),
  [1100] = {.entry = {.count = 1, .reusable = true}}, SHIFT(73),
  [1102] = {.entry = {.count = 1, .reusable = true}}, SHIFT(74),
  [1104] = {.entry = {.count = 1, .reusable = true}}, SHIFT(565),
  [1106] = {.entry = {.count = 1, .reusable = true}}, SHIFT(75),
  [1108] = {.entry = {.count = 1, .reusable = true}}, SHIFT(163),
  [1110] = {.entry = {.count = 1, .reusable = true}}, SHIFT(571),
  [1112] = {.entry = {.count = 1, .reusable = true}}, SHIFT(607),
  [1114] = {.entry = {.count = 1, .reusable = true}}, SHIFT(572),
  [1116] = {.entry = {.count = 1, .reusable = true}}, SHIFT(76),
  [1118] = {.entry = {.count = 1, .reusable = true}}, SHIFT(573),
  [1120] = {.entry = {.count = 1, .reusable = true}}, SHIFT(77),
  [1122] = {.entry = {.count = 1, .reusable = true}}, SHIFT(574),
  [1124] = {.entry = {.count = 1, .reusable = true}}, SHIFT(78),
  [1126] = {.entry = {.count = 1, .reusable = true}}, SHIFT(575),
  [1128] = {.entry = {.count = 1, .reusable = true}}, SHIFT(156),
  [1130] = {.entry = {.count = 1, .reusable = true}}, SHIFT(611),
  [1132] = {.entry = {.count = 1, .reusable = true}}, SHIFT(79),
  [1134] = {.entry = {.count = 1, .reusable = true}}, SHIFT(80),
  [1136] = {.entry = {.count = 1, .reusable = true}}, SHIFT(81),
  [1138] = {.entry = {.count = 1, .reusable = true}}, SHIFT(82),
  [1140] = {.entry = {.count = 1, .reusable = true}}, SHIFT(579),
  [1142] = {.entry = {.count = 1, .reusable = true}}, SHIFT(95),
  [1144] = {.entry = {.count = 1, .reusable = true}}, SHIFT(528),
  [1146] = {.entry = {.count = 1, .reusable = true}}, SHIFT(196),
  [1148] = {.entry = {.count = 1, .reusable = true}}, SHIFT(815),
  [1150] = {.entry = {.count = 1, .reusable = true}}, SHIFT(645),
  [1152] = {.entry = {.count = 1, .reusable = true}}, SHIFT(83),
  [1154] = {.entry = {.count = 1, .reusable = true}}, SHIFT(84),
  [1156] = {.entry = {.count = 1, .reusable = true}}, SHIFT(581),
  [1158] = {.entry = {.count = 1, .reusable = true}}, SHIFT(85),
  [1160] = {.entry = {.count = 1, .reusable = true}}, SHIFT(160),
  [1162] = {.entry = {.count = 1, .reusable = true}}, SHIFT(587),
  [1164] = {.entry = {.count = 1, .reusable = true}}, SHIFT(631),
  [1166] = {.entry = {.count = 1, .reusable = true}}, SHIFT(588),
  [1168] = {.entry = {.count = 1, .reusable = true}}, SHIFT(86),
  [1170] = {.entry = {.count = 1, .reusable = true}}, SHIFT(589),
  [1172] = {.entry = {.count = 1, .reusable = true}}, SHIFT(87),
  [1174] = {.entry = {.count = 1, .reusable = true}}, SHIFT(590),
  [1176] = {.entry = {.count = 1, .reusable = true}}, SHIFT(88),
  [1178] = {.entry = {.count = 1, .reusable = true}}, SHIFT(591),
  [1180] = {.entry = {.count = 1, .reusable = true}}, SHIFT(164),
  [1182] = {.entry = {.count = 1, .reusable = true}}, SHIFT(635),
  [1184] = {.entry = {.count = 1, .reusable = true}}, SHIFT(89),
  [1186] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17),
  [1188] = {.entry = {.count = 1, .reusable = true}}, SHIFT(48),
  [1190] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_if_command_repeat1, 2, 0, 0),
  [1192] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_if_command_repeat1, 2, 0, 0), SHIFT_REPEAT(592),
  [1195] = {.entry = {.count = 1, .reusable = true}}, SHIFT(103),
  [1197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(97),
  [1199] = {.entry = {.count = 1, .reusable = true}}, SHIFT(546),
  [1201] = {.entry = {.count = 1, .reusable = true}}, SHIFT(52),
  [1203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(531),
  [1205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(551),
  [1207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(568),
  [1209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(569),
  [1211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(570),
  [1213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(493),
  [1215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(496),
  [1217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(249),
  [1219] = {.entry = {.count = 1, .reusable = false}}, SHIFT(175),
  [1221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(550),
  [1223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(536),
  [1225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(498),
  [1227] = {.entry = {.count = 1, .reusable = true}}, SHIFT(269),
  [1229] = {.entry = {.count = 1, .reusable = false}}, SHIFT(177),
  [1231] = {.entry = {.count = 1, .reusable = true}}, SHIFT(360),
  [1233] = {.entry = {.count = 1, .reusable = false}}, SHIFT(174),
  [1235] = {.entry = {.count = 1, .reusable = true}}, SHIFT(532),
  [1237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(480),
  [1239] = {.entry = {.count = 1, .reusable = true}}, SHIFT(335),
  [1241] = {.entry = {.count = 1, .reusable = false}}, SHIFT(182),
  [1243] = {.entry = {.count = 1, .reusable = true}}, SHIFT(366),
  [1245] = {.entry = {.count = 1, .reusable = false}}, SHIFT(183),
  [1247] = {.entry = {.count = 1, .reusable = true}}, SHIFT(409),
  [1249] = {.entry = {.count = 1, .reusable = false}}, SHIFT(172),
  [1251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(533),
  [1253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(503),
  [1255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(504),
  [1257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(505),
  [1259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(582),
  [1261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(583),
  [1263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(566),
  [1265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(567),
  [1267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(552),
  [1269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(585),
  [1271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(586),
  [1273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(506),
  [1275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(299),
  [1277] = {.entry = {.count = 1, .reusable = false}}, SHIFT(179),
  [1279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(329),
  [1281] = {.entry = {.count = 1, .reusable = false}}, SHIFT(181),
  [1283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(305),
  [1285] = {.entry = {.count = 1, .reusable = false}}, SHIFT(180),
  [1287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(490),
  [1289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(534),
  [1291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(507),
  [1293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(390),
  [1295] = {.entry = {.count = 1, .reusable = false}}, SHIFT(184),
  [1297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(275),
  [1299] = {.entry = {.count = 1, .reusable = false}}, SHIFT(178),
  [1301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(535),
  [1303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(416),
  [1305] = {.entry = {.count = 1, .reusable = false}}, SHIFT(173),
  [1307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(396),
  [1309] = {.entry = {.count = 1, .reusable = false}}, SHIFT(185),
  [1311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(252),
  [1313] = {.entry = {.count = 1, .reusable = false}}, SHIFT(176),
  [1315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(521),
  [1317] = {.entry = {.count = 1, .reusable = true}}, SHIFT(491),
  [1319] = {.entry = {.count = 1, .reusable = true}}, SHIFT(553),
  [1321] = {.entry = {.count = 1, .reusable = true}}, SHIFT(518),
  [1323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(519),
  [1325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(520),
  [1327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(554),
  [1329] = {.entry = {.count = 1, .reusable = true}}, SHIFT(584),
  [1331] = {.entry = {.count = 1, .reusable = true}}, SHIFT(202),
  [1333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(234),
  [1335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(394),
  [1337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(226),
  [1339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(240),
  [1341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(296),
  [1343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(399),
  [1345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(400),
  [1347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(401),
  [1349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(402),
  [1351] = {.entry = {.count = 1, .reusable = true}}, SHIFT(403),
  [1353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(404),
  [1355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(219),
  [1357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(709),
  [1359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(241),
  [1361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(262),
  [1363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(242),
  [1365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(222),
  [1367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(694),
  [1369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(672),
  [1371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(463),
  [1373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(303),
  [1375] = {.entry = {.count = 1, .reusable = true}}, SHIFT(435),
  [1377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(455),
  [1379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(695),
  [1381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(261),
  [1383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(475),
  [1385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(462),
  [1387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(668),
  [1389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(669),
  [1391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(677),
  [1393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(309),
  [1395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(208),
  [1397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(212),
  [1399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(310),
  [1401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(311),
  [1403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(312),
  [1405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(723),
  [1407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(313),
  [1409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(314),
  [1411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(316),
  [1413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(720),
  [1415] = {.entry = {.count = 1, .reusable = true}},  ACCEPT_INPUT(),
  [1417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(236),
  [1419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(216),
  [1421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(805),
  [1423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(806),
  [1425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(816),
  [1427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(326),
  [1429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(225),
  [1431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(433),
  [1433] = {.entry = {.count = 1, .reusable = true}}, SHIFT(217),
  [1435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(215),
  [1437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(745),
  [1439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(817),
  [1441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(362),
  [1443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(473),
  [1445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(333),
  [1447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(421),
  [1449] = {.entry = {.count = 1, .reusable = true}}, SHIFT(670),
  [1451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(469),
  [1453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(778),
  [1455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(231),
  [1457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(246),
  [1459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(700),
  [1461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(701),
  [1463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(703),
  [1465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(476),
  [1467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(447),
  [1469] = {.entry = {.count = 1, .reusable = true}}, SHIFT(339),
  [1471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(340),
  [1473] = {.entry = {.count = 1, .reusable = true}}, SHIFT(341),
  [1475] = {.entry = {.count = 1, .reusable = true}}, SHIFT(342),
  [1477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(343),
  [1479] = {.entry = {.count = 1, .reusable = true}}, SHIFT(344),
  [1481] = {.entry = {.count = 1, .reusable = true}}, SHIFT(347),
  [1483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(422),
  [1485] = {.entry = {.count = 1, .reusable = true}}, SHIFT(228),
  [1487] = {.entry = {.count = 1, .reusable = true}}, SHIFT(448),
  [1489] = {.entry = {.count = 1, .reusable = true}}, SHIFT(456),
  [1491] = {.entry = {.count = 1, .reusable = true}}, SHIFT(470),
  [1493] = {.entry = {.count = 1, .reusable = true}}, SHIFT(273),
  [1495] = {.entry = {.count = 1, .reusable = true}}, SHIFT(232),
  [1497] = {.entry = {.count = 1, .reusable = true}}, SHIFT(449),
  [1499] = {.entry = {.count = 1, .reusable = true}}, SHIFT(750),
  [1501] = {.entry = {.count = 1, .reusable = true}}, SHIFT(751),
  [1503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(753),
  [1505] = {.entry = {.count = 1, .reusable = true}}, SHIFT(423),
  [1507] = {.entry = {.count = 1, .reusable = true}}, SHIFT(450),
  [1509] = {.entry = {.count = 1, .reusable = true}}, SHIFT(357),
  [1511] = {.entry = {.count = 1, .reusable = true}}, SHIFT(446),
  [1513] = {.entry = {.count = 1, .reusable = true}}, SHIFT(424),
  [1515] = {.entry = {.count = 1, .reusable = true}}, SHIFT(453),
  [1517] = {.entry = {.count = 1, .reusable = true}}, SHIFT(245),
  [1519] = {.entry = {.count = 1, .reusable = true}}, SHIFT(425),
  [1521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(364),
  [1523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(801),
  [1525] = {.entry = {.count = 1, .reusable = true}}, SHIFT(797),
  [1527] = {.entry = {.count = 1, .reusable = true}}, SHIFT(798),
  [1529] = {.entry = {.count = 1, .reusable = true}}, SHIFT(800),
  [1531] = {.entry = {.count = 1, .reusable = true}}, SHIFT(474),
  [1533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(468),
  [1535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(370),
  [1537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(371),
  [1539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(372),
  [1541] = {.entry = {.count = 1, .reusable = true}}, SHIFT(373),
  [1543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(374),
  [1545] = {.entry = {.count = 1, .reusable = true}}, SHIFT(375),
  [1547] = {.entry = {.count = 1, .reusable = true}}, SHIFT(279),
  [1549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(377),
  [1551] = {.entry = {.count = 1, .reusable = true}}, SHIFT(426),
  [1553] = {.entry = {.count = 1, .reusable = true}}, SHIFT(280),
  [1555] = {.entry = {.count = 1, .reusable = true}}, SHIFT(281),
  [1557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(282),
  [1559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(283),
  [1561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(284),
  [1563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(414),
  [1565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(661),
  [1567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(662),
  [1569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(663),
  [1571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(198),
  [1573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(199),
  [1575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(406),
  [1577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(201),
  [1579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(286),
  [1581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(387),
  [1583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(205),
  [1585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(206),
  [1587] = {.entry = {.count = 1, .reusable = true}}, SHIFT(210),
  [1589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(211),
  [1591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(454),
  [1593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(247),
  [1595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(471),
  [1597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(472),
  [1599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(479),
};

enum ts_external_scanner_symbol_identifiers {
  ts_external_token_bracket_argument_open = 0,
  ts_external_token_bracket_argument_content = 1,
  ts_external_token_bracket_argument_close = 2,
  ts_external_token_bracket_comment_open = 3,
  ts_external_token_bracket_comment_content = 4,
  ts_external_token_bracket_comment_close = 5,
  ts_external_token_line_comment = 6,
};

static const TSSymbol ts_external_scanner_symbol_map[EXTERNAL_TOKEN_COUNT] = {
  [ts_external_token_bracket_argument_open] = sym_bracket_argument_open,
  [ts_external_token_bracket_argument_content] = sym_bracket_argument_content,
  [ts_external_token_bracket_argument_close] = sym_bracket_argument_close,
  [ts_external_token_bracket_comment_open] = sym_bracket_comment_open,
  [ts_external_token_bracket_comment_content] = sym_bracket_comment_content,
  [ts_external_token_bracket_comment_close] = sym_bracket_comment_close,
  [ts_external_token_line_comment] = sym_line_comment,
};

static const bool ts_external_scanner_states[9][EXTERNAL_TOKEN_COUNT] = {
  [1] = {
    [ts_external_token_bracket_argument_open] = true,
    [ts_external_token_bracket_argument_content] = true,
    [ts_external_token_bracket_argument_close] = true,
    [ts_external_token_bracket_comment_open] = true,
    [ts_external_token_bracket_comment_content] = true,
    [ts_external_token_bracket_comment_close] = true,
    [ts_external_token_line_comment] = true,
  },
  [2] = {
    [ts_external_token_bracket_comment_open] = true,
    [ts_external_token_line_comment] = true,
  },
  [3] = {
    [ts_external_token_bracket_argument_open] = true,
    [ts_external_token_bracket_comment_open] = true,
    [ts_external_token_line_comment] = true,
  },
  [4] = {
    [ts_external_token_bracket_argument_open] = true,
  },
  [5] = {
    [ts_external_token_bracket_comment_close] = true,
  },
  [6] = {
    [ts_external_token_bracket_comment_content] = true,
  },
  [7] = {
    [ts_external_token_bracket_argument_close] = true,
  },
  [8] = {
    [ts_external_token_bracket_argument_content] = true,
  },
};

#ifdef __cplusplus
extern "C" {
#endif
void *tree_sitter_cmake_external_scanner_create(void);
void tree_sitter_cmake_external_scanner_destroy(void *);
bool tree_sitter_cmake_external_scanner_scan(void *, TSLexer *, const bool *);
unsigned tree_sitter_cmake_external_scanner_serialize(void *, char *);
void tree_sitter_cmake_external_scanner_deserialize(void *, const char *, unsigned);

#ifdef TREE_SITTER_HIDE_SYMBOLS
#define TS_PUBLIC
#elif defined(_WIN32)
#define TS_PUBLIC __declspec(dllexport)
#else
#define TS_PUBLIC __attribute__((visibility("default")))
#endif

TS_PUBLIC const TSLanguage *tree_sitter_cmake(void) {
  static const TSLanguage language = {
    .abi_version = LANGUAGE_VERSION,
    .symbol_count = SYMBOL_COUNT,
    .alias_count = ALIAS_COUNT,
    .token_count = TOKEN_COUNT,
    .external_token_count = EXTERNAL_TOKEN_COUNT,
    .state_count = STATE_COUNT,
    .large_state_count = LARGE_STATE_COUNT,
    .production_id_count = PRODUCTION_ID_COUNT,
    .field_count = FIELD_COUNT,
    .max_alias_sequence_length = MAX_ALIAS_SEQUENCE_LENGTH,
    .parse_table = &ts_parse_table[0][0],
    .small_parse_table = ts_small_parse_table,
    .small_parse_table_map = ts_small_parse_table_map,
    .parse_actions = ts_parse_actions,
    .symbol_names = ts_symbol_names,
    .symbol_metadata = ts_symbol_metadata,
    .public_symbol_map = ts_symbol_map,
    .alias_map = ts_non_terminal_alias_map,
    .alias_sequences = &ts_alias_sequences[0][0],
    .lex_modes = (const void*)ts_lex_modes,
    .lex_fn = ts_lex,
    .external_scanner = {
      &ts_external_scanner_states[0][0],
      ts_external_scanner_symbol_map,
      tree_sitter_cmake_external_scanner_create,
      tree_sitter_cmake_external_scanner_destroy,
      tree_sitter_cmake_external_scanner_scan,
      tree_sitter_cmake_external_scanner_serialize,
      tree_sitter_cmake_external_scanner_deserialize,
    },
    .primary_state_ids = ts_primary_state_ids,
  };
  return &language;
}
#ifdef __cplusplus
}
#endif
